-- ==============================================================
-- GNUmed database schema change script
--
-- License: GPL v2 or later
-- Author: karsten.hilbert@gmx.net
--
-- ==============================================================
\set ON_ERROR_STOP 1
--set default_transaction_read_only to off;

-- --------------------------------------------------------------
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'''Augenringe''',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'''Wachstumsschmerz'' beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'''spotting''',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'11-Hydroxylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'25-Hydroxyvitamin-D1-a-Hydroxylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'3-beta-Hydroxysteroid-Dehydrogenase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'4-Hydroxybutyrazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'48,XXXX-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'49,XXXXX-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'5-Alpha-Reduktase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'5-Alpha-Reduktase-Mangel mit Pseudohermaphroditismus masculinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'5-X-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'A-Beta-Lipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'A-V [Arteriovenöse]-Fistel der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AB0-Isoimmunisierung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AB0-Isoimmunisierung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AB0-hämolytische Krankheit beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AB0-hämolytische Krankheit beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ACTH [Adrenocorticotropes Hormon]-Hypersekretion, nicht in Verbindung mit Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ACTH [Adrenocorticotropes Hormon]-Hyposekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ACTH [Adrenocorticotropes Hormon]-Überproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ACTH [Adrenocorticotropes Hormon]-Überproduktion der Adenohypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ACTH [Adrenocorticotropes Hormon]-Überproduktion, nicht in Verbindung mit Cushing-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ADA [Adenosindesaminase]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ADS [Akutes Durchfallsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ADS [Akutes Durchfallsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AGS [Adrenogenitales Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS - s.a. HIV-Krankheit oder s.a. Erworbenes Immundefektsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS [Erworbenes Immundefektsyndrom]-Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS related complex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS, Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS, Latenzphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AIDS-Demenz-Komplex [kodiere zusätzlich F02.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ALL [Akute lymphatische Leukämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ALL [Akute lymphatische Leukämie] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ALS [Amyotrophische Lateralsklerose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AMI [Akuter Myokardinfarkt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AML [Akute myeloische Leukämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AML [Akute myeloische Leukämie] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AP [Angina Pectoris] - s.a. Angina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ARC [AIDS related complex]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ARDS [Atemnotsyndrom beim Erwachsenen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ASD [Atrioseptaldefekt] - s.a. Atrioseptaldefekt oder s.a. Vorhofseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AV [Atrioventrikular]-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AV [Atrioventrikular]-Dissoziation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AV [Atrioventrikular]-Kanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AV [Atrioventrikular]-junktionale Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AV [Atrioventrikular]-junktionale paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVK [Arterielle Verschlußkrankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVK [Arterielle Verschlußkrankheit] des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVK [Arterielle Verschlußkrankheit] vom Becken- und Oberschenkeltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVK [Arterielle Verschlußkrankheit] vom Beckentyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVK [Arterielle Verschlußkrankheit] vom Oberschenkeltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'AVSD [Atrioventrikulärer Septumdefekt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aarskog-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abakterielle Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abbaustörung von verzweigtkettigen Aminosäuren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abblättern der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abblättern der Zähne durch systemische Ursachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abbrechen von Fingernägeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abbruchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abbruchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Hiatushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Spasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominale Verwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaler Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaler Paratyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominales Desmoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominales Migräne-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominales Ösophaguskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalhernie mit Einklemmung ohne Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalrigidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominalschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominaltyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominelle Herien, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdomineller Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominothorakale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abdominouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abduzensparese [VI. Hirnnerv]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberration des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberration einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberration einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberrierende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberrierende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberrierendes Nierengefäß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aberrierendes Nierenpolgefäß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abflachung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abflachung der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abflußbehinderung des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abflußstörung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abflußstörung des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgangstenose der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgeheilter Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgekapselte Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgeschlossene Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgeschlossene Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgeschlossene Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abgesunkene glomeruläre Filtration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhebung des Netzhautpigmentepithels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhebung des retinalen Pigmentepithels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängige Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängige Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängige passive Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit vom Amphetamintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit vom Krankenstuhl, die Gesundheitspflege erfordert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit vom Morphinsulfattyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit vom Morphinsulfittyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Amobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Amobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Amytal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Amytal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Analgetika a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Barbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Barbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Barbituraten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Barbituraten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Benzedrin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Benzodiazepin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Benzodiazepin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Betain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Betain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Bhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Bromid a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Bromid a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Cannabis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Cannabis indica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Cannabis sativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Cannabisharz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Chloralhydrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Chloralhydrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Chlordiazepoxid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Chlordiazepoxid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Cocablättern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Codein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Coffein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von D-Lysergsäurediäthylamid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dagga',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Demerol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dexamphetamin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dexedrin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dextro-nor-pseudoephedrin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dextromethorphan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dextromoramid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dextrorphan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Diazepam',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Diazepam',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Dilaudid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Drogen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Drogen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Drogen bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Flugzeugkleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Ganja',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Glutethimid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Glutethimid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Halluzinogenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Hanf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Hanfprodukten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Haschisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Hemp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Heroin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Hypnotika a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Hypnotika a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Khat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Kiff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von LSD [Lysergsäurediäthylamid]-Derivaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Laudanum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Luminal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Luminal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Lysergsäure',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Maconha',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Marihuana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Meprobamat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Meprobamat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Meskalin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Metamphetamin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Methadon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Methaqualon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Methaqualon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Methylalkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Methylphenidat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Narkotika a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Narkotika a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Nembutal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Nembutal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neraval',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neraval',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neravan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neravan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neurobarb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Neurobarb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Nichtbarbiturat-Sedativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Nichtbarbiturat-Sedativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Nikotin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Opiaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Opium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Paraldehyd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Paraldehyd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Paregoric USP',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Pentobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Pentobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Pentothal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Pentothal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Peyotl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Pflege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Phenmetrazin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Phenobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Phenobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Psilocin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Psilocybin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Psilocylin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Psilocyn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Rauschgift',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Rauschgift',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Secobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Secobarbital',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Seconal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Seconal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Sedativa a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Sedativa a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Stickoxiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Stickoxiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Tinctura Opii benzoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Wermut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Wermut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von der Nierendialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Arzneimittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Arzneimittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Cocablatt-Derivat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Kokainderivat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Medikament bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Opiumderivat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Psychostimulans a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Schlafmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Schlafmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Stimulanzmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Tranquilizer a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem Tranquilizer a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem anästhetischen Mittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einem medizinischen Gerät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einer Cannabisverbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von einer morphinähnlichen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von indischem Hanf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeit von Äthylalkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeitssyndrom bei Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeitssyndrom bei Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abhängigkeitssyndrom bei Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abiotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abkapselungsreaktion beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abkapselungsreaktion beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung bei Verdacht auf Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung bei Verdacht auf bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung bei angeblichem Verdacht auf Selbstbeschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung bei angeblichem Verdacht auf Selbsttötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung bei angeblichem Verdacht auf Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung der toxischen Wirkungen einer aufgenommenen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung einer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung einer angeblichen Vergewaltigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung einer unerwünschten Nebenwirkung eines Arzneimittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung einer unfallbedingten Verletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung eines Verdachtsfalles',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung eines angeblichen Parasuizids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung eines angeblichen Selbstmordversuchs a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung eines angeblichen sexuellen Mißbrauchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung nach Unfall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung ohne Bedarf weiterer ärztlicher Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung von Bandenverhalten ohne manifeste psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abklärung von dissozialem Verhalten ohne manifeste psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae bei CMV [Zytomegalievirus]-Retinitis, HIV-positiv [kodiere zusätzlich H32.0* und B25.8]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae bei Netzhautnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae bei Pseudoaphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae exsudativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae exsudativa bei CMV [Zytomegalievirus]-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae exsudativa bei Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae exsudativa bei kongenitaler Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Foramen retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Hufeisenforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Netzhautdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Orariß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Riesenriß (nicht Orariß)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit Rundloch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae mit multiplen Foramina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae non sanata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablatio retinae ohne Netzhautdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ableitung der Hirnventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ableitung der Zerebrospinalflüssigkeit in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ableitung des Liquor cerebrospinalis in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ableitungsbronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablepharie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ablösung der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abmagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abmagerung durch Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Glukosetoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnahme der Tatkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Anästhesiereaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Anästhesiewirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Biosynthese der testikulären Androgene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Blutbestandteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Blutchemie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Blutung aus dem weiblichen Genitaltrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Brusttöne a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Brusttöne a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Brusttöne a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Brusttöne a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Einstellung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Erythrozyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Gewohnheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Hörempfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Kopfbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Lage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Leukozyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Lungenbelüftung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Lungenfunktion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Lungenfunktionsbefunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Nierenfunktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Pigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Plazenta a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Reaktion auf Nervenstimulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Reflexe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Samenflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Serumenzyme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Spermatozoen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Thoraxauskultation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Thoraxauskultation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Thoraxauskultation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Thoraxauskultation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Trauerreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Tuberkulin-Haut-Test-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Urinbestandteile a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Uterushämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Uteruskontraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Uteruskontraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Uteruswehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Uteruswehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Vaginahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Wehentätigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Wehentätigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Zahnform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Zahngröße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Zahnhartsubstanzbildung der Pulpa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Zahnlückenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme Zyklusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme akustische Empfindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme endokrine Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme fetale Herzfrequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme genitale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme immunologische Serumwerte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme intrakardiale elektrophysiologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme kalorische Nystagmus-Prüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme klinische Befunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme unklare Pathologie/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme unwillkürliche Bewegungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme unwillkürliche Bewegungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme vaginale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme visuell evozierte Potentiale [VEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnorme weiße Blutkörperchen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Befund in der Brustwarzenabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Blutbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Blutgaswert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer CT [Computertomographie]-Befund der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer CT [Computertomographie]-Befund des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Chromosomenbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Chromosomenbefund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Elektrolythaushalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Gewichtsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Herzrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Herzschatten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Hormonwert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Karyotyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Kieferschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Liquorbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mammasonographiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mammathermographiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mammographiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mantoux-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mendel-Mantoux-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Mineralblutwert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Nierenfunktionstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Perkussionsschall des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Perkussionsschall des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Perkussionsschall des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Perkussionsschall des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Pupillenreflex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Röntgenbefund des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Samen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Sonographiebefund des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Sonographiebefund des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Speichelbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Stempeltest auf Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Stuhl a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Tine-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Tuberkulintest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Ultraschallbefund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Urinbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Vaginalbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Verlauf der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Vulvabefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer Zahndurchbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer biochemischer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer fetaler Herzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer genetischer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer histologischer Befund a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer histologischer Befund im Liquor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer hämatologischer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer immunologischer Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer immunologischer Befund im Liquor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mammasonographischer Verdichtungsbezirk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mammathermographischer Verdichtungsbezirk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mammographischer Verdichtungsbezirk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mikrobiologischer Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mikrobiologischer Befund im Liquor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer mikrobiologischer Urinbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer radiologischer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer toxikologischer Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer zytologischer Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer zytologischer Befund bei Graviditäts-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormer zytologischer Befund im Liquor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Albumin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Alpha-Fetoprotein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Differentialblutbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Echoenzephalogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Echokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Elektroenzephalogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Elektromyogramm [EMG]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Elektrookulogramm [EOG]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Elektroretinogramm [ERG]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Erröten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Globulin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Granulationsgewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Konzeptionsprodukt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Phonokardiogramm [PKG]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Prostatasekret',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Sputum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Säure-Basen-Gleichgewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Thyreoglobulin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Transkortin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Transportprotein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormes Vektorkardiogramm [VKG]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität beim Harnlassen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität beim Wasserlassen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Beckenweichteile bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Pupillenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Pupillenreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Zahnform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der Zahngröße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der korrespondierenden Netzhautpunkte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität der retinalen Korrespondenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Beckenknochens bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Haars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Liquor cerebrospinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Pupillenreflexes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Sinus venosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Thyreoglobulins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des Transcortins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abnormität des kortisolbindenden Globulins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort aus gesetzlicher Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort aus ärztlicher Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort mit Infektion der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort mit Spätblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort mit septischem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abort nach drohendem Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortive Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortive Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortive Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortivei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus - s.a. Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus ampullaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus completus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus habitualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus imminens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus incipiens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus incompletus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abortus-Bang-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abrasio corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abrasio dentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abrikossoff-Geschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abrikossoff-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß des Kopfes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß des Symphysenknorpels bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abriß des Symphysenknorpels bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio graviditatis aus medizinischer Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio graviditatis aus sozialer Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio placentae bei Gerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abruptio placentae bei Gerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abscessus frigidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abscessus pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abscessus sudoriparus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abscheidungsthrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abschuppung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abschürfung/Kratzer/Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absencen im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absencen-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absencen-Epilepsie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absiedelung eines Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absinken der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absinthabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absinthismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absinthismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absolute Achlorhydrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absolute Agraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absolutes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absonderungen des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absorption einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absorptionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Absteigende Spinalparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstinenzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstinenzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung durch Transplantatversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung einer Mammaaugmentationsplastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung einer Mammaverschiebeplastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Hauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Herz-Lungen-Transplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Herztransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Knochenmarktransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Lebertransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung eines Lungentransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstoßung wiederangenähter Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abstrusio auriculae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszedierende Entzündung des Sinus pilonidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszedierende Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszedierender Sinus pilonidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszesse in allen Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß bei Haarbalgfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß bei Haarbalgzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß bei Pilonidalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Bartholin-Drüse durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Bartholin-Drüse durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Cowper-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Ellenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Fauces',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Fossa canina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Fossa ischioanalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Fossa ischiorectalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Fossa supraclavicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Gingiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Glandulae cervicales uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Glandulae urethrales durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Glandulae urethrales durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Kolonwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Littré-Drüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Mesosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Ovula Nabothi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Rachenenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Schläfengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Skene-Gänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Temporalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der vulvovaginalen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß der äußeren Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Douglas-Raums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Labium majus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Labium minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Mons pubis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Parametriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Processus mastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Septum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Zahnhalteapparates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß des breiten Mutterbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß einer Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abszeß einer Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abt-Letterer-Siwe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abtreibung - s.a. Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abtreibungsversuch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abtrennung der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aburabaku',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abusus einer psychoaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abusus einer psychoaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abusus von Nasenspray',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abusus von Nasentropfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abwehrschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abwehrspannung des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Abzehrung - s.a. Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acanthocephaliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acanthocheilonemiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acanthocheilonemiasis perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acanthocheilonemiasis streptocerca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acanthoma - s.a. Neubildung, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acardiacus amorphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acaro-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Accretio cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Accretio pericardii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnenlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillessehnenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillobursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achillodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achlorhydrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achlorhydrische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achlorhydrische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achloropsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acholurische familiäre Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acholurischer familiärer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achondrodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achondroplastischer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromatischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromatisches Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromatopsie mit Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achrome Hautveränderungen bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achseldrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselhöhlenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achselvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsendrehung der Sigmaflexur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsendrehung des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsendrehung des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsendrehung des Zökum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsenhypermetropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsenhyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achsenmyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achylia gastrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achylia gastrica refractoria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achylia pancreatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Achylische Chloranämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne - s.a. Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne androgenetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne artificialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne atrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne bromica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne cachecticorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne chlorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne comedonica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne decalvans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne excoriée',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne indurata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne jodica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne necroticans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne necroticans miliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne papulopustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne picea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne professionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne pustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne rosacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne vulgaris conglobata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acne vulgaris infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acquired immunodeficiency syndrome [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Acrodermatitis - s.a. Akrodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Actinomadura-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinom der Mandibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinom der Tibia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinom des Unterkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adamantinom eines Röhrenknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adams-Stokes-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adams-Stokes-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adams-Stokes-Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adams-Stokes-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adaptationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adaptationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adaptionsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Keloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Schilder-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Addison-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adduktorenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adduktorenzerrung des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis cervicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Bulbourethraldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Cowper-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Skene-Gänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Speicheldrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis der Urethraldrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis des Speicheldrüsengangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenitis lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoakanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoameloblastom des Unterkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenocarcinoma in situ der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenocarcinoma in situ in Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenofibrom des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenofibromatöse Prostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenofibrose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenogliom [Ependymom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenohepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoide Wucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoidinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoidnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinoid - s. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinoidtumor - s. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Gabelung des Ductus hepaticus [Klatskin-Tumor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Hürthle-Zellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Inselzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Nierenzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Schweißdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom der Talgdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom des Collum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom des Colon transversum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom des Querkolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom in Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokarzinom vom Gallengangstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenokystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenolipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenolymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Hautanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom der Zona glomerulosa der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenom des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma ceruminosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma insucellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma sebaceum Pringle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma sudoriparum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma testiculare bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma testiculare beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoma tubulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatoidtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatose des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatosis erosiva der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatosis erosiva der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöse Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöse Polyposis des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöse Uterushyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöse zystische Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöser Genitalpolyp bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöser Genitaltumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöser Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomatöser Polyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomyomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomyomatose der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomyose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomyosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenomyosis uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenoneoplasma der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenosindesaminasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenotonsillarhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenovirus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adenovirus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adergeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhaut- und Netzhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautabhebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautamotio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautdehnungsherd bei Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautdurchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauthämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauthämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautkolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhautsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauttuberkulose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aderverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion - s.a. Verwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Bauchinnenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Nasenmuschel am Septum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Nasenmuschel am Septum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Nasenmuschel am Septum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Ischiasnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des Spinalkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion des weiblichen Pelviperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion einer Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsion zwischen Amnion und Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsionsbeschwerden des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsionsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsionsschmerzen des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsionssyndrom des unteren Rückenmarks [Tethered-cord-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Kapselentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Kapsulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Mediastinoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Mittelohrkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Neurosyphilis der Meningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Neurosyphilis der Meningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Perikapsulitis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Schulterperitendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsive Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsiver Gewebestrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsiver Gewebestrang des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsiver peritonealer Gewebestrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adhäsivprozeß nach Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adiaspiromykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas cerebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas dolorosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas gigantea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas gigantea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas mit alveolärer Hypoventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas mit alveolärer Hypoventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas osteoporotica endocrinica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas permagna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositas permagna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adipositasbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adiposogenitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adiuretinhyposekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adminstrative Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A62'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexentorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexentuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexitis virilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnextumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adnexverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adoleszenten-Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adoleszenten-Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adoleszenten-Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adoleszenten-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Androgenhypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Androgenvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Androgenüberproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Hormonstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Makrogenitosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenale hormonelle Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Androgenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Hyperandrogenismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Pseudohermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Pseudohermaphroditismus femininus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenaler Virilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenales Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenales hämorrhagisches Syndrom durch Meningokokken-Sepsis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenalitis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenalitis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenalitis durch Zytomegalieviren [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenogenitale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenogenitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenokortikale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenoleukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adrenomedulläre Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adriblastinschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adult respiratory distress syndrome [ARDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adulte Form der GM2-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adulte Form der Still-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adulte Gaucher-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adulte Osteochondrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adulte T-Zellen-Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adultes Rhabdomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adultes T-Zell-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adultes leukämisches T-Zell-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adultes zystisches Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adynamia episodica hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adynamie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Adynamie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aeroembolismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aerootitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aerootitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aerosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aerothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afebrile Erkältung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Augenanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Augenbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Iris und des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Nervi olfactorii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Pupillenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Schultergegend a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Schulterregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Sehbahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Sehstrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der Vorderhornganglienzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Chiasma opticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Corpus geniculatum laterale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Hirnnerven X',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Hörnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Iliosakralgelenks a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus accessorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus cochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus hypoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus opticus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Nervus vagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Temporomandibulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Tractus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des kortikalen Sehzentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektion des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Psychose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Affektlabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Augenwurmkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Schlafkrankheit durch Trypanosoma gambiense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Schlafkrankheit durch Trypanosoma rhodesiense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanische Trypanosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afrikanisches Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'After-pill-Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afterfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aftergeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afterkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afterrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Afterschrunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aftervorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aganglionose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aganglionose des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aganglionosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aganglionäres Megacolon congenitum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agastrisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Brustdrüse bei vorhandener Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Brustdrüse bei vorhandener Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Dilatator-Fasern der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Fußwurzelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Harnorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Mittelfußknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Mittelhandknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Nabelschnurarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Tränenpünktchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Beckengürtels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Corti-Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Ductus ejaculatorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Kreislaufsystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Ligamentum rotundum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Orbitadaches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Punctum lacrimale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Vermis cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie des häutigen Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie endokriner Drüsen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie endokriner Drüsen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie peripherer Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie peripherer Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agenesie von Teilen des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ageusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggregatwechsel eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressive Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressive Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressive Störung ohne Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressive Störung ohne Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressiver Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressiver Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressiver Typ der Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressiver Typ der Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Osteoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Verhalten im Kindes- und Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressives Verhalten im Kindes- und Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agitatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agitierte Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agitierte Depression als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agitiertheit NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aglossie-Adaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agnosie des Körperschemas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agnosie sonstiger Sinne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agoraphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agoraphobie mit Panik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agoraphobie ohne Panikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agrammatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agranulocytosis infantilis hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agranulozytose mit Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agranulozytose mit nekrotisierender Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agranulozytose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agrypnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Agyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornrinden-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornrindenschälerlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornrindenstreiferkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornsirup-Harn-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornsirup-Harn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ahornsirup-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aicardi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aichmophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ainhum [Dactylolysis essentialis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ainhum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akalkulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akalkulie bei Entwicklungsrückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akamushi-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthamöbiasis der Konjunktiva [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthamöbiasis mit Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthamöbiasis mit Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthamöbiasis mit Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akantholyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akantholytische Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akantholytische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthom - s.a. Neubildung, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthose der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthose der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthozephaliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akanthozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akari-Rickettsiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akarinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akarophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akarus-Räude',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akatalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akatalasämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akathisie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akinetische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akinetischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akinetischer Mutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsdefizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodative Asthenopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodativer Strabismus convergens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akkommodierendes Schielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akneeffloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akneiforme Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aknekeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aknitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akontraktile Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akontraktilität des Blasenmuskels ohne neurologisches Substrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akranie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akranius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akroasphyxia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akroasphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis atrophicans Herxheimer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis chronica atrophicans Herxheimer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis continua pustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis continua suppurativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis enteropathica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis papulosa infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodermatitis perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrodynie infolge frühkindlicher Quecksilbervergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrokeratosis verruciformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromelalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromikrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromioklavikulare Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromioklavikulargelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromioklavikularluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akromionfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akroparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalopolysyndaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalopolysyndaktylie-Syndrom, Formenkreis [Carpenter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalosyndaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalosyndaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalosyndaktylie-Syndrom, Formenkreis [Apert-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akrozyanose beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Cheilitis durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Dermatitis durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Elastose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinische Präkanzerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinisches Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinobazillose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykose mit Pneumonie [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykotische Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykotische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykotischer Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykotischer Nodulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomykotisches Myzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinomyzetom des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktinoneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Algolagnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Leberhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive rheumatische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive trachomatöse Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktive ägyptische Körnerkrankheit [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktiver Pannus trachomatosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktivierte Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aktivierte Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akureyri-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akureyri-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustikusneurilemmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustikusneurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustikusneurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustikusneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustische Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustische Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustische Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustisches Recruitment',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustisches Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akustisches Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akut Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akut nichtrheumatische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akut rezidivierende Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Abstoßung eines Hornhauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Abszesse in allen Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Adenitis mesenterialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Adenoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Alkoholintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Amöben-Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Amöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Angina durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Angina durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Angina durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Angina simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Appendizitis mit Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Arthritis bei rheumatischem Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ateminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Beckenbindegewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastungsreaktion mit Bewußtseinsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastungsreaktion mit emotionaler Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastungsreaktion mit psychomotorischer Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastungsreaktion mit vorherrschender psychomotorischer Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Belastungsreaktion, Mischform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blastomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blinddarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blinddarmentzündung mit Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blockierung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Blockierung der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchiolitis mit Bronchospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchitis durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Bronchitis mit Bronchospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Chagas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Chagas-Krankheit mit Herzbeteiligung [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Chagas-Krankheit mit Myokarditis [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Chagas-Krankheit mit kardiovaskulärer Beteiligung [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Chorioenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Choriomeningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dakryoadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dakryoperizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dakryophlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dakryozystitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dermatitis durch Sonne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dermatomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Divertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Dorsolumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eierstockentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eierstocktuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eileiter-Eierstock-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eileiterentzündung mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eileitertuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eiterung des Felsenbein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Eiterung des Pyramidenspalts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endocarditis lenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endocarditis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endomyometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Endozervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterogastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterogastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterogastritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterogastritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Entzündung aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Entzündung der Kiefernebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Entzündung der Paukenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Entzündung der Tränenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Entzündung des Warzenfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enzephalomyeloradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ependymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Epiglottisentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erkrankung der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythroleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythroleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythrose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Erythrämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Felsenbeinentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Felsenbeinostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Funikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gallenblaseneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gallenblasensepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteritis durch Norwalk-Agens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gastroenteropathie durch Norwalk-Agens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gehirnerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gelenkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Glomerulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der oberen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der oberen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der oberen Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der oberen Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der unteren Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe der unteren Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe des Vas deferens [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Gonorrhoe des Vas deferens [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Halsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Harnwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Haßreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hebephrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hepatisation der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hepatitis A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hepatitis B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hepatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herdnephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Heroinintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzleistungsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Herzmuskelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Histoplasmose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der oberen Atemwege, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der oberen Luftwege multiplen Sitzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion der unteren Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Infektion mit Delta-Virus eines Hepatitis-B-Virus-Trägers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intestinumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch Cannabinoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch Halluzinogene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Intoxikation durch ein flüchtiges Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ischialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ischialgie mit Wurzelirritation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ischämie des Mesenterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kanalikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Katatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kehldeckelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kehlkopfentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Keilbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Keilbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Keilbeinhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kokainintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kokzidioidomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Koronarinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Koronarinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Koryza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kreislaufinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Kreuzbeinschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Krisenreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Laryngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Leberdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Leukämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Luftröhrenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lumbago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lumbalgie bei Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lumbalgie mit Facettenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lumboischialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lungenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lungenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphadenitis der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphadenitis der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphadenitis des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Lymphdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magen-Darm-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magen-Darm-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magen-Darm-Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magen-Darm-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Magenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mandelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mediastinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Megakaryoblastenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Melioidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Meningoenzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Meningoenzephalomyelitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Miliartuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Milzkapselentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Milzsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Mittelohrentzündung/Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Monozytenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myelofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myoendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myokarditis bei Grippe [Influenza], Influenzavirus nachgewiesen [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Myoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nasennebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nasennebenhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nasennebenhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nasenrachenraumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nasopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nebenhöhlenentzündung mit akuter Stirnhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nebennierenrindeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nierenbeckeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Nierenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Niereninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Non-A-Non-B-Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Oberbauchkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Oberbauchkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Oberbauchsymptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Oberbauchsymptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Opioidintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Orbitaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Osteoradionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis externa durch Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis externa durch eine chemische Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreaseiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreasentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreasinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreasnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pankreatitis anulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Panmyelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Panotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Parametritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Paraphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pelviperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Penislymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Peridakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Periendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perikoronitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perilabyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perimetritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Periodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perioophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Perisalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Peritonitis des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pharyngolaryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pharynxentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Polioenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Polioenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Poliomyelitis [Spinale Kinderlähmung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Polyradikuloneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Proktitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Psychose durch Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Psychose durch endokrine Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pulpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Pyosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rachenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinopharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinopharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rhinosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Rippenfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Salpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schizophrenie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Seitenstrangangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sepsis durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sialadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Siebbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Siebbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Siebbeinhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinularyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinupharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinusitis maxillaris mit akuter Sinusitis ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinusitis maxillaris mit akuter Sinusitis frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Sinutracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Skrotuminfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Stirnhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Stirnhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Stirnhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Strahlendermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Streßreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Säuglingsretikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Säuglingsretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tracheolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tracheopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Trommelfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Trunkenheit bei Alkoholabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tuberkulose der Tuba uterina [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tuboovarialentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tubulusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Tympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Typhlitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Unterleibschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Unterleibschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Urethritis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Urethritis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Urozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Uterusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Uveitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vaginainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vaginalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Verwirrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vorsteherdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vulvainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Wurzelspitzenhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zahnfleischentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zervikalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zervikobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zervikozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Zystopyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute alkoholische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute alkoholische Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute allergische Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute allergische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute allergische blutige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute allergische muköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute allergische seröse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute apikale Parodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute apikale Periodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute arzneimittelinduzierte interstitielle Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute aseptische Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute aszendierende Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute atopische Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute atrophische Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute atrophische infantile Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute aufsteigende Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Perikarditis mit seropurulentem Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Perikarditis mit serösem Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bakterielle Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute bilaterale Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute blennorrhagische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute blennorrhagische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute blutige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute chemische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute demyelinisierende Enzephalomyelitis [ADEM]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute differenzierte progressive Histiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute disseminierte Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute einfache Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute eitrige Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ekzematöse Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute emphysematöse Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute epidemische Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute epitheliale Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute erythrämische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute erythrämische Myelose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute essentielle Thrombopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute exsudative Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute exsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fibrinöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fieberhafte Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fieberhafte Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fieberhafte Polyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fieberhafte Racheninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fieberhafte Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fiebrige Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute fokale Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute follikuläre Konjunktivitis durch Adenoviren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gangränöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gangränöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gastrointestinale Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gelbe Leberatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hysterische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämatogene Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämorrhagische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämorrhagische Leukoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämorrhagische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämorrhagische Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute hämorrhagische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute idiopathische Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Lymphozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Polyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute infektiöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute intermittierende Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute intermittierende hepatische Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute interstitielle Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute interstitielle Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute interstitielle Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute interstitielle diffuse Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ischämische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ischämische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ischämische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ischämische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ischämische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute isolierte Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute kardiale Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katarrhalische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katarrhalische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katarrhalische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katarrhalische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katarrhalische Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute katatonische Katalepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute komplette Nasennebenhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute koronare Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute koronare Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute kortikale Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphatische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphatische Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphoblastische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute lymphozytäre Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute maligne Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute medulläre Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute megakaryozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute membranöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute membranöse Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute mesenteriale Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute monoblastische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute mukoide Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute muköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute multifokale plakoide Pigmentepitheliopathie der Aderhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute multiple Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute myeloblastische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute myeloische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute myelomonozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nekrotisierend-ulzeröse Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nekrotisierend-ulzeröse Gingivostomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nekrotisierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nervöse Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nichteitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nichteitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nichtinfektiöse Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nichttraumatische subdurale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute nichttraumatische subdurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute obstruktive Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute obstruktive Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute organische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute organische Psychose bei Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute papilläre Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute paralytische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute paralytische atrophische Spinalkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute paranoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute paranoide Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute perforierende Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute phlegmonöse Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute poliomyelitische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute polymorphe psychotische Störung mit Symptomen der Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute posthämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute postinfektiöse Polyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute postoperative Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute postpartale Hypophysenvorderlappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute posttraumatische organische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute primäre Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute progrediente Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute proliferierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute promyelozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute psychische Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute pulmonale Insuffizienz nach (nicht am Thorax vorgenommener) Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute purulente Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute reaktive Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute respiratorische Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute respiratorische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute respiratorische Insuffizienz nach (nicht am Thorax vorgenommener) Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute respiratorische Insuffizienz nach Thoraxoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rezidivierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Arthritis mit mehrfacher Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Herzklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Pankarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute rheumatische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute schizophrene Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute sekretorische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute septische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute septische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute seromuköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute seröse Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute seröse lymphozytäre Chorioenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute seröse lymphozytäre Choriomeningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute sezernierende Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute spastische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute spinale Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute spinale Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute subendokardiale Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute subglottische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute toxische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute toxische Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute transsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute transverse Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute traumatische Ablatio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute traumatische Enukleation eines Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute traumatische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute traumatische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute tuberkulöse Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute tubuläre Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ulzeröse Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ulzeröse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ulzeröse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute undifferenzierte Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute unreifzellige Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute vesikuläre Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute virale Bronchitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute virale Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute vorübergehende psychotische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute zerebrale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute zerebrale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute zerebrovaskuläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ödematöse Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akute ödematöse Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Abszeß der Achsellymphdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Abszeß der Leistenlymphdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Alkoholrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Angstzustand und Spannungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Atemwegskatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Augenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Bauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Brechdurchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Brechdurchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Brechdurchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Brechdurchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Coffeinrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Darmkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Darmkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Durchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Durchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Eierstockabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Gelenkrheumatismus mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter HWI [Hinterwandinfarkt] des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Hinterwandinfarkt des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Icterus catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Intestinuminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Katarrh der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Keilbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Kieferhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Kniebinnenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Kniegelenkknorpelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Kokainrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Koronarschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Koronarschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Lymphdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Lymphknotenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Magen-Darm-Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Magen-Darm-Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Mittelohrabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Nasenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Nasennebenhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Nasennebenhöhlenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Nasenrachenraumkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Ovarialabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Parametriumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Perikarderguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Racheninfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rachenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch bei Alkoholabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Cannabinoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Halluzinogene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Opioide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Sedativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Sedativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch Stimulanzien a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch ein flüchtiges Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch multiple psychotrope Substanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rausch durch multiple psychotrope Substanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Reaktionstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rezidivinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rotz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Rückenmarkinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Schiefhals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Schub einer chronischen Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Siebbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Stirnhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Tubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Tuboovarialabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Tubotympanalkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Uterusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter Zahnfleischabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter arterieller Verschluß des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter embolischer Rückenmarkinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter exogener Reaktionstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter kombinierter Luftwegekatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichtalkoholbedingter Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichtembolischer Rückenmarkinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichtpuerperaler Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichtpuerperaler Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichttransmuraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter nichttraumatischer subendokardialer Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter organischer Reaktionstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter psychotischer Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler Myokardinfarkt der Seitenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler anteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler anteroapikaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler anterolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler anteroseptaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler apikolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler basolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler diaphragmaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler hochlateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler inferiorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler inferolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler inferoposteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler lateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler posteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler posterobasaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler posterolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler posteroseptaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akuter transmuraler septaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Delir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Delir bei hirnorganischem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Delir bei psychoorganischem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Delir vom exogenen Reaktionstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Empyem des Warzenfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes HWS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes HWS-Syndrom mit Blockierung der BWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Keilbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Kieferhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Koronarsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Leberversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenödem bei Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenödem bei Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenödem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Lungenödem durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Magengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Magengeschwür mit Hämorrhagie und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Magengeschwür mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Nasennebenhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Nierenversagen mit Papillennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Pyovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Quincke-Ödem der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Siebbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Sinubronchialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Stirnhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus duodeni mit Hämorrhagie und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum jejuni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum mit Blutung und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum mit Hämorrhagie und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus pepticum mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Vulvaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes essentielles Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes gastrojejunales Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes gastrojejunales Ulkus mit Blutung und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes gastrojejunales Ulkus mit Hämorrhagie und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes komplettes Nasennebenhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes nephritisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes peripheres Kreislaufversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes postpartales Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes primäres Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes primäres Winkelblockglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes psychoorganisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes rezidivierendes Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes rheumatisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes schweres Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes sinubronchiales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes umschriebenes Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akutes zirkumskriptes Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung der Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzentuierung von Persönlichkeitszügen vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Aurikularanhänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Autosomen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Chromosomen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Gehörknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Großzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Harnorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Koronararterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Markerchromosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Nierenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Parotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Präaurikularanhänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Sehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Stimmbänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Teile des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Tränenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Vorhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische atrioventrikuläre Erregungsleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische atrioventrikuläre Überleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische endokrine Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorische endokrine Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Aortenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Aortenklappenzipfel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Augenmuskel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Daumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Dickdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Dünndarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Fußwurzelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Gallengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Gehörgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Gesichtsknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Handwurzelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Hautanhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Herzklappenzipfel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Hoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Knochen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Lebergang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Muskel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Ohrlobus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Parotisgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Speicheldrüsenausführungsgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Stirnfortsatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Tragus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Wirbel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorischer äußerer Muttermund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Augenlid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Blutgefäß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Herz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Hymen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Kahnbein des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Nierenbecken mit doppeltem Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Nierenpolgefäß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Präputium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Sesambein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Sternum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches Zökum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches axilläres Brustdrüsengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessorisches axilläres Brustdrüsengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessoriusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzessoriusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzidentelle Blutung bei Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzidentelle Hämorrhagie vor der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzidentelles Herzgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Akzidentelles Systolikum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alactoflavinose [Vitamin-B2-Mangel-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alagille-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alaktasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alastrim',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albers-Schönberg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albers-Schönberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albinismussyndrom mit Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albinismussyndrom mit Nystagmus und Kopfzwangshaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albinismussyndrom mit Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albino',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albright-McCune-Sternberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albright-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albrigth-Osteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albträume',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albuminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albuminurie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albuminverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Albuminveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alder-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alder-Reilly-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleppobeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukia haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukämische Leukämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukämische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aleukämische Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alexander-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algogenes Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algolagnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algoneurodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Algurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alibert-Bazin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alibidinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alienie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alieniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Entwicklungshemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Folsäuremangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Kardiomyopathie [kodiere zusätzlich I43.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Kollapsneigung nach Magenresektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentärer Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentärer Mangelzustand durch unausgewogene Nahrungszusammensetzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentärer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentärer Molybdänmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alimentäres Frühsyndrom nach Magenresektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkalische Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkaliämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkaptonurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkaptonurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholabstinenzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte Korsakow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte Pellagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte zerebellare Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte zerebellare Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingte zerebrale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbedingtes Delirium tremens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholbestimmung im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholdelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholdemenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholembryopathie mit Dysmorphien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholentzugsdelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholentzugserscheinung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholentzugskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholhalluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholintoxikation bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholintoxikation mit Tablettenintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Degeneration des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Laënnec-Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Psychose mit Polyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholischer Eifersuchtswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholischer Leberschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholischer Wahnsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholisches Korsakow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholisches Prädelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholismus mit Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholkater',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholkonsum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholmißbrauch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholpolyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholtoxische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholtoxische Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alkoholvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alle Formen der Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergentestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Bienengift und Wespengift',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Federn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Inhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Kosmetika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Kuhmilch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Pflaster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch Schimmelpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie durch ein organisches Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie gegen Analgetika in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie gegen Antibiotika in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie gegen Impfstoffe in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie gegen Sulfonamide in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie mit Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie-/Sensitivitätstestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergie/allergische Reaktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergietestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Alveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Alveolitis durch Organismen aus Belüftungsanlagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Alveolitis durch Pilze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Alveolitis durch eingeatmeten organischen Staub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Alveolitis durch thermophile Aktinomyzeten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Augenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Dermatitis durch ein chemisches Produkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Diathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Eosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Epituberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Hautreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Keratokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch Farbstoff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch Hautkontakt mit Nahrungsmitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch Klebstoff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch Mehl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktdermatitis durch ein chemisches Produkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kontaktsensibilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Kopfschmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Liddermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Phlyktäne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Reaktion auf Insektenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis durch Federn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis durch Inhalationsallergen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis durch Kapok',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis durch Pollen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinitis durch tierische Epithelien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinopathie mit Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinopharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Rhinosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische bronchopulmonale Aspergillose [ABPA] [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische granulomatöse Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergische vasomotorische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergischer Fließschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergischer Pannus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergischer Pannus eczematosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergischer Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergischer Schock durch giftigen Stich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Angioödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Bronchialasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Bäckerekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Kontaktekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Lidrandexanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Lidödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches angioneurotisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches hyperreaktives Bronchialsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches infantiles Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allergodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allescheriosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Beckenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Entwicklungsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Ermüdungserscheinungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Ermüdungserscheinungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Infektion bei Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Mattigkeit und Müdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Mattigkeit und Müdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Pathosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Reihenuntersuchung als arbeitsmedizinische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Reihenuntersuchung von Angehörigen der Streitkräfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Reihenuntersuchung von Bewohnern institutioneller Einrichtungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Reihenuntersuchung von Sportmannschaften',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine Vergeßlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine gynäkologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine psychiatrische Untersuchung auf behördliche Anforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeine psychogene Ermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Abbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Abbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Schwächezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner Schwächezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner physischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner physischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner physischer und psychischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner physischer und psychischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner psychischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeiner psychischer Abbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeines Erschöpfungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeines Erschöpfungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeines seniles Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeininfektion - s.a. Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allgemeinsymptome/andere Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allocheirie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allocheirie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Allorhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia androgenetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia areata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia atrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia cicatricans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia climacterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia cranialis totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia mucinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia parvimaculata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia postpartualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia praematura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia seborrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopecia totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopezie des ganzen Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alopezie nach Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpdrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-1-Antitrypsinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-Fetoprotein-Erhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-Schwerketten-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-Schwerketten-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-Zell-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alpha-Zell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alphahypolipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alport-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alptraum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Als akut klassifizierter Myokardinfakrt oder innerhalb von vier Wochen nach dem Ereignis (28 Tage)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Ablatio chorioideae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Herzkammerthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Herzohrthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Herzspitzenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Kniegelenkbandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Lazeration der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Lazeration des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Lazeration des Dammes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Luxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Subluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte TBC [Tuberkulose] mit schwerer Ventilationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Vorhofthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Vulvalazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte Vulvanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte inaktive Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte postpartale Adhäsion der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte rachitische Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte rektovaginale Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte vaginale Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alte vordere Kniegelenkkreuzbandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Fremdkörper nach perforierender Orbitaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Gebärmutterhalsriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Inferolateralinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Lidfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Meniskuskorbhenkelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Muskelriß des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Muttermundriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Scheidenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Vaginalriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter Vulvariß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter erworbener Herzohrseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter erworbener Kammerseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter erworbener Vorhofseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper der Bulbushinterwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper des Glaskörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer amagnetischer Fremdkörper des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper der Bulbushinterwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper des Glaskörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter intraokularer magnetischer Fremdkörper des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alter postpartaler Dammriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternaria-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternative Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternative Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Esotropie, ausgenommen intermittierend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Exotropie, ausgenommen intermittierend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Hyperphorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierende mittlere Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierender Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierender Strabismus convergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierender Strabismus divergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alternierendes Einwärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersabhängige Abnahme kognitiver Funktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersatrophische Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersbedingte Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersbedingte Sehschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersbegleitende Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterschorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersdemenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersdiabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersdiabetes mit Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersemphysem bei Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterserschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersirresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersjuckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterskachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterskatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterslaufnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersosteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterspruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersschwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterssichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersverwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Altersveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alterswarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminiuminduzierte Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminiumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminiumlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminiumosteopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminiumstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aluminosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarfortsatzverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarkammatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarkammhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarkammvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarpneumopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarproteinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarpyorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarwandschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolarzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolitis durch Aspergillus clavatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolitis durch Cryptostroma corticale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolitis mit Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolodentale Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveolokapilläre Blockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Echinokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Echinokokkose der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Mikrolithiasis der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläre Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläres Rhabdomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alveoläres Weichteilsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alymphocytosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alymphocytosis thymica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alymphoplasia thymica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alymphozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Demenz [kodiere zusätzlich F00.9*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Krankheit, früher Beginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Krankheit, später Beginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Alzheimer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amalgam-Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie bei vorhandener Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie bei vorhandener Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie mit angeborenem Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amastie mit angeborenem Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amaurosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amaurosis fugax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amaurotisch familiäre Sachs-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amaurotische Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambivalentes Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopia ex anisometropia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie bei Ametropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie bei Anisometropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie bei Deprivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie bei Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie durch Nachtblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amblyopie durch Nikotin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amboßagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amboßfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ambrosiagewächsallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameisenlaufen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameisenlaufen des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelanotischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelanotisches Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelie einer oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelie einer unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Fibroodontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Fibroodontom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Odontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Odontosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastisches Odontosarkom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastom der Mandibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastom der Tibia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastom des Unterkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastom eines Röhrenknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastoodontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastoodontom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ameloblastosarkom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelogenesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelogenesis imperfecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelogenesis imperfecta nonhereditaria segmentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amelosarkom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amenorrhoe bei Ovulationshemmereinnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amentia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amentielles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'American mountain tick fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amerikanische Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amerikanische Trypanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amerikanische Trypanosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amerikanisches Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amerikanisches Gebirgszeckenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ametropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amimie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminkolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminoazidopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminoazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminosäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminosäuremangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminosäurestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aminosäuretransportstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnesie durch Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestische Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestische Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestischer Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Cannabinoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Halluzinogenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Opioiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Syndrom nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnestisches Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amniographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionabnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionhydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionhöhlenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnioninfektionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnioninfektionssyndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnioninfusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnionzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amnioskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amniotische Plazentazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amniotische Schnürfurchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amniozentese-Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amoralische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amoralische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amotio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amphetaminabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ampulle des unteren Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputation der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputationsneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputationsstumpfinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputationsstumpfnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputationsstumpfneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amputierter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amsterdamer Degenerationstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyelenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyelenzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amygdalolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide Darmdegeneration [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide Neuritis [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide Polyneuropathie vom portugiesischen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloide autonome Neuropathie [kodiere zusätzlich G99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidherz [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidherz-Krankheit [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidleber [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidnephritis [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidnephropathie [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidnephrose [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidose bei Hämodialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidose mit Bindehautablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidose vom portugiesischen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyloidschrumpfniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amylopectinosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amylopektinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyoplasia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyostatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyotonia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyotrophia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyotrophische Lateralsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amyotrophische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöben-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöben-Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöben-Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbenbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbiasis intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöboidzellengliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Amöbom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia oligosideraemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia perniciosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia perniciosa progressiva idiopathica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia pleiochromica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaemia splenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaerobe Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaesthesia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analbuminämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anale Kryptitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analer Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analer Primäraffekt bei Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analer Primäraffekt bei Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analfissur/perianaler Abszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetika-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetikaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetikaintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetikamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetikanephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetikanephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analgetische Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analkanalentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analkondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analkondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analmarisken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analpapillenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analpapillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analphabetentum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analphabetismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analphalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analpruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analrandtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analringstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analschleimhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsolitärgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinkterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinkterinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinkterparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinkterrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinkterstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analsphinktertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Analvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anankasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anankastische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anankastische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anankastische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anankastische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphrodisie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphylaktische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphylaktischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphylaktischer Schock durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphylaktischer Schock durch giftigen Stich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaphylaxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplastisches Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplastisches Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplastisches Oligodendrogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplastisches Schilddrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaplastisches Seminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anarthria syllabaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anarthrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anasarka',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anasarka beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anaspadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anastomosengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anastomosenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anastomositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anazide Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anazidität des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ancylostomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauernde Persönlichkeitsänderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauernder Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauernder Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauernder Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauernder Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andauerndes Schreien beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anden-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung/NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung/NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchung/NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Laboruntersuchungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A38'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Vorsorgemaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A49'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere diagnostische Untersuchungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A43'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere infektiöse Erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere perinatale Erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahme/kleine Chirurgie NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere therapeutische Maßnahmen/kleine Chirurgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A59'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere virale Erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere virale Exantheme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andere Überweisungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A68'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanalass NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NAK',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlass NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderer Beratungsanlaß NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D69'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderes Carcinoma-in-situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andersen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andersen-Syndrom [Glykogenose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anderson-Fabry-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andrews-Bakterid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Andrews-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenbedingter Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgendeprivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenetische Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenetische Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenetischer Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenhyperkrinie der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenhypersekretion der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androgynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androides Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Androides Becken mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anenzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anerythropsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anetodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anetodermia maculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anetodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anetodermie vom Typ Jadassohn-Pellizzari',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurinmangelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma anastomoticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma cirsoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma cylindricum der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Aorta abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Aorta thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Arteria subclavia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Jugularisvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma der Milzgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma des Circulus arteriosus Willisii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma des Circulus arteriosus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma des Conus arteriosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma des Hirnvenensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma des Sinus cavernosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma dissecans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma dissecans aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma falsum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma spongiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma spurium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma spurium der Arteria femoralis profunda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysma varicosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmaperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmaruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmatische Kieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmatische Zyste des Kieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aneurysmatischer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfall bei Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfallsglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfallsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfallsweises Herzjagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfangsstadium des Trachoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anforderung eines Expertengutachtens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anfälle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Aberration der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Aberration der Talgdrüsen des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Abnormität der Pulmonalarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Abnormität der Zwerchfellöffnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Abwärtsverlagerung der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Achalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Adhäsion der Zunge am Zahnfleisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Afibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Alaktasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Aminosäurestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anastomose der Aderhautgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie Auge, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie Blut/Lymphe, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie Kardiovaskulär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie Nervensystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie als Komplikation der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie des Ohrs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie des männlichen Genitale, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie, muskuloskelettär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalie, weibliches Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anomalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Armhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Asplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Athyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Atresie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Atrophie der Fascia tarsoorbitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Augendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Augenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Azetabulumdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Beckenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Beckenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Beinhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Beinlängendifferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Beinverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Bronchusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Brustkorbdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Brustwarzendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Brustwarzendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Chorda penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Coxa valga',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Coxa vara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Darmdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Bläschendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Cartilago cricoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Concha auriculae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Eustachi-Röhre a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Füße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Gefäße der Sehnervenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Pfortader',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Pleurafalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Pupille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Tränenwege a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Aortenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Atmungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Corti-Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Gastrointestinaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Harntraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Herz-Kreislauf-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Iliosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Kreislaufsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Lumbosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Lymphsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Magen-Darm-Kanals a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Musculus sternocleidomastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Muskel-Skelett-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Nebenhodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Präputiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Ringknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Schildknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Sigmas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Speicheldrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Tränenganges a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Verdauungstraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des Zökums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des kardiovaskulären Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität einer Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität optikoziliarer Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Deformität peripherer Arterien a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Diaphragmadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dickdarmdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dickdarmverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dilatation des Sacculus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Duodenumdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dysfibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dysphagozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dysplasie der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dysplasie des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Dünndarmdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Elliptozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Epididymishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Extremitätenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung der Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Herzseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung großer Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung großer Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung von Nase/Pharynx/Trachea/Larynx/Bronchien/Lunge/Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fehlbildung, endokrines/metabolisches System',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Femurhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fettstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fibulahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fingerhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fissur des Ohrläppchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fistel zwischen Leberarterie und Pfortader',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Fußpronation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gallengangsdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gaumendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gaumenverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gehirnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gelenkdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gewebsdeformität des Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gewebsdeformität des Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Glukose-Galaktose-Intoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Gryposis penis ventralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hakennase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Halsrippendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Handwurzelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hautanomalie, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hautdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hautdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hepatosplenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hernie des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Herzfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Herzklappendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hodendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hornhautfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Humerushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hymendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypophysenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypophysenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypoplasie des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hüftgelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Hüftgelenksubluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ileumdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Infektion durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Integumentdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Irisfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Jodmangel-Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kehlkopfdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Keratodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kieferdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kielbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Klumphand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Knochenbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kolondeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kolonklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kontraktur des Sternocleidomastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Krallenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Lageanomalie des Herzens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Laktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Laryngozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Leberdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Lebervergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Lidfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Lungendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Lungensequestration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Löffelhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Macrogenitosomia praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Magendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Magenschleimhautverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Magenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Makrogenitosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Maskulinisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Megalodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Megalogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Milzverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Mittelohrdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Monilethrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Muskelatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Muskelhypertonie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nasenscheidewanddeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nasenscheidewandverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nasenseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nasenseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nasolakrimalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nebenhodenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nebennierenrindenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Nichtvereinigung der Symphyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ohrmuscheldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ohrmuschelverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ovalozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ovardeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ovarhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pankreashypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Parotisdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Penisdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Perikarddeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pierre-Robin-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pigmentierung der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pili anulati',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pili torti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Plattnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pneumonie durch Streptokokken der Gruppe B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Portioektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Präluxation der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pseudarthrose des Schlüsselbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pseudoneuritis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Pylorusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Reduktionsdeformität einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Retinoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Rhinoseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Rhinoseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Riesenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Rückenmarkmyelodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Saccharose-Isomaltose-Intoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schilddrüsenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schilddrüsendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schilddrüsendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schilddrüseninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schilddrüsenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schlüsselbeinhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Schwäche a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Septumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Septumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Singulärniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Solitärniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Spinalnervenwurzeldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Sprengel-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Stenose des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Stenose des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Stenose des ureteropelviner Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Steroidstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Striktur der Aorta ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Striktur des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Taschenbildung des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Teilung der Labia minora pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tibiaknochenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tortuositas der Netzhautgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tracheafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tracheozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tränenkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Tränenkanalstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ulnahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urachusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urachusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urachuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ureterdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ureterdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ureterklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ureterostiuminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ureterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urethradeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urethrahernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Urethralklappe in der hinteren Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Uterusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Uvuladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Uvulaverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Vaginaverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Varizellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Varusstellung des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verbiegung der langen Beinknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verbiegung von Tibia und Fibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Vergrößerung der Zwerchfellöffnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verkürzung des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verlagerung des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verlagerung des Ductus nasolacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verlagerung des Punctum lacrimale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Verlagerung einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Vermännlichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Vulvadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Vulvahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Wandergallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Wirbellumbalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zerebralparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zervixaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zervixatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zervixhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zungendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zungenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zwerchfelldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zyste der Paraphysis cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Zystenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene atonische Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene azyanotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene beidseitige Schallempfindungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene beidseitige Subluxation des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene dislozierbare Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene dyshämatopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene dyshämopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene einseitige Schallempfindungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene einseitige Subluxation des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene ektodermale Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene elastische Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene erythropoetische Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene fehlende akustische Wahrnehmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene gruppierte Pigmentierung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene hereditäre Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene isolierte aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene kaudale Hirnstammverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene kaudale Kleinhirnverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene laryngotracheale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene luxierbare Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene mobile Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene multiple Deformitäten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene neurenterische Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene nichttoxische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene nävusähnliche Pigmentierung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene okulofaziale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene perikardiale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene perniziöse Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene prominente Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene renofaziale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene spastische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene tibiofibulare Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene vaskuläre Deformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene vermehrte Antetorsion des Oberschenkelhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene zerebrale spastische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene zyanotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ösophagusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ösophagusdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ösophagusfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene Ösophagushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborene ösophagotracheale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Blutschwamm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Branchialknorpel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Buckel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Buphthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Extremitätenlängenunterschied',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Farbstoffmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Gefäßring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Gewebestrang der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Hacken-Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Hackenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Hypothyreoidismus ohne Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Intrinsic-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Kardiospasmus ohne Megaösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Kletterfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Klumpfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Klumpnagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Knick-Hackenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Knick-Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Knick-Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Lentiglobus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Lückenschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Metatarsus valgus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener NADH-Methämoglobinreduktase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Pylorospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Sanduhrmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Schulterblatthochstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Schulterhochstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Sichelfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Spitzfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Urachusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Virilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Zwerchfelldefekt mit Eventration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener Zwerchfellhochstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener gedrehter Ovarialstiel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener hoher Gaumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener hoher Gaumenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener hämolytischer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener periappendikaler Gewebestrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborener sphärozytärer hämolytischer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Aneurysma des Sinus aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Aneurysma extrakranieller hirnversorgender Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Ankyloblepharon filiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Augenzittern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlbildungssyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Augenlidfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Bauchspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Glottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Kniescheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Mamma mit Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Mamma mit Fehlen der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Nabelarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Nierenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Patella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Uvula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Vesiculae seminales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Wimpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Aortenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Brustbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Femurs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Hymen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Innenohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Jejunums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Kinns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Kreuzbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Luftröhrenknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Nebenhodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Perikards',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Punctum lacrimale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Radius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Ringknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Sakrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Samenleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Schildknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Steißbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Sternums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Tracheaknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Ureters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Vorhofseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Zwerchfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Zäpfchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen einer Sehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen einer Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Gelenks a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Lungenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Muskels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen eines Wirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen peripherer Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen peripherer Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen von Oberarm und Unterarm bei vorhandener Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen von Oberschenkel und Unterschenkel bei vorhandenem Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen von Schädelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen von Unterarm und Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fehlen von Unterschenkel und Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Fuchs-Kolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Großohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Hautanhängsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Hygrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Iriskolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Jodmangelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Jodmangelsyndrom vom gemischten Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Jodmangelsyndrom vom myxödematösen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Jodmangelsyndrom vom neurologischen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Kopfnickerhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Makrosigma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Makrosigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Pseudopapillenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Spitzohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Tyloma palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Ulerythema ophryogenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes Wollhaar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes adrenogenitales Salzverlustsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes adrenogenitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes ektopisches Gewebe der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes instabiles Hüftgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes interstitielles Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes multiples Enchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes perliges Haar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes pharyngoösophageales Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes rupturiertes zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes rupturiertes zerebrales sackförmiges Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes verdrehtes Haar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes verkürztes Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes vollständiges Fehlen der obere Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angeborenes zusätzliches Hautanhängsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angelhakenmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angelman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiitis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina Ludovici',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina agranulocytotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina decubitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina diphtherica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina hypertrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina lacunaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina lacunaris follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina lingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina mit Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina necrotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris bei Belastung erstmalig auftretend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris bei Stentstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris de novo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris durch Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris mit abnehmender Belastungstoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris nach Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pectoris vasomotorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina phlegmonosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pseudomembranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina pseudomembranacea diphtherica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina tonsillaris mit Streptokokkennachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina ulcero-membranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angina-pectoris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anginöse Herzbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioblastisches Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioblastosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiocholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiodysplasie des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioendotheliom des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioendotheliom des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioendothelioma cutaneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioendotheliomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiohämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiohämophilie A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiohämophilie B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiohämophilie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioid streaks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioid streaks der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioide Streifen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioide Streifen der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioide Streifen der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioide Streifen der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioimmunoblastische Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioimmunoblastisches Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiokeratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiokeratoma corporis circumscriptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiokeratoma corporis diffusum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioleiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiolipomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiom der Hirnbasisarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiom mit intrazerebraler Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioma sarcomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioma serpiginosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioma stellatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatosis Kaposi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatosis multiplex haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatosis retinocerebellaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatöser Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomatöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomyolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomyolipom der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomyoneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angionephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioneurotische Oktavuskrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioneurotisches Ödem mit Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioorganopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia diabetica [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia diabetica bei Typ-I-Diabetes mellitus [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia diabetica bei Typ-II-Diabetes mellitus [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia labyrinthica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathia retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiopathie des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioretikulosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiosarkom der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiospastische Angina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiospastische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiospastischer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiospastisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiostrongyliasis cantonensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiostrongyliasis durch Parastrongylus costaricensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiozentrische immunproliferative Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiozentrischer immunproliferativer Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angiozentrisches T-Zell-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angioödem mit Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst bei spezifischer emotionaler Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Atemwegserkrankung, anderer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Augenerkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Bluthochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Brustkrebs, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Folgen eines Medikamentes/einer medizinischen Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Geistesstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Genital-/Brusterkrankung Frau, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Genitalkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Genitalkrebs, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor HIV/AIDS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Hautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Herzanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs der Verdauungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs des Atmungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs des Blutes/der Lymphe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs des endokrinen Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebs, muskuloskelettär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Krebserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Ohrenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Schwangerschaftkomplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Selbstmordversuch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderen Nervenleiden/-erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer Blut-/Lympherkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer Erkrankung der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer Geschlechtskrankheit Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer Hauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer endokriner/Stoffwechselerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer gastrointestinaler Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor anderer muskuloskelettärer Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor angeborener Mißbildung des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor dem Tod/Sterben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor kardiovaskulärer Erkrankung, anderer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor sexuell übertragbaren Krankheiten beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor sexuell übertragbaren Krankheiten, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor sexueller Dysfunktion beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor sexueller Funktionsstörung, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst vor sozialen Problemen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angst-Spannungsschmerz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstattacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angsthysterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angststörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angsttraum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angsttraumstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstzustand NB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angstörung/Panikattacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anguilluliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angulus infectiosus der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angulus infectiosus des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Angulus infectiosus oris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anguläre Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende affektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende emotionale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende somatoforme schmerzhafte Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende wahnhafte Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhaltende ängstliche Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhedonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhidrotische ektodermale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhydration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anhydrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aniridie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aniridie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anisakis-Larven-Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anischurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aniseikonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anisokorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anisokorie bei Horner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anisometropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anisozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankyloblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankyloblepharon filiforme adnatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankyloglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankyloglossum-superius-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose der Gehörknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose des Krikoarytänoidgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose mehrere Gelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose nach chirurgischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylose nach chirurgischer Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylosierende Hyperostose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylosierende Hyperostose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylostomiasis brasiliense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylostomiasis caninum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylostomiasis ceylonicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylostomiasis duodenale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ankylostomiasis durch Necator americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anodontia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anodontia vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitale Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitale Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitalekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitales Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anogenitales Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Diaphragmaöffnungen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Durchtrittsstelle der Lungengefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Endung der rechten Lungenvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Gelenkflexion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Glukosetoleranz bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Gravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Konstriktion meningealer Bänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Lappenbildung der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Netzhautkorrespondenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Synchondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Trichromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale Tränensekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale atrioventrikuläre Erregungsausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale intraventrikuläre Erregungsausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomale intraventrikuläre Erregungsleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomaler Menstruationszyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomales Hämoglobin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Aorta a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Bauhin-Klappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Cartilago cricoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Caruncula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Chordae tendineae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Concha auriculae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Darmfixation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Dura mater encephali',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Fibula a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Fovea centralis retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Fußwurzel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Geschlechtschromosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Harnröhre a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Hüfte a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Ileozäkalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Kapillaren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Kehlkopfmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Kiefer-Schädel-Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Kiefergröße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Koronargefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Larynxmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Nasennebenhöhlenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Pupillenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Sigmaflexur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Thoraxwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Tibia a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Urethra a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Vallecula epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Valvula sinus coronarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der Zwerchfellöffnungen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der atrioventrikulären Erregungsüberleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie der extrakraniellen hirnversorgenden Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Benehmens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Benehmens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Benehmens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Benehmens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Corpus vitreum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Corti-Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Gartner-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Humor vitreus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Iliosakralgelenks a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Kreislaufsystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Labyrinthus membranaceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Magen-Darm-Traktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Meatus urinarius a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Muskel-Skelett-Systems o.n.A.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Nasenknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Nasenknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Nuck-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Orificium urethrae a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Os ilium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Os ischii a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Sinus Valsalvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Speicheldrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Sylvius-Aquädukts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Thyreoglobulins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Venenrücklaufs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Wirbelbogenschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Zahnbogenverhältnisses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des Zentralnervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des harten Gaumens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des kortisolbindenden Globulins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des peripheren Gefäßsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie des weichen Gaumens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie in der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie meningealer Bänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie meningealer Falten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie optikoziliarer Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie peripherer Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalie peripherer Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomalien im Mutterleib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorchidie [Anorchie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektale Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektaler Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektales Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorektisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorexia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorexia nervosa/Bulämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anorgasmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anosmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anosognosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anovulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anovulatorische Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anovulatorischer Zyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxie durch Untertauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxie in großer Höhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxie unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxische tubuläre Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxybionten-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anoxämie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen einer Ektoprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen einer Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen eines Ileostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen eines Kolostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen eines Kolostomiegurtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen eines Rollstuhls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen von Geräten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen von Hilfsmitteln a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassen von Vorrichtungen im Darmtrakt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung einer Lesebrille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung einer Lesebrille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung einer Zahnprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung eines Gerätes im Harntrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung eines Hörgerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung eines Neurostimulators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung eines kieferorthopädischen Gerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung eines orthopädischen Hilfsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung von Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung von Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassung von Zahnersatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem an den Ruhestand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem an den Ruhestand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Ausgrenzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Ausgrenzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Vereinsamung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsproblem wegen Vereinsamung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung im Alter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungsstörung mit emotionaler Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anpassungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ansatzperiostose des Kreuz-Darmbein-Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ansatztendinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anstrengungsasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anstrengungsbedingtes Bronchialasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antazidaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antazidamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antenatales Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepartale Blutung bei Koagulationsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepartale Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepartale Plazentablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepartale Vorstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepartale tiefe Phlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antepositio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteriore Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteriore ischämische idiopathische Optikusneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteriorer Faszikelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteriorer offener Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteriores Staphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antesystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteuterine Hämatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteversion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anteversion der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthracosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrakose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrakose mit Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrakose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrakosilikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax contagiosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax-Pneumonie [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthrax-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthraxmeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthropoides Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthropoides Becken mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anthropophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anti-D-Antikörper bei der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anti-Müller-Hormon-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiandrogen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antibiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antibiotika-assozierte Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antibiotika-assozierte Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antibiotikaprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antibiotische Endokarditisprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anticholinerges Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antidepressivaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antidepressivamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antidiabetika-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiepileptikaembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antigen-assoziierte Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiglomeruläre Basalmembranantikörper-Krankheit [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikardiolipinsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikoagulanzientherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeptionsmaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeptionsmaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikonzeptionsmaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikörper der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikörperimmundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikörpermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikörpersuchtest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antikörpertiteränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antimon-Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiperistaltik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiphospholipidsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antisoziale Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antisoziale Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antisoziale Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithrombinämie nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithromboplastinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithromboplastinogenämie nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithromboplastinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antithromboplastinämie nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antitubuläre Basalmembrannephritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antiöstrogen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anton-Babinski-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Abruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Abruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Interruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Interruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Sterilisation bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Sterilisation bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Sterilisation beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrag auf Sterilisation beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antriebshemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antriebsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrumerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrumgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Antrumpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anulus migrans linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anulus migrans linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anurie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anurie durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anus imperforatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anus-praeter-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anus-praeter-Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anus-praeter-transversus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anushämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuslues [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuslues [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuslues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuslues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuspapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anussyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anussyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anussyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anussyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anusverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anxiolytikaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anxiolytikaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anxiolytikamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anxiolytikamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie Vitamin B12/Folsäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie bei Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie bei Neubildung a.n.k. [kodiere zusätzlich D63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie bei Pseudoleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie bei Vitamin-B6-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Aminosäurestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Bothriocephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Diphyllobothrium [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Enzymdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Erythrozytenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Glukose-6-Phosphat-Dehydrogenase-Mangel [G6PD-Mangel]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Glutathionreduktasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Glutathionstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Hakenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Hexokinase-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Hexokinasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Hunger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Hämoglobinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Nahrungsmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Nukleotidstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Orotazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Pentose-Phosphat-Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Pyruvatkinasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie durch Störung der anaeroben Glykolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie mit funikulärer Myelose a.n.k. [kodiere zusätzlich G32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämie mit kombinierter Degeneration des Rückenmarks a.n.k. [kodiere zusätzlich G32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämien, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anämische Blutbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhesie mit Nebenwirkung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhesiekomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhetische Form der Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Anästhetischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aorten- und Mitralklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenaneurysmaverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenarteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenatheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenatherosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbifurkationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogensyphilis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenbogensyphilis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortendissektion - s.a. Aneurysma dissecans aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortengabelembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenisthmusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenklappenzipfelanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenkoarktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenlipoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenlipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenmitralvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortentransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortenwandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortoduodenale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortoiliakales Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortokoronarer Venenbypass [ACVB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortopulmonale Fensterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aortopulmonales Fenster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apallisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aparalytische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apatit-Rheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apepsia gastrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apert-Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apert-Syndrom [Form des Akrozephalosyndaktylie-Syndroms]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apfelschalen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphakie mit Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphakie ohne IOL [Intraokulare Linse]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphakie-Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphasia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphasie bei tertiärer Syphilis [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphasie bei tertiärer Syphilis [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphemie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthae epizooticae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthenseuche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthöse Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthöser Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthöses Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthöses Kehlkopfulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aphthöses Larynxulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikale Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikale Parodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikale Periodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apikales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasia axialis extracorticalis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasia cutis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasia extracorticalis axialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie der Fovea centralis retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie der Vorderhörner des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie des Labyrinthus membranaceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie des Ligamentum teres uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplasie des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplastische Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplastische Anämie durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplastische Anämie durch Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aplastische Anämie durch ein Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apnoe beim Neugeborenen a.n.k',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apokriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apokrines Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apokrines Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apokrines Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apollo-Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aponeurosenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apophysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apophysitis calcanei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apophysitis tibialis adolescentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektiforme Konvulsionen bei zerebraler Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektische Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplektischer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplex - s.a. Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexia cordis der Kammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexia cordis des Vorhofs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexia spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexie der Herzkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexie des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apoplexie des Herzvorhofs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appelt-Gerken-Lenz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendicopathia oxyurica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendikopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendix epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendix testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixabszess/-perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixdurchbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixruptur mit Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixtransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendixzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appendizitische Reizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitlosigkeit nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Appetitverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Applanatio corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Apple-peel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Approximale Zahnabnutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aprosopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aptyalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnoidalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnoidalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnoideatuberkulose [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arachnoiditis durch Meningokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aran-Krebs [Chlorom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aran-Krebs [Chlorom] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arbeitsangina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arbeitsmedizinische Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arbeitsmedizinischer Check up',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arbeitsplatzbedingte Schwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arbeitsplatzbedingte Schwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arborisationsblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arboviruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus lipoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus lipoides corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus lipoides juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arcus senilis der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Areolaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Areolaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Areolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Areolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argentaffines Karzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argentinisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arginin-Bernsteinsäure-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arginin-Bernsteinsäure-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argininosuccino-Azidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argininosuccino-Azidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argininstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argininämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argonz-del Castillo-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argyll-Robertson-Phänomen [Reflektorische Pupillenstarre] [kodiere zusätzlich H58.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argyll-Robertson-Phänomen [Reflektorische Pupillenstarre] [kodiere zusätzlich H58.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argyrie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Argyrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arhinenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ariboflavinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ariboflavinose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arizona-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armerfrierung mit Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armplexuslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armplexusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armprolaps beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armut/finanzielle Probleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Armvorfall beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arnold-Chiari-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arnold-Chiari-Mißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arnold-Chiari-Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arreflexie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhinenzephaliesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmia cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmogene rechtsventrikuläre Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arrhythmogene rechtsventrikuläre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arsenmelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arsenpigmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arsenpigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arsenvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artefakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-basilaris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-carotis-interna-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-cerebellaris-superior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-cerebri-anterior-Syndrom [kodiere zusätzlich G46.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-cerebri-media-Syndrom [kodiere zusätzlich G46.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-cerebri-posterior-Syndrom [kodiere zusätzlich G46.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-coeliaca-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-mesenterica-superior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-spinalis-anterior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-tibialis-anterior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteria-vertebralis-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Durchblutungsstörung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Embolie des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Hypertonie vom Goldblatt-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle PVK [Periphere Verschlußkrankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Thrombose der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Thrombose des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Verschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Verschlußkrankheit des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Verschlußkrankheit vom Becken- und Oberschenkeltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Verschlußkrankheit vom Beckentyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielle Verschlußkrankheit vom Oberschenkeltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieller Gefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieller Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieller Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieller transitorischer Gefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielles Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielles Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielles Durchblutungsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterielles Hämatom durch Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienaberration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienaneurysma der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienarrosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienastgefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienatresie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieneinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienembolie der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienembolie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengerinnsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengumma [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriengumma [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienhyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterieninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienknick',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienspasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienspasmus der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienstenose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienthromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterientuberkulose [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienverengung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienverschluß einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienwandabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterienwandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis der Aorta brachiocephalica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis des Aortenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis hyperergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis temporalis bei Morbus Horton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriitis temporalis bei Morbus Horton mit Augenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioarteriolohyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioarteriolosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriolenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriolenthrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriolonekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriolosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioläre Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioläre Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioläre hyaline Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arterioläre hyperplastische Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriopathia deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose der Koronararterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose der Retinagefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose eines Herzgefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerose in den Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Altersgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Aortitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Claudicatio intermittens des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Einengung der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Engstellung der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Gefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Gefäßveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Kardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nephritis mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nierenarterieneinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nierenarterienengstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nierenarterienstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Nierenarterienstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Retinitis [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Stenose der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotische Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotischer Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotischer Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotisches Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotisches Koronararterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriosklerotisches zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovaskuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöse Fehlbildung peripherer Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöse Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöse Malformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöse aneurysmatische Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöser Shunt für Dialysezwecke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteriovenöses Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artherosklerose/periphere Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis bei Sarkoidose [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis bei Skorbut [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis bei Sporotrichose [kodiere zusätzlich M01.69*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis bei Viruskrankheit a.n.k. [kodiere zusätzlich M01.59*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis bei infektiöser Endokarditis [kodiere zusätzlich M03.69*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Gonokokken [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Gonokokken [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Meningokokken [kodiere zusätzlich M01.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Salmonellen [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis durch Streptokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis dysenterica [Reiter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis mutilans psoriatica [kodiere zusätzlich M07.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis nach Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis nach Meningokokken-Infektion [kodiere zusätzlich M03.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis nach intestinalem Bypass',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis psoriatica [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis rheumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis syphilitica deformans [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis syphilitica deformans [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis urethritica [Reiter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritis urica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthritische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrodese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrogryposis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrogryposis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrokatadysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrolith des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthromyodysplasia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia neuropathica tabica [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia neuropathica tabica [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia psoriatica a.n.k. [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia syphilitica deformans [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathia syphilitica deformans [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Akromegalie [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Hyperthyreose [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Hämochromatose [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Hämophilie a.n.k. [kodiere zusätzlich M36.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Plasmozytom [kodiere zusätzlich M36.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Plasmozytom in kompletter Remission [kodiere zusätzlich M36.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Purpura Schoenlein-Henoch [kodiere zusätzlich M36.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Sarkoid [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Spätsyphilis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Spätsyphilis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei Thyreotoxikose [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie bei bösartiger Histiozytose [kodiere zusätzlich M36.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie des Krikoarytänoidgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropathie nach Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropoden-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthropodenbefall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrose bei Alkaptonurie [kodiere zusätzlich M36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrose des Karpometakarpalgelenks I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrose des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthrosis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arthus-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizielle Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizielle Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizielle Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizielle homologe Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizieller Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artifizielles Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Artikulationsauffälligkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittel- und Drogenmißbrauch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittel-Entziehungstherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelbedingte Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelbedingte Photodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelbedingter Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimitteldermatitis durch ein eingenommenes Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelexanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Enzymmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Folsäuremangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Myotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Osteoporose mit pathologischer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte Ticstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte interstitielle Lungenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierte nichtautoimmunhämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierter Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduzierter Östrogenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelinduziertes Insulinkoma beim Nichtdiabetiker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelreaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelreaktion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelwirkung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelüberdosierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arzneimittelüberempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Arztphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asbestlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asbestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asbestose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asbestosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asbeststaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aschoff-Geipel-Knötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ascites chylosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ascomycetes-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Harnblasensphinkternekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Hüftnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Knochennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Meningitis durch Leptospiren [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Mondbeinnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Myokarditis beim Neugeborenen [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Nekrose des Os naviculare pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Neurosyphilis der Leptomeningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Neurosyphilis der Leptomeningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Pankreasnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aseptische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asherman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asialie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiatische Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiatische Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiatische Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiatische Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiatische Wüsten-Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asiderotische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askaridiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askaridose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askaridose mit intestinaler Komplikation [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askin-Tumor [Bösartige Bindegewebeneubildung der Lungen-Thorax-Region im Kindesalter]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Askorbinsäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asoziale Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asoziale Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asozialer Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspartylglukosaminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asperger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillose mit Pneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Aortitis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Bronchiolitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Bronchitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Bronchopneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Duodenitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Enteritis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Gastritis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Ileitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Jejunitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Meningitis [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Myokarditis [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Perikarditis [kodiere zusätzlich I32.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Pneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Splenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Thyreoiditis [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Tonsillitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Tracheobronchitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-flavus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-fumigatus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-terreus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspergillus-Ösophagitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspermatogenese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxia pallida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie außerhalb der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Bettzeug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Erhängen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Ertrinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Gas a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Kohlenmonoxid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Konstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Schleim',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Untertauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Verschüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie durch Zerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie mit Apgar-Score 0-3 für 1 Minute postnatal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie mit Apgar-Score 4-7 für 1 Minute postnatal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxie unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxierende Thoraxdysostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asphyxierende Thoraxdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspiration durch Anästhesie bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspiration eines Schleimpfropfes durch das Neugeborene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspiration von Mageninhalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspiration von Magensekret',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspiration von Vernix caseosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationsbronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie durch Erbrochenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie durch Magensekret',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie durch Milch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonie durch regurgitierte Nahrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationspneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirationssyndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspirindauertherapie in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asplenie nach Splenektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aspleniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Assam-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Assimilationsstörung von Nahrungsmitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Assmann-Herd mit Krankheitszeichen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asteatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asteatosis cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astereognosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asteroide Hyalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenopische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthenospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma atopicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bei Idiosynkrasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bronchiale atopicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bronchiale durch Analgetika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma bronchiale intrinsicum et extrinsicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma cardiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma cardiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma cardiobronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma durch Detergenzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma durch Heu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma durch Mehlallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma durch Platin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma durch Pollen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma extrinsicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma intrinsicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma mit akuter Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma montanum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma nervosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthma thymicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmaanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmabronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmaemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmatische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmatische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmatische Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmatische endogene Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmatische obstruktive Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmoide Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asthmoide Spasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astigmatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astragalusdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astragalusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrocytoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrocytoma cysticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrocytoma juvenile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrocytoma pilocyticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astrozytäres Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Astvenenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymbolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymmetrie des Schädels beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymmetrischer lumbosakraler Übergangswirbel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische Bakteriurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische Bakteriurie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische HIV-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische Hyperurikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatische Urikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asymptomatischer Status einer HIV-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asynergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Asystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszendierende Hemiplegie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszendierende Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszendierende Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszendierende Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszendierende Neuromyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszites - s.a. Ascites oder s.a. Bauchwassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aszites durch bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxia hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxia muscularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxia ocularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxia teleangiectatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxie nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ataxoadynamie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atelokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atelomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemgymnastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemgymnastische Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemgymnastische Übung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ateminsuffizienz - s.a. respiratorische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnotsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnotsyndrom beim Erwachsenen [ARDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnotsyndrom beim Frühgeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnotsyndrom beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemnotzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atempausen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemprobleme, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemschwäche beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemstillstand beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemsymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegserkrankungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsinfekt, anderer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit bei Kryoglobulinämie [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit bei Sporotrichose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit bei Syphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit bei Syphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegskrankheit durch Baumwollstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atemwegsverschluß nach Tracheotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atheromatöse Arteriendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atheromembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerose - s.a. Arteriosklerose oder s.a. Aderverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerose der Arteria femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerose der Herzkranzarterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerose einer Extremitätenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerotische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atherosklerotische Retinopathie [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athetotische Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athyreosis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Athétose double',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atlantoaxiale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atlantookzipitale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atlantookzipitale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atlasblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atlasdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atmosphärische Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atmungs-Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atmungsdistreß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atmungsverminderung bei traumatischem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonisch-astatischer Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Absencen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Blutung nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Hämorrhagie nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Metrorrhagie post partum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische Obstipation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische epileptische Absencen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonische postpartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atonischer Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopikdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopiker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopische Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopische Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Fußekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Gesichtsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Handekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches Kopfhautekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atopisches impetiginisiertes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atransferrinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresia duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresia hymenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresia ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresia uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresia-multiplex-congenita-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Apertura lateralis ventriculi quarti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Apertura mediana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Apertura mediana ventriculi quarti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Aperturae laterales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Foramina Luschkae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Harnorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Ostia ureterum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Tuba pharyngotympanica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Ductus ejaculatorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Foramen Magendii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Meatus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Nasopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Ostium urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Speicheldrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Sylvius-Aquädukts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atresie des ureteropelvinen Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atretische Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atretische follikuläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atriale Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrichia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrichia congenita universalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atriomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioseptaldefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikularkanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikularkanaldefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikuläre Dissoziation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikuläre paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikulärer Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikulärer Block 2. Grades, Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikulärer Block 2. Grades, Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikulärer Knotenrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrioventrikulärer Septaldefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia cutis idiopathica progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia cutis senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia fusca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia gyrata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia gyrata chorioideae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia gyrata der Aderhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia striata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophia unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie bei Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie blanche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Gesichtshaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Augapfel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Hirnnerven III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Hirnnerven IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Hirnnerven VI',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des zahnlosen Alveolarfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie des zahnlosen Alveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophie eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Dakryosialoadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Fibrose der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Gastroduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Hautflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Kolpitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Leptothrix-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Polychondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Rachenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische hämorrhagische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische lobäre Sklerose des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische postklimakterische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische postklimakterische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophische senile Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophisches Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophisches Postmenopausen-Endometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophisches Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophisches klimakterisches Endometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophoderma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia idiopathica vom Typ Pasini-Pierini',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia maculata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia neuriticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia pigmentosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atrophodermia reticulata symmetricum faciei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atropinvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Attestausstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Attrition der Zahnhartsubstanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Attrition der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypisch verruköse Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Bulimie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Demenz vom Alzheimer-Typ [kodiere zusätzlich F00.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Form der Creutzfeldt-Jakob-Krankheit durch BSE [Bovine spongiforme Enzephalopathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Melanozytenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Portioektopieblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Portiogefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Portioumwandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Prosopalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Psychose im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische Umwandlungszone Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische familiäre Situation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische familiäre Situation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische kindliche Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische mykobakterielle Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypische primäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypisches Endometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Atypisches Fibroxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Audiogene Sprachentwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auditive Wahrnehmungsstörung und Verarbeitungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auditorische Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufbrechen der Operationswunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auffälliger Befund einer Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auffälliger CTG [Kardiotokogramm]-Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auffälliger Kolposkopiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auffälliger Urintest ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auffälliger Zervixabstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgedunsensein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgefundene Leiche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgefundene Leiche, Todesursache unbekannt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgefundener Toter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgenommene Person im Krankenhaus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgepfropfte Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgesprungene Lippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufgetriebenes Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeits- und Aktivitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit bei Hyperaktivitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit bei hyperaktivem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizit- und Hyperaktivitätsstörung [ADHS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsdefizitsyndrom [ADS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung (ADD)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung ohne Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung ohne Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufmerksamkeitsstörung ohne Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufnahme wegen prophylaktischer Organentfernung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufnahmeuntersuchung für Bildungseinrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufnahmeuntersuchung für Wohneinrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufpfropfgestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufplatzen von Stichen und Nähten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufreißen der Operationswunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufreißen der Sektiowunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufsteigende Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufsteigende progressive Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aufstoßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfeladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelhypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfellazeration ohne Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelsiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augapfelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auge Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auge abnorme Bewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auge abnorme Empfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auge abnormes Aussehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auge/Adnexen Erkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenastarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenastvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbewegungsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbewegungsspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblicklicher Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblicklicher Tod durch Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbrauenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbrauenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbrauenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenbrennen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augendruckerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augendrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenerkrankung durch Toxoplasmen [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenerkrankung nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augengefäßsklerose [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augengonorrhoe beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augengonorrhoe beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhypertension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlengumma [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlengumma [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenhöhlenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augeninfektion/-entzündung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenjucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenjucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenjucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenjucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkrankheit durch Herpesviren [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkrankheit in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlid Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlid-Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidchalodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenliddermatitis durch Herpesviren [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenliddermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidentropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenliderkrankung bei Zoster [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidgumma [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidgumma [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidhypertrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidinduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidkolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidleishmaniase [kodiere zusätzlich H03.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidlepra [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidmilien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidptose bei Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidptose bei Myasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidsyringom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidtrachom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidtuberkulose [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidvitiligo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidxanthelasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidzucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlidödem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlinsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlinsendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlinsenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlues [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenlues [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmelanose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmelanose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmelanose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmelanose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmotilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskeladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskelerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskelfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskelfibrosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmuskelparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenmyiasis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenneurose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenprellung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenrötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenschmerzen mit Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenschmerzen mit Übelkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augensenkerparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augensiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenstechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augensyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augensyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentränen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentränen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentränen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentränen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augentumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverblitzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverletzungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverätzung durch Kalk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenverätzung durch Mörtel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenwinkelbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenwinkelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenwinkelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzentralarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzittern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenzystizerkose [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenüberanstrengung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Augenüberdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aujeszky-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aura epileptica a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurantiasis cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikularanhänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikulotemporales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläre Form der paroxysmalen Tachykardie [Bouveret-Hoffmann-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläre Ossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläre Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikulärer Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläres Othämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aurikuläres nichttraumatisches Othämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbildungsbedingte Benachteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbildungsbedingtes Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbildungsprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der Eröffnung der Cervix uteri bei Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der Eröffnung der Cervix uteri bei Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der Ovulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausbleiben der erwarteten normalen physiologischen Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluss Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluß aus dem Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluß aus den Brustwarzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluß aus der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluß aus der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausfluß aus der Harnröhre bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgebliebene Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgebliebene Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgebliebene Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgebliebene Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgebreitete Hautgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgedehntes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeheilter Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Intelligenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Mitesser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Multiparität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Osteochondrose der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Osteochondrose der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Osteochondrose der Lenden- und Sakralwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Osteochondrose der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägte Osteochondrose der Wirbelsäule mit Foraminaeinengungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägter Komedo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgeprägter Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgesetztsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgesetztsein gegenüber Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausgesetztsein gegenüber Witterungsunbilden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auslösung der Menstruation (zur Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auslösung der Menstruation (zur Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussatz mit Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussatz mit Polyneuritis [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausscheidung von Kristallen im Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschluß einer Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschluß einer Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschluß einer Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschluß eines Verdachtsfalles',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschluß eines verdächtigen Befundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussetzen eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aussprachestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausstellung einer wiederholten Verordnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausstellung einer ärztlichen Bescheinigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Austin-Flint-Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Australische X-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Australische X-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Australisches Q-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Austritt von Liquor cerebrospinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Austrocknung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Austrocknung/Dehydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Austrocknungsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ausweichendes Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auswirkungen von Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auswirkungen von Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auswirkungen von Schwerelosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auswurf mit Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auswärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Auszehrung - s.a. Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autistische Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autistische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoaggressionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autodigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoerythrozytäre Sensibilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoerythrozytäres Sensibilisierungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunadrenalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunbedingte Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmune Kältesensibilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmune Parathyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmuner Hypoparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunerkrankung Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunes polyglanduläres Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunes polyglanduläres Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunhämolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autoimmunthyreopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autointoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autokrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Automatismen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autonome Dysreflexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autonome Faziozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autonome Gleichgewichtsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autonome kardiale Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autonomes Schilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosensibilisierung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomal-dominante Vitreoretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomal-dominante vitelliforme Best-Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomal-rezessive Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomal-rezessive Friedreich-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomal-rezessive fetale Akinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomale Anomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomale Trisomie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomenabnormität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autosomendeletion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotopagnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autotransplantatabstoßung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autumnalfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Autumnalkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenbandruptur des Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenbandruptur des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenknöchelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenknöchelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenmeniskusauffaserung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenmeniskuskorbhenkelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenmeniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenmeniskusläsion des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenmeniskusschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außenrotationsgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außereheliche Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außereheliche Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Außergewöhnlich großes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avaskuläre Hüftnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aversions-Therapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose B2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Avitaminose K',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axenfeld-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axenfeld-Schürenberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axiale Hiatushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillabasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillaekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillafurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillalymphknotenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillalymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axillarisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axilläre Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axilläre Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axilläre Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axilläre Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axisfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Axonaler Typ der peronäalen Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ayerza-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ayerza-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalobrachius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalochirus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalogaster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalostomus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azetabulumbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azetabulumfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azetonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azetonämisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azetonämisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azido-basophiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azidophiles Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azidophiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azidophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azinuszellen-Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azinuszellen-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azinöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azinöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azotämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azotämische Osteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Aztekenohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azyanopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azyanotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azyklische Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azyklische Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Azystie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Präkursor-Lymphom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zell-Lymphom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zellen-Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zellen-Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zellhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zellimmunozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'B-Zelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BK-Mole-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BKS [Blutkörperchensenkungsgeschwindigkeit]-Beschleunigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BNS [Blitz-Nick-Salaam]-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BNS [Blitz-Nick-Salaam]-Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BPH [Benigne Prostatahyperplasie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BSG [Blutkörperchensenkungsgeschwindigkeit]-Beschleunigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BSP [Bandscheibenprolaps] - s.a. Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BSP [Bandscheibenprolaps] - s.a. Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BSV [Bandscheibenvorfall]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BSV [Bandscheibenvorfall]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWK [Brustwirbelkörper]-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-LWS-Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Skoliose mit degenerativen Veränderungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'BWS-Zerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baader-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baastrup-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baastrup-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Babinski-Fröhlich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Babinski-Nageotte-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baby-Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Backenknochenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Badedermatitis durch Zerkarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Badehosen-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Badekonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Badeotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Badeotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baelz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagasse-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagasse-Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagasse-Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagasse-Staublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagassose-Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagassosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagdad-Frühlingsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bagdadbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bahia-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baker-Rosenbach-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baker-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baker-Zyste des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Diarrhoe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Enteritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Harnwegsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Harnwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Kultur mit Resistenzbestimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Meningoenzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Meningomyelitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Panophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pleuritis exsudativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pleuritis mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Prostatovesikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Pyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Ruhr durch Shigella boydii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Ruhr durch Shigella flexneri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Ruhr durch Shigella sonnei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Sepsis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Toxämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Vaginalinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Vaginose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Zoonose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle seröse Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle zoonotische Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielle/virale Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterieller Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterieller Hämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterieller Kontaktinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterielles Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterien im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterienarme Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterienarmer Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakterienruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch gesicherte Epituberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch gesicherter Ghon-Herd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und durch mikroskopische Sputumuntersuchung gesicherte Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht gesicherte Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht gesicherte tuberkulöse Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht gesicherte tuberkulöse Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht gesicherte tuberkulöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht gesicherter tuberkulöser Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht untersuchte tuberkulöse Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht untersuchte tuberkulöse Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht untersuchte tuberkulöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriologisch und histologisch nicht untersuchter tuberkulöser Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Anaerobier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Gasbrandbazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Pestbakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch Yersinia pestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bakteriämie durch gramnegative Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanciertes Chromosomen-Rearrangement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanciertes Rearrangement der Gonosomen und Autosomen beim abnormen Individuum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis candidomycetica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis candidomycetica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis candidomycetica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Amöben [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Ducrey-Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Ducrey-Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Herpesviren [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Herpesviren [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Trichomonaden [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis durch Trichomonaden [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis gangraenosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis infectiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis mycotica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis mycotica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis mycotica [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis phagedaena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanitis xerotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanochlamyditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanokandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanokandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanokandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanoposthitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanoposthitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanoposthitis durch Kandidose [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balanorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balantidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balantidienruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balbuties',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balggeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balgkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkanfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkangrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkannephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenharnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Balkenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballantyne-Runge-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballenhohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballonfahrerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballonkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballonzell-Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballonzell-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ballotierende Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baló-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baló-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bamberger-Marie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Banaler Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bancrofti-Filariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandansatzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandenaktivität ohne Manifestation einer psychischen Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandförmige Hornhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandförmige Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandl-Kontraktionsring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandl-Kontraktionsring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandl-Ring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandl-Ring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenbedingte Stenose des Spinalkanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibendegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibendegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibeneinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibeneinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenprolaps/-degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden der HWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden der LWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden der LWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenschaden im Bereich der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bandwurmkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bang-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bang-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bangigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bannayan-Riley-Ruvalcaba-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bannayan-Zonana-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bannister-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bannwarth-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Banti-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Banti-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barbituratabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barbituratabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barbituratintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barbituratmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barbituratmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barcoo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bare-lymphocyte-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bariumperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barlow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barodontalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barootitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barotrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barotrauma der Kieferhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barotrauma der Stirnhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barotrauma mit Odontalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barraquer-Simons-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barraquer-Simons-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barrett-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barrett-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barrett-Ulkus des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barré-Guillain-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barré-Liéou-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barré-Masson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartdermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartholin-Pseudoabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartholin-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartholini-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Barton-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartonellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartonellose der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bartter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalarachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basale Impression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basale Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basale Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalganglien-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalgangliendegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalganglienhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalganglienkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalganglienschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basaliom mit epidermoider Differenzierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalioma rodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalioma sclerodermiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalioma terebrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalmeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalpleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzelladenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellakanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellakanthom des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzelliger Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellkarzinom der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellnävussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basalzellpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basedow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basedow-Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basedow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basedow-Syndrom mit Exophthalmus [kodiere zusätzlich H06.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basilarisaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basilarisinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basilarisinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basilaristhrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basilarmeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Impression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basiläre Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baso-eosinophiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baso-eosinophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophile Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophile Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophileninvasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophiler Hyperpituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophiles Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basophilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Basozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bassen-Kornzweig-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bassen-Kornzweig-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bassen-Kornzweig-Syndrom mit Retinitis pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bathing-trunk-Naevus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bathophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batten-Kufs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batten-Mayou-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batten-Mayou-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Battered-child-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batterieerschöpfung eines ICD [Implantierbarer Cardioverter-Defibrillator]-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batterieerschöpfung eines implantierten Cardioverter-Defibrillators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Batterieerschöpfung eines implantierten Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Battey-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchaortenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchaortenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenaplasiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenfettschürze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckeninfektion durch Blasenfistelkatheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckeninfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchdeckenschmerzhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baucheingeweidekarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baucheingeweidemalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfell-TBC [Tuberkulose] [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfelladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfelladhäsion mit Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellmesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfelltuberkulose a.n.k. [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchfellverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchhöhlengravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchhöhlenschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchkrämpfe/Unbehagen/Schmerz NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchnarbenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchnarbenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchnetzmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschmerzen ohne Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschmerzen, andere Lokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschmerzen, epigastrische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschmerzen/-krämpfe, generalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchspeicheldrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchspeicheldrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchspeicheldrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchspeicheldrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchspeicheldrüsentuberkulose [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchtyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwanderfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwandverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchwassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchweh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauchweh/-schmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauerntölpel [Mumps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauernwetzel [Mumps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baumgarten-Cruveilhier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baumgarten-Cruveilhier-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Baumwollstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauxitfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bauxitfibrose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bayle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bayle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazillen im Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazillen im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazillurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazilläre Enteritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazilläre Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bazin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beard-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bearn-Kunkel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beatmungslunge beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beau-Reil-Querfurchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becherzellkarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becherzellmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becken-Schädel-Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenanomalie mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenarterienstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenasymmetrie mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenausgangsverengung mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbindegewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbodeninsuffizienz bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbodenplastik bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbodenrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbodenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbänderschädigung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenbänderschädigung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckendeformität mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckendistorsion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckeneingangsverengung mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenendlage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenentzündung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengelenkschädigung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengelenkschädigung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengradstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengürtelanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengürtelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengürtelmyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckengürteltuberkulose [kodiere zusätzlich M90.05*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenhämatom bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenhämatom bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenknochenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenknochenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenknochentuberkulose [kodiere zusätzlich M90.05*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenkyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenosteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenperitonitis nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenrandfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenringbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenringfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschiefstand bei Beinverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckentiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckentuberkulose [kodiere zusätzlich M90.05*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckentumor bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beckenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becker-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becker-Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Becker-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bednar-Aphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beeinträchtigte Glukosetoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beeinträchtigung des Harnstrahls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beendigung der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beengte Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beengte Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beengte Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beengte Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beerenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall der Leber durch Clonorchis sinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall des Blutes durch Schistosoma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall des Darmes durch Fasciolopsis buski',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Acanthocheilonema perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Acanthocheilonema streptocerca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Angiostrongylus cantonensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Anguillula stercoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Anisakis marina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ankylostoma brasiliense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ankylostoma canium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ankylostoma ceylonicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ankylostoma duodenale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ascaris lumbricoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Balantidium coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Bandwurm a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Bilharzia a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Bothriocephalus latus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Brugia malayi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Candiru',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Chilomastix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Cysticercus cellulosae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Darmegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Darmparasiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Darmälchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dauerlarvenfilarie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Demodex folliculorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dermanyssus gallinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dibothriocephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dicrocoelium dendriticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dioctophyma renale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dipetalonema perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dipetalonema streptocerca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Diphyllobothrium-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Diplogonoporus grandis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dipylidium caninum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Distoma hepaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Dracunculus medinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Echinococcus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Echinostoma ilocanum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Embadomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Entamoeba histolytica a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Enterobius vermicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Erntemilben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Fadenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Fasciola hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Fischbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Gasterophilus intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Gastrodiscoides hominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Gnathostoma spinigerum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Gongylonema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Grubenkopfbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Guineawurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Haarbalgmilben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Helminthen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Herbstmilben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Heterophyes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Hundebandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Hundespulwurm-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Hymenolepis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ixodeszecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Katzenleberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Katzenspulwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Kleiderläuse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Knäuelfilarie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Kokzidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Krätzmilbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Käsemilben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Larva migrans visceralis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Leberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Linguatula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Liponyssoides sanguineus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Loa-loa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Lungenegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Madenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Malaienfilarie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Mansonella ozzardi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Mansonella perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Mansonella streptocerca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Medinawurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Metagonimus yokogawai',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Microfilaria streptocera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Necator americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Oesophagostomum apistomum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Oestrus ovis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Onchocerca volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Oxyuren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Paragonimus ringeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Paragonimus westermani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Pediculus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Peitschenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Pentastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Phthirus pubis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Plerozerkoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Protozoen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Rattenbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Rhabdonema intestinale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Rinderbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Rinderfinnenbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Rodentolepis nana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Sandfloh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Saprophyten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Sarcoptes scabiei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Saugwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Schistosoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Skabies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Sparganum mansoni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Sparganum proliferum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Spirometralarven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Springwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Spulwurm a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Stellantchasmus falcatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Strongyloides stercoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia diminuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia mediocanellata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia nana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia saginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Taenia solium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Ternidens deminutus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Tetranychus molestissimus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Toxocara-canis-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Toxocara-catis-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Trematoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Trichocephalus trichiura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Trichostrongylus orientalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Trichuris trichiura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Trombicula-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Tunga penetrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Uncinaria americana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Vandellia cirrhosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Zerkarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Zestoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Zwergbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch Zwergfadenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch adulte Form von Diphyllobothrium latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch afrikanischen Augenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch breiten Bandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch chinesischen Leberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befall durch externe Blutegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befeuchterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befeuchterpneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befundbesprechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Befürchtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begehrensneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beginnende Kerntrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beginnende Pangonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitendes Papillenödem bei Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitendes Papillenödem bei Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitiritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitiritis bei Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitmyokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begleitotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Begriffsaphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behandlungsinduzierte Akathisie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behandlungsinduzierter Parkinsonismus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderter in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderung durch Blutungsneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behinderung infolge Hypoxie, Hyperkapnie, eingeschränkter Lungenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behr-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behr-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behçet-Aphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Behçet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitig Amputierter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Innenohrhochtonschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Innenohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Koxarthrose als Folge einer Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Schalleitungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Schallempfindungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Sehschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Stenose der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Torsion des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige Zwergniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige angeborene Hüftgelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige kleine Nieren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige posttraumatische Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige posttraumatische Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige posttraumatische Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige primäre Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige primäre Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitige sekundäre Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Leistenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Sehverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Status varicosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Visus < 0,05',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Visus < 0,3',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beidseitiger Visusverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beigel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bein/Oberschenkelsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beindysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beingangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinkrampfadern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinlängendifferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinphlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinthrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinvarikose mit Stauungsdermatose ohne Ulkus oder Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinvarizen im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverkürzung egalisiert durch Beckenasymmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beinödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bejel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bejel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beklemmung im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastung durch Einteilung der Arbeitszeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastung durch Einteilung der Arbeitszeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsabhängige Handgelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsabhängige Sprunggelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsdyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungserythrozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungshämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungshämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsinduzierte Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belastungsinkontinenz der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belegte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Belegte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Fazialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bellender Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bence-Jones-Albuminurie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bence-Jones-Proteinurie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benedikt-Paralyse [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benedikt-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benetzungsstörung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Akanthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Caruncula urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Epilepsie im Säuglingsalter [Watanabe]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Fruktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Geschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Hirndrucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Hypertonie bei Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Inokulationslymphoretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Lymphogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Lymphoretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Muskeldystrophie (Typ Becker)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Partialepilepsie mit affektiver Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Prostatahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Prostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Prostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Purpura hypergammaglobulinaemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Purpura hyperglobulinaemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Raumforderung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Schaumann-Lymphogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Säuglingsepilepsie mit komplex-fokalen Anfällen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne Uteruszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne chronische eitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne hypertensive Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne intrakranielle Drucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne intrakranielle Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne kardiorenale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne konzentrische Makuladystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne lymphoepitheliale Speicheldrüsenläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne myalgische Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne paroxysmale Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne psychomotorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne renale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne rezidivierende Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne skapuloperonäale Muskeldystrophie mit Frühkontrakturen (Typ Emery-Dreifuss)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne symmetrische Lipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigne/unspezifische Blutneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Aderhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Augentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Brenner-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Brusttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Brusttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Chorioideatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Hirnnerventumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Hornhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Hypophysentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Iristumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Karunkeltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Knochentumor des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Konjunktivatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Lidhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Lidtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Nebennierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Netzhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Nierenpoltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Nierenprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Optikustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Orbitaknochentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Orbitatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Prostatatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Prozeß des Nierenpols',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Retinatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Skleratumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tränenwegtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tumor der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tumor des Nervus abducens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tumor des Nervus oculomotorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tumor des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Tumor des Nervus trochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner Ziliarkörpertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner intrakranieller Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner paroxysmaler Lagerungsschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benigner paroxysmaler Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benignes Hepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benignes Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benignes Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benignes akzidentelles Herzgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bennett-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benommenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benzodiazepinabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benzodiazepinabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benzodiazepinintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Benzolvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung bei Verdacht auf Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung bei Verdacht auf psychische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung bei Verdachtsfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung nach Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung wegen Brandstiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung wegen Brandstiftung ohne manifeste psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung wegen Ladendiebstahl ohne manifeste psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Beratung/Diät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beobachtung/Gesundheitsschulung/Ernährungsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A45'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Blutsverwandtschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Konsanguinität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung bei Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung für nicht anwesende dritte Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung in Bezug auf HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung nach Paragraph 218',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung nach Paragraph 218',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung und Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Einstellung zur Sexualität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Empfängnisregelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Empfängnisregelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Interruptio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Interruptio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung wegen Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beratung zur Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berger-Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergflachslunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergleute-Anämie durch Hakenwurm [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergleute-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergleute-Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergleute-Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergmannslunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bergmeister-Papille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beri-Beri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beriberi-Kardiomyopathie [kodiere zusätzlich I43.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berlin-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berloque-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernard-Soulier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernard-Soulier-Thrombopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernhard-Roth-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernhardt-Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernheim-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bernuth-Pseudohämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berry-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berryliose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bertielliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beruflich bedingte Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beruflich bedingte Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufliche Exposition gegenüber Luftverschmutzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufliche Exposition gegenüber Vibration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufliche Exposition gegenüber extremer Temperatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufliche Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Bursitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Kontaktdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Kontaktekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Schwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Schwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Zahnabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingte Zahnerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingtes Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsbedingtes Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch Detergenzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsekzem durch ein organisches Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berufsschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliumgranulom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliumgranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliumlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliumpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berylliumstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berührungssinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Berührungssinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschleunigte Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschleunigte Herzfrequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschleunigte atrioventrikuläre Erregungsleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschleunigtes Wachstum in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschneidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschneidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschneidung ohne medizinische Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschränktheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden bei TEP [Totalendoprothese]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden im weiblichen Unterleib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden im weiblichen Unterleib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden im weiblichen Unterleib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden im weiblichen Unterleib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden nach Gallenblasenexstirpation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschwerden nach Gallenblasenoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschäftigungskrampf der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschäftigungsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschäftigungstherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beschäftigungstic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besenreiser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besessenheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besnier-Boeck-Schaumann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besnier-Boeck-Schaumann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besnier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besnier-Tennesson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis wegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis wegen Geisteskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis wegen sexueller Präferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis über äußere Erscheinung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis über äußere Erscheinung der Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Besorgnis über/Furcht vor medizinischer Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Best-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestiophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungsallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungsdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungsenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungslunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungsschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestrahlungstherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beständiges Trinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigung einer Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigung einer Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bestätigung einer Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beta-Aminosäurestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beta-Glukuronidase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beta-Zell-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beta-Zell-Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beta-Zell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betahypolipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betalipoproteinämie mit breiter Beta-Bande',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betazellen-Hyperplasie der Langerhans-Inseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beteiligung an Glücksspiel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beteiligung an Glücksspiel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beteiligung an Wetten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beteiligung an Wetten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betel-Zahnauflagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betel-Zahnbelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Fetus compressus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Fetus papyraceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Hydrozephalus des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Krankheit des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Schädigung des Fetus durch Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei Tragzeitüberschreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei fetaler Anenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei fetaler Wachstumsretardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei retiniertem totem Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter bei wechselnder Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter unmittelbar post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Mutter unmittelbar post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei AB0-Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei AB0-Inkompatibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Anomalie der Beckenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Anomalie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Anomalie der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Blutgruppenunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Cerclage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Chromosomenanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Einstellungsanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fehlbildung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fehlbildung des ZNS des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fetalanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fetalschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fetaltod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Fruchttod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Gesichtslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Herpes gestationis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Hypotoniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Isoimmunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Kinnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Kopf-Becken-Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Lageanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Large-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Lebererkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Light-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Nichteintreten des Kopfes beim Termin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Perineumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Plazentainsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Querlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Rh [Rhesus]-Inkompatibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Rhesus-Inkompatibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Scheitelbeineinstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Scheitellage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Schräglage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Schulterquerstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Schädigung des Fetus durch Amniozentese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Schädigung des Fetus durch Biopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Shirodkar-Naht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Small-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Steiß-Fuß-Lage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Steißlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Stirnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Symphysenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Tumor des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Uterus bicornis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Uterus duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Uterusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Vena-cava-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Vorderhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Vulvaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei Zervixinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei allgemein verengtem Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fehlendem Kopfeintritt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetalem Down-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetalem Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetalem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetalem Schaden durch hereditäre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Herztonalteration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Mißbildung des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetaler Wachstumsretardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei fetoplazentarer Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei hinterer Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei hohem Geradstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei intrauterinem Fruchttod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei intrauterinem Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei liegendem Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei tiefem Geradstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei tiefem Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei vorausgegangener Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei vorderer Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung der Schwangeren bei wechselnder Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer Drillingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer Geminischwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer Mehrlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer Vierlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer Zwillingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung einer normalen Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines Findelkindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines gesunden Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung eines kranken Familienmitglieds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung der Mutter unmittelbar nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung der Mutter unmittelbar nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung während der Laktationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung während der Laktationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung während der Stillperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betreuung und Untersuchung während der Stillperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von Krieg',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von Krieg',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von Krieg',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betroffensein von einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Betrunkenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bettlägerigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bettlägerigkeit, die Gesundheitspflege erfordert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bettnässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bettnässen/Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beugesehnenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beulenpest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegliche Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beweglicher Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegungseinschränkung des Iliosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegungskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegungskrankheit bei Reisen mit jedem Fahrzeug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewegungsübelkeit bei Reisen mit jedem Fahrzeug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bewußtlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsproblem mit Elternteil/Erwachsenem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsprobleme mit Elternteil/Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsprobleme mit Freund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsprobleme mit dem Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsschwierigkeiten beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungsstörung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Beziehungswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bianchi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biedl-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bielschowsky-Dollinger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bielschowsky-Dollinger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biemond-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bienengiftallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bienenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bienenstich mit Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bienenstich mit anaphylaktischem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biermer-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biermer-Ehrlich-Addison-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biermer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biermer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biett-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bigeminie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bigemismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bikuspidale Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Nierenrindennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Obstruktion der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale Syndrome der präzerebralen Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale kongenitale Athetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale massive Nierenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterale supravesikale Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilateraler Verschluß der präzerebralen Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilaterales Hiluslymphomsyndrom [Löfgren-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bildungsbedingte Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bildungsbedingte Benachteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bildungsbedingtes Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bildungsnachteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziose der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziose der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziose der Lunge a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziose mit pulmonale Herzkrankheit [kodiere zusätzlich I52.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilharziöse Lipurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilirubinausscheidungsdefekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilirubinausscheidungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilirubinenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilirubinhirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bilirubinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliäre Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliäre Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliäres Erbrechen unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliäres Erbrechen unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliöse Indigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biliöses Fieber mit Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binasale Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binasale Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebeabszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebegangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebemetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebenarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebeneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebetumor des Lids unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebige Stenose der Foramina intervertebralia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindegewebige Stenose des Spinalkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehaut- und Hornhauttrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautchemosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautdermoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauteinlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautentzündung durch Viren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauterythroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauthämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautmelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautnahtdehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautneurofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautsackfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauttuberkulose [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautxerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindehautübersplitterung mit Fremdkörpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindungsstörung mit Enthemmung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bindungsstörung mit Enthemmung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bing-Horton-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bing-von-Neel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binnenschaden eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binnenschädigung des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binnenverletzung des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binokulare Diplopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binokularstörung bei Fusion mit herabgesetztem Stereosehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binokularstörung bei Simultansehen ohne Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binokularstörung bei anomaler NH [Netzhaut]-Korrespondenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binswanger-Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binswanger-Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Binswanger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bioelektrischer Status epilepticus im Schlaf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biomechanische Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biomechanische Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biotinabhängiger Carboxylasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biotinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biphasische Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biphasisches Synovialsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biphasisches bösartiges Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolar-II-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Psychose bei gemischter Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Psychose bei schwerer depressiver Episode mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei hypomanischer Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei leichter depressiver Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei manischer Episode mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei manischer Episode ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei mittelgradiger depressiver Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bipolare affektive Störung bei schwerer depressive Episode ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Birch-Hirschfeld-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Birkenpollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bisalbuminämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bitemporale Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bitemporale Halbsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bitemporale Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bitot-Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bitot-Flecken beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizarres Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizeps-brevis-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizeps-longus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizepsrinnensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizepssehnenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bizepstendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Arthropoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Menschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Menschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Menschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Reptil a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Sandfloh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Skorpion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Tausendfüßler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch Trombicula-Larve',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch giftige Amphibie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch giftige Echse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch giftige Seeschlange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biß durch giftiges Meerestier a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Biörck-Thorson-Syndrom [Karzinoidsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bjerrumskotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blackfan-Diamond-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blackfan-Diamond-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blackout',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blackout',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blackwater fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bland-White-Garland-Syndrom [Koronararterienanomalie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blande Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blande Thrombose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Darm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Darm-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Darm-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Douglas-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Dünndarm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Mastdarm-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Mastdarm-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasen-Sigma-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenausgangsmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenausgangspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenauslaßobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenausschlag der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenbilharziose [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenbodenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenbodenzystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendistension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendivertikelstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasendrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenekstrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasengrundzystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsdeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalshypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalskongestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalskropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalssklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalstumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhalsödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhernie bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhernie beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blaseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blaseninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blaseninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkarzinom (Harnblase)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkarzinom in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkarzinom in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenprolaps bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenprolaps beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenscheitel-Nabel-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasensenkung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasensphinkterpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasensphinktersklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasensteinabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasensymptom/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasentenesmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasentrigonummetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasentuberkulose [kodiere zusätzlich N33.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenulkus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenverziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenvorfall bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenvorfall beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenwanddeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenwandfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenwandschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenwandtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenzellen-Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blasenzellnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastoma ependymale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomycosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomycosis queloidana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomykotische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastomykotische Meningomyelitis a.n.k. [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastzellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blastzellenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blattern - s.a. Pocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blau-Gelb-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blauer Jadassohn-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blauer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blaues Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blaues Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blausucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blausäureintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blausäurevergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleichsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleienzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleienzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleigicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleiintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleikolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleilähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleiminenarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleinephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleinephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleineuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleiparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleipolyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleipolyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleischrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleivergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blencke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blendung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Bubo durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Bubo durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Ophthalmie beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Ophthalmie beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhagische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blennorrhoische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bleomycinlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis angularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis bei Herpes [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis bei Rosazea [kodiere zusätzlich H03.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis bei Zoster [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis ciliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis granulomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis seborrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis squamosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharitis/Gerstenkorn/Hagelkorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharodermatochalasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharokonjunktivitis bei Rosazea [kodiere zusätzlich H13.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharophimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharophimose des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharophimose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharoptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blepharosynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blessig-Ivanoff-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blickbewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blickkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blickrichtungsnystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blind endender Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blind-loop-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blinddarmabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blinddarmentzündung - s.a. Appendizitis oder s.a. Wurmfortsatzentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blinddarmreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blinddarmruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blindheit durch Erschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blindheit durch Explosionsdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blindheit durch Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blindheit eines Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blinzeltic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blitz-Nick-Salaam-Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blitzkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blitzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bloch-Sulzberger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bloch-Sulzberger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockade eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung L5/S1',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der 1. Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Brust- und Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Hals- und Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Handwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Iliosakralfuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Kopfgelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Akromioklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Fibulaköpfchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Kreuz-Darmbein-Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Radiusköpfchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Sakroiliakalgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Tibiofibulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des Wirbelsäulensegments L5/S1',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung einer Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung eines Extremitätengelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung eines Fußwurzelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung eines Rippenwirbelgelenks [Articulatio costovertebralis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung eines zervikodorsalen Übergangswirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung im BWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung im HWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blockierung im LWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bloom-Machacek-Torre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blount-Barber-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blount-Barber-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blount-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blount-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blow-out-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blue Baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blue-diaper-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blut im Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blut im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blut im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blut-/Lymph-/Milzerkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutalkoholtest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutarmut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutaspiration beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdruckabfall durch Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdruckmessung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdrucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdrucktest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdruckuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutdruckverminderung bei traumatischem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutegelbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutende äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutender Sinus marginalis placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutendes Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutendes Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluterbrechen/Hämatemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutextravasation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfetterhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfettvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutflecken der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfleckenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutfülle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßreiches Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgerinnselembolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgerinnungsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgruppenantikörper der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutgruppenbestimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutharn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthochdruck mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthochdruck, komplizierter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthochdruck, unkomplizierter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bluthusten/Hämoptysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutiger Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutiges Sputum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutleere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutpfropfbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutplättchenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutplättchenverminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutschwamm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutspender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutspucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutsturz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutsymptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung ante partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung aus dem Tracheostoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung aus der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung bei Antikoagulanziendauertherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung bei Frühschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung bei septischem Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung beim Verkehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Fossa cranii posterior beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Fossa cranii posterior beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Sehnervscheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung der weiblichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung des Hodenparenchyms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung des Nierenhohlsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung des Tractus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung des visuellen Kortex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung einer Episiotomiewunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung einer Sektiowunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung einer Zahnalveole nach Extraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung im/ aus dem Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung in der Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung in der artifiziellen Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung nach Interruptio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung nach Lid-OP [Operation]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung vor Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung vor der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutung/Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutungsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutungsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutungsbereitschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutungsneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z34'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blutvolumenverringerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blähbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blähsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blähungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blähungslunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blähungsschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschen eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschenbronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschendrüsenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschendrüsentuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bläschenrickettsiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blässe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Blässe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boeck-Knochenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boeck-Lupoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boeck-Sarkoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boerhaave-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bogenförmiges Skotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bogengangfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bogenskotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bogenskotom des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bohnenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bolivianisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bone bruise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bone bruise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bonnaire-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bonnevie-Ullrich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bonnier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-lepromatöse Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-lepromatöser Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-tuberkuloide Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borderline-tuberkuloider Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borkenkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borkennase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borkige Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bornholmer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borreliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Borreliose durch Zeckenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boston-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Botryoidsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Botulinus-Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Arthrose der Fingermittelgelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Knoten mit Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Polyarthrose der Fingermittelgelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouchet-Gsell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouffée délirante',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouffée délirante mit Symptomen einer Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouffée délirante ohne Symptome einer Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouillaud-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouillaud-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bourneville-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bourneville-Phakomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bourneville-Pringle-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bourneville-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boutonneuse-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouveret-Hoffmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bouveret-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Darier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Darier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Epitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bowen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boxer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boyd-Bazilleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Boyd-Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialgia paraesthetica nocturna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexuskompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachialplexusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachydaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachydaktylie der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachydaktylie der Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachydaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachygenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachygnathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachymenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachyolmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachyzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachyzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brachyösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradley-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradyarrhythmia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradyarrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradykardie bei Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bradykardie, jeder Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchialknorpel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branching-Enzym-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogene Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogene Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogene Spalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogener Sinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogener Überrest des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogenes Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogenes Überbleibsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Branchiogenes Überbleibsel des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brand - s.a. Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brandt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brandverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brandwunde - s.a. Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brasilianische Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brasilianische Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brasilianische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brasilianischer Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brasilianisches Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brauer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Braune Herzmuskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bravais-Jackson-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bravais-Jackson-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Braxton-Hick-Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Breakbone fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechdurchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechdurchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechdurchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechdurchfall mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechungsfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechungshypermetropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechungshyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brechungsmyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Breda-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Breites Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Breites Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brenneman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brennen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brennen beim Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brennen beim Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brennen der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brenner-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brenztraubensäureschwachsinn [Fölling-Krankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Breus-Mole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bride',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bridenileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bright-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brill-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brill-Symmers-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brill-Symmers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brill-Zinsser-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brille Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brillenfehlrefraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brillenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Briquet-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Briquet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brittle diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Broad-beta-Lipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Broad-beta-disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Broca-Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brock-Graham-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brock-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brocq-Duhring-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brocq-Duhring-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brocq-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brocq-Parapsoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brocq-Pseudopelade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brodie-Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bromidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchial-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialallergose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiale Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiale Hyperreagibilität [Übererregbarkeit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiale Spätsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiale Spätsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiale Übererregbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialer Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialer Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialkarzinom des Oberlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialkarzinom des Unterlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiallues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiallues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchien-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchienverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolektasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolitis fibrosa obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolitis mit Bronchospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolo-alveoläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchiolo-alveoläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchioläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchioläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis bei Influenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis capillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis durch Spirochäten a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis durch protrahierte Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit Asthmaemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit Lungenblähung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit Lungenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis mit protrahiertem, nichtchronischem Verlauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis plastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis tuberculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis, chronische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchitis/Bronchiolitis, akute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoalveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoalveolärer intravaskulärer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoalveoläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoaspergillose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Broncholithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchomediastinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchomoniliasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchomykose a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopleurale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopleurale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopleuromediastinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie bei Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie durch Streptococcus pneumoniae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopneumonie durch Streptokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopulmonale Dysplasie perinatalen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopulmonale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopulmonale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopulmonale perinatale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchopulmonaler Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchospirochaetosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchospirochaetosis Castellani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchospirochätose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchotaxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchotracheale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoviszerale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchoösophageale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchus-Pleura-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuseinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuserosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuserweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuskalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuskarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuskontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchuspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchustuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronchusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronze-Baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronze-Baby-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronzediabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronzehautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bronzekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brooke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brooke-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brown-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brown-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brown-Séquard-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brown-Séquard-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brown-Séquard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brucella-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brucella-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruch einer Hüftgelenktotalendoprothese [TEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruchstelle eines Autosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruchvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruck-de Lange-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brugsch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brust-/Stillsymptom/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeindislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeindistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeinsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustbeschwerden im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenduktektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenentzündung außerhalb der Neugeborenenperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenentzündung außerhalb der Neugeborenenperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenentzündung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfibroadenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfibrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüseninvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenknoten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenknoten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusterkrankung während Schwangerschaft/Wochenbett, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustfellabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustfelladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustfelltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusthämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusthämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkorbprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkorbprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkorbprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkorbschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkorbtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustkrebs beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustmarkverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschmerz Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschmerz, der dem muskulären/knöchernen System zugeschrieben wird',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschmerzen bei Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustsymptome/-beschwerden Frau, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustsymptome/-beschwerden, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brusttuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwandverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenabszeß im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzeninversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzeninversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenrhagaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzenschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwarzensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwirbelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brustwirbelfraktur mit Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruton-Typ der Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruton-Typ des Antikörpermangelsyndroms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bruxismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brygmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brüchiger Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brüchigkeit der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Brückenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Haemophilus ducreyi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Haemophilus ducreyi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch Yersinia pestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch weichen Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo durch weichen Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bubo inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buchmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buchmann-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buckel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Budd-Chiari-Syndrom [Lebervenenverschlußsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buerger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buerger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bukkale Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbuserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusperforation mit Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusperforation mit Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusperforation ohne Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusperforation ohne Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusprellung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusprellung mit Orbitagewebeprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusruptur mit Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusruptur ohne Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusverbrennung mit Ruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbusverätzung mit Ruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbär-paralytische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Harnröhrenenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Harnröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Polioenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Urethralenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbäre Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulbärsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulimia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulimie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulimie mit Normalgewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulla acantholytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bulla rodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Keratopathie durch Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Sommerdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöser Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöses Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bullöses kongenitales ichthyosiformes Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buntes Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bunyamwera-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buphthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burdwan-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burkitt-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burkitt-Zell-Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burn-out-Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burnett-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burning-feet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burns-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Burns-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursagonorrhoe [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursagonorrhoe [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursatuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis achillea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis bei Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis calcanea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis calcarea im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis calcarea supraspinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis der Achillessehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis der Hüfte a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis der Os ischii-Region',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis des Fersenbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis des Knies a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis durch Beanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis durch Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis durch Gonokokken [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis durch Gonokokken [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis durch Überbeanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis gonorrhoica [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis gonorrhoica [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis im Bereich des Ligamentum collaterale tibiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis im Handbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis infrapatellaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis semimembranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis subachillea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis subacromialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis subcoracoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis subdeltoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis syphilitica [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis syphilitica [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bursitis/Tendinitis/Synovitis ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buruli-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bury-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buschfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Buschke-Ollendorff-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Busse-Buschke-Krankheit [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bwamba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bwamba-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Byler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Byssinose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bywaters-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bársony-Polgár-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bäckerasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bäckerekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bäckerkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderdehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderdehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderschwäche des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänderzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bänglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bärensprung-Krankheit [Erythrasma]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bärensprung-Zwergflechte [Erythrasma]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Blasenneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Geschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Hepatitis mit Leberversagen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Hyperpyrexie durch Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Kalixneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Lentigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Lippenneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Lymphknotenneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Lymphogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Malaria tertiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Mastozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Nesidioblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Atemwege, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Colon/Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Lunge/Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Nervensystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung an Harnleiter oder Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Alveolarmukosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ampulla Vateri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ampulla hepatopancreatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ampulla recti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Augenlidweichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Axilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Axillaweichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Baucheingeweide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bauchspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bauchwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bauhin-Klappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bläschendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Bronchien und der Lunge, mehrere Teilbereiche überlappend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Carina tracheae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Cauda pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Cellulae mastoideae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Cervix urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Cervix vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Columna vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Conchae nasales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Dammweichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Dorsalfläche der Zungenbasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Faszie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Flexura coli dextra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Flexura coli hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Flexura coli lienalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Flexura coli sinistra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Fossa piriformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Gallengänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Gaumentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Gesäßweichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Gingiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula parathyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula pituitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula submaxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula suprarenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Glandula vestibularis major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Harnleitermündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Harnwege, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut der Schläfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Haut des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Highmore-Höhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Hirnhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Hypopharynxwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ileozäkalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Karotisdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Keilbeinhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Kieferhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Klavikula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Knochen der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Langerhans-Inseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ligamente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenrotgrenze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenrotgrenze der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenrotgrenze der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Lippenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Luftröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mandibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mundhöhlenseite der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mundhöhlenseite der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mundhöhlenseite einer Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Muskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nasenmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nasopharynxwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nervi olfactorii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Nierenbeckenkelche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Oberkieferalveolarmukosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Oberkiefergingiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Oberlippenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ohrweichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Papilla Vateri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Paraganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Paukenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Penishaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Pleura parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Pleura pulmonalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Plica aryepiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Plica glosso-epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Plica vestibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Rachentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Randzone der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Rosenmüller-Grube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Samenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Scheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Schlundtonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Schweißdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Sehnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Sehnenscheiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Siebbeinhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Skrotalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Stirnhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Talgdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Trachea/des Bronchus/der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Ulna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterkieferalveolarmukosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterkiefergingiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterkieferspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterlippenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Unterzungendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Uterusadnexe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Uterusbänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Verbindungszone des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Vorhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Vulvahaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wangenseite der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wangenseite der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wangenseite einer Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wangenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Weichteile in Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Zungenmandel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Zungenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Zungenwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der anterioren nasopharyngealen Fläche des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der dorsalen Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der großen Magenkurvatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der hinteren Epiglottisfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der hinteren Rachenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der inneren Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der inneren Wange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der intra- und extrahepatischen Gallengänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der kleinen Magenkurvatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der laryngealen Epiglottisfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der laryngealen Seite der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der nasopharyngealen Fläche des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der oberen Lippenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der oberen Wangenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der posterioren nasopharyngealen Fläche des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der seitlichen Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der unteren Lippenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der unteren Wangenumschlagsfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der vorderen zwei Drittel der Dorsalfläche der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der vorderen zwei Drittel der Ventralfläche der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der Übergangsregion des Oropharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung der äußeren weiblichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Alveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Analrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Anorektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Antrum maxillare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Apex vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Augenlidbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Axillabindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bauches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bauchfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Beckenknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Beckenperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der Lungen-Thorax-Region im Kindesalter [Askin-Tumor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Hypochondriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bindegewebes des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Blasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Blasenscheitels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Brustbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Brustdrüsenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Brustdrüsenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Brustfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Bulbus olfactorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Canalis pyloricus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Caput pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Choanenhinterrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus cavernosum penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus ciliare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus pineale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Dammbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Dammes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Dickdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ductus hepaticus communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ductus nasolacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Epithelkörperchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Fettgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Frenulums der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Frenulums der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Frenulums einer Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gallensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gastrointestinaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gaumenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Gesichtsknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Großhirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Harnblasenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Harnsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Hirnventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Hoden bei Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Humerus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des IV. Ventrikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Innenohrs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kehlkopfknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kleinhirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Knochens mit Knorpel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Knorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kolons und Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Kreuzbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ligamentum rotundum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ligamentum vocale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lippenrots',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lippenrots der Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lippenrots der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lobus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lobus temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lungenhilus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lungenmittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lungenoberlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Lungenunterlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Magen-Darm-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Magenvorhofs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mastdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Meckel-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mediastinum anterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mediastinum posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mediastinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mesokolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mundrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Mundwinkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasenbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Naseninnenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasenknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasenseptumhinterrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasopharynxbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nasopharynxdaches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nebenhodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nervus vestibulocochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nierenbecken-Ureter-Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Nierenkelches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Oberkieferalveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ohrbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ostium cardiacum des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Pankreashalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Perikards',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Peritoneum parietale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Peritoneum viscerale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Peritoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Präputiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Präpylorus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Pudendum femininum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Querkolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Radius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Recessus axillaris der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Recessus axillaris der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Recessus pharyngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Rektosigmoids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Respirationstraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Schlüsselbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Schulterblattes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Schädelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sigmas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sinus ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sinus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sinus maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sinus sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Speiseröhren-Magen-Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sphincter ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Steißbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Sternums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Taschenbandes [falsches Stimmband]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Trigonum vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Tränenkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Tränensacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Unterkieferalveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Unterkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ventriculus laryngis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Verdauungskanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Verdauungstraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Vestibulum laryngis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Vestibulum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Waldeyer-Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Wolff-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Wolff-Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zentrums der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zentrums der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zungenrandes und der Zungenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zwerchfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Zwölffingerdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des anorektalen Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des echten Stimmbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des fixierten Zungenteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des freien Randes der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des hinteren Drittels der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des hinteren Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des hinteren Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des inneren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des intrahepatischen Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des kraniopharyngealen Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des mittleren Zungendrittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des männlichen Urogenitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen inneren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen inneren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen äußeren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des oberen äußeren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des pharyngealen Tubenostiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des postkrikoidalen Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des retrobulbären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des retrookulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des seitlichen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des seitlichen Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des seitlichen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des suprahyoidalen Anteils der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren Uterinsegments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren inneren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren inneren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren äußeren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des unteren äußeren Quadranten der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des vorderen Kehldeckels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des vorderen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des vorderen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des vorderen Teils des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des weiblichen Genitales, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des weiblichen Urogenitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des Überganges vom Rektum zum Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung des ösophagogastrischen Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer Bursa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer Synovialmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer branchiogenen Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer endokrinen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer großen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung einer kleinen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines Ovidukts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines Verdauungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines deszendierten Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines ektopischen Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines extraokulären Muskels in der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines retinierten Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung eines skrotalen Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung großer Gefäße des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung männliches Genitale, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung parasympathischer Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung parasympathischer Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung pektoraler Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung peripherer Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung peripherer Nerven der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung supraklavikulärer Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung sympathischer Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung sympathischer Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung unbekannter Primärlokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung verbunden mit Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung von Blutgefäßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung von Lymphgefäßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildung, muskuloskelettär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildungen an Adnexen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildungen der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildungen des Verdauungssystems, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neubildungmalignancy von Larynx/Mediastinum/Nase/Pharynx/Pleura/Sinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Veränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Zungenneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige Zungenneubildung des beweglichen Zungenteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige anorektale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige infratentorielle Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige intrathorakale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige rektovaginale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige rektovesikale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige supratentorielle Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige thorakale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige tuboovariale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartige uteroovariale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Bindehauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Gehirntumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Hirntumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Plasmazelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Plasmazelltumor in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Polyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Stammganglientumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Triton-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Tränendrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Tumor des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger Weichteiltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiger embryonaler Lebermischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Adamantinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Akanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Ameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Androblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Androblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Angiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Argentaffinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Arrhenoblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Arrhenoblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Chondroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Fibroxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Gangliozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Großhirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Hämangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Hämangioperizytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Insulinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Karzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Kleinhirnbrückenwinkelchordom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Kleinhirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Lymphangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Mastozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Mesenchymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Mesonephrom - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Myom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Nesidioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Neurilemmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Osteoklastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Pilomatrixom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Schwannom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Synovialom - s.a. Neubildung, Bindegewebe, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Thekom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Thymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges akrolentiginöses Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges granularzelliges Myoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges mediofaziales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges schleimbildendes Karzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bösartiges Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bürger-Grütz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bürger-Grütz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Bürstenschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C-Trigonozephalie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C-Zell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C-Zellen-Hyperplasie der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C1-Esterase-Inhibitor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C1-INH-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C7-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'C8-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CF [Fibrosis cystica] - s.a. Zystische Fibrose oder s.a. Cystische Fibrose oder s.a. Mukoviszidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CFS [Chronic fatigue syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CHARGE-Syndrom [CHARGE-Assoziation] [Fehlbildungskomplex mit Kolobom, Herzfehler, Choanalatresie, psychomotorischer Retardierung, Genitalhypoplasie und Ohranomalie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CIHK [Chronische ischämische Herzkrankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CLL [Chronische lymphatische Leukämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CLL [Chronische lymphatische Leukämie] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CML [Chronische myeloische Leukämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CML [Chronische myeloische Leukämie] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CNV [Contingent negative variation] bei Glaskörperblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CNV [Contingent negative variation] bei Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'COB [Chronisch-obstruktive Bronchitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'COFS-Syndrom [Cerebro-oculo-facio-sceletal syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'COLD [Chronic obstructive lung disease]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'COPD [Chronic obstructive pulmonal disease]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'COPE [Chronische obstruktive Pulmonalerkrankung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CP [Zerebralparese]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CREST-Syndrom [Spezialform der progressiven systemischen Sklerose mit Calcinosis cutis, Raynaud-Phänomen, Ösophagusdysfunktion, Sklerodaktylie und Teleangiektasie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CTG [Kardiotokogramm]-Auffälligkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CVAgamma - s.a. Common variable Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CVI [Chronisch-venöse Insuffizienz]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CVI [Zerebrovaskuläre Insuffizienz]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'CVI [Zerebrovaskuläre Insuffizienz] mit Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cacchi-Ricci-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia - s.a. Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia hypopituitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia pituitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia saturnina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia splenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cachexia strumipriva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caecum mobile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caffey-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caffey-Silverman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caisson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caisson-Krankheit mit Arthritis [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calciferolmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calcinosis - s.a. Kalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calcinosis circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calcinosis interstitialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'California-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Callositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvities',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvé-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvé-Legg-Perthes-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvé-Legg-Perthes-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvé-Legg-Perthes-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Calvé-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Campylobacter-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Camurati-Engelmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Camurati-Engelmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Canaliculitis lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Canalis atrioventricularis communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Canavan-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancer aquaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancer en cuirasse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancer en cuirasse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancer xanthosus [Chlorom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancer xanthosus [Chlorom] in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cancrum oris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Balanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Balanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Balanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Kolpitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Meningitis [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Mykid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Pneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Pyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Pyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Pyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Urethritis [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Urethritis [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Urethritis [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Vaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Vulvitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Vulvovaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candida-Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candidiasis der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candidid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Candidosis - s.a. Kandidose oder s.a. Candidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Canities',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cannabinoidintoxikation bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cannabinosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cannabisabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cannabismißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cannabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cantrell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Capgras-Syndrom [Wahnsyndrom mit Personenverkennung im Sinne der Doppelgänger-Illusion]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Capillaritis alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caplan-Colinet-Syndrom [kodiere zusätzlich J99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Capsulitis - s. Kapsulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caput medusae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caput obstipum sive distortum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caput succedaneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carate - s.a. Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carbunculus - s.a. Karbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma - s.a. Karzinom oder s.a. Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma adenomatosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma basocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma hepatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma hepatocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma hepatocholangiocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Ampulla Vateri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Ampulla hepatopancreatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Anushaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Brustdrüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Epidermis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Achselfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Bauchwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Gesäßbacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Leistenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des Dammes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Haut des äußeren Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Kopfschwarte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Lidhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Lippenrotgrenze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Nasenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Nasenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Nebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Randzone der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der hypopharyngealen Seite der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ der laryngealen Seite der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Analrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Dickdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Gallensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Kanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Milchganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Oropharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Ureters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des rektosigmoidalen Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des suprahyoidalen Anteils der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ des Übergangsepithels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ einer endokrinen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma in situ in Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma planocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma platycellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma sebaceum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma spino-basocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma spinocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma-in-situ der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinoma-in-situ der weiblichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinophobia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinosis peritonei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carcinosis pleurae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cardiomegalia glycogenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cardiomegalia glycogenica diffusa [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cardiomyopathia - s.a. Kardiomyopathie [CMP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cardiopathia nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carducci-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caries - s.a. Karies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caries dentum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carnitinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caro luxurians',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caroli-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carpaltunnelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carpenter-Syndrom [Form des Akrozephalopolysyndaktylie-Syndroms]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Carrión-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caruncula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Caruncula vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cassidy-Scholte-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Castellani-Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Castleman-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Castleman-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Castleman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Castleman-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta brunescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta caerulea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta centralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta congenita mit Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta congenita mit Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta congenita polaris anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta congenita polaris posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta congenita totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta coralliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta coronaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta corticalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta corticonuclearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta corticonuclearis et capsularis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta corticonuclearis et subcapsularis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta corticonuclearis provecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta diabetica [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta electrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta immatura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta incipiens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta intumescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta matura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta myotonica [kodiere zusätzlich H28.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta nuclearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta perinuclearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta polaris anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta polaris posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta praematura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta provecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta pulverulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta pyramidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis brunescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis coronaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis corticalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis hypermatura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis intumescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis matura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis nuclearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis provecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis subcapsularis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis subcapsularis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis subcapsularis provecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta senilis vom Morgagni-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cataracta zonularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Catarrhus aestivus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cauda-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cavare-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cavernitis - s.a. Kavernitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cavernoma capillare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cazenave-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cecile-Vogt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ceelen-Gellerstedt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cellulitis - s.a. Zellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cementoblastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cementoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cementoma gingantoforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Central-core-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalaea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalaea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalaea vasomotorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalgia - s. Kephalgie oder s. Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalgia - s. Kephalgie oder s. Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cephalgia nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cerclage bei Zervixinsuffizienz während der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cercomoniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cerebro-oculo-facio-skeletal-Syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cerebropathia psychica toxaemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cerumen obturans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicalgia - s.a. Zervikalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicalsyndrom - s.a. Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicitis - s.a. Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicitis gonorrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicitis gonorrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicitis subacuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicobrachialgia - s.a. Zervikobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicocephalgia - s.a. Zervikozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicocolpitis emphysematosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cervicothoracic-outlet-Syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cestan-Chenais-Paralyse [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cestan-Chenais-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chagas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chagas-Krankheit mit Myokarditis [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chagas-Krankheit mit kardiovaskulärer Beteiligung [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chagas-Krankheit ohne Organbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chagas-Myokardiopathie [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalcosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalcosis bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalcosis corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalcosis lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chalkose der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chandipura-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chandler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Changuinola-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chappa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charakteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charakterneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charakterstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Gelenk [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Gelenk [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Gelenksyphilis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Gelenksyphilis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Krankheit bei Syringomyelie [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Marie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Marie-Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Marie-Tooth-Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Marie-Tooth-Hoffmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Marie-Tooth-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Weiss-Baker-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charcot-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Charente-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chassaignac-Lähmung [Subluxatio radii per anularis des Kleinkindes] [Pronatio dolorosa des Kleinkindes]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chauffard-Still-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheadle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Check up',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Check up beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chediak-Steinbrinck-Higashi-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chediak-Steinbrinck-Higashi-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chediak-Steinbrinck-Higashi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilitis actinica solare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilitis angularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilitis exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilognathopalatoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilognathoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheiloschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilosis bei Pellagra [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheilosis bei Vitamin-B2-Mangel [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheiropompholyx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheirospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemikalienallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemische Verätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemodektom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemoprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie bei Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie bei Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie mit Erhaltungsdosis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapie-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chemotherapiesitzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cherubinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cherubismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheyne-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheyne-Stokes-Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cheyne-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiari-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiari-Netzwerk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiasmaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiasmakompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiasmakompression durch Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiasmakompression durch Hypophysenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiasmasyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chicago-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiclero-Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chignon-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chikungunya-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chilaiditi-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chilaiditi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chilomastigiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chimäre 46,XX/46,XY mit Hermaphroditismus verus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chinesische Leberegel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chininintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chiragra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chirotherapeutisch angehbare Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chirotherapeutisch behandelbare Gelenkblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chirurgisch bedingte Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chirurgisch sanierungsbedürftiges Gebiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chirurgische Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chitral-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chladotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Infektion der Harn- und Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Infektion des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Infektion des kleinen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Infektion des unteren Genitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydien-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydieninfektion weibliches Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydienurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlamydiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma cachecticorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma hormonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma medicamentosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma symptomaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloasma virginum periorale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlormadinonacetat-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloroformintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloroformvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlorom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlorom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chloropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlorose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chlorotische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choanalfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choanalpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholaemia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholaemia familiaris simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiohepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiohepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiohepatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiokarzinom der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiolitische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangiozelluläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangitis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholangitischer Leberabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochoduodenale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledocholith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledocholithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledocholithiasis des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledocholithiasis mit akuter Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochuseinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusspasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choledochusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis des Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis mit Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis mit akuter Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholelithiasis mit festsitzendem Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholepathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choleperitoneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choleperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera asiatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera durch Vibrio cholerae O:1',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholera-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choleraartige Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholestase mit Leberzellschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholestatische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholestatische Hepatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom bei chronischer epitympanaler Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom des Cavum tympani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom des Warzenfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatom mit Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesteatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterin-Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinablagerung im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinablagerung in der Galle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinablagerung in der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinkalkstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinlipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinpartikel in der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinpigmentstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinpneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystitis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystitis/Cholelithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystocholedocholithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystoduodenalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystolithiasis mit akuter Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholezystopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholostase a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cholämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondritis der Rippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrocalcinosis - s.a. Chondrokalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrocalcinosis articularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodermatitis der Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodermatitis nodularis chronica helicis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodermatitis nodularis helicis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasia calcificans congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasia fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasia punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasia-punctata-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasie mit Angiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodysplasie mit Hämangiomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophia calcarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophia calcificans congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophia myotonica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophia punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophische Myotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophischer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrodystrophischer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrogenesis imperfecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroides Syringom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrokalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrokalzinose-Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrokostale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromalacia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromalazie 2. Grades des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromatöser riesenzelliger Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromyxofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromyxoides Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromyxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondromyxosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroosteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroosteodystrophie Typ Morquio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroosteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondropathia patellae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondropathia tuberosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondropathie des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroplastisches Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondroplastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrosis intervertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrosis intervertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrosis intervertebralis cervicalis [Zervikalchondrose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chondrosternale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chopart-Gelenk-Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorditis fibrinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorditis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorditis tuberosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chordom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea Huntington mit Demenz [kodiere zusätzlich F02.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea Sydenham',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea Sydenham',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea chronica progressiva hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea gravis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea infectiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea minor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea minor mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorea simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choreatische Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choreoathetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioadenoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioadenoma destruens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioamnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioidalplexuspapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioidealymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioidearuptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideasklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideatuberkulose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioideremie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioiditis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioidpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choriokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choriomeningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionabnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionadenoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionadenoma destruens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionamnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioncarcinoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionepitheliommetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionepitheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionepitheliosis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionkarzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Choriontumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorionzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinale Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinale Narbe nach Ablatio-OP [Operation]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinale Narbe nach chirurgischem Eingriff wegen Ablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis bei Histoplasmose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis bei Spätsyphilis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis bei Spätsyphilis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis bei Toxoplasmose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis centralis serosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis durch Toxoplasmen [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinitis juxtapapillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinopathia centralis serosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chorioretinopathie mit Birdshots',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Christ-Siemens-Touraine-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Christbaumschmuck-Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Christian-Weber-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Christmas Disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Christmas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromatvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromoblastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromomykose des Gehirns [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromomykotischer Gehirnabszeß [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromophobes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromophobes Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromophobes Hypophysenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromophobes Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromophytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromoproteinniere [Hämoglobinurische Nephrose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomale Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomale Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenabnormität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenanomalie in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenanomalie in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenanomalie in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomenduplikation, Prometaphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomeninversion beim normalen Individuum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chromosomentranslokation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronic fatigue syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronifizierte Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch entzündliche Darmerkrankungen/Colitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch erosive Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch fibröse Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch interstitielle Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch interstitielle Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch lymphoproliferatives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch lymphozytäre Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch obstruktive Lungenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch persistierende Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch rezidivierende Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch rezidivierende Soorkolpitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch rezidivierendes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-bullöse Dermatose beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-bullöse Krankheit beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-entzündlicher ZNS-Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-hyperplastische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Atemwegskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Bronchitis mit akuter Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Bronchitis mit akuter Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Emphysembronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Lungenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Lungenerkrankung mit akuter Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Tracheobronchitis mit Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktive Tracheobronchitis mit akuter Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-obstruktives Bronchialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-rezidivierende Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-rezidivierende Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-spastische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-venöse Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-venöse Insuffizienz des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-venöse periphere Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-venöser Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisch-venöser Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Abstoßung eines Hornhauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Adenitis mesenterialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Adenoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Akroasphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Alkoholsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Angina tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Angstneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Antrumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Antrumgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Anämie durch Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Anämie nach Blutverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Arzneimittelinduzierte interstitielle Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ateminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Atemwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Atemwegskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Balanoposthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Beckenbindegewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Beckenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blastomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Blinddarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bronchiorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bronchitis obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bronchitis putrida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Brustdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit Beteiligung des Nervensystems [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit Beteiligung des Verdauungssystems [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit Herzbeteiligung [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit Kardiomyopathie [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit Myokarditis [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chagas-Krankheit mit kardiovaskulärer Beteiligung [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Cluster-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Colitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dakryoadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dakryoperizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dentalfluorose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dermatomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dermatosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dorsolumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eierstockentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eierstocktuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eileiter-Eierstock-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eileitertuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eisenmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eiterung der Nasenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Eiterung der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Emphysembronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Emphysembronchitis mit akuter Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Emphysembronchitis mit akuter Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endokardkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endomyometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Endozervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enteritis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enterocolitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Entzündung aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Entzündung der Mastoidhöhle nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ependymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Epicondylitis humeri radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Epicondylitis lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Epicondylitis radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Epiglottitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Erythrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Erythrose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Erythrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Felsenbeinentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Felsenbeinostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Funikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Furunkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Galle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gallenblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gastroduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gastroenteritis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gaumenmandelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gebärmutterhalsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der oberen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der oberen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der oberen Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der oberen Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der unteren Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der unteren Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der unteren Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Gonorrhoe der unteren Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Graft-versus-host-Krankheit, ausgeprägte Form',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Graft-versus-host-Krankheit, begrenzte Form',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Granulomatose im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Halsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Harnwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hepatitis B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hepatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzgefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Herzmuskelinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Histiocytosis X',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Histoplasmose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hornhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hypertrophie der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ileitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ileitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ileocolitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Infektion aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Infektion der Sinus paranasales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Instabilität des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Inversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ischialgie nach Bandscheibenoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kanalikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Karies des Processus mastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kehlkopfentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Keilbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Keilbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Keratokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kokzidioidomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolpitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolpitis durch Kokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kolpitis durch Leptothrixbakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Konjunktivitis durch Staphylococcus aureus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Koronarinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Krankheit des Epitympanums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Kälteagglutininkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Laryngitis durch äußere Wirkstoffe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Laryngitis mit Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Laryngopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Laryngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leberdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leberentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leistendrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leptothrix-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leukämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Libidostörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lumbago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lumboischialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lumboischialgie bei Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lumboischialgie bei Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenfibrose durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenfibrose durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenfibrose durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenfibrose durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lungenzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Lymphdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mandelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mastodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mediastinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Metatarsalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Miliartuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Milzkapselentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mitralklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Monozytenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Mukozele des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myelose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myokardinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Myoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhlenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhlenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhlenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasennebenhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasenrachenraumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nasopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nebenhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Nierenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Niereninsuffizienz, Stadium V',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Obstipation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Orbitaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Orbitamyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Osteomyelitis mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Osteoradionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis media epitympanalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis media mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis media mit nichteitrigem Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otitis mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Otorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ovariitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pankarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Parametritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Perikardkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Perikoronitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Perimetritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Periodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Perisalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Phlegmone a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Photodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pigmentpurpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pneumopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polyarthritis mit Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polyarthritis mit Lungenmanifestation [kodiere zusätzlich J99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polyarthritis mit Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polychondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Portioektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Portioerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Portiotransformationszone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Proktitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Prostatafibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Prostatastauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Puerperalpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pulmonalklappenendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pulpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyelonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Pyosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Quadriplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rachenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rachenmandelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Raucherbronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rectosigmoiditis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinoallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinopharyngitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinopharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Rhinosinusitis mit Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Salpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schizophrenie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Seitenstrangangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sepsis durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sialadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Siebbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Siebbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Siebbeinhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Siebbeinzelleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinupharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinuseiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sinusitis maxillaris et ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sonnendermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Sphenoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Steatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Stirnhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Stirnhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Stirnhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Strahlendermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Synovitis crepitans der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Synovitis crepitans des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tonsillenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tonsillenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tonsillensepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tracheainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tracheitis mit Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tracheopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Trommelfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Trunkenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Trunksucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tubenmittelohrkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tuberkulose der Tuba uterina [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tuboovarialentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Tympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ulzeration Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Urethritis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Urethritis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Uterusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vergrößerung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vibrionen-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vorsteherdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Warzenfortsatzkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Warzenfortsatzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Warzenfortsatznekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Wochenbettpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zahnfleischentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zervikalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zervikobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zervikozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zyklusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zystenbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Zystopyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische aggressive Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische aktive Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische alkoholische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische alkoholische Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische allergische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische arteriosklerotische Aortenklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische arteriosklerotische Herzklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische arteriosklerotische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische arteriosklerotische Nephritis mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische arteriosklerotische Pulmonalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische asthmatische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische asthmatische Bronchitis mit akuter Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische asthmatische Bronchitis mit akuter Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische atrophische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische atrophische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische atrophische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische bakterielle Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische bakterielle Vaginose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische bakterielle Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische blennorrhagische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische blennorrhagische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische chemische Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische diffuse Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische einfache Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische eitrige Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische eitrige Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische eitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische eitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische eitrige Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische emphysematöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische emphysematöse Bronchitis mit akuter Exazerbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische emphysematöse Bronchitis mit akuter Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische endemische Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische epitympanale Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische essentielle Thrombopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische exsudative Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische exsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische familiäre Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibroide Lungenverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibroide Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibröse Lungeninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibröse Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibröse Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische fibröse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische follikuläre Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gelbe Leberatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische generalisierte zerebrale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granulomatöse Krankheit in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granulomatöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granulozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granulozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granuläre Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische granulöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische halluzinatorische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hyperplastische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hypertonische ischämische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hypertrophische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hypertrophische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische hämorrhagische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische idiopathische Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische idiopathische hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische infektiöse Bronchorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische interstitielle Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische interstitielle Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische interstitielle Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische interstitielle Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ischämische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ischämische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ischämische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ischämische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische kardiale Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische kardiale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische kardiopulmonale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische kardiorenale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische katarrhalische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische katarrhalische Tubotympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische koronare Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische lichenoide Pityriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische lymphatische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische lymphozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische lymphozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische membranöse Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische membranöse proliferierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische mesenteriale Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische mesotympanale Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische mesotympanale eitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische muköse Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische multifokale Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische multiple Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische myeloische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische myokardiale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische nichteitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische nichteitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische nichteitrige destruktive Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische nichtrheumatische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obliterierende Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obliterierende Bronchiolitis durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obliterierende Bronchiolitis durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obliterierende Bronchiolitis durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obliterierende Bronchiolitis durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obstruktive Lungenkrankheit mit akuter Exazerbation und mit FEV1 < 35% des Sollwertes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obstruktive Lungenkrankheit mit akuter Exazerbation und mit FEV1 >= 35% und < 50% des Sollwertes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obstruktive Lungenkrankheit mit akuter Exazerbation und mit FEV1 >= 50% des Sollwertes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische obstruktive Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische organische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische paranoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische paroxysmale Hemikranie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische passive Leberstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische posthämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische postrheumatische Arthritis [Jaccoud-Arthritis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische postrheumatische Arthropathie [Jaccoud-Arthropathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische posttraumatische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische progrediente Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische proliferative Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische proliferierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische proliferierende Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische pulmonale Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische pulmonale Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische purulente Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische purulente Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rekurrierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische respiratorische Affektion durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische respiratorische Affektion durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische respiratorische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische respiratorische Insuffizienz nach Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische respiratorische Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rezidivierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Aortenklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Entzündung der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzbeutelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzbeutelverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzbeutelverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Herzmuskelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Insuffizienz der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Krankheit der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Mediastinoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Mitralklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Myoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Sklerose der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Stenose der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische rheumatische Valvulitis mit Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische schleimige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische sekretorische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische senile Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische seromuköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische seröse Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische sezernierende Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische sklerosierende Mitralklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische superfiziale Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische transsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische traumatische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische traumatische Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische traumatische Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische tuberkulöse Arthritis [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische tuberkulöse Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ulzeröse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ulzeröse Proktosigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ulzeröse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unbeeinflußbare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unbeeinflußbare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unbeeinflußbare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unbeeinflußbare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unbeeinflußbare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische undifferenzierte Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unregelmäßige Zwischenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische unspezifische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zerebrale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zerebrovaskuläre DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zerebrovaskuläre Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zirrhotische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zystische Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische zystische Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische Überlastungsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ödematöse subglottische Enge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronische ödematöse subglottische Verengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Abszeß des Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Abszeß des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Abszeß des Parametriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Alkoholabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Bromismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Bromismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Bronchialkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Douglasabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Duodenalileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Eierstockabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Eileiterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Erschöpfungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Erschöpfungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Kalkmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Kehlkopfkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Keilbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Kieferhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Leberschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Lupus erythematodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Mittelohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Morbus Bleuler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Nasenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Nasenrachenraumkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Nebenhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Nikotinabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Ovarialabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Rachenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Rhinopharyngealkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Rotz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schmerzpatient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schmerzpatient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schmerzpatient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schmerzpatient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schmerzpatient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Schnupfen beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Sexualkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Siebbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Stirnhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Tubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Tubenmittelohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Tubotympanalkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Uterusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Vaginismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Verschluß der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Wärmeschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer benigner familiärer Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer nichtpuerperaler Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer nichtpuerperaler Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer parauteriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer periuteriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer rheumatischer Aortenklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer rheumatischer Fehler der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer rheumatischer Mitralklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer tuboovarialer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer ulzerierender Mittelohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronischer Äthylismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Antrumempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Emphysem durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Emphysem durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Emphysem durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Emphysem durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Geschwür des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Geschwür des Corpus penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches HWS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches HWS-Syndrom mit Brachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Hautgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Keilbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Kieferhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Lungenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Lungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Magengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Müdigkeitssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Nasennebenhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Penisgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Postmenopausensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Potatorium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Siebbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Sinubronchialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Sinusempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Stirnhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus duodeni mit Blutung und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus duodeni mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus duodeni mit Hämorrhagie und Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus pepticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus pepticum mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulkus des Corpus cavernosum penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Ulkus mit Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Zahnfleischgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Zahngranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches alkoholisches organisches Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches figuriertes Erythem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches gastrojejunales Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches gastrojejunales Ulkus mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches gastrojejunales Ulkus mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches kardiorenales Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches kardiovaskuläres Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches nephritisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches primäres Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches rheumatisches Aortenklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches rheumatisches Mitralklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches rheumatisches Vitium der Mitral- und Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chronisches subdurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chrysops-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Churg-Strauss-Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Churg-Strauss-Syndrom [Allergische granulomatöse Angiitis] [Allergisch bedingte systemische granulomatös-nekrotisierende Vaskulitis [Arteriitis]] [Allergische Granulomatose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chyloperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylothorax durch Filarien [kodiere zusätzlich J91*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylothorax, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylozele der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylozele der Tunica vaginalis testis durch Filarien [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylozele durch Filarien [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylozele, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie bei Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie bei Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie durch Bilharzia haematobia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie durch Brugia malayi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylurie, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylusartiger Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylusartiger Pleuraerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chyluszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylöse Arthritis durch Filarien [kodiere zusätzlich M01.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylöser Aszites, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylöser Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylöser Hydrothorax, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Chylöser Pleuraerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cicatrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cicatrix hypertrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cipriani-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Circumcision',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cirrhose cardiaque',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cirrhosis - s.a. Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cirrhosis hepatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cirrhosis renis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Civatte-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Civatte-Poikilodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cladosporiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clarke-Hadfield-Syndrom [Mukoviszidose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clastothrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claude-Bernard-Horner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claude-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claudicatio intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claudicatio intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claudicatio spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Claustrophobia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clavus - s.a. Klavus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clifford-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Climacterium praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Climacterium tardum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Climacterium-virile-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Climax virile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cloaca persistens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clomifentest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clonorchiasis der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clonus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clonus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clouston-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cluster headache [Bing-Horton-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cluster-Kopfschmerz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cluster-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clusterkopfschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Hydrarthrose [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Hydrarthrose [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Krankheit [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Krankheit [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Syndrom [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Clutton-Syndrom [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coarctatio aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coats-Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coats-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cobalaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coccidioidmycosis pulmonalis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coccidiosis - s.a. Kokzidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coccygodynia - s.a. Kokzygodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cochinchina-Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cochinchina-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cochleadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cochrane-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cockayne-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Codman-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coecum mobile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coeliacia - s.a. Zöliakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coenurosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coeruloplasminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coffin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cogan-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cogan-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cogan-Reese-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coilonychia - s.a. Koilonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coli-Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica - s.a. Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica flatulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica mucomembranosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica mucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica saturnina a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica spastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colica verminosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis - s.a. Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis - s.a. Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis chronica purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis cystica superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis granulomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis granulomatosa regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis gravis regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis mucosa membranosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis polyposa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis pseudomembranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colles-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Collet-Sicard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Collum obstipum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coloboma - s.a. Kolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colon irritabile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colon irritabile mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colon irritabile ohne Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Colpitis - s.a. Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma acidoticum bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma acidoticum bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma acidoticum bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma apoplecticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma cardiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma cerebrale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma diabeticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma diabeticum bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma diabeticum bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma eclampticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma epilepticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma hepaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma hyperglycaemicum diabeticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma hyperglycaemicum diabeticum bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma hyperglycaemicum diabeticum bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma hypoglycaemicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coma uraemicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Combat fatigue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Comedo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Common variable Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Common variable immunodeficiency',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Common-Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Commotio cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Commotio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Commotio spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Commotio-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Compound-Naevus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Concretio cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Concretio pericardii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Concretio praeputii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condyloma - s.a. Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condyloma - s.a. Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condyloma latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condyloma latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata lata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata lata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Condylomata vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Congelatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conglutinatio praeputii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis - s.a. Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis aestivalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis allergica acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis allergica chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis blennorrhoica neonatorum [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis blennorrhoica neonatorum [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis diphtherica [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis epidemica [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis follicularis acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis follicularis acuta durch Adenoviren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis follicularis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis follicularis trachomatosa [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis granulosa [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis granulosa trachomatosa [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis haemorrhagica acuta [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis haemorrhagica epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis nodosa acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis nodosa chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis petrificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis phlyktaenulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis sicca im Sinne des Sjögren-Syndroms [kodiere zusätzlich H13.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis sicca im Sinne des Syndroms des trockenen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis trachomatosa [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis tuberculosa [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conjunctivitis vernalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conor-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conradi-Hünermann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conradi-Hünermann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio abdominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio abdominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio abdominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio orbitae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio retinae mit Berlin-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio thoracis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio thoracis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Contusio thoracis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Conus-medullaris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Convoluted-Cell-Typ-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cooley-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cooley-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cooley-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cor adiposum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cor biloculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cor bovinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cor triloculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cori-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cori-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornea guttata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornea plana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornea verticillata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornealulcus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornelia-de-Lange-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornu cutaneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cornu cutaneum des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coronariitis - s.a. Koronariitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Corpora amylacea der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Corpus liberum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Corpus-callosum-Agenesie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Corpus-pineale-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Corpus-uteri-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cortico-adrenaler Basophilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coryza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cossio-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Costa cervicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Costa fluctuans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Costa-Rica-Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Costen-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Costen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cotton-Wool-Spot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvade-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Couvelaire-Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cowden-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cowper-Drüsen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cowperitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa antetorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa saltans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa valga',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa valga antetorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa valga congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxa vara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxarthritis - s.a. Koxarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxarthrosis - s.a. Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxitis - s.a. Koxitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxitis fugax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxitis tuberculosa [Ischiophthisis] [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackie des Zentralnervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackie-Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackie-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackie-Karditis [kodiere zusätzlich I52.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackie-Perikarditis [kodiere zusätzlich I32.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackievirus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Coxsackievirus-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crampi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crampus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craniocleidodysostosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craniopharyngioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cranium bifidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis vulvae et ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Craurosis vulvae et vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Creeping Eruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crepitatio eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crescendoangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Creutzfeldt-Jakob-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cri-du-chat-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crigler-Najjar-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crohn-Ileitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crohn-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crohn-Krankheit mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crooke-Apert-Gallais-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crosby-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cross-McKusick-Breen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Croup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Croup - s.a. Laryngitis, obstruktiv, akut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crouzon-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crouzon-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crush-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Crushniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cruveilhier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cruveilhier-von-Baumgarten-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cruveilhier-von-Baumgarten-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cruveilhier-von-Baumgarten-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cruz-Chagas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cryptitis - s.a. Kryptitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cryptococcosis - s.a. Kryptokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cubitus valgus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cubitus varus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Culicosis bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Culture shock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Curschmann-Batten-Steinert-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cushing-Basophilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cushing-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cushing-Syndrom durch ektopischen ACTH [Adrenocorticotropes Hormon]-bildenden Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cushingsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis hyperelastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis laxa congenita [Cutis laxa hyperelastica] [Cutis laxa (hereditaria)]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis marmorata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis marmorata teleangiectatica congenita [CMTC]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis osteosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis vagantium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cutis verticis gyrata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cyclitis - s.a. Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cyclophoria alternans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cypern-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cyproteronazetat-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cyriax-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystadenoma - s.a. Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystathioninurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystathioninuriesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystathioninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystic eyeball',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystindiathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystinosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystinosis maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystis intrasellaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis - s.a. Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis cystica granulomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis gangraenescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis gonorrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis gonorrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis grangraenosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis intramuralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystitis parenchymatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides benignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides benignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cystosarcoma phylloides malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Cytomegalia infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Czerny-Spätatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'D1-Trisomie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] (Fontaine)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] der Aderhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] der Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] des Hirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] des Innenohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DBS [Durchblutungsstörung] des Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DCM [Dilatative Kardiomyopathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DHEA [Dehydroepiandrosteron]-Sulfat-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DIC [Disseminated intravascular coagulation]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DIG [Disseminierte intravasale Gerinnung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DILV [Double inlet left ventricle]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'DORV [Double outlet right ventricle]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dabue [Ainhum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dacryocystitis neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dacryosialadenopathia atrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dactylolysis essentialis [Ainhum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dactylolysis spontanea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryoperizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryophlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryozystoblennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dakryozystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daktylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dalmatien-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daltonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 1. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 1. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 2. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 2. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 3. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 3. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 4. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß 4. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammriß, nicht unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammrißdehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammrißhämatom im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammrißwunde im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammscheidenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammverletzung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dammverletzung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dandy-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dandy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dandy-Walker-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dandy-Walker-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darier-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darier-Roussy-Sarkoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darier-Syndrom [Erythema anulare centrifugum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darling-Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darling-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darm-TBC [Tuberkulose] [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmachsendrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmaktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmamyloidose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmamöbom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmarterienembolie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbefall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmblähung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmdivertikulitis/-divertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmduplikatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmegel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmeinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmeinklemmung durch Gallenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmeinscheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmeinstülpung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmeiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmfistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmgrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmhypertrophie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmhypomotilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darminfektion durch Flagellaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darminvagination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkrampfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmmotilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmmotorikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmmykose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmobturation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmschistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmsenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmspasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstrongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtrichobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtrichophytobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmträgheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmtyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmulkus durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmvenenembolie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverknotung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverschlingung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverschluß durch eingedickte Milch beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverwachsung mit Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmvolvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darmzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Darwin-Höcker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dassel-Beule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauerblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauererektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauerhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauerkatheterträger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauerschmierblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauerschwindel mit Gleichgewichtsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauertherapie mit Antikoagulanzien in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauertherapie mit Arzneimitteln a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dauertherapie mit Chemotherapeutika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumensattelgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenschrunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenschrunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenschrunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Daumenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dawson-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Almeida-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Beurmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Lange-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Morsier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Quervain-Krankheit [Tendovaginitis stenosans]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Quervain-Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Toni-Debré-Fanconi-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-Toni-Debré-Fanconi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'De-la-Peyronie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dead-fetus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deafferentierungsschmerzen bei Schädigung des Rückenmarkes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Debilitas mentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Debilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Debranching-Enzym-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Debré-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deciduoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt der Biosynthese der testikulären Androgene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt der posttranslationalen Modifikation lysosomaler Enzyme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt der zellulären Immunität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Foramen ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Hageman-Faktors',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Koronarsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Sinus coronarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Sinus venosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Vorhofseptums und Kammerseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekt des Zellmembran-Rezeptorenkomplexes (CR3)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defekter Verschluß des Vorhofseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deferentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defibrinationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defibrinierungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defizit des zentralen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defluvium capillorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defluvium ciliorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Defluvium unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Mitralklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität der Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität des Bulbus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität des Gesichtsfeldes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität des Nuck-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität des Sinus Valsalvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deformität/Narben als Resultat einer vorangegangenen Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneratio grisea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration der Bruch-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration der Thymusdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Cornu anterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Hirnnerven III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Hirnnerven IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Hirnnerven VI',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des ZNS mit Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des knöchernen Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration des peripheren autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneration eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Affektion des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Außenmeniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Chorioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Fettleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Gelenkerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Innenmeniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Knochenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Krankheit der Basalganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Makuladrusen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Meniskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Veränderung der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative Veränderung der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerative periokulare Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degenerativer Zustand des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degeneratives Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deglutitions-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Degos-Delort-Tricot-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehiszenz der Episiotomienaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehiszenz der Schnittentbindungswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehiszenz der geburtshilflichen Dammwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehiszenz einer Operationswunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehiszenz einer perinealen Wunde post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehydration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dehydroepiandrosteronsulfat-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekalzifikation der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekapitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekarboxylasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensation der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte CIHK [Chronische ischämische Herzkrankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Esophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Exophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Hyperphorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Hypophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Linksherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Myokardinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Rechtsherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Stauungsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte Zyklophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierte globale Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensierter Herzmuskelschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensiertes Schilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompensiertes autonomes Schilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekompressionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekubitalgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dekubitalgeschwür der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deletion des kurzen Arms von Chromosom 5',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deletion des kurzer Arms von Chromosom 4',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deletion des langer Arms von Chromosom 18',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deletion in der Prometaphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deletionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delhibeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delhigeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delhipustel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delinquenz beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delinquenz beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delir im Wochenbett a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deliranter Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirantes Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium alcoholicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium durch Hyperthyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium mit gemischter Ätiologie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium tremens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium tremens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Delirium, nicht Demenz überlagernd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dellenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dellenbildung der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dellwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dellwarzen/Condylomata acuminata bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dellwarzen/Condylomata acuminata beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia alcoholica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia infantilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia paralytica [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia paralytica [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia paralytica juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia paralytica juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia phantastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dementia senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Alzheimer-Krankheit mit frühem Beginn (Typ 2) [kodiere zusätzlich F00.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Alzheimer-Krankheit mit spätem Beginn (Typ 1) [kodiere zusätzlich F00.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Epilepsie [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Hirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Hyperkalzämie [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Morbus Alzheimer [kodiere zusätzlich F00.9*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Morbus Wilson [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Multipler Sklerose [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Neurosyphilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Neurosyphilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Niazinmangel [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Paralysis agitans [kodiere zusätzlich F02.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Parkinson-Krankheit [kodiere zusätzlich F02.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Parkinsonismus [kodiere zusätzlich F02.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Pellagra [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Schädelhirnverletzung [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei Vitamin-B12-Mangel [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei hepatolentikulärer Degeneration [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei unsicherer intrakranieller Neubildung [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei zerebraler Gefäßstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz bei zerebraler Lipidstoffwechselstörung [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz im Greisenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz mit Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz vom Alzheimer-Typ mit atypischer Form [kodiere zusätzlich F00.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demenz vom Alzheimer-Typ mit gemischter Form [kodiere zusätzlich F00.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demons-Meigs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demoralisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisation bei Neuritis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisation des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisierende Enzephalopathie des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisierende ZNS-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demyelinisierendes Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demütigende Ereignisse in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Demütigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dengue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dengue-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dens evaginatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dens in dente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dens invaginatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dens neonatalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Densaxisfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Densfraktur des zweiten Halswirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentale Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentale Fluorose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentale Karies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentale Resorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentaler Abszeß mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentaler Polyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentaler Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentes emboliformes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentes natales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Denticulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentindysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinoblastom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinogenesis imperfecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinogenesis-imperfecta-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentinom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitio difficile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitio praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitio tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitionsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitionsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentitionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentoalveolärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentoalveolärer Abszeß mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentofaziale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dentogener Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Denutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depersonalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depersonalisationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depigmentierte Hautveränderung bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depletion der extrazellulären Flüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depletion des Plasmavolumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression bei Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression bei manisch-depressiver Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression bei manisch-depressiver Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression des Atemzentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression nach Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depression post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressiv-schizoaffektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Form einer manisch-depressiven Psychose mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Form einer manisch-depressiven Psychose ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Reaktion als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Stimmungsschwankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive schizoaffektive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive schizophreniforme Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive senile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressive ängstliche Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressiver Angstzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressiver Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressiver Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressives Erschöpfungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Depressives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deprivationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dercum-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dercum-Lipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dercum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Derealisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Derealisationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermales ekkrines Zylindrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis ab igne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis ammoniacalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis anogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis artefacta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis artefacta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis atopica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis atrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis atrophicans maculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis bei Exsikkation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis calorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis combustionis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis congelationis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis contusiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis der Beugeseiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Demodex-Arten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Dermanyssus gallinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Detergenzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Erntemilben [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Liponyssoides sanguineus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Milben [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Schistosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Seife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Sensibilisierung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Waschmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Zerkarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch ein Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch ein eingenommenes Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis durch ein organisches Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis dysmenorrhoica symmetrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis erysipelatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis flexurarum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis gangraenosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis herpetiformis Duhring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis herpetiformis senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis hiemalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis hypostatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis infantis exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis intertriginosa atopica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis lichenoides chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis multiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis nodosa tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis nummularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis papillaris capillitii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis pellagrosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis plantaris sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis polymorpha dolorosa Brocq',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis praecancerosa Bowen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis pratensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis pruriginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis pustulosa contagiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis pustulosa subcornealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis repens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis seborrhoides infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis seborrhoides juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis solaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis solaris acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis toxica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis trophoneurotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis und Ekzem mit Rhagaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis varicosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vegetans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis venenata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis verrucosa [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vesicularis der Lippe durch HSV-2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vesicularis der Lippe durch humanes Alpha-Herpes-Virus, Typ 2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vesicularis des Ohres durch HSV-2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vesicularis des Ohres durch humanes Alpha-Herpes-Virus, Typ 2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis vesicularis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis/Atopisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatitis/Dermatose der Augenlider',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatobia hominis Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatocele lipomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatochalasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatofibrom - s. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatofibrosarcoma protuberans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatofibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatoglyphenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatographische Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatolysis palpebrarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomukosomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomycosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomycosis corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomycosis favosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomycosis furfuracea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyiasis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomykose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomykose des Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomykose im Windelbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyositis bei Neubildung a.n.k. [kodiere zusätzlich M36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyositis mit Lungenbeteiligung [kodiere zusätzlich J99.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatomyositis-Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytia inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie] der Leistengegend und des perianalen Bezirks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie] des Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie] durch Epidermophyton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie] durch Mikrosporum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatophytose [Dermatophytie] durch Trichophyton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatopolymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatopolymyositis bei Neubildung a.n.k. [kodiere zusätzlich M36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatopolyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosis factitia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosis papulosa nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosis pigmentaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosis pustulosa subcornealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermatozoenwahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoepidermitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermographismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoid durch nichtionisierende Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dermoidzyste mit maligner Transformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Derrick-Burnet-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descemetfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descemetozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descemetruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus uteri 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus uteri 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus uteri 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus uteri et vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus vaginae anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus vaginae et vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Descensus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desintegrative Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desintegrative Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desintegrative Störung beim Kind a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoid - s.a. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoidfibrom - s. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoidtumor - s.a. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoplastisches Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoplastisches Medulloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desmoplastisches bösartiges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desogestrel-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desorganisierte Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desorientiertheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desorientiertheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desquamatio areata linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desquamatio areata linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Desquamation der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruierende Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruierende Mole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruierendes Chorionadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktion des Septum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktion des Septum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktion des Septum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktion des Sphincter recti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktiv ulzerierende Rhinopharyngitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktive Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktives Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Destruktives Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detergenzienallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Beckenboden-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Beckenboden-Dyssynergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Blasenhals-Dyssynergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Harnblasenhals-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Sphinkter-Dyssynergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusor-Sphinkter-Dyssynergie bei Schädigung des Rückenmarkes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusoratonie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusordekompensation der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusorhyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusorhyperreflexie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusorhypoaktivität der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusorinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusormyasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Detrusorschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deuteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deuteranopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deuteromycetes-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deutschländer-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deutschländer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Devergie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Devergie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deviatio septi nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deviatio septi nasi congenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Devic-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Devic-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Devitalisierter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dextroflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dextropositio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dextrotransposition der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dextroversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dezentrierung einer IOL [Intraokulare Linse]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dezerebrationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deziduapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deziduom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Deziduomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dhat-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dhobie itch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Di-Guglielmo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Di-Guglielmo-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Di-Guglielmo-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes insipidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus - kodiere möglichst gemäß Typ I oder Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit AVK [Arterielle Verschlußkrankheit] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Azetonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit DBS [Durchblutungsstörung] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Gefäßveränderung [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Hautjucken [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Katarakt [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Ketose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Makulopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Myatrophie [kodiere zusätzlich G73.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Nephropathie [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Nephrose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Netzhautveränderung [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Neuralgie [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Neuritis [kodiere zusätzlich G59.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Pruritus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Präkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Retinitis [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit neurologischer Manifestation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit ophthalmologischer Manifestation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit peripherer Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ I mit renaler Manifestation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit AVK [Arterielle Verschlußkrankheit] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Azetonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit DBS [Durchblutungsstörung] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Gefäßveränderung [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Hautjucken [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Katarakt [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Ketose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Makulopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Myatrophie [kodiere zusätzlich G73.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Nephrose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Netzhautveränderung [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Neuralgie [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Neuritis [kodiere zusätzlich G59.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Pruritus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Präkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Retinitis [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit neurologischer Manifestation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit ophthalmologischer Manifestation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit peripherer Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ II mit renaler Manifestation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ IIa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ IIb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ Ia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus Typ Ib',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus bei Schwangerschaft, während derselben auftretend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus in Verbindung mit Fehl- oder Mangelernährung [Malnutrition]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit AVK [Arterielle Verschlußkrankheit] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Angiopathie [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Azetonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Cataracta diabetica [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit DBS [Durchblutungsstörung] [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Gefäßveränderung [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Hautjucken [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Katarakt [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Ketose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Ketoseneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Makulopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Myatrophie [kodiere zusätzlich G73.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Nephropathie [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Nephrose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Netzhautveränderung [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Neuralgie [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Neuritis [kodiere zusätzlich G59.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Polyneuropathie [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Pruritus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Präkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Retinitis [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Retinopathia diabetica [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Retinopathia diabetica proliferans [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Retinopathia diabetica simplex [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit neurologischer Manifestation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit ophthalmologischer Manifestation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit peripherer Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus mit renaler Manifestation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus ohne Ketoseneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus, insulinpflichtig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus, nicht Typ I oder II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mellitus, nicht insulinpflichtig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes mit Erstmanifestation während der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes oder andere vorbestehende Krankheiten, die die Schwangerschaft beeinträchtigen können',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetes spurius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesfettniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesfettniere bei Typ-I-Diabetes mellitus [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesfettniere bei Typ-II-Diabetes mellitus [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesleber bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetesleber bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Amyotrophie [kodiere zusätzlich G73.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Angiopathie [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Arthropathie a.n.k. [kodiere zusätzlich M14.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Charcot-Krankheit [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Dermatitis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Fetopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän des Fußes bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gangrän des Fußes bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gastroparese [kodiere zusätzlich G99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gastroparese bei Typ-I-Diabetes mellitus [kodiere zusätzlich G99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Gastroparese bei Typ-II-Diabetes mellitus [kodiere zusätzlich G99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulonephritis [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulonephritis bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulonephritis bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulosklerose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulosklerose bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Glomerulosklerose bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Hämochromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Iritis [kodiere zusätzlich H22.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Mikroangiopathie [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Mikroangiopathie bei Typ-I-Diabetes mellitus [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Mikroangiopathie bei Typ-II-Diabetes mellitus [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Mononeuropathie a.n.k. [kodiere zusätzlich G59.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Nephropathie [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Neuropathie [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Neuropathie bei Typ-I-Diabetes mellitus [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Neuropathie bei Typ-II-Diabetes mellitus [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Ophthalmoplegie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Polyneuritis [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Polyneuropathie [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Polyneuropathie bei Typ-I-Diabetes mellitus [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Polyneuropathie bei Typ-II-Diabetes mellitus [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Sexualstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Stoffwechsellage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulohyalinose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulohyalinose bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulohyalinose bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulosklerose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulosklerose bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische extrakapilläre Glomerulosklerose bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische lipoide Nekrobiose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische lipoide Nekrobiose bei Typ-I-Diabetes mellitus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetische lipoide Nekrobiose bei Typ-II-Diabetes mellitus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetischer Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetischer Fuß bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetischer Fuß bei Typ-II-Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetisches Koma bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetisches Koma bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diabetisches retinales Mikroaneurysma [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z40'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Hauttestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostische Sensibilisierungstestung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diagnostisches Röntgen/Bildgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z41'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dialysepflichtige Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dialysepflichtige terminale Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diamond-Blackfan-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diamond-Blackfan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphorasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphorasemangelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmaadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmaeinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmaeinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmahernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmarelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmatische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphragmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphysenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaphysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe bei Anguilluliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe bei Strongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Adenoviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Aerobacter aerogenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Balantidium coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Campylobacter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Chilomastix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Clostridium perfringens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Dientamoeba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Enteroviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Erreger der Arizona-Gruppe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Flagellaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Gardia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Isospora belli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Isospora hominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Kokzidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Kolibakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Kryptosporidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Lamblia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Milben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Nahrungsmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Protozoen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Trichomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe durch Yersinia enterocolitica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhoe/Erbrechen mit angenommener infektiöser Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhöische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diarrhöische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diastase der Schädelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diastematoglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diastematognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diathesis thrombasthenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diathesis urica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaz-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diaz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diazepamabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diazepamabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diazepammißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diazepammißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dibothriocephaliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dibothriocephaliasis durch Finnen des Fischbandwurmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dibothriocephaliasis latus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichoreale und diamniale Zwillingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichotomie des Zahns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichuchwa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dichuchwa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmdivertikulose mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmdivertikulose mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmeinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmeinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmtransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dickdarmzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Didymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dienzephalussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dieulafoy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dieulafoy-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Differenziertes Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Differenziertes Retinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Differenziertes Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffus sklerosierende Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Aneurysmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Glykogenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Infektion des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Leberdegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Meningeomatose - s. Neubildung, Meningen, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Metastasierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Otomykose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Peritonitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Raumforderung des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Raumforderung des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Raumforderung im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Raumforderung im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Schmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Unterhautzellgewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse abdominale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse eosinophile Fasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse idiopathische Skeletthyperostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse idiopathische Skeletthyperostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse intraabdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse intraabdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse intravasale Gerinnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse intravasale Koagulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse progressive atrophische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuse sklerosierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuser Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuser toxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuser Ösophagusspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Effluvium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Emphysem durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Emphysem durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Emphysem durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Emphysem durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Endotheliom [Ewing-Sarkom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Germinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Hämangioendotheliom des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Lymphoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Lymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Retikulolymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses Retikulosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses immunoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diffuses retikulozelluläres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitalisintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digiti hippocratici',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitus accessorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitus malleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitus mortuus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitus superductus der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitus superductus des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Digitusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatatio Cavum septi pellucidi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatatio cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatatio ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation der Brustdrüsenmilchgänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation der Harnblasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation der Kapillaren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation des Nierenbeckenkelchsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatation des Sphincter ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dilatative Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dimorphe Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 0 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 0 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 1 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 1 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 2 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dip 2 [Deceleration intra partem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dipetalonemiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphallus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphasische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie mit neurologischer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie-Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie-Pertussis-Tetanus-Vakzination [DPT] [DTPa] [DaPT]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie-Tetanus-Vakzination [DT] [Td]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherie-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Myokarditis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Ophthalmie [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Peritonitis [kodiere zusätzlich K67.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Polyneuritis [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Wundinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherische Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherischer Krupp [Croup]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphtherischer Laryngismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphyllobothriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphyllobothriose des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diphyllobothriose durch Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplakusis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegia der oberen Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegia inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegia superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie bei infantiler spastischer Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie bei spastischer infantiler Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie beider Arme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie der oberen Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplegie der unteren Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diplomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diprosopus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dipsomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dipsomanie mit Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dipylidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Direkte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dirofilaria-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dirofilariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dirofilariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disaccharid-Intoleranzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disaccharid-Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disaccharid-Malabsorptionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disaccharidasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskoider fokaler Lupus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskontinuität der Gehörknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskoordinierte Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskoordinierte Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskretes Stammeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskriminierung wegen der Geschlechtszugehörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskriminierung wegen der Geschlechtszugehörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diskussion über/Bitte um Sterbehilfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation der Gehörknöchelchenkette',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation der Metakarpalknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation der Schambeinfuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation der zervikothorakalen Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Akromioklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Articulatio sacroiliaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Iliosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Krikoarytänoidealgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Krikothyreoidalgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Processus articularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Radiohumeralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Septumknorpels der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Sternoklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des Temporomandibulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation einer IOL [Intraokulare Linse]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation einer Keratoprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation eines IUP [Intrauterinpessar]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation von Teilen des Kopfes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation/Subluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislokation/Subluxation an jeglicher Stelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dislozierte subtrochantäre Femurfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disloziertes Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disloziertes Tampon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Entmarkungsenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Herpesvirus-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Knochenverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Lobärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Myelosklerose des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Neurodermitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Periarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Retinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Retinochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Trophoneurose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Uveitis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte akute Demyelinisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte erhöhte Knochendichte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte intravasale Gerinnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte intravasale Gerinnung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte intravasale Gerinnung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte intravasale Koagulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierte zerebrospinale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminierter Lichen corneus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseminiertes Erysipeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Disseziierendes Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziale Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Empfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Sensibilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziative funktionelle Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziativer Krampfanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziierte Vertikaldivergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziierter Hirntod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziierter Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dissoziiertes Vertikalschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distalbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Femurfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Form der spinalen Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Humerusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Meatusenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Meatusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Oberarmfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Radiusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Radiusfraktur mit Ulnafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Radiustrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale interphalangeale psoriatische Arthropathie [kodiere zusätzlich M07.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distale tubuläre Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distension der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distichiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiase der Gallengänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiase der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiase der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiase im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distomolar [4. Molar]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsio genus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsio pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion - s.a. Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion - s.a. Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Rotatorenmanschette',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Rotatorenmanschettenkapsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Schilddrüsengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Symphysis pubica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion der Vertebrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Akromioklavikularbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Akromioklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Chopart-Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Karpometakarpalgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Kiefergelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Krikothyreoidalbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Krikothyreoidalgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Lisfranc-Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Metakarpalgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Ring-Gießbeckenknorpelgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Ring-Schildknorpelgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Semilunarknorpels des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des Sternoklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des proximalen Endes der Tibia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion des proximalen Endes des Schienbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion eines Bandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion eines Bandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Distorsion eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Districhiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divergenzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diverticulitis vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diverticulum ilei verum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikel der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikel der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikel der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikel des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikelperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Divertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dizentrische Chromosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dizephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetisch behandelter Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetisch behandelter Typ-II-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Beratung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Hyperkalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Hypervitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Hypokalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Hämosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätetische Überwachung bei Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätkontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Diätüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dolichogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dolichokolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dolichokolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dolichostenomelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dolichozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dominant vererbte sensible Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dominante Myotonia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Donovaniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Donovaniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Donovanosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Donovanosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelalbuminämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelbilder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelbilder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeleinstromventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelgallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelgesicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelmonstrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelniere mit doppeltem Nierenbecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia femoralis mit Einklemmung ohne Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia inguinalis mit Einklemmung ohne Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia inguinalis mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Hernia inguinalis ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Leistenhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitige Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitiger Hydrothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelseitiges Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelt heterozygote Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Nierenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Aortenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Darm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Dickdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Dünndarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Gallengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Gehörgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Herzvorhof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Speicheldrüsengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppelter äußerer Muttermund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeltes Herzohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeltes Nierenbecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeltes Nierenbecken mit doppeltem Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeltes Zökum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeltsehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Doppeniere/-ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dornwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsale Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsaler Zungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsales Zungenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsolaterales Oblongata-Syndrom [kodiere zusätzlich G46.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dorsolumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dottersacktumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dottersacktumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double inlet left ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double inlet ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double-outlet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double-outlet-Ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double-outlet-left-ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Double-outlet-right-ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglas-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglas-Vagina-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglasabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglasendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglashernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglasozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Douglastumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Down-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Down-Syndrom, Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Downhillvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drainage des Liquor cerebrospinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drainageperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drakontiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drehkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drehkrankheit der Schafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drehschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drehschwindel mit Gleichgewichtsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreifache Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreifacher Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreifacher Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreifaches X-Chromosom mit weiblichem Phänotyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreigeteilte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreigliedriger Daumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreimonatskolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreitagefieber [Exanthema subitum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreitagefieber [Pappataci-Fieber]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dreitagefieber-Exanthem [Exanthema subitum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drepanozytenanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drepanozytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drepanozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dresbach-Herrick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dresbach-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drescher-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drescher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drescherlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dressler-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dressler-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillingsfrühgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drillingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drittetags-Fieber [Pappataci-Fieber]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogen-Entziehungstherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenbestimmung im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenentzug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenentzugssyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenentzugssyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenentzugssyndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenhalluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenhalluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Paranoia und Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogeninduzierte Paranoia und Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenmissbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drogenwirkung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohende Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohende Frühgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohende Frühgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohende Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohende Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drohender Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drop attack',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drop finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drop toe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druck auf das Rückenmark',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druck auf den Plexus brachialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druck auf den Plexus lumbosacralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druck/Engegefühl des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druckerhöhung bei medikamentös eingestelltem Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druckluftkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druckschmerzhaftigkeit des Bauches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druckstelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Druckulkus der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drusen der Papilla nervi optici',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drusenmakula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dry socket',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsendysfunktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenkarzinom des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Drüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dschungelgelbfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dual-Photonen-Absorptiometrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dual-X-ray-Absorptiometrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duane-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubin-Johnson-Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubin-Johnson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubin-Johnson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubin-Sprinz-Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubin-Sprinz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dubowitz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Aran-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Aran-Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Aran-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Erb-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Griesinger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duchenne-von-Leyden-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ducrey-Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ducrey-Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ductus arteriosus persistens (Botalli)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ductus-nasolacrimalis-Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duhring-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duhring-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dukes-Filatow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dukes-Filatow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dukes-Filatow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dukes-Filatow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duktales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duktales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duktales Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duktales invasives Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duktales invasives Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dumdum-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dumping Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dumping-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenaldivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalschleimhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenaltorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenalulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenocholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumbulbitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duodenumtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplay-Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplay-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplay-Periarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplay-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplicitas asymmetra [Doppelmißbildung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duplikatur des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dupuytren''sche Kontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dupuytren-Kontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dupuytren-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duraanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durand-Nicolas-Favre-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durand-Nicolas-Favre-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durand-Nicolas-Favre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durand-Nicolas-Favre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durasinusthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch Institutionen wandernder Patient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch Kultur gesicherte Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch mikroskopische Sputumuntersuchung und Kultur gesicherte tuberkulöse Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch mikroskopische Sputumuntersuchung und Kultur gesicherte tuberkulöse Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch mikroskopische Sputumuntersuchung und Kultur gesicherte tuberkulöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durch mikroskopische Sputumuntersuchung und Kultur gesicherter tuberkulöser Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblasung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung (Fontaine)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung bei Diabetes mellitus [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung bei peripherer Gefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung der Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung des Beins mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung des Innenohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchblutungsstörung des Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchbruchsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall - s.a. Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall - s.a. Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall mit Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall mit Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall mit Erbrechen mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall mit Erbrechen mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall-Krankheit mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchfall-Krankheit mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchgangssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchschlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchsickern von Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchsickern von Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchsickern von Zerebrospinalflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchstechen des Ohrläppchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung des Hypophysenstiels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung des Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchtrennung des Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durchwanderungsperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Duroziez-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Durst durch Wassermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyke-Young-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysakusis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysarthria syllabaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysarthrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysarthrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysautonomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbasia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbasia angiosclerotica intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbasia intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbasia lordotica progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbasie nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysbiose [Gleichgewichtsstörung der Darmflora]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyscholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschondroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschondroplasie mit Hämangiomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyschromie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysencephalia splanchnocystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysendokrinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Balantidium coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Chilomastix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Dientamoeba fragilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Embadomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Giardia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Isospora belli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Isospora hominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Kokzidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Lamblia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Protozoen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Schistosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Shigella a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Sonne-Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Trichomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterie durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Arthritis [kodiere zusätzlich M01.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Arthritis [kodiere zusätzlich M01.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterische Strongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterischer Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterischer Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterischer Leberabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterisches Ulkus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysenterisches Ulkus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyserythropoetische kongenitale Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion der Papillarmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Corpus pineale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Temporomandibulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des Tracheostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion des autonomen Nervensystems durch Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines Darmstomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines Gefäßtransplantates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines Gerätes im Harntrakt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines ICD [Implantierbarer Cardioverter-Defibrillator]-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines Shunts a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines implantierten Cardioverter-Defibrillators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines implantierten Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion eines ventrikulären Shunts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion nach Enterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion nach Ileostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion nach Jejunostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion nach Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktion nach Zystostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktionelle gynäkologische Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktionelle uterine Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysfunktionelle vaginale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysgerminoma ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysgeusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysgnathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysgrammatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysgraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosiformes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosiformes Fußekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosiformes Hand- und Fußekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosiformes Handekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosis lamellosa sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrosis manuum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrotisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshidrotisches Fingerekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshormogener familiärer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshämatopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyshämopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskalkulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskeratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskeratosis follicularis Darier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskeratosis follicularis vegetans Darier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskeratotischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskinesia tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskinesie nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskinetisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskoordinierte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskoordinierte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskraniopygophalangie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskrasie des Blutes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyskrinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyslalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyslexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyslexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyslipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmaturität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmaturität der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmelie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmenalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmenorrhoea membranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmnestisches Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmorphie durch Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmorphie durch äußere Ursache a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmorphophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysmukorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysnomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysorexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysorgasmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysostosis cleidocranialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysostosis craniofacialis hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysostosis multiplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysostotische Idiotie [Pfaundler-Hurler-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspareunie der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspepsie mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspepsie mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspepsiedarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspeptische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphagozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysphorisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasia epiphysealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasia oculo-auriculo-vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasia spondylothoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie der Nierenhauptarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasie-Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplasiehüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplastischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysplastisches Nävuszellnävussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspnoe beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysponderosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyspraxie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysregulativer Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysregulativer Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysregulativer Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysrhaphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysrhaphiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyssomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyssynergia cerebellaris myoclonica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dyssynergie der Gallengänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysthymie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Einstellungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Einstellungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Haltungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Haltungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetale Meningomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetale Meningomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetalen Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetalen Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetalen Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetalen Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetales Steißteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch fetales Steißteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch mütterliche Ursachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystokie durch mütterliche Ursachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystone Bewegungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystonia deformans progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystonia musculorum deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophia adiposogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophia albipunctata retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophia brevicollis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophia myotonica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophia retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophie der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophie durch Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophie durch abnorme Gewichtsabnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dystrophische Thrombozytopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysäquilibrium-Syndrom bei Dialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dysästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dämmerungsamblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dämmerungsblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dämmerungssehstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Klumpke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Roussy-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Sottas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Sottas-Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Sottas-Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Sottas-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Thomas-Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déjerine-Thomas-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dérangement interne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Déviation conjuguée',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarm-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarm-Vagina-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmamyloidose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmbride',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmbridenileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmdivertikulose mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmdivertikulose mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmfehlbesiedelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarminvagination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmkarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmkonglomerattumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmlymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmsyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmsyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmtasche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmtransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmvolvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Dünndarmzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'E1-Trisomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'EBV [Epstein-Barr-Virus]-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ECHO-Virus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ECHO-Virus-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ED [Encephalomyelitis disseminata]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'EOCA [Früh beginnende zerebellare Ataxie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'EPH [Ödem-Proteinurie-Hypertonie]-Gestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'EPS [Extrapyramidales Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ESES [Electrical status epilepticus during slow-wave sleep]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eales-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eales-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eastern-Equine-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eaton-Lambert-Syndrom [kodiere zusätzlich G73.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eaton-agent-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eberth-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ebstein-Herzanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ebstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ecchondrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinococcus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinococcus-Infektion der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinococcus-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinococcuszyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinokokken-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinokokkenbefall der Orbita [kodiere zusätzlich H06.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinokokkose der Leber a.n.k. [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinokokkose der Orbita [kodiere zusätzlich H06.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinorhynchiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echinostomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echolalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echte Dextrokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echte Grippe [Influenza] ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echte Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echte Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echte Pocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Hermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Hermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Nabelschnurknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Nabelschnurknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Zwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echter Zwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Echtes Neurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eclampsia neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Economo-Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ectopia cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ectopia lentis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ectopia pupillae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ectopia vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ectopia viscerum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eczema - s.a. Ekzem oder s.a. Ekzema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Edwards-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Effluvium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Effluvium capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehegattenmißhandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehegattenmißhandlungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehekonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eheproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ehescheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eichelentzündung - s.a. Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eichelkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockstieldrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eierstockvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eifersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eifersucht im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eifersucht unter Geschwistern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eifersuchtswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eigen-/Familienanamnese für Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eigen-/Familienanamnese für bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eihäuteschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eihäutestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eihäuteveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiteragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiteratresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiteratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterblockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileitergonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileitergonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileitertorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterundurchgängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileitervolvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileitervorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eileiterzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eimole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ein Kind betreffende Institutionalisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einbruch des Fußgewölbes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eine Blutung verursachende unsachgemäße Abnabelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Akroparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Obesitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Obesitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Obstipation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Schultze-Akroparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Silikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache häutige Syndaktylie ohne Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache paranoide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfache senile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfacher Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfacher Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfacher Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfacher fokaler Anfall mit Entwicklung zu sekundärem generalisierten Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfaches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einfarbensehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einführen von Bougies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einführen von Sonden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingebildete Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmte Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmte innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Bruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Harnleiterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Harnröhrenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Kotstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Urethrastein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeklemmter Uterus durch Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeschlafene Hände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeschränkte Nierenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeschränkte Spermienmobilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeschränkter Harnfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingewachsene Barthaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingewachsener Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingewachsener Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingewachsener Zehennagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweidebruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweidebruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweideperforation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweideptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweidesenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eingeweideverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einheimische Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung durch Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung durch Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung eines Enteroliths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung eines Gallensteins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung eines Zahns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einklemmung von Fäzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einkoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einkoten/Darmkontrollproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einlage eines Intrauterinpessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einlingsgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einnässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußkonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußkörperchenenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußkörperchenkonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußkörperchenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußzyste der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußzyste der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschlußzyste der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einschränkung von Aktivitäten durch Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitig helle Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Amaurose bei Sehschwäche des anderen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Amaurose bei normalem Visus des anderen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Femoralhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Hernia inguinalis ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Koxarthrose als Folge einer Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Leistenhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Schallempfindungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Sehschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Spalte des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Spalte des harten und des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Spalte des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Torsion des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige Zwergniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige angeborene Hüftgelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige kleine Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige posttraumatische Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige primäre Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige sekundäre Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige übermäßige Brustentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitige übermäßige Brustentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Hörverlust durch Schalleitungsstörung bei nichteingeschränktem Hörvermögen der anderen Seite',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Hörverlust durch Schallempfindungsstörung bei nichteingeschränktem Hörvermögen der anderen Seite',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Leistenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Visusverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Visusverlust <0,05 bei normalem Visus des anderen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiger Visusverlust <0,3 bei normalem Visus des anderen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einseitiges Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einsetzen eines intrauterinen Pessars zur Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einstellungsanomalie des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einstellungsuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eintagsfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eintagsfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einwärtsgewendete Tränenpünktchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einwärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeitiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeitiger Abort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelepisode einer larvierten Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelimpfung - s.a. Einzeleinträge der Impfungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzeln Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelne Episode einer majoren Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelne Episode einer vitalen Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelne Episoden einer majoren Depression mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelne Episoden einer schweren reaktiven Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelne manische Episode einer bipolaren Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einzelniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Einziehende Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenablagerung in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenbahnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenharte Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangel ohne Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangelanämie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangelanämie nach Blutverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmangelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmenger-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenmenger-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenspeicherungskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenstoffwechselkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eisenstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiter im Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiter im Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiter im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterpickel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung der Pyramidenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung der Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung des Speicheldrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung des dentalen Periostes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung des äußeren Gehörganges a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiterung eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitervergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Adenitis der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Adenitis der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Adenitis der Parotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Angina tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Bindehautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Blinddarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Choledochitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Chondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Entzündung des Wharton-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Episkleritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Gallenblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Gebärmutterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Hidradenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Hodenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Hydroadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Kieferentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Kieferostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Kieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Leberentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Lungenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Mastitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Nierenbeckenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Orchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Osteoradionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pansinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Perinephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Phlegmone a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pleuritis mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pulpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Rhinobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Rhinosinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Rippenfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Seitenstrangangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sialadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinularyngobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinusitis frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinusitis maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Sinusitis sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Skleritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Typhlitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige Zystitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige chronische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitrige intrakranielle Phlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriger Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriger Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriger Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriges Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriges Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriges Mundgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eitriges Postmenopausen-Endometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweiß im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißausscheidung im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißmalnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißmangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißmangelernährung mit Entwicklungsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eiweißunterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eizellenimplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eizellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eizellentnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eizellentnahme zur In-vitro-Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejaculatio deficiens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejaculatio praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejaculatio praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejaculatio retarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejakulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ejakulatorische Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchymose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchymose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchymose beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekchymose der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekkrine Schweißdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekkrines Spiradenom - s. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekkrines papilläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie mit Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie mit Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie mit schwangerschaftsinduzierter Hypertonie a.n.k',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsie mit vorher bestehender Hypertonie a.n.k',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklampsieanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklamptische Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklamptische Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklamptische Urämie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklamptischer Krampf bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eklamptisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekstrophia splanchnica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekstrophie der Bauchorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektasie des Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektasie des Ductus lactiferi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektasie des Nierenbeckenkelchsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektasie des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma contagiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma gangraenosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma infectiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekthyma vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektodermal-Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektodermaldysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektodermale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektodermosis erosiva pluriorificialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektope Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopie der Baucheingeweide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopie der Magenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopie von Brustdrüsengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopie von Brustdrüsengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische Graviditas abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische Hormonsekretion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische Systolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopische rupturierte Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopischer Hyperinsulinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopischer Knochen in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopischer Knorpel in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopischer Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektopisches ACTH [Adrenocorticotropes Hormon]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektozervixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektozervixkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektrodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektrodaktylie der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektrodaktylie der Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektromelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektromelie der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektromelie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium nach Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium spasticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ektropium urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem - s.a. Ekzema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Detergenzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Seife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch Waschmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem durch ein organisches Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem mit Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzem/Abzeß/Furunkel im äußeren Gehörgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema crurum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema fissum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema flexurarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema flexurarum infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema herpeticatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema herpeticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema hypertrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema impetiginosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema intertriginosum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema lichenificatum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema marginatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema nummulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema pustulosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema rubrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema scabiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema seborrhoicum infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema vaccinatum durch Schutzimpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzema varicosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematisierte Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematisierte Psoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematisierte Skabies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematoid - s.a. Ekzematid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematöse Augenliddermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematöse Dermatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematöse Liddermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematöse Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ekzematöse Tinea manuum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'El-Tor-Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'El-Tor-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastische Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastoidosis cutanea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastoidosis senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastomyofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastose durch Sonnenbestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastosis atrophicans senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastosis senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elastosis solaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elefantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elefantiasis nach Mastektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektive Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrokardiogramme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A42'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytentgleisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytstörung mit Flüssigkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytverschiebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektrolytverschiebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elektroschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis congenita hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis der Lymphgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis graecorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis italica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis nach Mastektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis scroti durch Onchocerca volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis teleangiectodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elephantiasis, nicht durch Filarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elevatio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellbogensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenbursitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogengelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogengelenkbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogentuberkulose [kodiere zusätzlich M01.12*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenbogenzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elliptozyten-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elliptozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elliptozytose durch Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellis-van-Creveld-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ellis-van-Creveld-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elongatio cervici uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elongatio colli uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Elschnig-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eltern-Kind-Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emanzipationskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embadomoniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embadomoninale Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie bei Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Aorta abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Aorta thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria iliaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria poplitea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Mesenterialgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie einer Extremitätenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie einer peripheren Arterie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie extrakranieller hirnversorgender Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie in der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie nach Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie nach Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie und Thrombose einer Extremitätenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolie unter Ovulationshemmer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Hemiplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Herdenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Monoplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolische Tetraplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Gehirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Lungeninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Rückenmarkabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embolischer zerebraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryofetales Alkoholsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryofetales Hydantoin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryofetopathia alcoholica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Adenorhabdomyosarkom der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Adenosarkom der Niere [Wilms-Tumor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Hepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Nephroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Rhabdomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonales Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonalkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonalkatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryonaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryopathia rubeolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryopathie durch äußere Ursache a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryotoxon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryotoxon posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emesis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emesis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emmet-Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emmet-Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotional bedingte Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotional instabile Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Kindesmißhandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Labilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung der Identität mit Überängstlichkeit im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung mit Geschwisterrivalität im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung mit Trennungsangst im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Störung mit sozialer Ängstlichkeit im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Unausgeglichenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Verhaltensstörung im Kindes- und Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Verhaltensstörung im Kindes- und Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Verhaltensstörung im Kindes- und Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale Vernachlässigung in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionale instabile Persönlichkeitsstörung vom impulsiven Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionaler Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emotionaler Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfindliches Dentin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfindlichkeitsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfindlichkeitsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfindungsstörung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütende Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütende Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütende Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empfängnisverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem im Alter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysem nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysema pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysemasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysembläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysembronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Emphysemthorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empty nest syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empty nest syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empyem des Brustkorbs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Empyema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'En-plaques-Sclerodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalitis japonica B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalitis periaxialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalitis periaxialis diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalitis saturnina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalomyelitis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalomyelitis periaxialis sclerotica disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalopathia acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalopathia hyperbilirubinaemica beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalopathia hyperbilirubinaemica durch Isoimmunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Encephalopathia saturnina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enchondrale Dysostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enchondroma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endangiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endangiitis obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endarteriitis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endarteriitis obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endarteriitis retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endarteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Balkannephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Balkannephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Bazillokokkie [Brucellose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Funikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Neuritis [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Polyneuritis [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Schilddrüsenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Struma diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Struma nodosa simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Struma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische hämorrhagische Nephrose-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische kolloide Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische tuberkulöse Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemische zystische adenomatöse Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Jodmangelkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Kretinismus vom gemischten Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Kretinismus vom myxödematösen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Kretinismus vom neurologischen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer adenomatöser Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer einfacher Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer kolloider Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemischer zystischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemisches Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endemisches Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis lenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis parietalis fibroplastica (Löffler)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis parietalis fibroplastica (Löffler) mit Hypereosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis ulceropolyposa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endocarditis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Crusta lactea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Depression mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Magersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Ochronose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene monopolare Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogene reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogener Milchschorf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogenes Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogenes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endogenes nichtallergisches Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokard-Fibroelastose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarderkrankung bei Syphilis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarderkrankung bei Syphilis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarderkrankung durch Gonokokken [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarderkrankung durch Gonokokken [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardgonorrhoe [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardgonorrhoe [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardiale Fibroelastosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardiale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis bei Kandidose [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis bei Q-Fieber [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis der Mitralklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis der Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Coxiella burnetii [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Coxsackieviren [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Gonokokken [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Gonokokken [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Klappenprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Listerien [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Meningokokken [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch künstliche Herzklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis durch prothetische Herzklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditis mehrerer Klappen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokarditisprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardkissendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardlipoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardtuberkulose [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokardverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Drüsenkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Drüsenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Dysfunktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Myopathie [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Neubildung, andere/nicht spezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Ophthalmopathie [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Orbitopathie [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Orbitopathie mit Pseudoglaukom [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Pankreasinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine/stoffwechselbedingte/ernährungsbedingte Erkrankungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrine/stoffwechselbedingte/ernährungsbedingte Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrines multiples Adenom-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endokrinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endolymphatische Stromamyose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endolymphatische stromale Myose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endolymphatischer Hydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriale Stromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrialer Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrialer Stromaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Adenokarzinom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Adenokarzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Zystadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Zystadenokarzinom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrioides Zystadenokarzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriose des Pelviperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriose des Septum rectovaginale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriose post abruptionem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosezyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis genitalis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis genitalis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis tubae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis uteri externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis uteri interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriosis vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometrische Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis durch Chlamydien [kodiere zusätzlich N74.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis nach Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis nach Molenschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis nonpuerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometritis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumhyperplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumkalkherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumsynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endometriumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomonopolare Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomyofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomyokardfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomyokardiale Fibroelastosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomyokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endomyometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endoperineuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophlebitis portalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophthalmitis bei Onchozerkose [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophthalmitis bei Toxokariasis [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endophthalmitis bei Zystizerkose [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endoprothesenschaftbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endoreaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endosalpingiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheldystrophie der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheliales Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheliom eines Blutgefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheliomatöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endotoxinschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endourethrale Polyposis im Sinne der Harnröhrenkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endourethrale Polyposis im Sinne einer Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endozervixinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endozervixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endozervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Endozervizitis durch Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Energiemangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Engegefühl im Hals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enger Introitus vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enges Becken mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Englische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Engman-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Engwinkelglaukom bei Plateau-Iris-Konfiguration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enkopresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei hinterer Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei hinterer Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei regelwidriger Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei regelwidriger Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei tiefer Querlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung bei tiefer Querlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Kombination von Vakuum- und Zangenextraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Kombination von Vakuum- und Zangenextraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Saugglocke a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Saugglocke a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Vakuumextraktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Vakuumextraktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Vakuumextraktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung durch Vakuumextraktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung eines Einlings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung festsitzender Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung festsitzender Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung mit Fibroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung vor dem Termin a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung vor dem Termin a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindung vorausgehende Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindungs-Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindungsverzögerung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbindungsverzögerung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entbundene Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entdifferenziertes Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterische Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Chilomastix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Kokzidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Kryptosporidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Mikrosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Nahrungsmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Protozoen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Shigellosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Trichomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Yersinien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis durch enteropathogene Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis membranosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis necroticans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis ohne Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis ohne Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis segmentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis von Dünndarm und Kolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritis, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteritisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterobiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterochromaffiner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterocolitis fulminans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterocolitis necroticans beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterocolitis necroticans beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterocolitis pseudomembranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterocolitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterogastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterogastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterogastritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterogastritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterogene Zyanose [Erworbene Methämoglobinämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterokolische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterokolitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteromphalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteromyiasis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteropathie durch Proteinverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterostomie mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterothorax beim Neugeborenen [Angeborener Zwerchfelldefekt mit Eventration]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterotyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enteroviren-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enterozystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung einer Frakturplatte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung einer äußeren Extensionsvorrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung einer äußeren Schiene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Dauerkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Gefäßzugangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Gipsverbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Impulsgenerators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Intrauterinpessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Katheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Kirschner-Drahtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Nagels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Parazentese-Röhrchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Pessars (zur Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Stabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Urinkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Verbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines Verweilkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung eines äußeren Zuggurtungsapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfernung von Nahtmaterial [z.B.Fäden ziehen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entfremdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthauptung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie der Ellenbogenregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie der Hüftregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie der Plantaraponeurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie des Ligamentum iliolumbale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesiopathie in der Schulterregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie - s.a. Enthesiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie der Handwurzel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie des Fußes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie des Handgelenks a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie des Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enthesopathie des Tarsus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entkräftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entkräftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entkräftung durch Hunger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entkräftungsfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entkräftungsfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entlastungspolyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entmarkungsenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entmarkungskrankheit des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entomophthora-Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entropium senile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entropium spasticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entschädigungsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entstellung durch Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungs-Akalkulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Agraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Alalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Alexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Amusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Artikulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Dyslalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Dyslexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Koordinationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Krankheit des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Myasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Porenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Störung des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Wernicke-Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingte expressive Schreibstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsbedingtes Gerstmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsdyslexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsdyspraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungshemmung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungshemmung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungshemmung durch Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsproblem des Lernvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsrückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsrückstand, Mischform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstottern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstörung des Rechnens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstörung in der Schule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsstörung schulischer Fertigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwicklungsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entwurzelungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entziehungstherapie bei Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugsdelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugsdelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Alkoholgebrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Cannabinoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Halluzinogenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Opioiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom mit Delir nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Alkoholgebrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Cannabinoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Halluzinogenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Opioiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzugssyndrom nach Gebrauch von Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündete Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündeter Klavus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündetes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündetes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündetes Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündetes Cholesteatom des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündetes Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Ablatio retinae exsudativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Affektion des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Brustdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Brustdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Chiasmaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Glaskörperinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Krankheit der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Krankheit der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Krankheit des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Nierenbeckenkelchveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Nierenkelchveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Polyarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Unterbaucherkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche Uteruserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliche allergische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündlicher Croup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündlicher Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündlicher Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündlicher Skrotalknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündlicher ZNS-Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündliches Douglasinfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Areola mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Beckenorgane bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Cowper-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Gebärmutterschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Glandulae bulbourethrales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Skene-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Skene-Gänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tenon-Kapsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tonsilla pharyngea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tränenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tunica conjunctiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der Zahnalveolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der oberen Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der oberen Luftwege durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der oberen Luftwege durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung der paraurethralen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Antrum mastoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Brustwarzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Brustwarzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Ganglion geniculi nach Zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Meatus urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Mundrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Nervus vestibulocochlearis bei Syphilis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Nervus vestibulocochlearis bei Syphilis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Operations-Bereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Pars plana corporis ciliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Unterhautzellgewebes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Uvealtraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des kleinen Beckens (PID)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des männlichen Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des visuellen Kortex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Beckengewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Beckens durch Chlamydien [kodiere zusätzlich N74.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Beckens durch Gonokokken [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Beckens durch Gonokokken [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des weiblichen Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung durch Apparat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung durch Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung durch Implantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung durch Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung durch Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung einer Adnexe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung einer Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung einer Moll-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung einer Zeis-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung im Brustraum NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Entzündung von areolärem Gewebe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enukleation eines Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis diurna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis nocturna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis nocturna neurotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis nocturna persistens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis nocturna secundaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuresis organischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enuretisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Aktinomykose [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Herpes zoster [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Kryptokokkose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Listeriose [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Naegleriainfektion [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Naegleriasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Rubella [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Röteln [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Torulosis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Trichinose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Tuberkulose [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei Windpocken [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei afrikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei amerikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei chronischer Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei parasitärer Krankheit a.n.k. [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis bei systemischem Lupus erythematodes [kodiere zusätzlich G05.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Adenoviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Arboviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Arthropoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Enteroviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Herpes-simiae-Virus [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Herpesviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Ilhéusviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Kryptokokken [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Mengo-Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Meningokokken [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Negishi-Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Poliovirus [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis durch Zytomegalieviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis lethargica sive epidemica [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis nach Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis nach Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis nach Pockenimpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis nach Varizellen-Infektion [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitis vom Wiener Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalitische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalokutane Angiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomeningomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomeningopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Masern [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Naegleriainfektion [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Rubella [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Röteln [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei Toxoplasmose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei afrikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei amerikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei chronischer Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis durch Adenoviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis durch Enteroviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis durch Herpes-simiae-Virus [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis nach Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelitis nach Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyeloneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyeloradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyeloradikulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie bei Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie bei Vitamin-B-Mangel a.n.k. [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie durch Toxoplasmen [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie durch hypoglykämisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalopathie nach Strahlenexposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalotrigeminale Angiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Enzymmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Meningitis [kodiere zusätzlich G02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Meningoenzephalitis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Zellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophile leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Granulom der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Hypophysenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Lungeninfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophiles Lungeninfiltrat mit Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eosinophilie-Myalgie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymales Glioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymitis durch Zytomegalieviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymom des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ependymozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis humeri radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis humeri ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis medialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylitis ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylopathia humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylopathia humeri radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epicondylopathia radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Enzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Fischvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Genickstarre [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Grippe [Influenza] ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Hirnhautentzündung [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Meningitis a.n.k. [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Myalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Myokarditis beim Neugeborenen [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Myositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Nausea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Nephropathie [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Neurolabyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Neuromyasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Pleurodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Polyarthropathie mit Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische hämorrhagische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemische virale Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Schluckauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Schwindel [kodiere zusätzlich H82*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemischer Singultus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Exanthem mit Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Lymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Läusefleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches Megalerythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches arthritisches Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidemisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermale Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermatophytose [Epidermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermisverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermiszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermo-dermaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermodysplasia verruciformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoides Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoidzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoidzyste der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoidzyste der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoidzyste des 3. Hirnventrikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermoidzyste des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermokutaner Grenzflächennävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermokutaner Übergangsnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermolysis acuta toxica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermolysis bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermolysis necroticans combustiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermolysis-bullosa-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidermomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymale Spermatozoenaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymistuberkulose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymiszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis durch Chlamydien [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis durch Gonokokken [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis durch Gonokokken [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis durch Herpesviren [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis durch Herpesviren [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymitis mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymoorchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymoorchitis mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epididymoorchitis ohne Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidurale Narbenfibrose nach Diskektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiduraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiduraler intrakranieller Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiduraler intraspinaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidurales intrakranielles Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epidurales intraspinales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epigastralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epigastralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epigastrische Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottischondromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottistuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottiszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottisödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiglottitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epignathus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikardiale Plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikardkarzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikardverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikondylitis des Ellenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikondylitis mit Blockierung des Radiusköpfchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epikondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia minor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia partialis continua',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsia traumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie bei Zystizerkose [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie des limbischen Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie im Kindesalter mit okzipitalen Paroxysmen im EEG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie mit Bewußtseinstrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie mit Wesensänderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie mit myoklonisch-astatischem Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie mit myoklonischen Absencen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie vom gemischten Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie, unbestimmt, ob fokal oder generalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epilepsie-Symptom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptiforme Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptiformer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptiformer Anfall bei Zystizerkose [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Absencen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Absentia a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Automatismen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Bewußtseinstrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptische Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Absencenstatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall durch Schlafentzug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall durch Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall durch hormonelle Veränderungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall im Zusammenhang mit Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall im Zusammenhang mit Drogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall im Zusammenhang mit einem Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Anfall ohne Bewußtseinsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Dämmerzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptischer Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptisches Anfallsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptisches Syndrom, unbestimmt, ob fokal oder generalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptisches Äquivalent',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epileptoider Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiloia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epimenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epinephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epinephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epipharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epipharynxhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphrenales Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysenlösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysenlösung des Femurkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysenlösung des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysenverschiebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphyseolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphyseolysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphyseolysis capitis femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiphysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiploischer Darmanhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiploitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiploonabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiplozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epiretinale Gliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episcleritis periodica fugax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episiotomiehämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episiotomienarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episiotomienarbenkeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episkleraentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episkleritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episkleritis bei Gicht [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episodisch paroxysmale Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episodische Cluster-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episodische Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epispadia clitorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epispadie bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epispadie beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Episplenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliale Dysplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliale Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliale Zervixdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelialer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliales Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliales Molluscum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliales Molluscum contagiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliales Nephroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheliom - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma adenoides cysticum Brooke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma basocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma calcificans Malherbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma papillare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma seminifere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelioma spermatogonique Masson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelkörperchenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelkörperchenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelkörperchenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloides Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloides Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloides Leiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzellige Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzellige Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliger Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliges Melanosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliges Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epitheloidzelliges Synovialsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epithelödem der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epituberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epituberkulose mit Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epizoonose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epizoonosenwahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epizootie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epizootische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epoophoronzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epstein-Barr-Virus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epstein-Barr-Virus-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epstein-Epithelperlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epstein-Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epulis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epulis des Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epulis fibrosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Epulis gigantocellularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Armplexuslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Charcot-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Goldflam-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Lähmung durch Geburtstrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Oppenheim-Goldflam-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Paralyse durch Geburtstrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erb-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbgrind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbleichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbliche Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erblindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erblindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen außerhalb der Neugeborenenperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen außerhalb der Neugeborenenperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen bei Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen bei psychischer Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen im Spätstadium der Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen nach Magen-Darm-Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbrechen über 1 Woche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbsenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erbveitstanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erdbeergallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erdheim-Gsell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erdheim-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektile Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektile Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektile Potenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektile Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektile psychogene Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektionsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erektionsstörung beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erethismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung der Knöchelregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung mehrerer Körperregionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierung mit Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierungsfolgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erfrierungsgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Leistungserbringer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergebnis Untersuchung/Test/Brief von anderem Versorger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A61'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergosterinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergosterolmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergosterolmangel bei Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergotismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergrauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ergrauen der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhebliche Energie- und Eiweißmangelernährung mit Anzeichen von Kwashiorkor und Marasmus gleichzeitig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhebliche Mangelernährung mit Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhängen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Aldosteronproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Aldosteronsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Blutungsneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Durchlässigkeit von Kapillargefäßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Knochendichte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Körpertemperatur unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Körpertemperatur unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Leukozytenzahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Miktionsfrequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte Sphärizität der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte ovariale Androgenproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhte testikuläre Androgenproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Alphafetoproteingehalt im Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Blutglukosewert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Blutzucker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Blutzuckerspiegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Fettspiegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Grundumsatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Venendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter Venendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhter analer Sphinktertonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhtes Mißbildungsrisiko beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhtes genetisches Risiko beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhung der Immunglobuline',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhung der Kapillarpermeabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhung der Laktatdehydrogenase [LDH]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erhöhung der Stuhlmenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankung der männlichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankung des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankung des Sehnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankung motorischer Neuronen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankung/Zustand ohne bekannte Ursache/Stelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankungen der Atemwege oder als Folge von Erkrankungen der Nase/des Kehlkopfes/des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankungen der Lungengefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkrankungen des Verdauungssystems, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältung mit Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältung mit Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältung mit Influenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältung ohne Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältungsinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältungsinfekt mit Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältungskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erkältungsschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erlebnisreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Untersuchungsergebnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erläuterung von Verordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermattung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermattung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdung durch Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsbruch eines Wirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsbruch eines Wirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsfraktur eines Wirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsfraktur eines Wirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ermüdungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erniedrigte Glukosetoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erniedrigter Blutzuckerspiegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erniedrigtes Alpha-Fetoprotein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erntearbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erntekrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingte Hyperkarotinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingte Polyneuropathie a.n.k. [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingter Hydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingter Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingter Kupfermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingter Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsbedingter Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsberatung beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsmangel in der Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsmangelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsproblem beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsstörung beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ernährungsödemsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio corneae bei epithelialer Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio follicularis uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio interdigitalis blastomycetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio papillaris uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio simplex uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio vera der Scheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosio vera uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosion bei Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosion der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosion der Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosion der Portio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erosive Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erotomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregbare Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregungsausbreitungsstörung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregungsleitungsstörung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregungsverspätung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erregungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erröten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erröten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Errötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschlaffung der Gesichtshaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschlaffung des weiblichen Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschwerte Dentition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschwerter Zahndurchbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschwertes Zahnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung durch Ausgesetztsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung durch Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung durch Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfung durch Überanstrengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungsdelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungsdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungssysndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschöpfungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschütterung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erschütterung des Conus medullaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstgeburt in fortgeschrittenem Alter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ersticken durch Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ersticken durch Gas a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung an Nahrungsmittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung an Schleim a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung durch Erbrechen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung durch Inhalation von Öl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung durch Konstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickung durch Verschüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickungsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstickungstod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstschädigung bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstuntersuchung eines neuen Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstverordnung eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erstverordnung eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ertrinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ertrinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ertrinkungsunfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eructatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eruktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erweiterung des Nierenbeckenkelchsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erweiterung des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Abnormität der Ohrknöchelchen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Achromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Adhäsion der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Akanthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Anodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Anonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Anophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Anusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Aphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Aphasie mit Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Aplasie des Alveolarfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Armdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Armverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Athetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Athyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Atresie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Atrophie der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Beckenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Beindeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Beinlängendifferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Beinverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Blockade des Foramen Magendii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Blutungsneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Brustbeindeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Brustkorbdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Bänderdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Choledochusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Daumendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Augenlinse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Aurikula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Bandscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Bandscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Caruncula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Cervix uteri a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Ferse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Großzehe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Koronararterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Mittelhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Corpus vitreum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Ellenbogengelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Muskel-Skelett-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Tränenkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deformität eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Dermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Dermatorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Deviatio septi nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Dilatation des Gallenblasenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Eileiterverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Erschlaffung der Augenlidhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Extremitätendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Farbsinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Femurverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Femurverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Fibrinogenopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Fibrinopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Fingerdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Fußabflachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Gallengangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Gehörgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Gelenkdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Gelenkfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Gesichtsdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Glaskörperdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Halsdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hammerzehe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Handgelenkverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Harnblasenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hepatitis durch Toxoplasmose [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Humerusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hypofibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hypophosphatasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hypophosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hypoprothrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hüftverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Hühnerbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Insuffizienz der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Irisdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Irisheterochromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Jodmangel-Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kanthusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Keratodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Keratosis pilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Keratosis suprafollicularis [Keratosis pilaris simplex]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kieferdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kielbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kinndeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Klauenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Klauenzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Klavikuladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Klumphand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Knochendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Knöcheldeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kompressionsatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kopfdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Korneadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Krallenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kraniumdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Lichen pilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Liddeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Lidfaltendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Lippendeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Lordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Makroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Makroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Megalogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Meningoenzephalitis bei Toxoplasmose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Meningoenzephalomyelitis bei Toxoplasmose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Methämoglobinämie mit Sulfhämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Minderung des Hörvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Mittelfußdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Munddeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nageldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nasendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nasenscheidewanddeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nasenscheidewandverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nasenseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nasenseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Nierenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene O-Bein-Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Oberschenkelverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ohrdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Orbitadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ovarialverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Panmyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Panzytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Patelladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Pectus excavatum sive infundibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Platyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Poliosis circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Polyzythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Porenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Präputialkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Pulmonalklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Pupillenverziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Radiusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Radiusverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Rhinoseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Rhinoseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Rotationsdeformität eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Rumpfdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Samenstrangadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Schilddrüsenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Schulterblattdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Schusterbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Schädeldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Septumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Septumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Skapuladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Spitzfußstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Sprunggelenkdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Stenose des äußeren Ohrkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Sternumdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Stirnbeindeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Stirndeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Subluxation des Nasenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Sulfhämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Taubstummheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Teilung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Tibiadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Tibiaverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Trichterbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Tyloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ulnadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ungleichmäßigkeit der Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Unterarmdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Urethradilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Uveitis bei Toxoplasmose [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Vaginadeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Verformung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Verlagerung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Verlängerung eines Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Vulvastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Wangendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Wimperndeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene X-Bein-Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Zahnfleischdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Zervixdeformität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Zungenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Zungenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene beidseitige Aphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene einseitige Aphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene elastische Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene fibrinolytische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene hämatogene Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene ileozökale Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene isolierte aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene kapilläre Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene koronare Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene koronare arteriovenöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene nasale Septumdeflexion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene periventrikuläre Zyste beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene reitende Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene vaginale Enterozele a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene zerebrale Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene zerebrale arteriovenöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene zystische Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ösophagusdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ösophagustasche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbene Ösophagusverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Beckenschiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Buckel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Equinovarus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hackenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hallux malleus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hallux valgus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hallux varus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hammerfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Herzfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Herzseptumdefekt der Kammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Herzseptumdefekt des Herzohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Herzseptumdefekt des Vorhofs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hydrocephalus internus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hydrozephalus durch Foramen-Magendii-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hypothyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Hypothyreoidismus durch Jodmangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Irisdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Klauenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Klauenhohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Mangel an Tränenflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Schatzki-Ring des unteren Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Spitzfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Spitzklumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Ventrikelseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Verschluß der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Verschluß des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener Wasserkopf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener hämatogener Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener hämolytischer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbener reitender Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Ankyloblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Ektropium der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Thyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ambosses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Duodenums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ileums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Jejunums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen eines Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen eines Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen eines Beins oberhalb des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen von Fingern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen von Teilen des Kopfes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen von Verdauungsorganen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Fehlen von Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Immundefektsyndrom [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Immundefizitsyndrom [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Immunmangelsyndrom [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Megakolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Megaloblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Netzhautaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Trichterbecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Vitium cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Xeroderma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes adrenogenitales Syndrom mit Feminisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes adrenogenitales Syndrom mit Virilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes arteriovenöses Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes einseitiges Fehlen des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes partielles Fehlen des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erworbenes Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipel beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipel des äußeren Ohres [kodiere zusätzlich H62.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelas gangraenosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelas phlegmonosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelatöse Zellgewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelatöser Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipelatöses Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erysipeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema a frigore',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema ab igne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema arthriticum epidemicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema chronicum migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema chronicum migrans durch Borrelia burgdorferi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema chronicum migrans durch Borrelien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema endemicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema exsudativum multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema figuratum perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema induratum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema infectiosum acutum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema nodosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema palmare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema rheumaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema scarlatiniforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema solare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema subitum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema toxicum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythema-nodosum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematodes chronicus discoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematodes chronicus discoides des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Entzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Entzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Plaques bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöse Plaques bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöser Ausschlag beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythematöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrasma intertriginosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroblastopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroblastophthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrocyanosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrocyanosis crurum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrocyanosis crurum puellarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia desquamativa Leiner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia ichthyosiformis congenita bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermia psoriatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrogenesis imperfecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukoblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukoblastose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukämische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroleukämische Myelose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythromelalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythromelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrophagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrophagozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroplakie der Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroplakie der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroplakie des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroplakie des Mundhöhlenepithels und der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythropoetische Protoporphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrothermalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozyanose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozyten-Glutathion-Mangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytenabnormalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytenartige Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozythämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytophagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrozytäre Autosensibilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrämische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erythrödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Erziehungsschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eröffnungswehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Escherichia-coli-Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esodeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esophorie bei Divergenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esophorie bei übermäßiger Konvergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esotropie bei Strabismus deorsoadductorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esotropie bei Strabismus sursoadductorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esotropie mit Konvergenzexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Espundia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Cholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Fruktosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Fruktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Irisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Kryoglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Pentosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle braune Lungeninduration [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle familiäre Teleangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentielle progressive Irisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Essentieller Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esthiomène',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Esthiomène',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Estradiol-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Estriol-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Estron-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethinyl-Estradiol-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethmoiditis bei Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethmoiditis bei Influenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethnische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ethnische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Euboea-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eulenburg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eulenburg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eunuchoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Europäische Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Euthyreote Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Euthyreote diffuse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Euthyroid-Sick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Evans-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eventration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eversio puncti lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eversion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Evertierter Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eviszeration durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eviszeration durch Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ewing-Angioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ewing-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ewing-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Examensangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthem durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthem durch Serumbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema chronicum migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema subitum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exanthema subitum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exazerbation einer chronischen Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exazerbierte Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exazerbiertes Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Excoriatio chronica linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Excoriatio chronica linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exercise-induced Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliatio areata linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliatio areata linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliatio lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliation der Zähne durch systemische Ursachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliative Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliative Dermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliative Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliative Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exfoliativzytodiagnostik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exitus innerhalb 24 Stunden nach Beginn der Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exkretorische Pankreasinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exodeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exogene Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exogene Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exogene spastische Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exogenes allergisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exokrine Pankreasinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophorie bei Konvergenzschwäche des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophorie bei übermäßiger Divergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophthalmischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophthalmus bei Kropf [kodiere zusätzlich H06.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophthalmus bei Störung der Schilddrüse [kodiere zusätzlich H06.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophthalmus bei Thyreotoxikose [kodiere zusätzlich H06.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exophthalmus durch Orbitahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exostose des Olekranon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exostose des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exotropie mit Konvergenzexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exozervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expansiv-paranoide Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expansiv-paranoide Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expansiv-paranoische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Explosible Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Explosionstrauma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Bodenverschmutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Bodenverschmutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Folterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Folterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Folterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Immission a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Immission a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Lärm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Lärm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Staub a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Staub a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Strahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Strahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Terrorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Terrorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Terrorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Tollwut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Wasserverschmutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber Wasserverschmutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber einem industriellen toxischen Feststoff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber einer industriellen toxischen Flüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber einer industriellen toxischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber eines industriellen toxischen Dampfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber mechanischen Schwingungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exposition gegenüber mechanischen Schwingungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expositionskeratokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expressiver Typ einer entwicklungsbedingten Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expressiver Typ einer entwicklungsbedingten Dysphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expulsive Aderhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expulsive Aderhauthämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expulsive Blutung nach Kataraktextraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expulsive Chorioideablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Expulsive Chorioideahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsikkationsdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsikkationsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsikkationsekzematoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Iriszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Vorderkammerzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Ziliarkörperzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudative Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exsudativer Tubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Externe Zahnresorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Externer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraabdominales Desmoid - s.a. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraadrenales Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraduraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraduraler intrakranieller Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraduraler intraspinaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extradurales Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extradurales intrakranielles Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extradurales intraspinales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extragenitaler Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extragenitaler Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrahepatische Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrahepatische Cholestase a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrahypophysäres ACTH [Adrenocorticotropes Hormon]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrakorporale Befruchtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrakorporale Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrakorporale Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraktion des Fetus mit Haken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraktion eines IUP [Intrauterinpessar]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extramedulläres Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraovariales Ovarialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extraperitonealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidal-motorische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidale Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidaler Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrapyramidales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrarenale Reststickstoffvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrarenale Stickstoffretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrasystolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrasystolische Arrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrauteringravidität im Uterushorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrauterinschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extravasater Harn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extravasation von Lymphe ins Mesenterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extravasationszyste der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrem unreifes Frühgeborenes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Abmagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Armut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Prämaturität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Verarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Verarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Verarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extreme Verarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extremitätenverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrinsische Alveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrinsische Zahnverfärbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrinsisches Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Extrusion eines Augenimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exulceratio simplex Dieulafoy',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exulzerierendes Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzentrische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzentrische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Divergenz der Augen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessive Somnolenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Daumenlutschen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Rauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Trinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzessives Zigarettenrauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Exzision/Entfernung von Gewebe/Biopsie/Destruktion/Debridement/Verkauterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z52'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßattacken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßattacken nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßstörung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßstörungen NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßunlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Eßverhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'FSME [Zentraleuropäische Frühsommer-Meningoenzephalitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fabry-Anderson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fabry-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fabry-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Facette der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Facies lunata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fadenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fadengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fadengranulom des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fadenwürmer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fahr-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-I-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-II-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-IX-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-IX-Mangel mit Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-V-Genmutation in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-VII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-VIII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-VIII-Mangel mit Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-VIII-Mangel mit Gefäßendothelfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-X-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-XI-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faktor-XII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallot''sche Tetralogie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fallzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Einmündung der Vena portae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Ernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Ernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Lungenveneneinmündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche Pfortadereinmündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsche vergebliche Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falscher Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falscher Sitz der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falsches Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falschgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falschwachsende Wimpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falte der Descemet-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Falten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faltenmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faltenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faltenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienbezogene Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienbezogene Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung Mann, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung bei Frauen mit oraler hormoneller Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung durch Sterilisierung der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung mittels Intrauterinpessar/Spirale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienplanung mittels männlicher Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiär bedingter Bluter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiär konjugierte Hyperbilirubinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiär-hemiplegische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Analphalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Bänderschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Cholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Cholämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Chondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Chondrokalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Dysautonomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Dyschondrosteose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Ectopia lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperbetalipoproteinämie mit Präbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperchylomikronämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperkalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hyperpräbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hypobetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hypophosphatasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hypophosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Karzinombelastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Konfliktsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Lymphopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Motoneuronkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Osteochondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Pleonostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Polyposis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Polyzythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Präbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Sphärozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre amaurotische Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre benigne Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre dyshormogene Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre essentielle Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hyperkaliämische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hyperkaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hypokaliämische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hypokaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hypokalziurische Hyperkalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hypoplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hämophagozytäre Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre hämorrhagische Diathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre kombinierte Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre kongenitale zystische Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre myotonische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre myotonische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre nichthämolytische Bilirubinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre nichthämolytische Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre normokaliämische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre normokaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre olivopontozerebellare Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre periodische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre rezidivierende Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäre zentrolobäre Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Antitrypsinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Hypoparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Lipoproteinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiärer gutartiger Neugeborenenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Mittelmeer-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres arterielles Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres arterielles Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres venöses Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Familiäres venöses Thromboserisiko',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fanatische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fanatische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fanconi-Andersen-Syndrom [Mukoviszidose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fanconi-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fanconi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbenfehlsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farber-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbringsehen um Lichtquellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbsinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farbveränderung während der Zahnbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farmerhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Farnkrautphänomen [Zyklus- bzw. Fertilisationstest]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasciculitis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasciitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasciitis nodularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasciitis plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasciolopsiasis buski',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasertypendisproportion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasziales Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasziales Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszienanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszienentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszienruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszienruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszientuberkulose [kodiere zusätzlich M73.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszikelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faszikuläre Zuckungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fatale Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fatale familiäre Insomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faulecke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fauleckensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Favismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Favismus mit Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Favismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Favus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Favus capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faziale Hemihypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faziales Fehlbildungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialislähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisparese/Bell''sche Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazialisstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-Londe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-Londe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-bukko-linguale Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-skapulo-humerale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-skapulo-humerale Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazio-skapulo-humerale Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fazioplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faziozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Faßthorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris abortus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris biliosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris carbuncularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris enterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris flava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris haemoglobinurica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris mediterranea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris melitensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris pappataci',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris petechialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris quartana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris quintana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris quotidiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris rubra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris tertiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris undulans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris undulans Bang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris undulans melitensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris uveoparotidea [Heerfordt-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Febris uveoparotidea subchronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fede-Riga-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fede-Riga-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Dura mater',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Haut a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Nabelschnur als Entbindungskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Nabelschnur als Entbindungskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Spinalnervenwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung des Innenohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung des Kreislaufsystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung des Processus mastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlbildung des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Darmgeräusche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Gammaglobuline im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Hitzeempfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Hitzeempfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Kälteempfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Kälteempfindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Neutrophilen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen der Uvula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Ligamentum latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Tränenkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Wurms des Kleinhirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen des Zwerchfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen von Albumin im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlen von Atmungsorganen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Entfaltung der terminalen Lungenabschnitte beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Kindsbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Ovulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Röteln-Immunität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Sozialisation bei Aggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Sozialisation bei Aggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Stereopsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Virushepatitis-Immunität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Zähne durch Extraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Zähne durch Parodontose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende Zähne durch Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlende/unzureichende Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Kolondrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Zahnreihenokklusion durch Fingerlutschgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Zahnreihenokklusion durch Lippenlutschgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Zahnreihenokklusion durch Mundatmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Zahnreihenokklusion durch Zungenlutschgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafte Zahnreihenokklusion durch abnormen Schluckakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafter Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafter Biß durch Mundatmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafter Biß durch abnormes Schlucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlerhafter Biß durch fehlende Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlernährung in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeburt - s.a. Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeschlagene Anwendung einer Zange mit nachfolgender Schnittentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeschlagene Anwendung einer Zange mit nachfolgender Schnittentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeschlagene Vakuumextraktion mit nachfolgender Schnittentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlgeschlagene Vakuumextraktion mit nachfolgender Schnittentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehllage der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehllage einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehllage eines Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehllage eines Transplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlstehende Wimpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlversuch einer Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlversuch einer Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlversuch einer Zangenentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fehlversuch einer Zangenentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feigwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feigwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feindseligkeit gegenüber einem Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feinknötchenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feinmesser-Zelig-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feinmotorikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feldflaschenmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinabsprengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeineiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinlängsbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinlängsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinquerbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsenbeinquerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felsengebirgsfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Felty-Syndrom [Polyarthritis, Splenomegalie und Leukopenie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feminisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femorale Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femorale Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femorale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralhernie mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralisneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralisneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoralisverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoroinguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoropatellararthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoropatellare Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoropatellares Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femoropatellares Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femur-Fibula-Ulna-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femuragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femuranomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurkopfabflachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurkopffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Femurverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fenster eines Herzklappenzipfels a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fenster eines Pulmonalklappenzipfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fensterlabyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fensterung eines Herzklappenzipfels a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fensterung eines Pulmonalklappenzipfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fernöstliche Enzephalitis durch Zecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersensporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fersenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertiler Eunuchoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilisationsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilisationsfördernde Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilisationsförderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilisationstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilisationsunterstützung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätsstörung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätsstörung beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätsuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätsverlust bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fertilitätsverlust beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Festsitzender Gallenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Festsitzender Leberstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Festsitzender renaler Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Festsitzendes Ohrenschmalz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Festsitzendes Zerumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetalblutanalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale AB0-Inkompatibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Anoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Arrhythmie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Arrhythmie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Chondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dekapitation zur Geburtserleichterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dezeleration bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dezeleration bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Erythroblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Hypotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Kranioklasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Kraniotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Lipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Makrosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Mißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Rh [Rhesus]-Erythroblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Wachstumsretardierung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale Wachstumsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetale kardiale Dysrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Blutverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Blutverlust aus Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Blutverlust aus rupturierter Nabelschnur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Blutverlust bei Insertio velamentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Blutverlust bei Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Distreß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Gefahrenzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Oszillationsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Schaden durch ein Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaler Zottenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Fettzellenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Mißverhältnis bei normal ausgebildetem Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Rhabdomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetales Röteln-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaltod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetaltod unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetofetale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetofetales Transfusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetomaternale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetomaternale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetomaternales Transfusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetopelvines Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fett im Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fett-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettdrüsenzyste/Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettdurchwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettembolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettembolie des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettembolie in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebetumor des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebsatrophie der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebsdurchwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebseinlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebsgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebsprolaps des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebstumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettgewebsödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettige Herzdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettige Myokarddegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettige Thymusinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettintoleranz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettleber a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettleberhepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettleibigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettleibigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettnekrose des Peritoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettpolster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettschürze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettstoffwechselstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettsäurestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fettzellenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetus dysmaturus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetus papyraceus bei Mehrlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusamputation zur Geburtserleichterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetuskompression während der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Abruptio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Alkoholkonsum der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Amnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Analgesie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Anästhesie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Chemotherapie bei Krebs der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Chorionamnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Eklampsie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Ernährungsmangelkrankheit der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Ernährungsstörungen der Mutter (Zustände unter E40-E64)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Fünflingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Geburtshindernis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Gesichtslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Hepatitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Hydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Hyperemesis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Hypertonie der Mutter (Zustände unter O10-O11, O13-O16)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Hysterotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Kortikalnekrose der Niere der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Krankheit der Mutter a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Lebernekrose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Malaria der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Malnutrition der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Mehrlingsgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurumschlingung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurverwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nabelschnurvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Narkose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nephritis der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nephrose der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nierenkrankheit der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nierenrindennekrose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Nierenversagen der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Oligohydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Operation der Mutter ohne Zusammenhang mit der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Plazentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Polyhydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Proteinurie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Pyelitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Pyelonephritis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Querlage vor den Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Röteln der Mutter (Zustände unter B06)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Schnittentbindung post mortem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Schwangerschaftskomplikationen der Mutter a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Sechslingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Sturz der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Sturzgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Syphilis der Mutter (Zustände unter A50-A53)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Tabakkonsum der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Thrombophlebitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Tod der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Toxikose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Urämie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Verletzung der Mutter während der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Vierlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch Zwillingsgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch akute gelbe Leberatrophie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch anhaltendes Erbrechen der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch gestationsbedingte Hämorrhagie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch glomeruläre Krankheiten der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch infektiöse Krankheit der Mutter (Zustände unter A00-B99, J10-J11)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch kongenitale Herzkrankheit der Mutter (Zustände unter Q20-Q24)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch kurze Nabelschnur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch manuelle Rotation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch multipler Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch mütterlichen Blutverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch nephrotisches Syndrom der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch parasitäre Krankheit der Mutter (Zustände unter A00-B99, J10-J11)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch radiologische Maßnahmen bei der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch rheumatische Herzkrankheit der Mutter (Zustände unter I05-I09)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch tiefen Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch tiefsitzende Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fetusschädigung durch zytotoxisches Arzneimittel der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchtblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchte Form der Beriberi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchte Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchte Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchtes phagedänisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuchtkalte Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuermahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuermal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Feuerstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrilläres Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinogenolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinogenolysehämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinogenopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinolytische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinopurulente Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinopurulente Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinorrhoea plastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinorrhoea plastica des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinorrhoea plastica des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Chorditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrinöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenom der weiblichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenoma cellulare intracanaliculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenoma cellulare intracanaliculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenomatosis uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroameloblastisches Odontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroangiochondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroblastenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroblastisches Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroblastisches Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrochondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrodysplasia ossificans progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroelastosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroelastosis cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroepithelialer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroepitheliales Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroepitheliales basalzelliges Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroepithelioma benignum ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroid - s.a. Neubildung, Bindegewebe, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroider Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroliposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom der Schädelbasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom des Nasenrachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrom des Penisschaftes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma chondromyxoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma durum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma intracanaliculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma intracanaliculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma molle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma mucinosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma myxomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma nasopharyngeale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma pendulans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma sarcomatosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma simplex Unna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroma thecacellulare xanthomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatose der Palmarfaszie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatose der Plantarfaszie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatöser Nävuszellnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromatöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Dysplasie einer Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Einengung der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Engstellung der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Hyperplasie einer Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Nierenarterieneinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Nierenarterienengstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Nierenarterienstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Nierenarterienstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromuskuläre Stenose der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyom der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyom der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyom des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyositis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyxoidchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyxolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibromyxosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroosteoklasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroosteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroplastische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroplastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibropurulente Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibropurulente Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosarkom der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose der Milz bei Schistosomiasis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose des Ductus ejaculatorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrose des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosierende Alveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosierende kryptogene Alveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosis vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosklerose des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrosplenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrotische Querbarre des Harnblasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibroxanthosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozementom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Degeneration der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Erkrankung Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Krankheit der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibrozystische Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Briden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Kieferdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Papeln der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröse Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröser Tumor - s.a. Neubildung, Bindegewebe, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröses Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröses Histiozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibröses Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibulaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibulakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibulaverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fibulaverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber - s.a. Febris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber - s.a. Febris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber bei Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber bei vesikulärer Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Arboviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Bartonella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Leptospiren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Metalldämpfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Plasmodium ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Polyesterdämpfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Spirillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Streptobazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber durch Sumatra-Milben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber mit Exanthem durch Enteroviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber mit Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieber unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberanstieg',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberanstieg',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Angina tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Bläschenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Halsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Infektion der unteren Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Racheninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Tracheolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafte Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter Infekt der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter Infekt der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter Infekt der unteren Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberhafter grippaler Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberkrämpfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberschauer a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberschauer a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberschub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fieberschub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fiebrige Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fiebrige Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fiebrige Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fiedler-Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fiessinger-Leroy-Reiter-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Figueira [Form der Chromomykose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filaria-ozzardi-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filarien-Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filarien-Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filariose durch Mansonella ozzardi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filatow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filiae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filiforme Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filtrationsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Filzläusebefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fimbrienzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielle Schwierigkeiten, die die Versorgung beeinflussen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielle Schwierigkeiten, die die Versorgung beeinflussen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielle Schwierigkeiten, die die Versorgung beeinflussen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielle Schwierigkeiten, die die Versorgung beeinflussen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielles Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielles Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielles Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Finanzielles Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Findelkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingeradaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingeragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingeramputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingeranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingeraplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingererfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerfehlstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingergelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingergelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingergliederfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerknöchelpolster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerkontraktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerkuppenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingermykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingernagelbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingernagelverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingernagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingernagelverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingernagelüberrest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerperodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerpolyarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingersyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingersyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fingerverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'First-arch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischmehlarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischparasitenbefall durch Vandellia cirrhosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischschuppenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fischwirbelbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fisher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fissur des Dammbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fissura ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fissura urethrae inferioris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Rippengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Processus mastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Speicheldrüsenausführungsganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des Tränen-Nasenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel des weiblichen Genitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel im Genitalbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel nach Tracheotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistel zwischen der Vena portae und der Arteria hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fisteleiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistelnder Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula biliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula bronchialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula cholecystocolica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula cholecystoduodenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula cholecystoenterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula cholecystogastrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula cholecystointestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula choledochoduodenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula enterovaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula enterovesicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula gastro-jejuno-colica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula gastroduodenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula ileovaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula ileovesicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula in ano',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula mamillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula mamillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula scrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula splenocolica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula stercoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula vesicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fistula vesicoenteralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fitz-Hugh-Curtis-Syndrom [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fitz-Hugh-Curtis-Syndrom [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fixierte BWS-Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fixierter Rundrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fixierter Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fièvre boutonneuse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach gedrücktes Gesicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach linkskonvexe BWS-LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach linkskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach linkskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach rechtskonvexe BWS-LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach rechtskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flach rechtskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flachbogige Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flache BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flache Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flache Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flache Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flaches Azetabulum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flaches Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flachrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flachsarbeiterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flachthorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flajani-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flammeninhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flanken-/Achselsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flankenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flatau-Schilder-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flatulenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flatulenz/Blähungen/Aufstoßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flatus vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flechtengrind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckfieber durch Rickettsia mooseri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckfieber durch Rickettsia orientalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckfieber durch Rickettsia tsutsugamushi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckfieber durch Rickettsia typhi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckförmige Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckig erhöhte Knochendichte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleckige Knochenverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flecktyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleischgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleischmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleischner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fleischner-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexibilitas cerea bei Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionsblockierung L5/S1',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionsblockierung im BWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionsblockierung im LWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionsdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionskontraktur des Amputationsstumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexionskontraktur eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexner-Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flexner-Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fliegende Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fliegenlarvenbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fliegerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fliegerohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fliegersinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fließschnupfen durch Pollen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flimmerskotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flint-Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Floating-Betalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flohfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Floppy-Infant-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Floppy-valve-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Floride konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Floride konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Florides Tumorleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flossenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flottierender Hoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flughautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor albus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor cervicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluor vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fluormangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flush',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flushsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flußblindheit [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flöhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Hypertonie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Tachypnoe beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige ischämische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige ischämische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüchtige neonatale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flügelfell des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit im Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit im Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit in der Peritonealhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeit in der Pleurahöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeitsinhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeitsretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeitsretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeitsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Flüssigkeitsüberlastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foetor ex ore',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fogo selvagem [Pemphigus brasiliensis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foix-Alajouanine-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokal proliferierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokal sklerosierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Glomerulosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Jackson-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Retinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Retinochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Uveitis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale Zahninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale chronische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale orale Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokale perikardiale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokaler Jackson-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fokaltoxikose der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folatmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgeerscheinungen einer Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen der Hansen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Femurfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Fraktur des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Fraktur in Höhe der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Fraktur in Höhe des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Kopfverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Luxation der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Luxation der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Muskelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Prellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung der Beckenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung der Nerven der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung der Nerven der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung intraabdominaler Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung intrathorakaler Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung nach Bulbusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verletzung nach Contusio bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verstauchung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verstauchung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Verätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerquetschung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerquetschung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerrung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Zerrung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer infektiösen Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer offenen Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer parasitären Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer pyogenen intrakraniellen Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer pyogenen intraspinalen Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer traumatischen Amputation der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer traumatischen Amputation der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer viralen Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer zerebrovaskuläre Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen einer Überernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines Blitzschlags',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines Schlaganfalls a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines Trachoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines Vitamin-A-Mangels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines Vitamin-C-Mangels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines alimentären Mangelzustands',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines intrakraniellen Abszesses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen eines intraspinalen Abszesses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen nach Lidverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Kalziummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Niacinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Schäden durch äußere Ursachen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Selenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Thiaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgen von Vitaminmangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgevorstellung unspezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z63'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Tuberkulose der Knochen und Gelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Tuberkulose des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Tuberkulose des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand einer Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand eines Trachoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folgezustand nach Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folie à deux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis abscedens et suffodiens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis barbae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis et Perifolliculitis capitis abscedens et suffodiens (Hoffmann)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis sclerotisans nuchae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis staphylogenes superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis ulerythematosa reticulata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folliculitis vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikelpersistenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikelstimulierendes-Hormon-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikulitis mit Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuloides Ovarialadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Eierstockzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Konjunktivitis durch Adenoviren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre Zyste der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläre odontogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikulärer Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Germinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Lymphom mit diffuser Ausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Lymphom ohne diffuse Ausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Lymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Non-Hodgkin-Lymphom mit diffusen Bezirken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Non-Hodgkin-Lymphom ohne diffuse Bezirke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Retikulolymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Follikuläres Schilddrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folsäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Folsäuremangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fonsecaea-Infektion [Chromomykose der Haut] [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fonsecaea-Krankheit [Chromomykose der Haut] [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foramen retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foramen-jugulare-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foramina parietalia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forbes-Albright-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forbes-Hers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forbes-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forbes-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fordyce-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forestier-Ott-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forestier-Ott-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Formabweichung eines Zahns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Formanomalie der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Forssell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fort-Bragg-Fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fortbestehende Gonarthrose trotz Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fortbestehende Lanugo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fortschreitende Ataxie bei Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fortschreitende Ataxie bei Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fothergill-Krankheit [Trigeminusneuralgie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fothergill-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fothergill-Syndrom [Trigeminusneuralgie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fournier-Gangrän bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fournier-Gangrän beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fournier-Gangrän der männlichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Foville-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fox-Fordyce-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fox-Fordyce-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fractura capitis humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fractura humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frage nach Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fragilitas crinium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fragilitas ossium hereditaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fragliche Röteln-Immunität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur bei Neubildung a.n.k. [kodiere zusätzlich M90.79*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Cartilagines tracheales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Cartilago cricoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Cavitas glenoidalis scapulae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Fossa cranii anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Fossa cranii media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Fossa cranii posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Gesichtsknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Karpalknochen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Knorpelspangen der Luftröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Ossa tarsi eines Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Phalangen an Hand/Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Spina scapulae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Symphysis pubica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der Trochlea humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der distalen Epiphyse des Humerus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der proximalen Epiphyse des Humerus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Caput femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Collum anatomicum humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Collum chirurgicum humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Epicondylus lateralis humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Epicondylus medialis humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Manubrium sterni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Metakarpale V',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Os scaphoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Processus xiphoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Sinus ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Sinus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Sinus sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Trochanter major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Trochanter minor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Tuberculum majus humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des Tuberculum minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des ersten Halswirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des ersten Mittelhandknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des großen Vieleckbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des kleinen Vieleckbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des knöchernen Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des knöchernen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur des knöcherner Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur durch Inaktivitätsosteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur von Radius- und Ulnaschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur, Femur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur, Hand-/Fußknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur, Radius/Ulna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur, Tibia/Fibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraktur, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frakturheilung in Fehlstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Framboesia - s.a. Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Framboesia tropica - s.a. Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Framböside im Frühstadium der Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie bei Gangosa [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie mit Gelenkläsion [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie mit Gummigeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie mit Knochenläsion [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösie mit positiver serologischer Reaktion ohne klinische Manifestationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösiepapillom der Fußsohle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösiepapillom der Handfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösieschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frambösiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franceschetti-I-Syndrom [Mandibulofaziale Mißbildungskombination]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franceschetti-Zwahlen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Francis-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franklin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franklin-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franklin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franzosenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Franzosenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fraser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frauenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frauenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frauenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frauenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freeman-Sheldon-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frei flottierende Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freiberg-Infraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freiberg-Köhler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freiberg-Köhler-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freiberg-Köhler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freier Gelenkkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freier Gelenkkörper des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freier Knorpel eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Freiwilliger Hunger a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper Nase/Larynx/Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Alveolarfortsatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Duodenum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Gastrointestinaltrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Gaumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Hauptbronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Ileum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Kolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Magen-Darm-Trakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Nasopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Rektosigmoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Respirationstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Schlund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Sinus piriformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Tränenapparat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Tränengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Urogenitaltrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Verdauungsorgan a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Verdauungssystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Zahnfleisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Ziliarkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im Zökum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper im äußeren Auge a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in Bronchiolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in den Harnorganen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Kieferhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Stirnhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper in der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper unter dem Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörper verschluckt/im Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörperaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergefühl im Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergefühl im Hals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergranulom der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergranulom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergranulom der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergranulom der Unterhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörpergranulom des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörperingestion beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörperinhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdkörperinspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fremdneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frenulum breve',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frenulum breve praeputii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frenulumverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fressendes Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frey-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedländer-Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedländer-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedländer-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedreich-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedreich-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedreich-Rückenmarksklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedrich-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friedrich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Friesel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frigidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frigidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frische Gelenkknorpelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frische Gelenkknorpelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frischer Korbhenkelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frischer traumatischer Tortikollis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Froin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frontalhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frontalhirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frontalhirnsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frontotemporale Demenz [FTD] [kodiere zusätzlich F02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Froschgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frostbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frostbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frostgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frotteurismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frozen shoulder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtblaseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchttod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasseraspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasserdiagnostik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasserschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasserscreening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasserstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasseruntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasseruntersuchung auf Chromosomenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruchtwasserveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktokinasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktose-1,6-diphosphatasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktoseintoleranzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktosestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktosurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fruktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frustrane Kontraktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frustrane Kontraktionen mit Wehenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frustrane Kontraktionen nach 37 vollendeten Schwangerschaftswochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frustrane Kontraktionen vor der 37. Schwangerschaftswoche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frustrane nichtmuttermundwirksame Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fröhlich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frösteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Früh beginnende zerebellare Ataxie mit Myoklonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Früh beginnende zerebellare Ataxie mit erhaltenen Sehnenreflexen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Früh beginnende zerebellare Ataxie mit essentiellem Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühblüherallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühdiabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe Frambösie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe konnatale syphilitische Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe konnatale syphilitische Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe makulopapulöse Frambösie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe makuläre Frambösie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe mikropapulöse Frambösie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe myoklonische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühe papulöse Frambösie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Früher Fetaltod mit Retention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühere Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Früherkennungsmammographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühgeborenenretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühgeborenes zwischen 1000g und1249g',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühgeburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühgeburtsbestrebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühhydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühjahr-Sommer-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühjahrs-Augenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühjahrs-Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkindliche Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkindliche Hirnschädigung mit zerebralem Residualsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkindliche Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkindlicher Hirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkindliches Autismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühkomplikation eines Traumas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsommer-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsommer-Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsommer-Meningoenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühsyphilitische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Frühzeitiges Ergrauen der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-Blutung des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-Heterochromiezyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-Hornhautepithelendothel-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuchs-III-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fugue durch Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fukosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fulminante Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fulminante Sepsis durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fulminante ischämische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus albipunctatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus diabeticus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus diabeticus bei Typ-I-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus diabeticus bei Typ-II-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus hypertonicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundus myopicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusarteriosklerose [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusmyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusvarizenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fundusveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fungi-imperfecti-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fungus testis benignus [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fungus umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fungus-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fungämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funkensehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Abasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Artikulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Astasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Blasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Cholezystopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Darmbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Darmstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Dysphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Einzelniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Enkopresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Gallenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Gebärmutterblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Gesichtsfeldkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Harnabflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Herz-Kreislauf-Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Herzbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Herzrhythmusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Hypoglykämie, ohne Anstieg des Insulinspiegels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Indigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Kolonbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Leberdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Magen-Darm-Trakt-Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Magenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Magenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Nierenbeckenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Ovarialinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Stenokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung der neutrophilen Granulozyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung des Muskel-Skelett-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung psychischen Ursprungs der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung psychischen Ursprungs des Muskel-Skelett-Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Störung psychischen Ursprungs des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Ureterobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Uterusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle Verdauungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle dentofaziale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle gastrointestinale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle kardiovaskuläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle nervöse Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelle neurotische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktioneller Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktioneller Hyperinsulinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktioneller Megaösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktioneller gastrointestinaler Distreß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktioneller intestinaler Distreß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelles Angina-pectoris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelles Darmproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelles Herzgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelles Intestinalproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionelles Megakolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (A)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (B)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (D)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (F)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (H)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (K)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (L)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (N)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (P)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (R)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (S)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (T)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (U)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (W)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (X)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (Y)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionseinschränkung/Behinderung (Z)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsgestörte Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionslose Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsmangel nach Enterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsmangel nach Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung der Galle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung der Nebenniere/Eierstöcke/Hypophyse/Nebenschilddrüse/Hoden oder andere endokrine Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung der Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung des Ileostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung des Kiefergelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung des Tracheostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung nach Enterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung nach Herzoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Funktionsstörung psychischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Krankheit ohne diagnostische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furcht vor Möglichkeit ungewollter Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchtkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchtreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchtsamkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furchtsamkeit beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel an multiplen Lokalisationen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel/Abszess Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkel/Karbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Furunkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusarium-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusiforme Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusiformes Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion der Labia majora pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion der Labia minora pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion der Nasenlöcher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion des Ductus sublingualis und Ductus submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion eines Herzklappenzipfels a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion tarsaler Knochenkerne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion von Larynx und Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusion von Trachea und Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusionsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusionsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusionsstörung mit Ausfall korrespondierender Gesichtsfeldareale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusospirillose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusospirilläre Plaut-Vincent-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fusospirochätische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fuß-/Zehensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußasymmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußdermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußeversion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgelenkdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgelenkverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgelenkzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußgelenkübertretung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußheberparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußhöcker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußknöcheltuberkulose [kodiere zusätzlich M01.17*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußmyzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußpronation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußrückenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußrückenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußrückenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußrückenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußschweiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußsohlenekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußsohlenfasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußsohlenwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußwurzelarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußwurzelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußwurzelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußwurzelknochenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fußödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fädchenkeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäkalieneinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäkalurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäkulentes Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäkulentes Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fältelung einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäulnisbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fäulungsdyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fölling-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fölling-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fötide Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fötider Schweiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Führerscheinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fünflingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fünflingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fünftagefieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Fünfte Krankheit [Erythema infectiosum acutum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Für das Gestationsalter zu kleines Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Für das Gestationsalter zu leichter Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Für das Gestationsalter zu leichtes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Für das Gestationsalter zu schweres Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'G-Zell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GM [Gamma-Kettenmarker]-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GM1-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GM3-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GN [Glomerulonephritis] - s.a. Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galactorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galactorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktokinasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktorrhoe, nicht bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktorrhoe-Amenorrhoe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktosediabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktosestoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktosämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktozele der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galaktozele der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galakturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galakturie bei Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galeazzi-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasen-Magen-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenadenomyomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenausgußstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasencholesteatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenduodenalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasendyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsdyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangshypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsokklusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangsverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengangszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenhydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblaseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblaseninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenokklusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenschleimzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenstein mit akuter Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenstein ohne Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasentorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasentuberkulose [kodiere zusätzlich K87.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasentyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenverdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenblasenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangobliteration nicht durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangobstruktion nicht durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangshypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangshypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangskolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangskonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangskontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsproliferation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstein mit Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstein mit Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangsverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangswucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallengangverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstase nicht durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstein im Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstein im Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstein im Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenstein in der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensteinbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensteine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensteinkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensteinkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensteinleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensystemkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensystemkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallensystemmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsdyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegshämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallenwegsverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galleperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallepfropfsyndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallereflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallertbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallertkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gallige Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galliges Erbrechen unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galliges Erbrechen unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Galopprhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gametentransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gametopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gamma-Hydroxybutyrazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gamma-Schwerketten-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gamma-Schwerketten-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gammaglobulinmangel im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gammopathie mit lymphoplasmozytischer Dyskrasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gamna-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gandy-Nanta-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gang-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganganomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglientuberkulose [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglion bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglion bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglion bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglion-geniculi-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglioneuroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglioneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglioneuroma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglioneuroma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglioneuromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglionitis Gasseri nach Herpes zoster [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglionitis bei Herpes zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglionitis des Hirnnerven V',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglionitis geniculata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganglionitis geniculata nach Zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangliosidthesaurismose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangliozytisches Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangliozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangosa [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangraena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangraena emphysematosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangraena pulmonis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän der Abdomenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän des Perineum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän durch Bacillus Welchii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän durch Clostridium perfringens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän durch Fusospirochäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangrän durch Spirochäten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Hernie mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Nierenbeckenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Noma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Periurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Purpura ohne Verbrauchskoagulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Pyodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöser Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangränöses Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gangunsicherheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganzjährig bestehende allergische Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganzkörperknochenszintigraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ganzkörperszintigraphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardner-Diamond-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardnerella-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardnerella-Infektion der Vagina (Aminkolpitis)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardnerella-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gardnerella-Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gargoylismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Garrulitas vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Garré-Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Garré-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gas im Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbazillus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbrand-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbrand-Myositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbrand-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrin-Sekretionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrinproduzierendes Pankreasadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Hyperazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Hypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Hypoazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Krise bei Syphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Krise bei Syphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Spätsyphilis mit Polyposis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Spätsyphilis mit Polyposis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Subazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrische Superazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis durch Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis durch Helicobacter pylori [kodiere zusätzlich B96.81!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis durch Unterernährung [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis erosiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastritis phlegmonosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrodiscoidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroduodenalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroduodenalschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroduodenitis durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroduodenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenterische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis bei Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis bei Paratyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Kryptosporidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Lebensmittelvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Nahrungsmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Rotaviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Strahleneinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis mit vermuteter infektiöser Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis paratyphosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs, mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs, mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritis, vermutlich infektiösen Ursprungs, mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteritisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenterokolische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroenteroptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrohepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Aktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Hypersensibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Hypomotilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Infektionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Mukormykose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Perforation bei Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Reizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Tuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinale Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinaler Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinaler Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrointestinalschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunales Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunales Ulkus mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunales Ulkus mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunales akutes Ulkus mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunalgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrokolische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastropathia hypertrophica gigantea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrostaxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastrosukkorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroösophageale Refluxkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroösophagealer Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gastroösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasvergiftung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gasödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaucher-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaucher-Krankheit beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaucher-Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaucher-Splenomegalie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaucher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumen- und Rachenmandelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumen-Nasengang-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenbogenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenbogenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumendachperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenmandelhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenmandelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenmandelnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenmandeltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenmandelvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumensegellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumensegelparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumensegelparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumensegelspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenspalte mit Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gaumenzäpfchenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebißanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geblähtes Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt aus Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt aus Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Kaiserschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Kaiserschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung bei Gefahrenzustand für Mutter und Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung bei Gefahrenzustand für Mutter und Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung mit Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Schnittentbindung mit Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Vakuumextraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch Vakuumextraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch elektive Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt durch elektive Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt mit protrahiert verlaufender Austreibungsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt mit protrahiert verlaufender Austreibungsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt mit protrahiert verlaufender Eröffnungsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt mit protrahiert verlaufender Eröffnungsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburt vor dem Termin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbedingte Fazialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch Beckenweichteilgewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch Beckenweichteilgewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch Rektozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch Rektozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch abnorme Beckenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsbehinderung durch abnorme Beckenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht 1000 bis unter 1250 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht 1250 bis unter 1500 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht 1500 bis unter 2500 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht 500 bis unter 750 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht 750 bis unter 1000 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht unter 500 Gramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsgewicht von 4500 Gramm oder mehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshilfliche Verletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshilfliche Verletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Anomalie des mütterlichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Anomalie des mütterlichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Armvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Armvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Beckenausgangs- und Beckenmittenverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Beckenausgangs- und Beckenmittenverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Einstellungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Einstellungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Fetalanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Fetalanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Fußlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Fußlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Haltungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Haltungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Kinnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Kinnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Mißverhältnis zwischen Fetus und Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Mißverhältnis zwischen Fetus und Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Steiß-Fuß-Lage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Steiß-Fuß-Lage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Steißlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Steißlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Tumor des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch Tumor des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch festsitzende Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch festsitzende Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch fetale Meningomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch fetale Meningomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch fetales Steißteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch fetales Steißteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch konstante hintere Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch konstante hintere Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch konstante vordere Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtshindernis durch konstante vordere Hinterhauptslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtskomplikation des ZNS durch Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtskomplikation durch Narkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtskomplikation in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsmal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsmal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsparalyse beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtstrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtstrauma des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung des Skeletts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverletzung des peripheres Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung im ersten Geburtsabschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung im ersten Geburtsabschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung im zweiten Geburtsabschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverlängerung im zweiten Geburtsabschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverzögerung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverzögerung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverzögerung beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geburtsverzögerung beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalsabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalsgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalshypertrophie mit Elongation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalskatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalsmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterhalsverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmuttermalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmuttermyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmutterriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmuttersenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmuttertuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gebärmuttervorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedeckt perforierte Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedeckt perforiertes Bauchaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedeihstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedeihstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedeihstörung beim Kleinkind/Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedrehte ovariale Zyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedrehter Harnstrahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedächtnislücke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedächtnisminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gedächtnisstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gee-Herter-Thaysen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gee-Thaysen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefleckter Zahnschmelz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geflügelzüchter-Krätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßaffektion des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßanomalie des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßarteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßatheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßatresie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßdissektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßeinscheidung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßeinsprossung der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßerkrankung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßkrankheit der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßkrankheit der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßneubildung der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßneubildung des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßring der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßschädigung der Nabelschnur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßschädigung der Nabelschnur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßveränderung der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßwandamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßwandaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßwandverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefäßähnliche Streifen der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühl der Unzulänglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühl von Herzschwere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühl ängstlich/nervös/angespannt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlsarme Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlsarme Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlsarme Psychopathie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlsarme Psychopathie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlskälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlssinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gefühlssinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gegenwärtig remittierte bipolare affektive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gegenwärtig remittierte rezidivierende depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehemmter Orgasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehemmter männlicher Orgasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehemmter weiblicher Orgasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirn-TBC [Tuberkulose] [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnabszeß durch Amöben [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnapoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnarteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnblutung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirndeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirndysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnendarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnerschütterung mit leichter Nebenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngerinnsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirngumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnkryptokokkose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnmetastase bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnpurpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirntoxoplasmose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirntuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirntumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirntyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnventrikelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnventrikelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehirnödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehunfähigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehäufte Miktionsfrequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehäufter Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangscholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangseiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsexostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsgranulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangshautneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangshypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangslues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangslues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsmykose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangspruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörgangsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörlosigkeit - s.a. Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörschwäche - s.a. Schwerhörigkeit oder s.a. Gehörverminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörverlust durch Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gehörverminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geisteskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistesschwäche - s.a. Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistesstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistesverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistig zurückgebliebene Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistige Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistige Entwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistige Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistige Spätentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistiger Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geistiges Defizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gekerbte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gekerbte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gekerbtes diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gekrösekarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gekörntzelliges Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelatinöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelb-Blau-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbe Leberatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelber-Nagel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbfieber-Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbfieber-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbkörperhormonschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbkörperzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbsucht durch Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelbsucht durch Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelegenheitsmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenk-TBC [Tuberkulose] [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkchondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkdestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkeiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkentzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkflächendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpelaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpeldegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpelerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpelerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpelschaden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkknorpelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkmaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenknahe Frambösieknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenknahe Knötchen bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkpsoriasis [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkpyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkschmerz/-erguß/-schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenksepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenksteife nach chirurgischer Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenksymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenktuberkulose [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gelenkxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemeinsamer Ventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemeinsames Stehlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemeinsames Stehlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geminiabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geminigravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischt klein- und großzelliges gekerbtes follikuläres Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Hyperglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Konversionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Kryoglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Neurose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte Thalassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte affektive Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte dissoziative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischte einfache und mukopurulente Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischter Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischter Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischter Speicheldrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtes Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtes azido-basophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtes baso-azidophiles Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtes baso-spinozelluläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtzellige Form der Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtzelliges Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtzelliges Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemischtzelliges Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemistozytisches Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemistozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemütskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemütskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemütsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gemütsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiert erhöhte Knochendichte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Aderhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Arzneimitteldermatitis durch ein eingenommenes Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Aspergillose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Atherosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Dermatitis exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Eiterabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Epilepsie als Symptom einer anderen Hirnerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Gesichtsfeldreduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Gingivaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Glykogenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Histoplasmose durch Histoplasma capsulatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Kalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Knochenverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Kokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Kolibazillose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Krankheit durch Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Kryptokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Lipogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Lymphknotenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Mukormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Osteosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Parakokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Psoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Raumforderung des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Raumforderung des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Raumforderung im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Raumforderung im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Skelettanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Skeletthämangiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Sporotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Thrombangiitis obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Vaccinia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte degenerative Ticstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte intraabdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte intraabdominale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte obliterierende Arteriolenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte primäre Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte syphilitische Arteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte syphilitische Arteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierte zytomegale Einschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter Gefäßprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter arteriosklerotischer Gefäßprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter primärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter primärer maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter sekundärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter sekundärer maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisierter/lokaler toxischer Effekt von Kohlenmonoxid, industriellen Materialien, Blei, giftigen Tieren/Insekten/Pflanzen/Schlangen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiertes Arzneimittelexanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiertes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiertes amyloides Infiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiertes atopisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generalisiertes neoplastisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generationspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generelle Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Generelle Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetisch bedingte Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetisch bedingte Granulozytenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetisch bedingte Leukozytenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetische Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetische Beratung im Zusammenhang mit der Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genetische Untersuchung im Zusammenhang mit der Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Candidaerkrankung, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Chlamydien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Pilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Soormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Soormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Soormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Trichomoniasis, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitale Verwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaler Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaler Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalherpes, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalorganvarizen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalprolaps bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalschmerz bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalsymptome/-beschwerden Frau, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalsymptome/-beschwerden Mann, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitaltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitalvarizen im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitoadrenales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitofemoralissyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genitosuprarenales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genu recurvatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genu valgum-varum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genua recurvata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genua valga',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genua vara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genuine Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genuine Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genuine Polyarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Genuine Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geometrisches phagedänisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gephyrophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geplatztes Äderchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerbasi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerichtete Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gering fixierter Rundrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringe Gewichtszunahme bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringe Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringe Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Niveau des Lese-Schreib-Vermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geringes Sehvermögen beider Augen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnsel im Kreislauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsfaktormangel durch Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsfaktormangel durch Vitamin-K-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerinnungsstörung beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Germinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerontoxon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerontoxon der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerstenkorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerstenkorn einer Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gerstenkorn einer Zeis-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geruchs-/Geschmacksstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geruchssinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geruchssinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geruchstäuschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geräuscheinwirkung auf Innenohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geräuschinduzierte Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geräuschinduzierte Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechterrollenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechtsidentitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechtskrankheit Mann, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechtskrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechtskrankheit bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlechtskälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlossene Harnleiterverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlossene Nasenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschlossene Ureterverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschmackssinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschmackssinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwister/anderem Familienmitglied',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwistereifersucht im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwisterrivalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwisterrivalität bei spezifischer emotionaler Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwollene Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwollene Knöchel/Ödeme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwollener Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwollenes Bein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst - s.a. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst eines Verdauungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst eines großen Gefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwulst im Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür des Hornhautrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Geschwür des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesellschaftliche Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesellschaftliche Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesetzlicher Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesicherte Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesicht-Stirnlage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichts- und Schädelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsdysmorphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtserfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtserysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldbegrenzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfelddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldeinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldeinschränkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldkontraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfeldtrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtshautbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtshautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtshautspinaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsherpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtshypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsknochenverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtslage des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsneuralgie des Trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsrötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschmerzen bei Erkrankung Kauapparat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschädelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschädelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschädelknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschädelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsschädelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtsverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtswundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesichtszerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestagen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestagenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestagentest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingte Galaktophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingte Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingte Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingte interstitielle Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingte parenchymatöse Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingter Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsbedingtes Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsdiabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationshypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationshypertonie mit Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsnephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsproteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestationsödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestaute Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte Fruchtwasserbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte Libido',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte Salivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte Schmerzempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte Schmerzempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerte neonatale Hämolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerter Speichelfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigerter Würgreflex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesteigertes sexuelles Verlangen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestielte Nierentorsion mit Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestielter Kolonprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Fertilität bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Frühgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Frühschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Glukosetoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Scheidenflora',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Spermatogenese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte Vaginalflora',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte intrauterine fetale Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörte sexuelle Befriedigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörter Elektrolythaushalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörtes Gleichgewicht des Elektrolythaushaltes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörtes Gleichgewicht des Endokriniums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörtes Gleichgewicht im Nahrungszusammenhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörtes Hormongleichgewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gestörtes binokulares Sehvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesund lebendgeborenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesunde Begleitperson eines Kranken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitliches Problem in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitsförderung/Präventive Medizin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitsuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesundheitsvorsorgeuntersuchung beim Kind (U1, U2, U3, usw.)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gesäßverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Getreidearbeiterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Getreidearbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Getreidekrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebemasse NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebespender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebestrang der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebestrang der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebestrang des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebetransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewebswassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewehrschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewehrschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewehrschußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewichtserhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewichtsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewichtsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewichtsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewichtszunahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewohnheitsmäßiges Trinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewohnheitstic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewächs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gewöhnliche Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ghon-Herd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ghost-cell-Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ghost-vessel-Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ghoul hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gianotti-Crosti-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gianotti-Crosti-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Giardiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gibbusbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gibert-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gibraltar-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gicht durch Nierenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtarthropathie bei Lesch-Nyhan-Syndrom [kodiere zusätzlich M14.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtarthropathie bei Sichelzellenkrankheit [kodiere zusätzlich M14.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtdiathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtekzem [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Gelenkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Iritis [kodiere zusätzlich H22.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Nephropathie [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Nierenentzündung [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtische Synovitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtknoten des Herzens [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtneuritis [kodiere zusätzlich G63.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichtniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gichttophus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Giemen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gießerfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Giftiger Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gigantismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gigantomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gigantomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gigantopapilläre Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilbert-Cholämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilbert-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilbert-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilchrist-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilles de la Tourette-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gilles-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivafibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivaleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivaläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivaschaden durch Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis desquamativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis desquamativa chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis hyperplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis hyperplastica chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis simplex marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis simplex marginalis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivitis ulcerosa chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivoglossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivoglossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivostomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivostomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivostomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivostomatitis herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gingivostomatitis herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gitterförmige Retinadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gittrige Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gittrige Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glandulär-zystische Uterushyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Cheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Endometriumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Mammahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanduläre Mammahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzmann-Naegeli-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzmann-Naegeli-Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzmann-Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glanzmann-Thrombozytasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glasbläser-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glasbläseremphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glasbläserkatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glasbläserstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glasknochenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörper-Prellungs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperabhebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperanheftungslinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperblutung bei Gerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperblutung bei proliferativer Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperblutung mit Netzhautforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperdestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörpererkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperfloater',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperfremdkörper ohne Netzhautaufschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörpermembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperprolaps bei Bulbusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperprolaps nach Contusio bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperstränge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörpertrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörpertrübung bei intraokularer Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörpertrübung nach Glaskörperblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperundurchsichtigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperverflüssigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperverlust bei CE [Kataraktextraktion]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaskörperzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaucoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaucoma absolutum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaucoma chronicum simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaucoma noncongestivum chronicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaucoma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Linsenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Linsendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Lowe-Syndrom [kodiere zusätzlich H42.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Netzhautvenenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Onchozerkose [kodiere zusätzlich H42.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Papillenprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Rubeosis iridis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom bei Rötelnembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom durch Hypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom durch Übersekretion von Kammerwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom mit Pseudoexfoliation der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom ohne Druckerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukom ohne Hochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomato-zyklitische Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomgrenzfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomverdacht bei entsprechendem Gesichtsfeldausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomverdacht bei entsprechendem Papillenbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glaukomverdacht bei retinalem Nervenfaserschichtdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichgewichtsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichgewichtsstörung der Darmflora [Dysbiose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichgewichtsstörung und Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichgewichtsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichzeitige depigmentierte und hyperpigmentierte Hautveränderung bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichzeitige optische Wahrnehmung ohne Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleichzeitiger Nieren- und Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleitbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleitepiphyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleithernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleithernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleithoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gleitrippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glenosporella-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliederstarre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliedmaßenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastom des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastom des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastom mit sarkomatöser Komponente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastoma gigantocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioblastoma multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliom des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma durum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma nasale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glioma sarcomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliomatosis cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliosis spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gliozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glisson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globale Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globale Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globale Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globoidzellen-Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globulinveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globulomaxilläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globus hystericus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globus nervosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globusgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Globusgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glockenklöppelfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomangiomatöses Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomangiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulo-tubuläre Globalinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulonephritis durch Zytomegalieviren [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulonephritis nach Streptokokkeninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulonephritis/Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomerulusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Herdnephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Amyloidose [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Fabry-Anderson-Krankheit [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Kryoglobulinämie [kodiere zusätzlich N08.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Lecithin-Cholesterin-Acyltransferase-Mangel [kodiere zusätzlich N08.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Makroglobulinämie Waldenström [kodiere zusätzlich N08.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Makroglobulinämie Waldenström in kompletter Remission [kodiere zusätzlich N08.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Malaria quartana [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Mumps [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Plasmozytom [kodiere zusätzlich N08.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Plasmozytom in kompletter Remission [kodiere zusätzlich N08.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Purpura Schoenlein-Henoch [kodiere zusätzlich N08.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Schistosomiasis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Sichelzellenkrankheit [kodiere zusätzlich N08.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Strongyloidiasis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Syphilis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei Syphilis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei hämolytisch-urämischem Syndrom [kodiere zusätzlich N08.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Krankheit bei subakuter bakterieller Endokarditis [kodiere zusätzlich N08.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomeruläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomusangiosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glomustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis areata exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis areata exfoliativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis atrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis atrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis bei Pellagra [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis bei perniziöser Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis chronica superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis chronica superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa geographica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa geographica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa marginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis exfoliativa marginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis interstitialis sclerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis interstitialis sclerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis migrans benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis migrans benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis mycotica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis superficialis corticalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossitis superficialis corticalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopharyngeuskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopharyngeusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossophytie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossophytie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopyrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossopyrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glossoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottis-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottische Kehlkopfmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottiskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottiskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottiskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottislähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottistuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glottisödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glucuronyltransferasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glue ear',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glue ear',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukagonom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukagonom des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gluko-Amino-Phosphat-Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukoglyzinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukokortikoid-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukoneogenesestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukose-6-Phosphat-Dehydrogenase-Inaktivität [G6PD-Inaktivität]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukose-6-Phosphat-Dehydrogenase-Mangel [G6PD-Mangel]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glukose-Galaktose-Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutaminazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutaminstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutarazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutenenteropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutenunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäalabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäale Tendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäaler Furunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäales Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäales Karbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäalhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäusfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäuskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glutäusphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenes Rhabdomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogeninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogeninfiltration des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenose mit Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenreiches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenreiches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenspeichersyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykogenthesaurismose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykolipoide Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykoproteinabbaudefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykoproteinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykosaminoglykan-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glykosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glyzinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glyzinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glénard-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Glückspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gnathopalatoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gnathoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gneis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gnomenwaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gnorrhoe jeglicher Lokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Effekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Mechanismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldblatt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldenhar-Symptomenkomplex [Dysplasia oculo-auriculo-vertebralis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldenhar-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldflam-Erb-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldmann-Favre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldmannspirale des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goldscheider-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Golfarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Golfellenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Golflochostium der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gombault-Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonadendysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose 2.-3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose 4. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonarthrose und retropatellare Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gongylonemiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goniosynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonoblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonoblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion der unteren Harn- und Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion der unteren Harn- und Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokken-Infektion des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokkämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonokokkämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Cowper-Drüse mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Cowper-Drüse mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Tuba uterina [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe der Tuba uterina [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe des Präputium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe des Präputium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe des unteren Urogenitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe des unteren Urogenitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe jeglicher Lokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe mit Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe mit Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe mit Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoe mit Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Adenitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Adenitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Adnexitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Adnexitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bakteriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bakteriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Balanoposthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Balanoposthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bartholinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bauchfellentzündung [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bauchfellentzündung [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bindehautentzündung [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bindehautentzündung [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bulbitis urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bulbitis urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bursitis [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Bursitis [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Condylomata acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Condylomata acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Deferentitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Dermatose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Dermatose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endometritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endophthalmitis [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Endophthalmitis [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Exostose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Exostose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Funikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gelenkentzündung [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gelenkentzündung [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gonarthritis [kodiere zusätzlich M01.36*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gonarthritis [kodiere zusätzlich M01.36*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gonitis [kodiere zusätzlich M01.36*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Gonitis [kodiere zusätzlich M01.36*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Harnblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Harnblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Hydrarthrose [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Hydrarthrose [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Keratodermie [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Keratodermie [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Keratosis [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Keratosis [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Konjunktivitis beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Konjunktivitis beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Lymphangitis des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Lymphangitis des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Mastdarminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Mastdarminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Monarthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Monarthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Nebenhodenentzündung [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Nebenhodenentzündung [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ophthalmia neonatorum [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ophthalmia neonatorum [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ophthalmie beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ophthalmie beim Neugeborenen [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Paraurethritis mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Paraurethritis mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Periarthritis [kodiere zusätzlich M73.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Periarthritis [kodiere zusätzlich M73.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Perihepatitis [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Perihepatitis [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Peritonitis [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Peritonitis [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Proktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Proktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Pyelitis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Pyelitis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Pyosalpinx [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Pyosalpinx [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Regenbogenhautentzündung [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Regenbogenhautentzündung [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Salpingo-Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Salpingo-Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Schleimbeutelentzündung [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Schleimbeutelentzündung [kodiere zusätzlich M73.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sehnenentzündung [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sehnenentzündung [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sehnenscheidenentzündung [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sehnenscheidenentzündung [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Septikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Septikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Spermatozystitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Spermatozystitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Spondylitis [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Spondylitis [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Synovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Synovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Tendosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Tendosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Tendovaginitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Tendovaginitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ureteritis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Ureteritis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zellgewebsentzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zellgewebsentzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoischer Abszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoischer Abszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoischer Eicheltripper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoischer Eicheltripper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoisches spitzes Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gonorrhoisches spitzes Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goodall-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goodpasture-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gordan-Overstreet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gorham-Stout-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gorlin-Chaudhry-Moss-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gougerot-Carteaud-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gougerot-Carteaud-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gougerot-Hailey-Hailey-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gougerot-Hailey-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gougerot-Sjögren-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Goundou bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gowers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gradenigo-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graft-versus-host-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graft-versus-host-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graham-Burford-Mayer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graham-Steell-Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graham-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gramnegative Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grand mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grand-mal-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grand-mal-Aufwachepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grand-mal-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grand-mal-Status mit tonisch-klonischem Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granularatrophie der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granularzelladenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granularzelliger Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granularzelliges Zungenmyoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granularzellmyoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulation einer Episiotomienaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulation nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulationsgewebe der Mastoidhöhle nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom durch Schistosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulom nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma annulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma apicale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma brasiliensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma eosinophilicum faciei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma faciale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma fungoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma gangraenescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma inguinale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma inguinale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma inguinale tropicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma inguinale tropicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma multiplex haemorrhagicum Koebner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma nitidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma paracoccidioides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma pediculatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma pediculatum der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma pyogenicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma rubrum nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma septicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma teleangiectaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma trichophyticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma umbilicale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuloma xantho-sidero-gigantocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatosis benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatosis disciformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Hepatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Moniliasis der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Skleritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulomatöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulosazellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulosis rubra nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulozytäres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulozytäres Sarkom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuläre Ependymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuläre Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuläre Nierenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granuläre Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Granulöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitfibrose der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitfibrose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitpneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphitstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graphospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graue-Thrombozyten-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grauer Altersstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grauer Star - s.a. Cataracta oder s.a. Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graves-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei AB0-Isoimmunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Anomalie der Beckenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Cerclage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Chromosomenanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Einstellungsanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Fehlbildung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Fehlbildung des ZNS des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Fetalanomalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Fetalschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Gesichtslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Herpes gestationis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Hydrozephalus des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Kinnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Kopf-Becken-Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Lageanomalie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Large-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Light-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Perineumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Plazentafehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Plazentainsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Querlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Retroflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Rh [Rhesus]-Inkompatibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Rh [Rhesus]-Isoimmunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Schräglage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Schädigung des Fetus durch Biopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Schädigung des Fetus durch Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Shirodkar-Naht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Small-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Stirnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Uterus bicornis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Uterus duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Uterusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Vaginaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Vena-cava-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Vulvaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Zervixanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei Zervixinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fehlendem Kopfeintritt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetalem Anenzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetalem Hygroma colli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetalem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei fetaler Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei hohem Geradstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei intrauterinem Fruchttod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei retroplazentarer Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei tiefem Geradstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei vorausgegangener Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravida-Betreuung bei wechselnder Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditas ampullaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditas extrauterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditas isthmica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditas ovarica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität am Termin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität bei kongenitaler Herz-Kreislauf-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität im Mesometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität im Uterushorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität in der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit HELLP [Hemolysis, elevated liver function test, low platelet counts]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Komplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Lebernekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit Zervixinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit akuter Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit bösartiger Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit chronischer Veneninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit pathologischem Kardiotokogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit subakuter Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit venostatischem Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität mit venöser Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidität über dem Termin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graviditätsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravidophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gravitationsbedingte Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grawitz-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Graybiel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Greenfield-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Greig-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Greisenasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Greither-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grenzdextrinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grenzpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grenzschizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grenzwertige intellektuelle Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grenzwertiger Augeninnendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grey-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grey-platelet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Griesinger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grießabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grindausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grindblasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grindflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grindknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippale Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippale Luftwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippale Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippale Virusinfektion [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippaler Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippaler Infekt mit Infektion der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippaler Infekt mit Infektion der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippaler Infekt mit bakterieller Superinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Grippaler Infekt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] der Mutter mit Schädigung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] der Mutter mit Schädigung des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Arthralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Koryza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Laryngitis, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Magen-Darm-Beteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Otitis, Influenzavirus nachgewiesen [kodiere zusätzlich H67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Pharyngitis, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Pleuraerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Seitenstrangangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit bakterieller Superinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] mit gastrointestinaler Beteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza] ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippe [Influenza]-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippebronchiolitis [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippebronchitis [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippebronchopneumonie [Influenza] ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippeotitis [Influenza] [kodiere zusätzlich H67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippeotitis [Influenza] ohne Virusnachweis [kodiere zusätzlich H67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippepneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippepneumonie [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippepneumonie [Influenza] ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippepneumonie [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippetracheitis [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippevirusinfektion [Influenzavirus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grippevirusinfektion, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grobmotorische Teilleistungsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grossesse imaginaire',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ground itch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grover-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung des Arms mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Große Weichteilverletzung mit Sehnenbeteiligung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großer chirurgischer Eingriff a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großfleckenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großfollikuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großhirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großhirnkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großhirnkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großhirnmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großhirnrindenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzehenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzehengrundgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzellig-oxyphiles Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzellig-oxyphiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzellige Einschlußkörperchenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzelliger Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzelliges Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzelliges diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Großzelliges follikuläres Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grundimmunisierung - s.a. Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppenaggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppenaggressivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppendelinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppendelinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gruppendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gryposis penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gryposis penis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gryposis penis bei Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gryposis penis lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gryposis unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gräser-Frühblüherallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gräserpollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grönblad-Strandberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Größenabweichung eines Zahns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Größenwahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grübelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grübelzwang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grün-Rot-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grünblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grüne Zahnauflagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grüner Star - s.a. Glaucoma oder s.a. Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grüner Zahnbelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grünes Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Grützbeutel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gsell-Erdheim-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guam-Parkinson-Demenz-Komplex [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guama-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gubler-Millard-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guduram',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guillain-Barré Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guillain-Barré-Polyradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gull-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma der Cauda equina [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma der Cauda equina [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des weichen Gaumens [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma des weichen Gaumens [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma syphiliticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gumma syphiliticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummiallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummöse Ostitis bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummöse Ostitis bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummöse Periostitis bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummöse Periostitis bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gummöses Frambösid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gunn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gustatorische Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gustatorisches Reflexschwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gut differenziertes Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Einimpfretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Epilepsie im Kindesalter mit zentrotemporalen Spikes im EEG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Geschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Harnblasenpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Hautgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Malaria tertiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Mammadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Mastdarmneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Nesidioblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung Nervensystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Bauchspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Bauhin-Klappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Beckenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Blutgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Bläschendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Bänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Epiglottisvorderfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Faszien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Flexura coli dextra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Flexura coli hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Flexura coli lienalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Flexura coli sinistra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Fossa tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Gaumentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haarfollikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Hauptspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut der Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut des Lidwinkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Haut des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Hirnhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Hirnventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Ileozäkalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Kalix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Karotisdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Kopfschwarte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Langerhans-Inseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Ligamente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lippenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lippeninnenseite',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lippenrotgrenze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lippenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Lymphgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Mandibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Muskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Nasenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Nasenmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Nebenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Rachentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Rippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Samenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Schlundtonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Schweißdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Sehnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Sehnenscheiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Skrotalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Synovialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Synovialmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Talgdrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Tuba Falloppio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Unterhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Vallecula epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Weichteile des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der Zungentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der extraokulären Muskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der intrahepatischen Gallengänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der paraurethralen Drüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung der peripheren Nerven der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Augenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Axillabindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bindegewebes des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Brustbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Bulbus olfactorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Canalis analis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Choanenhinterrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Dickdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ductus nasolacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Epipharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Fettgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Frenulum labii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gallensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gastrointestinaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gaumenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gelenkknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Gesichtsknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Harnsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Hirnstamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Hüftbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des IV. Ventrikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Knochens der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Knorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Kreuzbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Larynxbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Larynxknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ligamentum teres uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ligamentum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Lobus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Lobus temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Magen-Darm-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nasenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nasenknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nasenseptumhinterrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Nierenkelches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ohrbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ohrknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Orbitabindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os ethmoidale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os frontale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os nasale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os occipitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os parietale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os sphenoidale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os temporale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Os zygomaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Peritoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Retroperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Samenstrangfettgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Schlüsselbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Schädelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Steißbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Tränenkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Tränennasenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Tränensacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Unterkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Verdauungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Vomer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Zerebrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des Zwerchfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des kraniopharyngealen Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des retrobulbären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des retrookulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung des suprahyoidalen Anteils der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung einer Bursa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung einer großen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung einer kleinen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung großer Gefäße des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung muskuloskelettär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung, weibliche Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildung, weibliches Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neubildungen der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Polyzythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Rektumneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige Zyste des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige atypische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige essentielle Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige familiäre Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige myoklonische Epilepsie im Kleinkindalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige pemphigoide Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige zerebrale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige/bösartige Neubildung des Auges/der Adnexen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige/nicht spezifizierte Neubildung männliches Genitale, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartige/nicht spezifizierte Neubildung verbunden mit Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Analtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Bindehauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Darmtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Hauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Inselzelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Knoten der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Knoten der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Lymphgefäßtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Mammaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Mammaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Mammatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Mammatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Nebennierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Neugeborenenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Nierenpoltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Ovarialtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Prostatatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Rektumtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Tränendrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Tuba-uterina-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Tumor der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Uterustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Vaginaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger Vulvatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiger odontogener Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Akanthom - s.a. Neubildung, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Androblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Androblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Angioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Arrhenoblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Arrhenoblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Blasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Epitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Harnblasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Harnleiterpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Hämangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Hämangioperizytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Insulinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Kleinhirnbrückenwinkelchordom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Mesenchymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Mesonephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Nesidioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Nierenbeckenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Schleimhautpemphigoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Synovialom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Thymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Ureterpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges Zementoblastom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gutartiges rezidivierendes Blasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Guérin-Stern-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GvH-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'GvH-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandrismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandrismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandroblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynandroblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Routineuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkologische Vorsorgeuntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gynäkophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gyriverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gänsegurgelarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gänsslen-Erbsyndrom [Kugelzellenanämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gärgasintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gärgasvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gärungsdyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gärungsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gélineau-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gélineau-Westphal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Günther-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gürtelrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gürtelrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Gürtelrose/Herpes zoster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'H-Ketten-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HDL-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HELLP [Hemolysis, elevated liver function test, low platelet counts]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HFM [Hand-Fuß-Mund]-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HFME [Hand-Fuß-Mund-Exanthem]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Infektion/AIDS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Abgeschlagenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Blutkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Burkitt-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit CMV [Zytomegalievirus]-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit CMV [Zytomegalievirus]-Retinitis [kodiere zusätzlich H32.0* und B25.8]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit CMV [Zytomegalievirus]-Retinitisrezidiv [kodiere zusätzlich H32.0* und B25.8]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Candida-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Candida-Retinitis [kodiere zusätzlich H32.0* und B37.88]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Candidiasis des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Demenz [kodiere zusätzlich F02.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Demyelinisierung [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Dermatomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Entwicklungsretardierung beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Enzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Ernährungsmangel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Gedeihstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Gelegenheitsmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Gewichtsabnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hepatomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Herpes zoster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hypersplenismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Hypovolämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Isospora-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kandidose der Haut und der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kaposi-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kokzidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Krankheit der blutbildenden Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kryptokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Kryptosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Leukoplakie der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Lungenkandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Lymphknotenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Mangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Pilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Pneumocystosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Primärlymphom des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Radikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Retikulumzell-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Retinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Septikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Slow-Virus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Speicheldrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Strongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Unterhautzellgewebekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Viruspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Wasting-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit ZNS-Affektion [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit Zytomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit akuter Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit aseptischer Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit bakterieller Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit bakterieller Retinitis [kodiere zusätzlich H32.0* und A49.9]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit bösartiger Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit disseminierter Candidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit eitriger Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit erworbener hämolytischer Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit generalisierter Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit geringem Sehvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit geschwollenen Drüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit immunoblastischem Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit infektiöser Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit infektiöser Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit infektiöser Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit interstitieller lymphoider Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit interstitieller lymphoider Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit intestinaler Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit multifokaler Leukoenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit mykobakterieller Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit mykotischer Retinitis [kodiere zusätzlich H32.0* und B49]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit organisch bedingter Demenz [kodiere zusätzlich F02.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit organischem Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit präseniler Demenz [kodiere zusätzlich F02.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit respiratorischer Abnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit retinaler Gefäßveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit sekundärer Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit viraler Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Krankheit mit viraler Retinitis [kodiere zusätzlich H32.0* und B34.9]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Mikroangiopathie-Syndrom der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-Mikroangiopathie-Syndrom der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HIV-positiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HK [Herzkomplikation] - s.a. Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HKS [Herz-Kreislauf-Stillstand] - s.a. Herz-Kreislauf-Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HNCM [Hypertrophische nichtobstruktive Kardiomyopathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HOCM [Hypertrophische obstruktive Kardiomyopathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HOPS [Hirnorganisches Psychosyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HTLV [Human T-lymphotropic virus]-LAV [Lymphadenopathie-assoziiertes Virus]-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWI [Harnwegsinfekt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWK [Halswirbelkörper]-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-BWS-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Blockierung mit Zervikobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Schleudertrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Syndrom mit Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HWS-Zerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haab-Dimmer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haar-/Kopfhautsymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haaratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarausfall ohne Narbenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarausfall/Glatze/Kahlköpfigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarbalgdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarbalgfistelinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarbalgzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarbalgzysteninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarfarbenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarfollikelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarfollikelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarknäuel im Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarschaftanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarschuppenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haartransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haartransplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarwachstumsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarzellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haarzupfen bei stereotyper Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Gelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Patellaluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Patellasubluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Schulterluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle Zahnabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelle atlantoaxiale Subluxation mit Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habitueller Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habitueller Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelles Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Habituelles Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hacken-Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hackenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hackenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hackenmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hadern-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma capillare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma intramusculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma racemosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma simplex cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangioma venosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangiopericytoma benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemangiopericytoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haematocephalus internus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haematoma auris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemoglobinurica malarica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemophilus-influenzae-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemophthalmus externus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemoptysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia ante partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia intraocularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia post partum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haemorrhagia rectalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haferkorn-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haferzell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haffkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hagelkorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hageman-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hageman-Faktor-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haglund-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haglund-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haglund-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hailey-Hailey-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hairy cell Leucaemia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakennase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Krankheit durch Ancylostoma brasiliense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Krankheit durch Ancylostoma ceylonensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Krankheit durch Ancylostoma duodenale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hakenwurm-Krankheit durch Necator americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbseitenlähmung - s.a. Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbseitige Kopfschmerzen (im Sinne von Migräne)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbseitiger Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbwirbel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halbwirbelverschmelzung mit Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halitosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halitosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallermann-Streiff-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallervorden-Spatz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallopeau-Akrodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallopeau-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluces valgi mit Ballenbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallux malleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallux valgus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallux valgus et rigidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hallux valgus/varus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinatorische Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinatorische Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinogenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halluzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halo-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halothanschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hals-/Rachensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsanhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsbräune',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsentzündung durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halserfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halserfrierung mit Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halslymphknotenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halslymphknotentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsmarkverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsrippenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsrippensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halssymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halsverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halswirbelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halswirbelfraktur mit Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halswirbelsäulenschleudertrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halswirbelsäulensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halswirbelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Halszerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltlose Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltlose Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsanomalie des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsbedingte Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsbedingte Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungskyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungskyphose beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsschwäche im Schultergürtelbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haltungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hamartie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hamartoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hamartom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hamartose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hamman-Rich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammerfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammerfinger als Spätfolgen nach Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammerzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammerzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammerzehe als Spätfolgen nach Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hammond-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hand-/Fingersymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hand-Fuß-Mund-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hand-Fuß-Mund-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hand-Schüller-Christian-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hand-Schüller-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handdermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handflächenerythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handflächenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handfraktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handfurchenabnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkfraktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkssymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenktuberkulose [kodiere zusätzlich M01.13*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handgelenkverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung einer Ektoprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung einer Infusionspumpe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung einer Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines Herzschrittmachers a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines Neurostimulators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines implantierten Gerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines implantierten Gerätes für das Innenohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines implantierten Gerätes für die Knochenleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handhabung eines vaskulären Zugangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handknochenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handprolaps beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handrückenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzel-/ Mittelhandfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Handwurzelverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanhart-Syndrom [Keratodermia palmoplantaris papulosa]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanhart-Syndrom [Oroakraler Fehlbildungskomplex]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Chauffard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-MacMahon-Tannhäuser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Rössle-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hanot-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hansen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hansen-Mykobakteriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harada-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harada-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harlekinfetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harley-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnabflußbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnabflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Darm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Darm-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Douglas-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Dünndarm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Ileum-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Mastdarm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Mastdarm-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Mastdarm-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Rektum-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Rektum-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Sigma-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasen-Vaginalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenabszeß bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenausgangsmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenausweitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenbodenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenbodenzystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasendekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasendistension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasendivertikelstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenekstrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseneversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenextraversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenfistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengangrän bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasengrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsdeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalshypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalskongestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalssklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsstarre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhalsödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseninfektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseninstabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblaseninversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenphlebektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschistosomiasis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinktermyasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasensphinkterverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasentabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasentabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasentenesmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasentrigonummetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenträgheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasentuberkulose [kodiere zusätzlich N33.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenulkus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenverziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenvorfall bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwandblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwanddeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwandfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwandmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwandschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenwandtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblasenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnextravasation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnflut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harngrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harngrießabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harninfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harninkontinenz als Streßinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnkristalle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiter-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterabgangsenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterachalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteraffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteraplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteratonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiteratresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleitererweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleitergrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkolik durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleitertuberkulose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleitertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnleiterzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnorganinfektion bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnorganstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnorgantuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhren-Damm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhren-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhren-Mastdarm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenausfluss',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrendivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrendivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrendoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhreninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhreninfektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenkolik durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenmündungsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenpolyp im Sinne der Harnröhrenkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenpolyp im Sinne einer Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenpyozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenschleimhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenschleimhautvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenstriktur durch Katheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnröhrenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnrückstau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsperre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstarre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstauungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstein der unteren Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsteinabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsteindiathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsteinkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsteinleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstoff im Blut erhöht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstoffzyklusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstrahlabschwächung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstrahldrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstrahlspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnstrahlveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäureauskristallisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäureblasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäurediathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäureerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäurekonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäurestein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnsäurestein-Diathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntrakt-Pilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntraktdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntraktmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntrakttuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntransportstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harntröpfeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegedoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegserkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Enterokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Koli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Pseudomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsinfektion durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegssymptom/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegstuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnwegsverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnzuckerausscheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harnzuckerruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harris-Wachstumslinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harter Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Harter Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hartes Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hartleibigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hartnup-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hartnup-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hasenauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hasenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hasenpest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hasenscharte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hashimoto-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hashimoto-Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hashimoto-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hashimoto-Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hashitoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hass-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hass-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hass-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hassal-Henle-Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haubenleptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haubenmeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haupthistokompatibilitäts-Komplex-Klasse-I-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haupthistokompatibilitäts-Komplex-Klasse-II-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauptzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hausstauballergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hausstaubmilbenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hausstaubmilbenallergie mit Bronchialasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haustier-Rabies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haut mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haut- und Unterhauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haut-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautabszeß des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautabszeß durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautaktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie durch Kontakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie durch Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie durch Wärme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautallergie unklarer Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautamyloidose [kodiere zusätzlich L99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautamöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautanhängsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautartefakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag/Exanthem, generalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautausschlag/Exanthem, lokalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautbasalzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautbefall nach Kala-Azar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautbeschaffenheitssymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautblastomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautblässe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautchromomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautdystrophie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauteffloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauteffloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauteffloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauteiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauteruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauterysipeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautfarbe verändert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautfibrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautframbösie bis zu 5 Jahre nach der Ansteckung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautfurunkel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgeschwür a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgonorrhoe [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgonorrhoe [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgranulom durch Candidaarten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgumma [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautgumma [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauthorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauthypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauthämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion der Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion des Beins a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion des Knies a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion durch Mycobacterium marinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion durch Mycobacterium ulcerans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinfektion, posttraumatisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautinspektion nach Radiatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautintertrigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautjucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkarbunkel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkokzidioidomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkrankheit, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkruste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautkryptokokkose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautleishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautleishmanoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautleishmanoid post-Kala-Azar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautleistenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautlisteriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautläsion durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautläsion durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmadenfraß [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmelanokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmukormykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmuzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmyiasis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautnarbe mit Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautnarbenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautnekrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautnokardiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautparasitenbefall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpetechien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpigmentierungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautpustel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautrötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautrötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautschaden bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautschaden bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautschuppung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautstrongyloidiasis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsyphilis mit Geschwürbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautsyphilis mit Geschwürbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttest auf Hypersensitivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttest auf eine bakterielle Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hauttyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautunreinheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverbrennung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverletzungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautverätzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautxerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautzylindrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hautödem, nicht Quincke-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haverhill-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haxthausen-Hyperkeratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haxthausen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Haygarth-Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb [Hämoglobin]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-C-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-D-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-E-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-M-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-S-Erbanlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-SC-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-SD-krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-SE-krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hb-SS-Krankheit mit Krisen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'HbS [Sichelzellenhämoglobin]-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heavy chain disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heavy-for-date-Säugling a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heavy-for-date-baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hebephrene Dementia praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hebephrene Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hebephrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden''sche Knötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden- und Bouchard-Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Arthrose der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Knoten mit Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Polyarthrose der Fingergelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heberden-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hedinger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heerfordt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heerfordt-Mylius-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heerfordt-Mylius-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heerfordt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hefe-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hefe-Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hefepilz-Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hefepilz-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heftpflasterekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegemann-Krankheit der Trochlea humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegemann-Krankheit des Caput radii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegemann-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegemann-Syndrom des Caput radii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegglin-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hegglin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heidenhain-Syndrom [kodiere zusätzlich F02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilgymnastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilgymnastische Übung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilmeyer-Schöner-Erythroblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilmeyer-Schöner-Erythroblastose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilmeyer-Schöner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heilmeyer-Schöner-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heimweh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heine-Medin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heiserkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heiserkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heiserkeit bei Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heißhunger auf bestimmte Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heller-Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heller-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hellzelliges Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hellzelliges Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hellzelliges Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Helminthiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Helminthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Helminthose durch Ankylostoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Helminthose durch Necator americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemeralopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemianalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemianenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemianenzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemianästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiathetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophia faciei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiatrophie der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiballismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemichondrodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemichondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemichorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiektromelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemifaziale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemifaziale Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemihypalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemihypalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemihyperästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemihypästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemikardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemikranie (im Sinne von Hemizephalie)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemikranie (im Sinne von Migräne)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemimelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemimelie der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemimelie der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiparkinson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegia alternans facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegie bei infantiler Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegie bei spastischer infantiler Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegie beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemiplegische Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemispasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemispasmus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemisphärenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemisporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemitremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemizephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemizephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemmkörperhämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hemmungsfehlbildung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hench-Rosenberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Henoch-Schoenlein-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Henoch-Schoenlein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepar crocatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepar moschatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Distomiase [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische Venenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatische portal dekompensierte Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis A durch Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis A ohne Coma hepaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis A ohne Folgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B durch Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B mit Nachweis von HBcAG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B mit Nachweis von HBeAG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B mit Nachweis von HBsAG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B ohne Coma hepaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B-C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B-E',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis B-S',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis C durch Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis E',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis bei Mononukleose durch Gamma-Herpes-Viren [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis contagiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Entamoeba histolytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Herpesviren [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Immunisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Toxoplasmen [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis durch Zytomegalieviren [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis infectiosa acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis infectiosa chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis infectiosa subacuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis mit Australia-Antigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis-A-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis-B-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis-Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitis-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatitisinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatocholangiokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatocholangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatocholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatolentikuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatolienale Fibrose mit portaler Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatolienale Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalia glycogenica diffusa [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalie bei Mononukleose durch Gamma-Herpes-Viren [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalie mit Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatomegalie mit Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatonephromegalia glycogenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatopathie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatopleurale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatopulmonale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatorenale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatorenales Syndrom nach Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatorenales Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatosplenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatosplenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatozelluläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatozelluläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatozerebrales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hepatozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herabgesetztes Hörvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herauslösung aus dem Elternhaus in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herauslösung aus dem Elternhaus in der Kindheit, in ein Pflegeheim',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herausreißung eines Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herbstlaubleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdförmige Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdförmige Chorioretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdförmige Retinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdförmige Retinochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdglomerulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdmyokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdnephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herdpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Amyloidnephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Ataxie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Ataxie des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Brüchigkeit der Kapillargefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Cholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Chorioideadystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Chorioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Disaccharid-Intoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Eosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Fibrinopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Fruktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Fruktoseunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hyperlipidosis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hypoprothrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hämochromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Kapillarbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Koproporphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Leptozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Leukomelanopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Lävuloseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Lävuloseunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Nephropathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Optikusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Optikusatrophie bei Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Orotazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Osteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Ovalozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Palmoplantarkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Persistenz des fetalen Hämoglobins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Polyposis coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Pseudohämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Purpura thrombopenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Sphärozyten-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Teleangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Xanthinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre Zahnstrukturstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre ataktische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre dominante Drusen [Doyne-Drusen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre exsudative Vitreoretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre familiäre Friedreich-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre hämorrhagische Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre kleidokraniale Dysostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre leukozytäre Hypersegmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre leukozytäre Hyposegmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre olivopontozerebellare Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre periphere Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre primäre Banddegeneration der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre progressive Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre progressive Muskeldystrophie Duchenne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre sensomotorische Neuropathie, Typ I-IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre sensorische Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre sensorische Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre sideroachrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre spinale Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre spinale Friedreich-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre spinozerebelläre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre symmetrische Keratosis palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre zerebellare Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre zerebellare Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäre zerebellare Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer AC-Globulin-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Aldolasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Bluter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-I-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-II-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-V-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-VII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-X-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-XII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Faktor-XIII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Fibrinogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Gerinnungsfaktormangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Koagulationsfaktorenmangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Mangel an fibrinstabilisierendem Faktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Mangel an labilem Faktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Proakzelerinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Prokonvertin-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Prothrombinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditärer Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres Angioödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres Trophödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres Zerebellarsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres akutes Hautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres angioneurotisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres dominantes zystoides Makulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hereditäres zerebellares Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredofamiliäre Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredopathia atactica polyneuritiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredopathia hemeraloptica polyneuritiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredoretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heredosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herlitz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermansky-Pudlak-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphroditismus 46,XX mit Streak-Gonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphroditismus 46,XY mit Streak-Gonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hermaphrodytismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia abdominalis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia diaphragmatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia diaphragmatica mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia directa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia epigastrica mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia femoralis links',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia femoralis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia femoralis mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia femoralis rechts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia funiculi umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia incarcerata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia indirecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinalis directa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinalis indirecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinalis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinalis obliqua',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia inguinoscrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia intestinalis mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia ischiadica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia labialis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia littreana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia lumbalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia obliqua',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia obturatoria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia omentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia paraoesophagealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia paraoesophagealis mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia paraumbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia pudendalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia rectovaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia retroperitonealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia scrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia umbilicalis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia vaginalis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia vaginolabialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia varicosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia ventralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernia ventralis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herniation des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herniation des Gehirnstamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herniation des Mediastinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie der hinteren Scheidenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie des Corpus vitreum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie des Foramen magnum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie des Mediastinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie des graviden Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie mit Magenstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernie mit Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hernieninkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heroinabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heroinintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heroinintoxikation bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heroinmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpangina durch Coxsackie-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes circinatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes corneae [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes der Vulva [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes der Vulva [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Penis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Penis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Rektums [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Rektums [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes febrilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis recidivans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis recidivans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes genitalis, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes glutaealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes labialis recidivans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes oticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes perianalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes perianalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes progenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes progenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex Infektion des Auges ohne Cornealulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex des Auges [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex progenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex progenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex recidivans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes simplex recidivans in loco',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes tonsurans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes tonsurans corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes urogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes urogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster - s.a. Zoster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster conjunctivae [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster des Augenlids [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster des Auges [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster des Nervus facialis [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster generalisatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster mit Neuralgie [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster ophthalmicus a.n.k. [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes zoster oticus [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes-Effloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpes-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpesvirus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpesvirus-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetiforme Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetiforme Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Blepharitis [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Ganglionitis geniculata [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Gingivostomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Gingivostomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Keratitis [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Keratokonjunktivitis [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Mundschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Mundschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Pharyngotonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Pharyngotonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Rachenschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Rachenschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Vulvovaginitis [kodiere zusätzlich N77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetische Vulvovaginitis [kodiere zusätzlich N77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herpetisches Panaritium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herrick-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herrick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hers-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herter-Gee-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herter-Heubner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herter-Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hervortretende Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herxheimer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herxheimer-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herxheimer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-/Arterielles Geräusch ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herz-Kreislauf-Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzamyloidose [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzangstsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzarteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzatheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeutelhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeutelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzbeuteltamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock 2. Grades, Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock 2. Grades, Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzblock 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzdekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzdekompensation bei Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzerkrankungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzerschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzfehlbildung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzfibroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzflattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzflimmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgefäßsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgonorrhoe [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgonorrhoe [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgumma [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzgumma [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzhyperkinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzhypochondrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinfantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinfarkt - s.a. Myokardinfarkt oder s.a. Herzmuskelinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinfarktschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinnenhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz bei Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz durch Herzprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz mit Globaldekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz mit Lungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz nach Herzoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzinsuffizienz nach kardiochirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzjagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkammerflimmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkammerscheidewanddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenatresie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenerkrankungen ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappentransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklappenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzklopfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkrankheit durch Meningokokken [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkrankheit mit Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzleistungsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelschwäche im Alter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskeltuberkulose [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmuskelzellnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzohrthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzrasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzrheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzrhythmusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzrhythmusstörung durch medikamentöse Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzrhythmusstörungen ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschlagstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzspitzenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzspitzenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzsteatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzstillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzstolpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzsynkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herztamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herztransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herztransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herztuberkulose [kodiere zusätzlich I43.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzunterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzventrikelaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzventrikelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzventrikelinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzventrikelseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzverletzung mit Hämoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzversagen NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzversagen durch Herzprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzversagen nach Herzoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzversagen nach kardiochirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzvorhofdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzvorhofseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzwandaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzwandaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzwandruptur ohne Hämoperikard als akute Komplikation nach akutem Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzwassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Herzödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochrome Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochrome Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochrome Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochromie bei Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochromie bei Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochromie des Haars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterochromie durch verbliebenen metallischen nichtmagnetischen Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterologe Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heteronyme Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heteronyme Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heteropagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterophyiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterophyiasis des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterosexuelle Pseudopubertas praecox feminina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterotoper Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterozygote Hyperlipoproteinämie Typ IIa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heterozygotes Hämoglobin S',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heubner-Herter-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heubner-Krankheit [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heubner-Krankheit [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuck-Assmann-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heufieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heuschnupfen mit Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hexadaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hexenmilch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hexenschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hexenschuß durch Bandscheibenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hexenschuß durch Bandscheibenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Heyd-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatusgleitbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatusgleithernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatushernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiatusinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hibernom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenitis axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenitis der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidradenom - s.a. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidrotische Ektodermaldysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hidrozystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'High-density-Lipoprotein-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hilusdrüsen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiluslipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiluslymphknotenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hilusmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiluszelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hilärer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Himbeermal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterbliebener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hintere Spalte des Ringknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hintere Synechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hintere Synechie des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hintere Zungenbißstellung der Unterkieferzähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterer Kreuzbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterhauptbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterhornsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterstrangdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterstrangsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterstrangsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterwandinfarkt des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterwandischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterwandischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterwandschwiele des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hinterwandseptumschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiob-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hippus pupillae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnabbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnabbauprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnabszeß durch Gonokokken [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnabszeß durch Gonokokken [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienaneurysmaruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienatheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnatherosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnbasisaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnbasisarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnblutung durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirndrucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirndrucksymptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirndruckzeichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirndurchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnerweichungszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnfiliae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngefäßembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngefäßruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngefäßsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngefäßsyndrom bei zerebrovaskulären Krankheiten a.n.k. [kodiere zusätzlich G46.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirngranulom bei Schistosomiasis [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhaut-TBC [Tuberkulose] [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhauthämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhauttuberkulose [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Embolie einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Embolie einer intrakraniellen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose der Stammganglienarterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Stenose einer intrakraniellen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Thrombose einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Thrombose einer intrakraniellen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Verschluß der Stammganglienarterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Verschluß einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch Verschluß einer intrakraniellen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch komplette Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch nichteitrige Thrombose des intrakraniellen venösen Sinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch nichteitrige Thrombose einer Hirnvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarkt durch partielle Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninfarktfolge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirninsult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnleistungsschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervensyphilis [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervensyphilis [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnnervverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganische Ausfälle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganischer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganisches Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnorganisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnpurpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnrindenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnrindenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnrindendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnsinusthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammeinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammherniation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstamminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstamminsult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstammsyndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnsubstanzdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirntod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirntrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirntumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirschfliegen-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hirsutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hiss-Russel-Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histamin-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histamin-ähnliches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histaminrefraktäre Achylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histidinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histidinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histidinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histidinämiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiocytosis X',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiolymphozytäres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiomonozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytische medulläre Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytisches diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytoides Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytose mononukleärer Phagozyten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytose-Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histiozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histochromatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologie/Abstrichuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologie/Abstrichuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologie/Abstrichuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologisch gesicherte Epituberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologisch gesicherte Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologisch gesicherter Ghon-Herd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histologische Untersuchung/zytologischer Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z37'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histoplasmose durch Histoplasma capsulatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histoplasmose mit Pneumonie a.n.k. [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histoplasmose-Rhinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Histrionische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeapoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzebläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzedermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeerschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzefieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzefrieseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzekollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzemüdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeohnmacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzepyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzetetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzeurtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzewallungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hitzschlag mit Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochdruck mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochdruck mit Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochfieberhafte Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochfieberhafte Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochfieberhafter Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochfieberhafter Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochfieberhafter grippaler Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgebirgspolyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Affektbereitschaft in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Dysplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Dysplasie der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradige Vulvadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochgradiger Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochrisikoschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochtonschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochtontaubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hochwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoden bei Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenchorionepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodendystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenelefantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenembryom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodengerminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhochstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhypotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkarzinom bei Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrebs bei Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenkrebs/Seminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenmaldeszension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenmesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenreifungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackhydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackpruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensackulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensacködem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenseminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensyphilis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodensyphilis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenteratokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentuberkulose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenunterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenvarikozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenvenenkonvolut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenverlagerung in den Bauchraum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodenüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Krankheit mit lymphozytär-histiozytärer Prädominanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Paragranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hodgkin-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoffmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoffmann-Werdnig-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohe Brustrippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohe Hyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohe Kopfeinstellung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Blutdruck ohne Hochdruckkrankheit als einmaliger Meßwert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Harnleiterabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Harnleiterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Harnleiterstein mit Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Harnleiterstein ohne Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Scheidenriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Scheidenriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Ureterabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Ureterstein mit Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hoher Ureterstein ohne Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohes Alter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohl-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlkreuz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlnagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlrunder Rücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hohlwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hollenhorst-Plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Holoprosenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Holoprosenzephaliesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Holt-Oram-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Holtermüller-Wiedemann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Holzige Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homologe Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homologe Serumgelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homologe Serumhepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homonyme Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homonyme Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homozystinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homozystinurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Homozystinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hordeolum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hordeolum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hordeolum externum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hordeolum internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horizontaler Überbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Dysfunktion der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Dysfunktion der Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Dysregulation der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonelle gynäkologische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormoneller Ausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonmangel-Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonsekretion einer Non-in-loco-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonstoffwechselstörung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hormonstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horner-Bernard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horner-Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horner-Syndrom mit Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horner-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horngeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautablagerung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautabscherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautaffektion des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautanästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautdegeneration des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautdellen des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautdystrophie der vorderen Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautepitheldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauterkrankung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauterweichung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautherpes [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauthypästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautkrankheit des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautlues [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautlues [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautneovaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautperforation durch Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautperforation mit Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautperforation ohne Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautpigmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautpigmentierung durch Hornhauteinlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautreizung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautruptur mit Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautruptur ohne Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautskleraperforation mit Hornhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautspender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautstaphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautstippung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautstromadystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautsyphilis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautsyphilis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttransplantatdekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttransplantatstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhauttüpfelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautulkus des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautundurchsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautvaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautvaskularisation durch weiche Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverbrennung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautveränderung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverätzung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverätzung des Auges durch Lauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautverätzung des Auges durch Säure',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhautübersplitterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornhouttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hornschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horrortrip',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horrortrip',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horton-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horton-Magath-Brown-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horton-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Horton-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hosennässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospital-hopper-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospitalinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospitalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospitalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospitalismus beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hospitalismus beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Howship-von-Romberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hudson-Linie der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hufeisenforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hufeisenforamen der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hufeisennebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hufeisenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hufeisenriß der Retina ohne Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hultkrantz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humane Immundefizienz-Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humane granulozytäre Ehrlichiose [HGE]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humangenetische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusfraktur des proximalen Endes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humeruskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humeruskopffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humeruskopffraktur mit zwei bis vier Fragmenten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humeruskopfschiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerussarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humerusverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Humoraler Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hundebißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunds-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunger durch Nahrungsmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunger-Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungeratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungerdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungertod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungertyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hungerödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunner-Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunner-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunt-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunt-III-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunt-Neuralgie [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunt-Syndrom [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Addison-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Hurler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hunter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Huntington-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Huntington-Krankheit mit Demenz [kodiere zusätzlich F02.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Huntington-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hupert-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hupert-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hurler-Scheie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hurler-Scheie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hurler-Scheie-Variante [Mukopolysaccharidose Typ I-H/S]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hurst-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Husten (trocken oder feucht)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Husten bei grippalem Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Husten mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hustenreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Boeck-Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Boeck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Gilford-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Gilford-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Zähne durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hutchinson-Zähne durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Lymphknotendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Membranen beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Membranen beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Membranenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Membranenkrankheit der Neugeborenenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Nekrose der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyaline Skleradegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyalines Membransyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyalinflecken der Sklera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyalinose der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyalinosis cutis et mucosae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydantoin-Dysmorphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydatidenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydatidentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydatidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyde-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyde-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydranenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydranenzephalie mit Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydranzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydranzephalie mit Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrargyrosis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrarthrose bei Frambösie [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrarthrose bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrarthrose bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrarthrose durch Gonokokken [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrarthrose durch Gonokokken [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa aestivalia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa herpetiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa pruriginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa puerorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroa vacciniformia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroadenitis der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele feminae a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele multilocularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele testis mit Hydrocele funiculi spermatici',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele vaginalis communicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocele vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus externus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus internus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocephalus noncommunicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrocrania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroenzephalomeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroenzephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrohämatopneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrokalix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrokolpos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromeningozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrometrokolpos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromikrozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromphalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromphalus seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydromyelozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrose bei Obstruktion durch Nierenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrose bei Obstruktion durch Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrose ohne Funktionseinschränkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrotische Sackniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrotische Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydronephrotische stumme Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroperitoneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrophobie - s.a. Tollwut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropneumohämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropneumoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops in der Bauchhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops intermittens articulorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrops tubae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropyelon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropyonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropyoureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydropyoureteronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhachis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhoea gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhoea gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhoea nasalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhoea nasalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrorrhoea nasalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrospermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroureter mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrourethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxykynureninurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxylapatit-Rheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxylysinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxylysinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxyprolinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydroxyprolinämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozele des Nuck-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozephalus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozephalus durch Verschluß des Aquaeductus Sylvii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrozephalus ohne Hirndrucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hydrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hygroma praepatellare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen cribriformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen falciformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen fimbriatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen imperforatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen imperforatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen imperforatus sive occlusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen semilunaris bifenestratus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen septus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymen subseptus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenalfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenalplattenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenalseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenolepiasis diminuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenolepiasis nana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenolepis-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hymenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypakusis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperabduktions-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperadrenalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperadrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperadrenokortizismus, nicht in Verbindung mit Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaktives Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaktivität beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaktivität im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperakusis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalimentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalimentation durch Karotin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalimentation durch Vitamin A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalimentation durch Vitamin D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperalimentationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaminoazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaminoazidurie durch Arginin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaminoazidurie durch Lysin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaminoazidurie durch Ornithin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperaminoazidurie durch Zystin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperammonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperandrogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperandrogenämie bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperandrogenämie beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperazidität des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperazotämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperbetalipoproteinämie mit Präbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperbilirubinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchlorhydrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchlorämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypercholesterinämie mit endogener Hyperglyzidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypercholesterinämie mit endogener Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypercholesterinämische Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchrome Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchrome Schädigung bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchrome Schädigung bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperchylomikronämie mit Hyperbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperdaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperelektrolytämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis bei Frühgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperemesis mit Stoffwechselstörung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperergische Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperexzitabilität beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperfibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperfibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperfollikulinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperfruktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperfunktionelle Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypergammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypergammaglobulinämie Waldenström',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypergastrinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperglykämie nach Pankreatektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperglyzinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperheparinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperheparinämie nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhistidinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhormonale Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperhydroxyprolinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperimmunglobulin-E-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperinsulinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperinsulinismus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperinsulinismus mit hypoglykämischem Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperinsulismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkaliämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkalziurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkalzämische Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkapnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Fußsohle bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Fußsohle bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Fußsohle bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Handfläche bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Handfläche bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratose der Handfläche bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis follicularis et parafollicularis in cutem penetrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis gonorrhoica [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis gonorrhoica [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis palmoplantaris climacterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratosis vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratotische Fußmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratotisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkeratöse Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinesie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinesie in der Adoleszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinesis laryngis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Reaktion im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Reaktion im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetische Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetisches Herzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetisches Syndrom im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetisches Syndrom mit Entwicklungsrückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkinetisches Syndrom mit Störung des Sozialverhaltens im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperkyphose der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperleukozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperleuzin-Isoleuzinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie I nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie III nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie IIa nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie IIb nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie IV nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie Typ IIa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämie V nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipidämische Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie I nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie Typ III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie Typ IIa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie Typ IIb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie Typ IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie V nach Fredrickson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie vom Low-densitiy-Lipoprotein-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipoproteinämie vom Very-low-density-lipoprotein-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlipämische Hepatosplenomegalie vom Typ Bürger-Grütz [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlordose der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperlysinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermagnesiämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermethioninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermetropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypermobilitätssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypernatriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypernephroider Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypernephroides Nierenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypernephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperorexia nervosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperornithinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperosmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperosmolalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperosmolares diabetisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis ankylosans vertebralis senilis [Forestier-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis ankylosans vertebralis senilis [Forestier-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis corticalis des Schädels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis corticalis infantilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperostosis frontalis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperovarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperoxalurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperperistaltik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpermeabilität der Kapillaren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphalangie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphenylalaninämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphosphaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperphosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpigmentation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpigmentierte Hautveränderungen bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpigmentierte Veränderungen bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpinealismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasia cementi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des Zahnzements',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des endokrinen Pankreasdrüsenanteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie des endokrinen Pankreasdrüsenanteils mit Glukagonüberproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie durch Zahnprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplasie von Halslymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Endozervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Pansinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Periostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Pulpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische endemische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperplastische ileozökale Tuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpotassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperprolinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperprolinämie Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperprolinämie Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpräbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpyrexie durch Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpyrexie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperpyrexie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperreaktives Bronchialsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperreflexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperreflexive Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperreflexive Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperreninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersalivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion der Tränendrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion testikulärer Hormone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Adrenalin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Gastrin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Glukagon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Katecholaminen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Somatostatin aus dem endokrinen Pankreasdrüsenanteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Somatotropin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Somatotropin-Releasing-Hormon [SRH] [GHRH] aus dem endokrinen Pankreasdrüsenanteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Speichel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Thyreokalzitonin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Wachstumshormon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von pankreatischem Polypeptid aus dem endokrinen Pankreasdrüsenanteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von vasoaktivem gastrointestinalem Polypeptid aus dem endokrinen Pankreasdrüsenanteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretion von Östrogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersekretive Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensibilität des Karotissinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensibilität des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitive Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitive Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitive Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitive Pneumonitis durch eingeatmeten organischen Staub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitiver Karotissinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersensitives Labyrinth',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersexualität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersomnie-Bulimie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperspleniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersplenismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersteatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersteatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypersuprarenalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herz- und Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herz- und Nierenkrankheit mit Herz- und Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herz- und Nierenkrankheit mit Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herz- und Nierenkrankheit mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Herzkrankheit mit Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Nierenkrankheit mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Nierenkrankheit ohne Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensive kardiorenale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensives Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensives Linksherzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertensives Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthecosis ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthermie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthermie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyme Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthymie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreoidismus ohne Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreokalzitonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose bei Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose bei Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose bei Struma mit multifokaler Autonomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose mit toxischer einknotiger Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose vom Typ Basedow',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperthyreose/Thyreotoxische Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Netzhautgefäßveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Uteruskontraktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Uteruskontraktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie der Mutter bei Schwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie durch endokrine Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Altersherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Nephrosklerose und Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Nierenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit Zyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonie mit diffusen sklerosierenden glomerulonephritischen Läsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonische Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonische Wehenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonische Wehenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonisches Gehirnödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertriglyzeridämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophe Analfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophe Analpapillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophe Hautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Papillae foliatae der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Papillae foliatae der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Tunica muscularis der Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Unterzungendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der Zungentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Colliculus seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Corpus cavernosum penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Trigonum vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Zungenfrenulums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des Zungenfrenulums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie von Hiluslymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophie von adenoidem Gewebe und Tonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophiertes Hautanhängsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Déjerine-Sottas-Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Form der peronäalen Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Gastropathie Ménétrier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Neuropathie im Kleinkindalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Osteoarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Periostitis bei Frambösie [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Periostitis bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Periostitis bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Pylorusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Querbarre des Harnblasenausganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Subaortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Zikatrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische hyperplastische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertrophische nichtobstruktive Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypertyrosinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperurese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperurikosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperurikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervalinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperventilationsdyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperventilationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperventilationstetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperviskositätssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervitaminose B6',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervitaminose durch übermäßigen Gebrauch von Vitaminpräparaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervitaminose-A-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypervolämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperämie der Analschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperästhesie der Körperoberfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyperöstrogenismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyphäma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypnolepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypnotikaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypnotikaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypnotikamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypnotikamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoadrenalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoakusis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoalbuminämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoaldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoalimentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoalphalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoazidität des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypobarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypobaropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypobetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochlorhydrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochlorämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochlorämisches Nierensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrischer Wahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondriumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondriumsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondrogenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondroplastischer Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondroplastischer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochondroplastischer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochrome Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochrome Anämie mit Eisenspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochrome mikrozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochromie der roten Blutkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypochylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoeosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoferroanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypofibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypofunktionelle Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogammaglobulinämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogeusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossuskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossuslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglossusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämie des Säuglings durch den Diabetes der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämie mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämische Reaktion durch Insulin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämischer Schock bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämischer Schock bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämischer Schock bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämisches Koma bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämisches Koma bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoglykämisches Koma bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogonadismus-Syndrom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogonadotrope Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogonadotroper Eunuchoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypogonadotroper Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypohidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypohydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokaliämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokaliämische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokaliämische periodische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokalziämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokalzämie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokinetisches rigides Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokomplementämische urtikarielle Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokontraktilität des Blasenmuskels ohne neurologisches Substrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokortisolismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoleukozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypolipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomagnesiämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomanische Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomanische Form der manisch-depressiven Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomanische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomanische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypometabolismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyponatriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyponatriämie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoosmolalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoovarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharyngeale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxtasche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopharynxzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophosphatasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysendystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysengumma [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysengumma [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophyseninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophyseninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenlues [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenlues [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysensekretionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysensyphilis [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysensyphilis [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysentuberkulose [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenvorderlappenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenvorderlappenüberfunktion mit Akromegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenvorderlappenüberfunktion mit Gigantismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenvorderlappenüberfunktion mit Riesenwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysenüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysitis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysäre Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysäre Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Basophilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Gigantismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Hyperadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Hyperkortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Hypoadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Riesenwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysärer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypophysäres Infantilismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopinealismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopituitarismus nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopituitarismus post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopituitarismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasia uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Nabelschnurarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Thyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Vorderhornzellen des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie der Zonula ciliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Corpus callosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Corti-Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Labyrinthus membranaceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Myokards im rechten Ventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie des knöchernen Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie einer endokrinen Drüse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie peripherer Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie peripherer Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplasie peripherer Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoplastische Chondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoproakzelerinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoprokonvertinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoprothrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoptyalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypopyon der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyporeflexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyporeninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposekretion der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposensibilisierung gegenüber Allergenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposialie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposiderinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposomnia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospadia coronaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospadia glandularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposphagma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypospleniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostasepneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostatische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostatische Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostatische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostatische Lobärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypostatisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposthenurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposuprarenalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hyposystolischer Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotelorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothalamische Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothalamischer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothalamusdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothalamusüberaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothermie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothermie durch niedrige Umgebungstemperatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothermie nach Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothermie ohne niedrige Umgebungstemperatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyme Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyme Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyme Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreoidismus nach Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreoidismus nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose durch Jodmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose durch PAS [p-Aminosalicylsäure]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose durch Phenylbutazon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose durch Resorzin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose nach Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose nach Jodbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose nach Strumektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreose/Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreote Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypothyreoter endemischer Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Dehydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Hyperhydratation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Kreislaufdysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone Regulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie bei Kreislaufdysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie mit Kreislaufbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie mit Kreislaufschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie nach langem Stehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotonie, Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotrichose durch ein zytotoxisches Arzneimittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotropher Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotrophes Frühgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotrophes Reifgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovitaminose K',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovolämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovolämie bei postoperativem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypovolämie bei traumatischem Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxie unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxisch-ischämischer Hirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxischer Hirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoxämische Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypoästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypsarrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hypästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysteralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysteralgie des graviden Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Abasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Ageusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Akkommodationslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Anorexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Anosmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Astasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Asthenopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dysbasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dysorexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dysphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Dysästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Fugue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Kamptokormie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Katalepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Kontraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Körperhaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Mondsüchtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Pseudogravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Pseudotetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Psychoneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Stummheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Taubstummheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Trance',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterische flüchtige Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Dämmerzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Mutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Somnambulismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Traumzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterischer Vaginismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterisches Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterisches Ganser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysterisches Nachtwandeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysteroadenosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hysteroepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioblastisches Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioendotheliales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioendotheliom des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioendotheliosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioleiomyolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiom/Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiomatose, eine Lokalisation betreffend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiomatöses Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioperizytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangioperizytöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämangiosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämarthros',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatemesis und Meläna beim Neugeborenen durch Verschlucken mütterlichen Bluts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämathidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatobilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatochylurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatochylurie bei Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatochylurie bei Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatochylurie durch Bilharzia haematobia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatogene Infektion der Nierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatogener Leberabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatokolpos mit Hämatometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatokolpos mit Hämatosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatokornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatologische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatologischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom der Aorta dissecans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom durch Geburtsverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom einer Episiotomiewunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom einer Sektiowunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom einer geburtshilfliche Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom eines chirurgischen Amputationsstumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatom nach Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatommole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatomole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatomyelie beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatomyelie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatopneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatorrhachis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatorrhachis beim Fetus durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatorrhachis beim Neugeborenen durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatosalpinx mit Hämatometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele bei der Frau a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele beim Mann a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämatozele des Ligamentum teres uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämaturie bei Antikoagulanzientherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämobilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämochromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämochromatose der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämochromatose des Myokard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämochromatose mit refraktärer Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämodialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobin vom AS-Genotyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobin-M-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinopathie mit Thalassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinurie durch Belastung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinurie durch Hämolyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinurie durch erworbene hämolytische Anämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinurische Nephrose [Chromoproteinniere]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoglobinämie durch Bluttransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Anämie durch instabile Hämoglobine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Krankheit beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Krankheit beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Krankheit durch Rh-Faktor beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Kälteanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Lederer-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische Wärmeanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische autoimmune Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische familiäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische familiäre Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische hereditäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische konstitutionelle Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische mechanische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytische toxische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytischer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytischer familiärer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämolytischer konstitutioneller Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoperikard beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophagozytäres Syndrom bei Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophilie A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophilie B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophilie C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämopneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämopneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoptyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämoptyse beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie aus dem Tracheostoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie bei Frühschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie bei Schlaganfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Capsula interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Cervix uteri a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Chorioidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Medulla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Pons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Retinagefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Schleimhaut a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Thyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Tonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Zervix a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der inneren Organe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Corpus Luysi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Duodenums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Fundus oculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Mesenzephalons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Nagels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Nasopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Nucleus subthalamicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Peritoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Rektumsphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Urogenitaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des Zervixstumpfes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie des rupturierten Graaf-Follikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie durch Sichlösen einer Nabelschnurligatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie einer Gefäßligatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie einer Zahnalveole nach Extraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie einer rupturierten Zyste des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie eines Amputationsstumpfes nach Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie in peritonsilläres Gewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagie post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Adrenalitis durch Meningokokken [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Apoplexie der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Dengue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Anti-IXa-Vermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Anti-VIIIa-Vermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Anti-XIa-Vermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Anti-Xa-Vermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Antikoagulanzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diathese durch Antithrombin-Vermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Follikelzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Glaskörperabhebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Intestinumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Kieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Konjunktivitis durch Enterovirus Typ 70 [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Leptospiren-Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Lungenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Luteinzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Metropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Nebennierenentzündung durch Meningokokken [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Nephrose-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Pocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Polioencephalitis superior [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Spirochäten-Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Zyste des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Zyste des Kieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische infektiöse Endotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagische nichtthrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagischer Ikterus durch Leptospiren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagischer Ikterus durch Spirochäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Arthropoden-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Bangkok-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Chikungunya-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber durch Arboviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber durch Arenaviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber durch Lassa-Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber durch Moskitos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Fieber mit Nierenbeteiligung [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches Philippinen-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches postoperatives Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches pulmorenales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhagisches zystisches Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidale Marisken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidalvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden mit Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoiden ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämorrhoidenstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämosiderinablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämosiderinspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämostasestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hämothorax beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängebauch bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängebrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängebrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängefuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängeohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hängeohrdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufige Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufige nächtliche Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufige oder flüssige Darmentleerungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufiges Harnlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufiges Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufiges nächtliches Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häufiges psychogenes Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häusliche Betreuung eines Kranken in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häutige Fingersyndaktylie ohne Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Häutige Zehensyndaktylie ohne Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höckerbildung der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höckernase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höhenangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höhenflugspolyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höhenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höhenpolyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Höhenschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörbarer Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hördefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörnervenneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörnervensyphilis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörnervensyphilis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörsturz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörtest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüft-TBC [Tuberkulose] [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkinstabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkpfannendachfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkpfannenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkreifungsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenktuberkulose [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftgelenkversteifung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftkopfbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftkopffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftkopfnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftpfannengrundfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüfttuberkulose [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hüftzerquetschung mit Oberschenkelzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hühnerauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hühnerbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hürthle-Zell-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hürthle-Zell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Hürthle-Zell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'I-Zell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ICE [Iridokorneales endotheliales Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IDDM [Insulin dependent diabetes mellitus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IHK [Ischämische Herzkrankheit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IHSS [Idiopathische hypertrophische Subaortenstenose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IQ 20-34 [Schwere Intelligenzminderung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IQ 35-49 [Mittelgradige Intelligenzminderung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IQ 50-69 [Leichte Intelligenzminderung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IQ unter 20 [Schwerste Intelligenzminderung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IRDS [Infant respiratory distress syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ISTA [Isthmusstenose der Aorta]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogene Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogene Hypophysenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogene Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogene Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogener Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogener Hyperinsulinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogener Hypothyreoidismus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogener Östrogenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iatrogenes Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosiformes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis congenita gravis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis hystrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ichthyosis vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus - s.a. Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus intermittens juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus maligne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus neonatorum durch gesteigerte Hämolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus neonatorum gravis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Icterus neonatorum prolongatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ictus solaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Id-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Id-Reaktion durch Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Identitätskrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Identitätsstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ideokinetische Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ideomotorische Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idioglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hautsarkomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hoffa-Kastert-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hyperkalziurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hypoprothrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Kardiomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Kardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Kataplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Kryoglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Makroglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Osteoporose mit pathologischer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Parkinson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Pfortaderhypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Proktokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Pyknolepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Skoliose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Skoliose beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Skoliose beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Steatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Urethrahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische Zahnerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische adrenogenitale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische aseptische Knochennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische autonome Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische generalisierte Osteomyelofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische hypertrophische Subaortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische hämorrhagische Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische infantile Hyperkalzämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische membranöse Glomerulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische nichtthrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische peripher progressive Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische periphere Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische progressive Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische retroperitoneale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische rezidivierende Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathische thrombozytopenische Purpura (Werlhof)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathischer Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathischer Riesenharnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathischer Somatotropinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathischer Wachstumshormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathisches Chloasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathisches Cushing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathisches Grand mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathisches Petit mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiopathisches kardiorespiratorisches Distreßsyndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiosynkrasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Idioventrikulärer Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgA [Immunglobulin A]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgA [Immunglobulin A]-Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgA [Immunglobulin A]-Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgA [Immunglobulin A]-Plasmozytom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgE [Immunglobulin E]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgG [Immunglobulin G]-Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgG [Immunglobulin G]-Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgG [Immunglobulin G]-Plasmozytom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'IgM [Immunglobulin M]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ikterische Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ikterus im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis segmentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis terminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileitis ulcerosa chronica stenosans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileocolitis regionalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileocolitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileosigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileostomie mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileostomieprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileotyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileovaginalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileozökale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileozökale Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileozökaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumabknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumkarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumknick',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileumvolvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus durch Bauchfellverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ileus obturatorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliakalabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliakale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliofemorale Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliofemorale Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliofemorale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ilioinguinalissyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakrale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenkblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenkkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralgelenksteifheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliosakralschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliotibial-band-syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iliumfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Illegale Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Illegale Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Illegaler Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Illegaler Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imbezillität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imerslund-Gräsbeck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imidazol-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iminosäurekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immaturität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imminenter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunadrenalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunallergische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefekt mit Antikörpermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefekt mit Thrombozytopenie und Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefekt mit disproportioniertem Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immundefektsyndrom [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunglobulin-A-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunglobulin-M-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunglobulinprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunhemmkörperhämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immuninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunisation - s.a. Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunisierung - s.a. Impfung oder s.a. Isoimmunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunisierung/Transfusionsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunitätsmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunkomplex-Glomerulonephritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunkomplex-Nephritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunkomplex-Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunmangelsyndrom [AIDS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunmyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunoblastisches Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunoblastisches diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunogene Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunogenes Hornhautinfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunogenes Hornhautinfiltrat durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunogenes Hornhautinfiltrat durch Staphylokokken-Blepharokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunologisch bedingte Sterilität bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunologisch bedingter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunproliferative Dünndarmkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunproliferative Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunproliferative Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunprophylaxe [passive Impfung] gegen Hepatitis B (mit spezifischem Immunglobulin)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunprophylaxe [passive Impfung] gegen Tetanus (mit spezifischem Immunglobulin)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunprophylaxe [passive Impfung] gegen Tollwut (mit spezifischem Immunglobulin)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunthyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunvaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Immunvaskuläre Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impaktierter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impaktierter Zahn mit abnormer Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impaktierter Zahn mit abnormer Stellung benachbarter Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impaktiertes Cerumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imperativer Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imperforatio ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imperforatio vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imperforation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetiginisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetiginisation anderer Dermatosen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetiginisiertes endogenes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetiginöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo Bockhardt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo als Folge anderer Hautkrankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo contagiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo contagiosa durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo contagiosa durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo des Augenlids [kodiere zusätzlich H03.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo des äußeren Ohrs [kodiere zusätzlich H62.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo furfuracea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo herpetiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impetigo vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfkomplikation nach BCG [Bacille-Calmette-Guérin]-Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfmalaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Diphtherie-Pertussis-Tetanus-Haemophilus influenzae Typ b mit Poliomyelitis [DPT-IPV-Hib] [DTPa-IPV-Hib] [DaPT-IPV-Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Diphtherie-Tetanus [DT] [Td]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Diphtherie-Tetanus-Haemophilus influenzae Typ b [DT-Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen FSME [Zentraleuropäische Frühsommer-Meningoenzephalitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Hepatitis A und B [HAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Hepatitis B-Haemophilus influenzae Typ b (HB-Hib)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Keuchhusten [Pa] [aP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Meningokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Pertussis [Pa] [aP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Tetanus-Diphtherie mit Poliomyelitis [Td-IPV]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Viruserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Windpocken [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impfung gegen Zentraleuropäische Frühsommer-Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impingementsyndrom der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantationszyste der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantationszyste der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantationszyste der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantationszyste der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantationszyste des Ziliarkörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Implantatproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impotentia sexualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impotenz ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impotenz organischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impotenz organischen Ursprungs a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impulsiv-Petit-mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impulsives Petit mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Impulsivneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imstichlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imstichlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Imstichlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Ernährung, die eine Mangelernährung verursacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Eßgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Eßgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Reaktion auf die Anforderungen des täglichen Lebens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inadäquate Wohnverhältnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktive Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktive Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktive Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktive rheumatische Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktivitätsosteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inaktivitätsosteoporose mit pathologischer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition bei Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition bei Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition durch Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition durch Verhungern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanition mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanitionsatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanitionsdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inanspruchnahme des Gesundheitswesens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inappetenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Incontinentia - s.a. Inkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Incontinentia alvi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Incontinentia faecalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Incontinentia urinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Incontinentia vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indeterminierte Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indiana-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indigestion völlig verdorbener Lebensmittel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indirekte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indirekter Leistenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indische Wäscherflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indisches Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indisposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indisposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Individuum mit Marker-Heterochromatin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Individuum mit autosomaler Bruchstelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indolentes Fußulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induratio penis plastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induration des Corpus cavernosum penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induration des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induration des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induration des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Indurationspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Industriell bedingte Sprühinjektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induzierte Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induzierte paranoide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induzierte paranoide Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induzierte psychotische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Induzierter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inertia des Uterus bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inertia des Uterus bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inertia uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inertia uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infans mortuus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infant-Petit-mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Form der GM2-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Gaucher-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Gaucher-Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Genitalien nach der Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Melanodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Petit-mal-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Pseudoleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Quadriplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Querschnittlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Triplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Zerebralparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile amaurotische Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile ataktische Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile dyskinetische Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile papulöse Akrodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spastische Diplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spastische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spastische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spastische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spastische Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spinale Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile spinale Muskelatrophie Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile zerebrale Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile zerebrale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantile zerebrale spastische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiler Autismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiler Skorbut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiler Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiler Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Ekzem mit Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Myxoedema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles endogenes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantiles primäres Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infantumekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt der Mesenterialgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt des Hypophysenvorderlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infarkt des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt der unteren Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekt ohne Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektanfälligkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektarthritis [Reaktive Arthritis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektbedingte Exazerbation eines allergischen Bronchialasthmas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektbedingtes Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektbedingtes Bronchialasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion aller Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion als Komplikation der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion an nicht spezifizierter Stelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion bei Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion bei artifizieller Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Amnionhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Atemorgane durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Beckenorgane nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Eustachi-Tube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Fruchtblase und Eihäute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Geschlechtsorgane bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Geschlechtsorgane nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Glans penis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Harnorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Harnwege NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Leber durch Clonorchis sinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Maxilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Sektiowunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Skene-Gänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der Zeis-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der axillären Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der oberen Atemwege, akute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion der unteren Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Fruchtwassers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Kreislaufsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Meatus urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Präputiums a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Respirationstraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Speichelganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Urogenitaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Urogenitaltraktes bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Vas deferens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Verdauungskanals a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des Verdauungskanals a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des muskuloskelettären Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des männlichen Genitaltraktes durch Herpesviren [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des männlichen Genitaltraktes durch Herpesviren [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des weiblichen Genitaltraktes durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion des weiblichen Genitaltraktes durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Absidia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Acanthocheilonema perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Acinetobacter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Acremonium falciforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Actinobacillus actinomycetem comitans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Actinomyces israelii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Allescheria boydii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Anaerobier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Anisakis-Larven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ankylostoma duodenale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ankylostoma-Arten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Anthraxbazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Arboviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ascaris lumbricoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Bacillus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Bacillus anthracis - s.a. Anthrax oder s.a. Milzbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Bacteroides a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Balantidium coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Bandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Basidiobolus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Blastomyces',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Bordetella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Borrelia burgdorferi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Brucella abortus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Brucella canis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Brucella suis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Brugia malayi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Candiru',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Capillaria hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Capillaria philippinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Cephalosporium falciforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Chilomastix intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Chlamydia psittaci',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Clonorchis sinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Coccidioides immitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Conidiobolus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Coxiella burnetii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Cryptococcus neoformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Cryptosporidium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Cunninghamella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Cysticercus cellulosae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Dibothriocephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Dicrocoelium dendriticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Dipetalonema perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Diphyllobothrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Dracunculus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Dracunculus medinensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Drechslera hawaiiensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ducrey-Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ducrey-Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Eberthella typhosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Echinococcus alveolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Echinococcus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Echinococcus granulosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Echinococcus multilocularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Entamoeba histolytica - s.a. Amöbiasis oder s.a. Krankheit durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Enterobius vermicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Enteroviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Entomophthora',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Epidermophyton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Erysipelothrix insidiosa rhusiopathiae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Essigbakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fadenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fasciola gigantica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fasciola hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fasciola indica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fasciolopsis buski',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fischbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fischbandwurmfinnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fonsecaea compactum [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Fonsecaea pedrosoi [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Francisella tularensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Friedländer-Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Geotrichum candidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Gnathostoma spinigerum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Gongylonema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Guineawurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Hantaan-Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Helicobacter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Helicobacter pylori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Helicobacter pylori bei Ulcus duodeni [kodiere zusätzlich B96.81!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Helicobacter pylori bei Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Helminthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Heterophyes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Histoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Hormodendrum compactum [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Hormodendrum pedrosoi [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Hundebandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Hymenolepis nana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch ICD [Implantierbarer Cardioverter-Defibrillator]-System',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Isospora belli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Isospora hominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Katzenleberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Koronaviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Lamblia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Lanzettegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Larven des Schweinebandwurmes - s.a. Zystizerkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Lebensmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Legionella pneumophila',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Leishmania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Leishmania infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Leptosphaeria senegalensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Leptospira interrogans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Leptospiren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Listeria monocytogenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Loboa loboi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Madenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Madurella grisea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Madurella mycetomi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Malassezia furfur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mansonella ozzardi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mansonella perstans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mansonella streptocerca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Medinawurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Metagonimus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mikrosporum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mycelium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mycobacterium leprae - s.a. Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mykobakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Mykoplasma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Myzel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Naegleria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Necator americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Neotestudina rosatii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Oesophagostomum-Arten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Onchocerca volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Opisthorchis felineus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Opisthorchis tenuicollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Opisthorchis viverrini',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Orfviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Orthopoxviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Oxyuris vermicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Papovaviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Paracoccidioides brasiliensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Paragonimus westermani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Paragonimus-Arten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Parainfluenzaviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Parvoviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pasteurella multocida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Peitschenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Petriellidium boydii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Phialophora verrucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Piedraia hortai',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pneumocystis carinii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pneumokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Proteus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Proteus mirabilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Proteus morganii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Proteus vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pseudallescheria boydii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pseudomonas aeruginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pseudomonas mallei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pseudomonas pseudomallei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Pyrenochaeta romeroi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rattenbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Retroviren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rhinosporidium seeberi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rhinoviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rhizopus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rickettsia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rickettsia burnetii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Rinderbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Salmonella paratyphi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Salmonella typhi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sarcocystis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schafleberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma haematobium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma intercalatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma japonicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma mansoni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma mattheei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schistosoma mekongi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Schweinebandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sparganum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sparganum mansoni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sparganum proliferum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Spirillum minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Spirometralarven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sporothrix schenkii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Sporotrichon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Spulwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Staphylokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Stellantchasmus falcatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Streptobazillus moniliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Streptokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Streptomyces',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Taenia saginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Taenia solium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Ternidens deminutus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Torula histolytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Toxocara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Toxoplasma gondii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trematoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Treponema pallidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Treponema pallidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trichinella-Arten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trichomonas intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trichophyton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trichosporon beigelii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trichosporon cutaneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trypanosoma brucei gambiense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trypanosoma brucei rhodesiense',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Trypanosoma cruzi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Vacciniavirus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Yersinia pestis - s.a. Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Zestoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Zwergbandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch adulte Form von Diphyllobothrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch adulte Form von Diphyllobothrium latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch adulte Form von Diphyllobothrium pacificum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch adulte Form von Taenia saginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch einen Katheter zur Peritonealdialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch gemischte bakterielle Flora a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch gramnegative Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch humanes Papillomavirus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch humanes T-Zell-lymphotropes Virus Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch implantierten Cardioverter-Defibrillator',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch implantierten Herzschrittmacher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion durch tropische Candida albicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion einer Episiotomiewunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion einer Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion einer postoperativen Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion eines Gefäßkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion eines Harnwegskatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion eines Hauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion eines Zystostomiekatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion eines chirurgischen Amputationsstumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion inguinaler Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion nach Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion paraurethraler Gänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion von Lymphknoten der Leiste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion wiederangenähter Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektion zervikaler Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektionen endokriner Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Amboß-Steigbügel-Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Beule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Diarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Enteritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Enteritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Gastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Harnröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Hypertrophie der Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Hämatosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Ischialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Krankheit in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Mononukleose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Mononukleose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Noma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Penisleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Periarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Perisplenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Phthisis bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Ruptur des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Sehnenscheidentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse atrophische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse branchiogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse diarrhöische Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse diarrhöische Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse ekzematöse Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse multiple Neuritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse submammäre Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse virale Enzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöse Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Croup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöser Pyopneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Fieber a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Granulom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Hämoperitoneum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Lungengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Nasennebenhöhlengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses intertriginöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektiöses Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infektsinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infekttracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infertilität bei Uterusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infertilität bei fehlender Ovulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infertilität/Subfertilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infertilität/Subfertilität, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infiltration der Hornhaut des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infiltrierendes Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Callositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Nahtdehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Steißbeinzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte Wunde ohne Erstversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierte adenoide Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Finger/Zeh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Hautsinus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Insektenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Kallus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Klavus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Sinus pilonidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infizierter Spontanabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infiziertes Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infiziertes Hautanhängsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infiziertes Hühnerauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inflammatorisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inflammatorisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza - s.a. Grippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza mit Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza mit Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza mit Pneumonie, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza mit Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza ohne Virusnachweis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Influenza, Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infraklavikulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infraorbitale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infraorbitalneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infrarenale Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infrarenales Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infrarenales Bauchaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infratentorielle Hirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infraumbilikale Bauchwandhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Infusionskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ingestion bei Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ingestions-Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinale Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinale Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinale Epidermatophytose [Epidermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie mit Inkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie mit Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhernie mit Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinalmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inguinaltunnel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ingwer-Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ingwer-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Erbrochenem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Gas a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Kohlenmonoxid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Mageninhalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Nahrungsmitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Rauch a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalation von Schleim',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalations-Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalationsmilzbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalationsmittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhalationsmittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inhibitor des systemischen Lupus erythematodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inienzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Initiale Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Initiale Karies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Initiale Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Initiale Makrohämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Initiales Ulkus bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Injektionskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzeration der Iris in einer Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzeration der Linse in einer Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzerierte Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzerierte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzerierte Nabelhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzerierte Narbenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkarzerierte Schenkelhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Fehlgeburt mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Interruptio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Interruptio mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Kompression der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplette Schädigung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter AV [Atrioventrikular]-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter Abort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter Rechtsschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter Spontanabort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter legaler Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkompletter thorakaler Querschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplettes Cauda-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplettes Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkomplettes traumatisches Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkontinenz des Afterschließmuskels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkontinenz des Harnröhrenschließmuskels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkontinenz des Sphincter ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkoordinationsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inkrustation der Kornea durch Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innen- und Außenmeniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenbandinsuffizienz des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenknöchelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskushinterhornlappenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskushinterhornläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskushinterhornquerriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskushinterhornriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskuskorbhenkelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskuskorbhenkelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskusreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskusriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskusschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenmeniskusvorderhornläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrlues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrlues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrotosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenohrtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innenrotationsgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Kniegelenkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Tracheozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Unruhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Innere Verätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inneres Gerstenkorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inokulationsadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inokulationshepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inositmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insektenbiss/-stich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insektengiftallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insektenstichallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inselzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inselzellhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inselzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inselzelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inselzelltumor des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertio centralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertio lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertio marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertio velamentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertionsligamentopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertionstendopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insertionstendopathie im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insolation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inspiration von Nahrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inspiratorisches Sprechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inspissated-bile-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inspissated-bile-Syndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instabile Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instabilitas oculorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Institutionalisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Institutionelle Erziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Institutioneller Aufenthalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Instrumentelle Manipulation/Katheterisierung/Intubation/Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z53'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insufficientia cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Inselzellen des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Tränensekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Tränenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz der Venae perforantes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz des Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz des Immunsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz des Urethralsphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuffizienz peripherer Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insufflation der Tuben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulin-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Diabetes mellitus Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Diabetes mellitus in Verbindung mit Fehl- oder Mangelernährung [Malnutrition]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-I-Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinabhängiger Typ-II-Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbedingte Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbedingte Hypoglykämie bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbedingte Hypoglykämie bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbedingte Hypoglykämie bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbehandelter Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbehandelter Typ-I-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbehandelter Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinbehandelter Typ-II-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinkoma bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinkoma bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinkoma bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinpflichtiger Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinpflichtiger Diabetes mellitus bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinpflichtiger Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insulinpflichtiger Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Insuläre Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Integumentumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenzmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenzminderung mit autistischen Zügen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenzminderung ohne Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intelligenztest a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intentionstremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interaktionsstörung Mutter-Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitale Pilzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitale Pilzinfektion der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitale Pilzinfektion des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitales Neurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitales Neurom der Füße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitales Neurom der Hände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitales Pseudoneurom der Füße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitales Pseudoneurom der Hände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitalisneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitalmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitalmykose der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interdigitalmykose des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interferenzdissoziation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interkapilläre Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interkapilläre Glomerulosklerose [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interkostalblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interkostalgefäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interkostalneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interlobuläres Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermediäre Form einer erheblichen Energie- und Eiweißmangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermediäres Koronarsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermenstrualschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermenstruelle Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermenstruelle Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermenstruelle Schmierblutung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermetatarsales Neurom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Gastrosukkorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Heterotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Hydrarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Restesotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Restexotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende alternierende Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierende alternierende Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierender Exophthalmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierender Hydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierender Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierender Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes Auswärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes Einwärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes Hinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intermittierendes primäres Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interne Okulomotoriusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Internes Granulom der Pulpa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Internukleäre Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interphalangeale Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interphalangeale Mykose der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interphalangeale Mykose des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interruptio aus sozialer Indikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interruptio legalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interskapulago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratokonjunktivitis bei Masern [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratokonjunktivitis bei Zoster [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratokonjunktivitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratokonjunktivitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Keratokonjunktivitis durch Akanthamöben [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Lobärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Mastitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Splenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle arteriosklerotische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle arteriosklerotische Nephritis mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle hypertrophische progressive Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle idiopathische Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielle plasmazelluläre Pneumonie [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielles Emphysem beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interstitielles Lungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöse Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöse Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöse Psoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöse Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöser Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertriginöses Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertrigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertrigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertrigo-Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intertrigo-Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intervall-Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Interzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinal adenomatöse Polyposis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalabszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Adhäsion mit Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Anastomose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Dipylidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Distomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Distomiase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Endometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Fasciolopsiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Helminthose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Infektion durch Campylobacter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Infektion durch Capillaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Infektion durch Taenia solium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Invagination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Kokzidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Lipodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Mikrosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Myiasis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Sarkosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Spätsyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Spätsyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Strongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Taeniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Trichomoniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Unterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Verwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Wurm-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinale Yersiniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Befall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Befall durch Capillaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Befall durch Nematoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Befall durch Schweinebandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Typ des Adenokarzinoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaler Typ des Karzinoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinales Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinales Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalknick',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinalthrombose mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinaltorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinovaginale Fistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumabknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumfistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumgranulom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumhypertrophie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intestinumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation - s.a. Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation bei Überdosierung eines Medikaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Halluzinogene bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Sedativa und Hypnotika bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Sedativa und Hypnotika bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Tabak bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch Tabletten und Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intoxikation durch ein flüchtiges Lösungsmittel bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Lymphknotenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominale Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominaler Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominaler Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraabdominales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraalveoläre Hämorrhagie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraamniale Fetalinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraartikuläre Fraktur des Radius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intradermaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intradermales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraduktales nichtinvasives Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepidermaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepidermales Epitheliom vom Typ Borst-Jadassohn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepidermales Jadassohn-Epitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaneoplasie 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaneoplasie 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaneoplasie 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliale Vulvaneoplasie 3. Grades mit hochgradiger Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliales Epitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraepitheliales Epitheliom vom Typ Borst-Jadassohn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrahepatische Cholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrahepatische Cholestase [Cholostase] a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrahepatische Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrahepatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakanalikuläres Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakanalikuläres Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakardiale Thrombose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Drucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Eiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Embolie des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Endophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Hypotonie nach ventrikulärem Shunt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Infektion mit Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Phlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Pneumatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Thrombophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Venensinusthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle Verletzung mit verlängertem Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle arterielle Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle eitrige Entzündung des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Embolie des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Endophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Endophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Phlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Thrombophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Thrombose des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Venenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielle septische Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranieller Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranieller Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranieller multipler Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranieller subduraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielles Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielles Gumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielles Gumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrakranielles Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraligamentäre Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraligamentäre Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraligamentäre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramedulläre Hämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramurale Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramurale Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramurale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramurale Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intramuskuläres Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intranasales Malignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intranukleäre Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokulare Drucksteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokulare Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokulare Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokulare Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokularer Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokularer amagnetischer Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraokularer magnetischer Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraoperative Glaskörperblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraorbitaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraossäres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrapartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrapartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrapartale Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrapartale Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraperitoneale Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraperitoneale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraperitonealer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraperitonealer Gametentransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrapontine Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrarenale Verkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrarenaler Aortenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraretinale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraretinale Netzhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraskrotale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrasphinktärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale Venensinusembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Endophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Endophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Phlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Thrombophlebitis des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Thrombose des Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Venenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Venensinusembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinale septische Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspinaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspongiöse Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspongiöse Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspongiöser Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraspongiöser Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrathorakale Lymphknoten-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrathorakale Lymphknotenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrathorakale Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrathorakales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratonsillarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratubare Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratubarer Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratubarer Pronukleustransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratubarer Zygotentransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intratubarer transabdominaler Gametentransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Anoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Hypoxie erstmals festgestellt bei Wehen oder Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Hypoxie erstmals festgestellt vor Wehenbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Infektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Mangelentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Synechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauterine fetale Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauteriner Distreß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauteriner Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauteriner Fetaltod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauteriner Fruchttod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrauteriner Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intravasale Gerinnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intravasale Koagulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intravaskuläre Leiomyomatose - s. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre Hirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 1. Grades beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 1. Grades beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 2. Grades beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 2. Grades beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 3. Grades beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intraventrikuläre nichttraumatische Blutung 3. Grades beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intravesikale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale Hirnstammblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale Kleinhirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale nichttraumatische Blutung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrale nichttraumatische Blutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazerebrales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazystisch papilläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazystisches papilläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrazytoplasmatische Spermieninjektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsische Minus-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsische Plus-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsische Verfärbung der Zähne a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsisches Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsisches Bronchialasthma mit extrinsischem Ursprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intrinsisches Pillendrehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intubationsgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intumeszenz der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Intussuszeption des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invagination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invagination des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invagination des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invaginationshernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invaginationsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invalidität seit Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasiv-sklerosierende Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasive Aspergillose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasive Aspergillose mit Pneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasive Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasive hydatidiforme Mole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives Angiolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives duktales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives duktales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives duktales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives duktales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives lobuläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Invasives lobuläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inverse Zilien (der Augenwimpern)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversio testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversio uteri bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversio uteri bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversio viscerum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion der Sehnervenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion des Albumin-Globulin-Verhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion des Nacht-Tag-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion des Schlafrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inversion des zirkadianen Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutions-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutionsdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutionsmelancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutionsosteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutionsparaphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Involutionspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperfl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperfl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperfl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperfl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperfl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Inzision/Drainage/Spülung/Absaugung/Entfernung von Körperflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z51'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridodialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridodonesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridokorneale endotheliale Dystrophie [ICE-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridokorneale endotheliale Dystrophie [ICE-Syndrom] mit Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridoparalysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyclitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei Infektionskrankheit a.n.k. [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei Sarkoidose [kodiere zusätzlich H22.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei Zoster [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei parasitärer Krankheit a.n.k. [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei sekundärer Syphilis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis bei sekundärer Syphilis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis durch Gonokokken [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis durch Gonokokken [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis durch Herpesviren [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklitis mit Linseninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iridozyklochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iris bombée',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisadhäsion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisdisruption a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisdurchleuchtbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisdurchsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iriserythem [kodiere zusätzlich H22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisgumma [kodiere zusätzlich H22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisgumma [kodiere zusätzlich H22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisherpes bei Erythema exsudativum multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irishyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irishämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iriskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iristrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iristuberkulose [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iristumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iristumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iriszerreißung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iriszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irisödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis bei Lepra [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis durch Gonokokken [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis durch Gonokokken [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis durch Herpesviren [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis papulosa [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iritis papulosa [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Hartsubstanzbildung der Pulpa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Herztätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Kontur der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Periode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Pupille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläre Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irregulärer Alveolarfortsatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irregulärer Schlaf-Wach-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläres Dentin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreguläres Nasenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Femoralhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernia abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernia diaphragmatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernia femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernia umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernia ventralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponible Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponibler Bauchwandbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponibler Eingeweidebruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponibler Nabelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponibler Schenkelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irreponibler Zwerchfellbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritabilität beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritable bladder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritables Kolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritation der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritations-Syndrom des Mesodienzephalon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritationsdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritationsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritative Hyperplasie des zahnlosen Alveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritative Mundschleimhauthyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Irritative papilläre Gaumenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isaacs-Mertens-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isaacs-Neuromyotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiadikusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie durch Bandscheibenschaden [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie durch Bandscheibenschaden [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie durch Bandscheibenvorfall [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie durch Bandscheibenvorfall [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie mit Lumbago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischialgie mit Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiasschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiophthisis [Coxitis tuberculosa] [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiorektale Tuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiorektaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischiothorakopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämie der Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämie des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämie des Tractus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämie des visuellen Kortex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämieschmerzen bei arteriellem Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Chiasmaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Herzerkrankung mit Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Herzerkrankung ohne Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Neuropathie des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Optikusneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische Volkmann-Paralyse als Verletzungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämische intestinale Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämischer Hirninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämischer Infarkt im Stromgebiet der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämischer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ischämischer Thoraxschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iselin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iselin-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Iselin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Island-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoimmunisation a.n.k. beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoleuzin-Abbaustörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoleuzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoliert lebende Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoliert lebende Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoliert lebende Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isoliert lebende Person',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Cholestase a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Erythrozytenanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Erythrozytenaplasie bei Thymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Gehirnerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Hautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Kommotio des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Lävokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Proteinurie mit fokaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Rechtschreib-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte Trachea-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte aplastische Anämie bei Thymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte aplastische Anämie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierte aplastische Anämie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter ACTH [Adrenocorticotropes Hormon]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Durchfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Fundus flavimaculatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Gonadotropinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Hypophysenhormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Prolaktinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Somatotropinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Thyreotropinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierter Wachstumshormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isolierung der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isosexuelle Pseudopubertas praecox masculina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isosporiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isosthenurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Isovalerianazidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Itai-Itai-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Italienischer Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ivemark-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ixodiasis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jaccoud-Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jaccoud-Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jackson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jacquet-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jactatio capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jadassohn-Lewandowsky-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jaffé-Lichtenstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jaffé-Osteoidosteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jake-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jakobs-Kreuzkraut-Pollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jamaika-Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jamaika-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jammerdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Janet-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Janizeps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Japan-B-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Japanisches Flußfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Japanisches Herbst-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Japanisches Siebentagefieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunale Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunales Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunum imperforatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumimperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jejunumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jensen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jet-lag-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jetlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jeune-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jirásek-Zuelzer-Wilson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jirásek-Zuelzer-Wilson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbeinfraktur und Oberkieferfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbeinimpressionsbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbeinimpressionsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbogenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jochbogenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jock itch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodmangelbedingte diffuse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodmangelbedingte knotige Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodmangelbedingte mehrknotige Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodmangelstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jodnegativer Portiobezirk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Joubert-Boltshauser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juckblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jucken an der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juckreiz/Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jugendirresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jugendliche Beziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jugendvorsorgeuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jugularisvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juguläres Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juhel-Renoy-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Junge Erstgebärende',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Junge Erstschwangere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Junktionaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Junktionsnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Absencen-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Apophysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Dermatitis herpetiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Epiphysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Form der GM2-Gangliosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Form der spinalen Muskelatrophie (Typ III)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Kalkaneusosteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Kienböck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Lunatummalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Meesmann-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Mondbeinnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Fibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Handwurzelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Mittelfußknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Mittelhandknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Symphysis pubica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Tibia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Ulna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Astragalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Azetabulum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Caput femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Caput humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Darmbeinkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Femurkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Fersenbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Fußes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Kahnbeins des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Os lunatum der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Os naviculare pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Radius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Schienbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des Sprungbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des primären Patella-Ossifikationszentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteochondrose des sekundären Patella-Ossifikationszentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Panarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Parodontose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Spondylitis ankylosans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Still-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile amaurotische Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile chronische Arthritis, oligoartikulär beginnende Form',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile chronische Arthritis, systemisch beginnende Form',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile chronische Polyarthritis vom adulten Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile chronische seronegative Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile chronische seronegative Polyarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile myoklonische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile progressive Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile progressive Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile progressive Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile progressive Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile taboparalytische Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juvenile taboparalytische Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniler Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniler Hypopituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Angiofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Elastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Fibroangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Pemphigoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juveniles Still-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juxtaartikuläre Knoten bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juxtaglomerulärer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juxtakortikales Chondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juxtakortikales Chondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Juxtakortikales Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Jüngling-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'KHE [Koronare Herzerkrankung] - s.a. Koronare Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'KHK [Koronare Herzkrankheit] - s.a. Koronare Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'KTS [Karpaltunnelsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kabuki-Niikawa-Kuroki-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kabuki-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachektische Diarrhoe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie bei Ernährungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie bei Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie durch Blei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie durch bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kachexie-Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaffeearbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaffernpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahler-Buzzolo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahler-Buzzolo-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahler-Krankheit in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahnbeindistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahnbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahnbeinhypertrophie des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kahnschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaiserschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaiserschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kakké',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kakosmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kala-Azar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalabarbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalabarschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalifornische Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalium-Verlustsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaliumintoxikationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaliummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaliumverarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaliumvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaliumüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalixhydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalixinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalixurolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkaneus-Navikulare-Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkaneusapophysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkaneusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkaneustrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkgicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkhaltiges Infiltrat a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkige Degeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalksalze im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkseife im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalkstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kallmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kallositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kallus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalottenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalottentrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalte Füße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalter tuberkulöser Lungenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Basalganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Falx cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Papilla dentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Pulpa dentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Zahnpulpa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der spinalen Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation der zerebralen Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifikation des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifizierende Arteriendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifizierende Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzifizierende odontogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziprive Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumnephrolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumoxalatkonkrement in den Harnwegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumoxalatnephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumoxalatstein in den Harnwegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumoxalatsteinabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumpyrophosphat-Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumsalze im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumsalzinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumseife im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumurolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziumverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kalziurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kamerun-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammer-Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerflattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerflimmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerflimmern/-flattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerscheidewanddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerwinkelatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerwinkeldeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kammerwinkelrecessus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kampfneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kamptokormie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanalikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanalikulitis bei Aktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose der Vulva und der Vagina [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose des Urogenitaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose des Urogenitaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kandidose des Urogenitaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanikola-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaninchenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kankroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kankrophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanthusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanthusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanthusschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanthuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanzerophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanzerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kanzeröse Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarektasien der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillargefäßatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillargefäßektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillargefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillariasis der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillaritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillarthrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre fettige Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläre hämorrhagische Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapillärer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläres Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläres Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläres Netzhauthämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapilläres Orbitahämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaposi-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaposi-Sarkom der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaposi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kappa-Leichtketten-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kappa-Leichtketten-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselentzündung der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselentzündung der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselentzündung eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselfibrose durch Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselhäutchenglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselotosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselreizung der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselreizung des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselreizung des Schultergelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselreizung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapselruptur einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapsulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapsulitis eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapsuläres Glaukom mit Pseudoexfoliation der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kapsuläres primäres Glaukom mit Pseudoexfoliation der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel an der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel an multiplen Lokalisationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel der Schläfengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karbunkel des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardia-ösophageale Relaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiaachalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiadivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiainsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Amyloidose [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Anasarka',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Dysrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Geburtskomplikation durch Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Glykogenose [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Ossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Ruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Stase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Stauungsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialer Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialer Hydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialer Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialer Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialer Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Reibungsgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiales Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardialgie des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiaobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiaschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiavarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiavarizenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiaverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiochalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomegalie bei Glykogenspeicherkrankheit [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie bei Diphtherie [kodiere zusätzlich I43.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie bei Ernährungsmangelkrankheit [kodiere zusätzlich I43.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie bei Sarkoidose [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiomyopathie durch Amyloidose [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiopathie bei Mukopolysaccharidose [kodiere zusätzlich I52.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardioperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiopulmonale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiopulmonales Syndrom bei Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiopulmonales Syndrom bei Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorenaler Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorespiratorischer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorespiratorischer Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorespiratorisches Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiospasmus der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiospasmus des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiotonische Ösophagusdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Erkrankungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Kollagenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Lues [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Lues [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Schmerzen ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Syphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Syphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Veränderungen bei Pinta [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre konnatale Spätsyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläre konnatale Spätsyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskulärer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskulärer Schaden bei Carate [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskulärer Schaden bei Pinta [kodiere zusätzlich I98.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Symptom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Symptom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Symptom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Symptom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Syphilom [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Syphilom [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiovaskuläres Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kardiozerebrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karditis bei chronischer Polyarthritis [kodiere zusätzlich I52.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karditis durch Meningokokken [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karies der Ohrknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kariesprophylaxe durch Fluoridgabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kariöse Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kariöse Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotidodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotinämie diätetischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotisaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotisdrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotissinus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotissklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotisstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karotisthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karpopedalspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karpopedalspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karpusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kartagener-Syndrom [Situs inversus viscerum, Bronchiektasie, chronische Sinusitis und Nasenpolypen] [Pluriglanduläre Insuffizienz infolge mukoziliarer Transportstörung] [Immotile cilia syndrome] [Kartagener-Trias]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kartagener-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kartilaginäre Enchondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kartilaginäre Exostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kartilaginäre Exostose der Großzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karussellkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotyp 45,X',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotyp 46,X iso (Xq)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotyp 46,X mit Gonosomenanomalie, ausgenommen iso (Xq)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotyp 47,XXX',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotyp 47,XYY',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karyotypisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoid - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoid der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoid mit Struma ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoid vom Bronchusadenom-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinoidsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Anushaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Cauda pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Cervix vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Columna vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Flexura coli dextra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Flexura coli hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Flexura coli lienalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Flexura coli sinistra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Fossa tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula parathyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula pituitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glandula suprarenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Harnleitermündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Axilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Bauchwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Schläfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Haut des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Hautanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Hirnhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Kardia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Kieferhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Kloake',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Langerhans-Inseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Magenkuppel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Papilla Vateri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Pleura parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Pleura pulmonalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Plica aryepiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Retromolarregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Rückenmarkhäute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Siebbeinzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Uterusadnexe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Uterusbänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Vallecula epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Verbindungszone [Übergangsregion] des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Weichteile des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Zungenmandel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Zungentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der Zungenunterfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der großen Magenkurvatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der großen Schamlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der hinteren Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der hinteren Rachenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der inneren Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der inneren Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der inneren Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der kleinen Magenkurvatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der kleinen Schamlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der linken Kolonflexur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der männlichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der männlichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der männlichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der paraurethralen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der seitlichen Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der seitlichen Wand des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der ventralen Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der vorderen Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der weiblichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der weiblichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der weiblichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der äußeren Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom der äußeren Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Analrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Antrum pyloricum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Beckenperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Bindegewebes und der Weichteile des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Bindegewebes und der Weichteile des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Bindegewebes und der Weichteile des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Blasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Blasenscheitels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Brustfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Caput pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Collum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Colon ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Colon descendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Colon transversum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus cavernosum des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus ciliare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus pineale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Corpus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Ductus pancreaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Epipharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Fundus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Fundus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Glomus caroticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Hauptbronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Ileozäkums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Isthmus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Kolons und Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Ligamentum teres uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Lobus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Lobus temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Magenmundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Meckel-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Mediastinum anterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Mediastinum posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Mundrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Myometriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Os frontale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Os nasale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Os occipitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Os temporale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Recessus piriformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Retroperitonealraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sinus ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sinus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sinus maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sinus paranasales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sinus sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sulcus glossoalveolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sulcus glossopalatinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Sulcus glossopharyngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Trigonum vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Waldeyer-Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Wurmfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Zungenrandes und der Zungenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des Zäkums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des extrahepatischen Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des fixierten Zungenteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des hinteren Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des hinteren Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des kraniopharyngealen Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des oberen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des oberen Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des postkrikoidalen Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des seitlichen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des seitlichen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des unteren Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des vorderen Kehldeckels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des vorderen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des vorderen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des vorderen Teils des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom einer endokrinen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom im Status progressivus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom in Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom-Nachsorgeuntersuchung nach Chemotherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom-Nachsorgeuntersuchung nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinom-Nachsorgeuntersuchung nach chirurgischer Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomatöse Blasenwandinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomatöse Neuropathie [kodiere zusätzlich G13.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomatöse Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomdisposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinominfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinommetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomnachsorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinomvorsorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Karzinöses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaschin-Beck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaschin-Beck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaskadenmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kast-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katalasedefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katalepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kataleptische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kataleptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kataplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt bei Heterochromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt bei Hypoparathyreoidismus [kodiere zusätzlich H28.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt bei Myxödem [kodiere zusätzlich H28.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt durch Lens tough',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt durch Mangelernährung und Dehydratation [kodiere zusätzlich H28.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt durch Wärmestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt infolge Augenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt mit chronischer Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarakt vom Morgagni-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrh der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Entzündung der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Tubotympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalische Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalischer Croup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katarrhalischer Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatone Agitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatoner Erregungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatoner Spannungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatoner Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatonische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatonische Erregung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katatonischer Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katayama-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katayama-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katheterdysfunktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katheterokklusion bei suprapubischem Fistelkatheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katheterthrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenhaarallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenkratz-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenkratz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenkratz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Katzenschrei-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaubeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaudastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaudastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaumuskelkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kausalgie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kaverne der Sehnervenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernöser Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernöses Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernöses Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernöses Netzhauthämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kavernöses Orbitahämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kawasaki-Syndrom [Mukokutanes Lymphknotensyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kayser-Fleischer-Kornealring a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kayser-Fleischer-Pigmentring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kazal-Ronchese-Kern-Angioretikulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kearns-Sayre-Syndrom [Ophthalmoplegia plus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kedani-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kedani-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehldeckelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehldeckelgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehldeckeltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopf-/Luftröhrenentzündung/Laryngitis/Tracheitis, akute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopf-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfentzündung - s.a. Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopffremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfknorpelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfknorpelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopflähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfmuskelprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfpachydermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfschleimhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopftuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfventrikelprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfvernarbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kehlkopfödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhleneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlensinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilbeinhöhlenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilförmiger Zahndefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilwirbel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keilwirbel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger der humanen T-Zell-lymphotropen Viruskrankheit Typ I [HTLV-1]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger des HBc-Antigens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger des HBs-Antigens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger einer Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger einer Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger einer bakteriellen Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger einer infektiösen Darmerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger einer venerischen Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger eines Infektionserregers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger pathogener Keime des Gastrointestinaltraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Amöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keimträger von Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keine Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keine Krankheit gefunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kelchstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kelis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kelly-Paterson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keloid-Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keloidakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keloidale Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kemerovo-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kenya-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kenya-Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis Schneeblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis actinica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis arborescens bei Herpes simplex [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis areolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei Herpes [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei Infektionskrankheit a.n.k. [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei Masern [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei Psoriasis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei Rosazea [kodiere zusätzlich H19.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bei parasitärer Krankheit a.n.k. [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis dendritica [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis dendritica durch Herpes simplex [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis disciformis [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis disciformis durch Herpes simplex [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis durch Adenoviren [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis durch Akanthamöben [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis durch Herpesviren [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis durch Onchocerca volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis e lagophthalmo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis ekzematosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis filiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis herpetica [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis mit Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis mit Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis neuroparalytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis nummularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis obturans des Gehörgangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis parenchymatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis petrificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis phlyctaenulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis photoelectrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis profunda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis punctata superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis sicca im Sinne des Sjögren-Syndroms [kodiere zusätzlich H19.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis sicca im Sinne des Syndroms des trockenen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis stellata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis striata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitis superficialis punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratitisgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kerato-Akanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoakanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoakanthom des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis ekzematosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis epidemica [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis neuroparalytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis phlyctaenulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis sicca im Sinne des Sjögren-Syndroms [kodiere zusätzlich H19.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoconjunctivitis sicca im Sinne des Syndroms des trockenen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermia climacterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermia palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermia palmoplantaris papulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermia punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratodermie bei Reiter-Syndrom [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoglobus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratohämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoiritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivale Benetzungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis actinica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis bei Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis bei Masern [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis bei Zoster [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis bei konnataler Syphilis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis durch Adenoviren [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis durch Akanthamöben [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis durch Herpesviren [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonjunktivitis herpetica simplex [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratokonus bei Down-Syndrom [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoma palmoplantare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratoma senile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomycosis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomycosis nigrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomycosis nigricans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomycosis nigricans palmaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratomykose [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathia bullosa bei Hornhautdekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathia bullosa bei Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathia bullosa durch Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathia bullosa durch IOL [Intraokulare Linse]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathia medicamentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose der männlichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose der weiblichen Genitalorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose durch Arsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose durch Gonokokken [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose durch Gonokokken [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis nigricans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis obturans des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis pilaris simplex [Erworbene Keratosis suprafollicularis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis punctata palmoplantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis seborrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis solaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratosis vegetans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratouveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keratozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keraunoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kerion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kerion Celsi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernikterus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernikterus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernsklerose-Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kernstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keshan-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ketoazidose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ketoazidotische Entgleisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ketonurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ketose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keuchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keuchhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keuchhusten durch Parapertussis-Erreger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keuchhusten-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Keuchhusten/Pertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefer-Gaumen-Spalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefer-Lid-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefer-Lid-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferalveolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferasymmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferexostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkarthralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkknacken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergelenkstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefergranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhle-Alveole-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhle-Mund-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhle-Wange-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhleneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlensinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferhöhlenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferknochenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferknocheninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferknochensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferknochensequester',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefernekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferorthopädische Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferorthopädische Nachbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefersequester',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferspaltzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefersperre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefersymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiefertuberkulose [kodiere zusätzlich M90.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kielbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kielkopf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiemengangfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiemengangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kienböck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kienböck-Krankheit beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kienböck-Meisel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kienböck-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kienböck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kiesellunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kieselsäuregranulom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Killian-Polyp der Nasenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kimmelstiel-Wilson-Syndrom [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kimmelstiel-Wilson-Syndrom bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kimmelstiel-Wilson-Syndrom bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindbettfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindbettfieber mit Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindervorsorgeuntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinderwunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindesmißbrauch (emotional)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindesmißhandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindesmißhandlung durch Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindesmißhandlungssyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindheitsform der spinalen Muskelatrophie (Typ II)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindliche Launenhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindliche Launenhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindliche Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindliches Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindliches Verhalten Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindstod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindstod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindszerstückelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kindszerstückelung zur Geburtserleichterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinking-Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinking-Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinking-Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinky hair disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinky-hair-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinky-hair-Syndrom [Menkes-II-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnlage des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kinnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kippniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kissing spine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kissing spine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kittniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kladosporiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klaffende Tube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klaffende Tube des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klarzelliges Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klarzelliges Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klarzelliges Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klarzelliges Hidradenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klarzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Dengue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Form des 21-Hydroxylase-Defektes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Form des 21-Hydroxylase-Mangels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassische Morquio-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klassisches Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klatskin-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauenhohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauennagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauenseuche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klauenzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klaustrophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavikulaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavikuladislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavikulafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavikulafraktur durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavikulaverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klavusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleidotomie beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleidotomie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleienpilzflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klein-Waardenburg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Schürfwunde des Handrückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Schürfwunde des Handrückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine Schürfwunde des Handrückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine offene chirurgisch versorgte Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine offene chirurgisch versorgte Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine offene chirurgisch versorgte Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleine-Levin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleiner Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleiner schneller Puls durch Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleines Ostium vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinfollikuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnapoplexiesyndrom [kodiere zusätzlich G46.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnbrückenwinkel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnbrückenwinkelchordom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnbrückenwinkeltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirncholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnsyndrom [kodiere zusätzlich G46.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirntuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinhirnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinkinderkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinkindervorsorgeuntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges Bronchialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges Plattenepithelkarzinom des Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges gekerbtes Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleinzelliges gekerbtes follikuläres Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kleptomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klicksyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimaanlagenpneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Arthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Ausfallerscheinung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Hitzewellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Keratodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Konzentrationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Krankheit bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Melancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Paraphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Psychoneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Psychose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Reizblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Schlaflosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Symptome bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Wallungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Zustände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische Zykluslabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterische toxische Polyarthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterisches Hormonmangelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimakterium beim Mann a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimatischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimatischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klimaxbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klinefelter-Reifenstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klinefelter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klinefelter-Syndrom, männlicher Phänotyp, mit Karyotyp 46,XX',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klinefelter-Syndrom, männlicher Phänotyp, mit mehr als zwei X-Chromosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klinisch diagnostizierte Malaria ohne parasitologische Bestätigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klippel-Feil-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klippel-Feil-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klippel-Trenaunay-Weber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisepispadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitoristumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitorisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klitoriszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kloakenekstrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kloakogenes Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klonische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klonischer Spasmus hemifacialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kloßgefühl im Hals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumphand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Déjerine-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Déjerine-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Geburtslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Lähmung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klumpnagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Klärung/Besprechung des Beratungsanlasses mit dem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z48'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knalltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knarrendes Gelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Hackenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Hohl-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Platt-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knick-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniearthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniebinnenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniedistorsion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniefurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenk-TBC [Tuberkulose] [kodiere zusätzlich M01.16*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkblockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniegelenkzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniehämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniehämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniehämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniekarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniekaries [kodiere zusätzlich M01.16*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniequetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniescheibenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniesymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knietuberkulose [kodiere zusätzlich M01.16*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knieverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kniezerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knistern oder Knallen im Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochen-TBC [Tuberkulose] [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenagenesie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochendaktylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochendegeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochendekalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochendemineralisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochendestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knocheneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfiliae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfraktur nach Einsetzen einer Gelenkprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfraktur nach Einsetzen einer Knochenplatte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfraktur nach Einsetzen eines orthopädischen Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochengumma [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochengumma [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochengumma bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochengumma bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenhypoplasie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knocheninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knocheninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knocheninfektion durch Echinococcus granulosus [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkaries a.n.k. [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkarzinom mit Knorpelbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenkryptokokkose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmalazie beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkdepression mit Panzytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmarkphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenmetastase bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochennekrose bei Caisson-Krankheit [kodiere zusätzlich M90.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochennekrose durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochennekrose durch vorangegangenes Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenrarefikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensarkom mit Knorpelbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensequester',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensporn des Darmbeinkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensyphilis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochensyphilis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochentabes [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochentabes [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochentransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochentuberkulose [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knochenzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knollennase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knopflochdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpeldegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelerweichung der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelkarzinom mit Knochenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelsarkom mit Knochenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelschaden des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelschaden des Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpelstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knorpeltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knospenbrust [Mikromastie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knospenbrust [Mikromastie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten im Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten in der männlichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten-Filariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten/Geschwulst, weibliche Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten/Schwellung, generalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knoten/Schwellung, lokalisiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotenaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotenkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotenlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotenrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotenstruma ohne Thyreotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Lungenverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Schwellung des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Verdickung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Veränderung der Nebenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Veränderung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotige Veränderung der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knotiger Prozeß der Nebenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knuckle pads',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knuckle-pads-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knäueltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelgelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelgelenktuberkulose [kodiere zusätzlich M01.17*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelpronation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöchelödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherne Ankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherne Stenose der Foramina intervertebralia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherne Stenose des Spinalkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherner Ausriß des ulnaren Seitenbandes des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherner Bandausriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knöcherner Bandausriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Knötchenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koagulationsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koagulationsfaktorenstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koagulationsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koagulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koagulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koch-Weeks-Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kocher-Volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kochleahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kochleare Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kochlearotosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koffeinabhängigkeitssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koffeinentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koffeinmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohabitationsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohabitationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohabitationsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohabitationsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohabitationsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohlenhydratintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohlenoxidhämoglobin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kohlenstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koilonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koitalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kojewnikoff-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kojewnikow-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kojewnikow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainintoxikation bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokainsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidioidales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidioidomykose der Prostata [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzygealdermoidzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzygealsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzygealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kokzygodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolbenfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koli-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koli-Enteritis beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koli-Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolibazillose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koliken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Balantidium coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Giardia lamblia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Isospora belli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Isospora hominis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Kokzidien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Lamblia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Milzbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Nahrungsmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Protozoen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Strahleneinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Trichomonas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koliurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollagengefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollagenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollagenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollagenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollaps des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollateralkreislauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolliquationsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollodium-Baby',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloidale Milien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloide Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloider Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloides Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloides Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloides Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloidknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolloidstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollumkarzinom (Collum uteri)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kollumkarzinom des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolobom der Papilla nervi optici',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolobom des Fundus oculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolon-Magen-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolondilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolondivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolondivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolondivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolondysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloneinscheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolongranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloninvagination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonschistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonspasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolontorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolontransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolontumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolonzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koloptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolostomaversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolostomie mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolostomie-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolostomieprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Hormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Kokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpitis durch Östrogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolporrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kolpozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinationsimpfung - s.a. Einzeleinträge der Kombinationsimpfungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinationskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinationskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinationsnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Entwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Impfung - s.a. Einzeleinträge der Kombinationsimpfungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Innenohr- und Mittelohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Kataraktform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Krankheit der Aorten- und Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Krankheit der Mitral- und Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Krankheit der Mitral-, Aorten- und Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Schwerhörigkeit durch Schalleitungs- und Schallempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Störungen der schulischen Fertigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierte Taubheit durch Schalleitungs- und Schallempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombinierter Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Antikörpermangelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Aortenklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Aortenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Cholangiokarzinom und hepatozelluläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Mitral- und Aortenklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Mitralklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kombiniertes Mitralvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedomastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedomastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedonen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komedonenakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kommotio des Gehirns bei leichter Nebenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kommunikationsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kommunizierender Hirnventrikelshunt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompartmentsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompensationsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompensationsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompensierte Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompensierte Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompensiertes autonomes Schilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplementdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplementsystemdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Fehlgeburt mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Interruptio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Interruptio mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Iridoparalysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Iridoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Kompression der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Obstruktion der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Schädigung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Unterarmfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplette Unterschenkelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter AV [Atrioventrikular]-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Abort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Herzblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Rechtsschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter Spontanabort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompletter atrioventrikulärer Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplettes Cauda-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplettes Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplettes traumatisches Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexe Anurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexe knöcherne Syndaktylie mit Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexer fokaler Anfall mit Entwicklung zu sekundär generalisiertem Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexes Fehlbildungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplexes Odontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Anästhesie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Beatmungstherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Dialyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Elektroschocktherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Inhalationstherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Phototherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei Ultraschalltherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation bei extrakorporalem Kreislauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der Malaria tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der Mastoidhöhle nach Mastoidektomie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der männlichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der männlichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der männlichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation der männlichen Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Blasenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Processus mastoideus nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation des Urogenitalsystems nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Harnröhrenkatheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Inokulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Mammaimplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Sedierung bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch künstliche Befruchtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch nichtresorbierbares Dauernahtmaterial a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch versehentliche Zerreißung während einer ärztlichen Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation durch versehentlichen Einstich während einer ärztlichen Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Anastomose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Bluttransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Brustprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Dauernaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Drahtnaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Enterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Gallengangsprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Ileostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Infusionsmaßnahme a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Injektionsmaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Jejunostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Kinnplastik-Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Lumbalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Lymphozytentransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Nephrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Plasmatransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Radiotherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Samenleiterprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Schnittentbindungswunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Spinalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Strahlenbehandlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Zystostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer Zökostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer geburtshilflichen Dammnaht a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer implantierten Penisprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer inneren Gelenkprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer intraokularen Linsenprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer intrauterinen Kontrazeptionseinlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer operativ angelegten arteriovenösen Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation einer ösophagealen Anti-Refluxvorrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Brustimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Bypass a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Gallengangsimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Gegenpulsationsgerätes in der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Gehirnnervenstimulators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Hauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Hornhauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Katheter zur Peritonealdialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Katheters a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Koronararterien-Bypasses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Nervenstimulators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Neurostimulators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Reimplantates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Samenleiterimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Shunts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Stomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Tracheostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Transplantates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines Vena-cava-Schirms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines chirurgischen Amputationsstumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines inneren orthopädischen Fixationsgerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation eines operativ angelegten arteriovenösen Shunts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach In-vitro-Fertilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Molenschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Plomben-OP',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach Pyelogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation nach intrauterinem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation von medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikation wiederangenähter Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplikationen einer medizinischen Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplizierte Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplizierte Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplizierte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplizierte Wehentätigkeit/Entbindung Lebendgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Komplizierte Wehentätigkeit/Entbindung Totgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des Gehirnstamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des Lumbosakralplexus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des Neugeborenen während der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompression des peripheren autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionsapneumatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionsatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionsfraktur des Lendenwirbels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionsmyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kompressionssyndrom der Arteria coeliaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konduktive Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konfiguration des kindlichen Kopfes während der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konfliktschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenital erhöhtes Schulterblatt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenital verlegte Tränenpünktchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Achromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Adhäsion der Labia majora pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Adhäsion der Labia minora pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Adhäsion der Schamlippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Adhäsion des Penis mit dem Skrotum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Afibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Akanthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aniridie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anisokorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anisometropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anomalie der Schädelknochen und Gesichtsknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anomalie des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aortenisthmusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aortenklappenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aortenklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aortentorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Atonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Atransferrinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Aufwärtsverlagerung des Hymen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Augenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Augenlidhypotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Bindehautadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Bindehautfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Blepharochalasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Blepharophimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Blepharoptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Blepharosynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Canities',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Cataracta coerulea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Cataracta pulverulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Cholämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Chorioideafehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dakryostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Darier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Degeneration des Sacculus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dichromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dichromatopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dilatation der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Diplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dislokation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Drusenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dysfibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dyskeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Dysphagozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Elliptozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Epiglottisfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Eventratio diaphragmatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Faltenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Fehlbildung des hinteren Augenabschnittes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Fehlbildung des vorderen Augenabschnittes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Fibrinogenopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Froschgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Fußhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Galaktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gallenblasenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gastroschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gaumenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gehirnhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gehirnunterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gehörgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Glaskörperfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gliederstarre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Gliedmaßenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Grubenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hammerzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Harnröhrenmündungsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Harnröhrenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Harnstauungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hautaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Heinz-Körper-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hepatomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hernia cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Herzverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Heterochromie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hirnventrikeldilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hufeisenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hydroenzephalomeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hydroenzephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hymenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hymenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hyperammonämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypermetropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypertrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypertrophie des Hiatus oesophageus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypertrophie des Meckel-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypofibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypophosphatasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypophosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypoprokonvertinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypoprothrombinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hypotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hüftdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hüftluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Hühnerbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Innenkörper-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Insuffizienz der tarsoorbitalen Faszie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Intussuszeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kapillarfragilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kardiomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Keratektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Keratodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kerbe der Nasenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Klauenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Klauenzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Klitorishyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Koilonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kolonverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Krallenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Laryngozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Leber-Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Leberhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Leberzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Lentigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Leukonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Leukopathia unguinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Lidanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Lidverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Linsenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Lordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Luftröhrendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Löffelnägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makrocheilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makrogyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makrotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Makulaverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Malaria a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Meniskushypertrophie des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrogyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrokornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikromyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrophakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mikrotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Minderung des Hörvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mitralklappenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mittelfußverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Mißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Monilethrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Myasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nagelverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Naseneingangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nasenscheidewanddeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nasenseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nasenseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nebennierenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nephrolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nephroptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nervensystemschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Netzhautdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Nierenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale O-Beinstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Obstruktion der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Obstruktion des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Oligotrichie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Omphalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Onychauxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Onychodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Onychorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ophthalmozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Orotazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Osteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ovalozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pachydermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pachyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Panhämozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Panzytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Papillenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Paraphimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Parese des Nervus abducens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Parese des Nervus oculomotorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Parese des Nervus trochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Parese mehrerer Augenmuskelnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Peritonitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Phimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Phlebektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pigmentierung der Sehnervenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pigmentierung des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pigmentierung des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pinselhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Platyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pneumonitis durch Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Poikilodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Porenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Präspondylolisthesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pulmonalisstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pulmonalklappenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pupillenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Purpura thrombopenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pyloruskonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Pylorusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Querfurchen der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ranula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Retinafehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Retinopathia pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Retinoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ringelhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Rubella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Schildknorpelspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Schwerhörigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Schädelknochenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Senkniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Skrotalzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Spermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Sphärozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Spindelhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Spondylolisthesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Stabsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Stenose der Lungenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Sternumretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Striktur des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Taubheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Taubstummheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Thorakogastroschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Thoraxabflachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Thymushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tibia recurvata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Torsion des Meckel-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tracheadilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tracheaverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tracheomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tracheozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Trichostasis spinulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Trichterbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Trikuspidalklappenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Triplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tränenapparatfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tränenapparatverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tränengangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tränenwegstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ungleichmäßigkeit der Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Ureterozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Urethramündungsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Urethraspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Uterusanomalie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Vaccinia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verkürzung des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verkürzung des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verlagerung der Unterzungendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verlagerung des Iliosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verlagerung des Plexus brachialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verlagerung des Unterzungendrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Verstopfungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Wabenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Wassersackniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Weitsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Wirbelsäulenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale X-Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zehenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zerebralparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zerebrospasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zwerchfellerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zystenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Zytomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale adhäsive Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale anomale Trichromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale disseminierte Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale dyshämatopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale dyshämopoetische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale enzymopathische Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale erythrozytäre Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale geistige Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale generalisierte Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale geschlechtsgebundene Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale hereditäre Hypoprokonvertinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale hereditäre Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale hereditäre endotheliale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale hypertrophische Pylorusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale idiopathische progressive Radiusverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale knorpelige Schiefnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale longitudinale Furchen der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale longitudinale Streifen der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale multiple Gelenkstarre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale multiple artikuläre Rigidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale okulomotorische Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale retrozökale Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale retrozökale Appendixverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale schankröse Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale schankröse Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale subendokardiale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale substernale Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale substernale Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale vaginale Enterozele a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale zerebrale Unterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale zystische pulmonale Lymphangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitale Übersichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler AC-Globulin-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Anophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Astigmatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Buckel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Defekt der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Defekt der Bauchwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Defekt der Descemet-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Epikanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Exophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-I-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-II-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-V-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-VII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-X-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-XII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Faktor-XIII-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Fibrinogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Hammerfinger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Herzfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Hohlfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Hydroureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Hyperadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Intrinsic-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Irisverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Keratoglobus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Keratokonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Klauenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Klumpnagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Kollaps des Labyrinthus membranaceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Konus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Laryngismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Lentikonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Linsenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Mangel an fibrinstabilisierendem Faktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Mangel an labilem Faktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Megaureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Megaösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Metatarsus adductus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Metatarsus adductus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Metatarsus varus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Mikrophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler NADH-Diaphorase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler NADH-Methämoglobinreduktase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler NADH-Reduktase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Nystagmus mit Blockierung in der Nähe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Nystagmus mit Kopfzwangshaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Nystagmus mit wechselnder Kopfzwangshaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Pes equinovarus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Proakzelerinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Prokonvertin-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Prothrombinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Sanduhrmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Scheibenmeniskus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Sinus dermalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Spitz-Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Spitzfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Ventrikelseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Volvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Vorhofseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler ektodermaler Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler muskulärer Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler nichttoxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler vesikoureterorenaler Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitaler Ösophagusdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Analgie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Analgie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Ankyloblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Bronchusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Epiblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Ergrauen der Haare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Fehlbildungssyndrom mit vorwiegender Gesichtsbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Fehlen der Zilien (der Augenwimpern)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Herzdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Hornhautstaphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Lidkolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Megasigma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Megasigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Mikrokolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Netzhautaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Perikarddivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Pharynxdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Pneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Riesenkolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Röteln-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Symblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Vitium cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales aganglionäres Megakolonsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales arteriovenöses Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales interstitielles Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales kleines Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales multiples Osteochondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales peripheres Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales primäres Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongenitales Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestion des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestion des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestive Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestive Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestive Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestive Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongestive Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konglomerattumor im Unterbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konglomerattumor im Unterbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kongo-Krim-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konische Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konische Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konische Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konischer Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjugationsikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjugierte Blickparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjugierte Paralyse der Augenmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjugierter Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaargyrie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaargyrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivachemosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaeinlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivagranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivahyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivahyposphagma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivainduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivakalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivakonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivale Konkremente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivale Pigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaler Reizzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivales Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivalsackfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivalsackverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivalymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivamelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivapigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivastein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivatuberkulose [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivazyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivisch-urethrisches synoviales Syndrom [Reiter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei Herpes zoster [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei Heuschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei Reiter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei Rosazea [kodiere zusätzlich H13.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei Zoster [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis bei parasitärer Krankheit a.n.k. [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Adenoviren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Akanthamöben [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Chlamydien [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Coxsackievirus A24 [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Enterovirus 70 [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Gonokokken [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Gonokokken [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Herpes-simplex-Virus [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Herpesviren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Meningokokken [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Newcastle-disease-Virus [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Staub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch Tularämie [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis durch chemisch-physikalische Einflüsse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis nach Fremdkörpereinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis, allergische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konjunktivitis, infektiöse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konkrement im Nierenkelchsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konkrementkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Chorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühsyphilis mit Okulopathie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Frühsyphilis mit Okulopathie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Hepatomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Leberhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Hutchinson-Zähnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Hutchinson-Zähnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Lues mit Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Mikrozephalie durch Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Schleimhautpapeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Spätlues mit Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Spätlues mit Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis mit Frühstadiumsymptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Syphilis mit Frühstadiumsymptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale floride Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale floride Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Augenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Augenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondritis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondritis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondrosis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Osteochondrosis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische interstitielle Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale frühsyphilitische interstitielle Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale gonorrhoische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale gonorrhoische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale kutane Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale kutane Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale latente Lues im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale latente Lues im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale latente Syphilis im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale latente Syphilis im Frühstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale mukokutane Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale mukokutane Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätauftretende Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätauftretende Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätauftretende Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätauftretende Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Arthropathie [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Arthropathie [kodiere zusätzlich M03.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Okulopathie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Okulopathie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Osteochondropathie [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Osteochondropathie [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische interstitielle Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale spätsyphilitische interstitielle Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Deformität der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Deformität der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Epiphysitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Epiphysitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Koryza [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Koryza [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Kyphose [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Kyphose [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Oxyzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Oxyzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Stigmata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Stigmata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Taubstummheit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale syphilitische Taubstummheit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale viszerale Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatale viszerale Frühsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler Hydrozephalus durch Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler Mikrophthalmus durch Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Katarrh [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Katarrh [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Schnupfen [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnataler syphilitischer Schnupfen [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Pneumomediastinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Syphilid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Syphilid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Syphilom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konnatales Syphilom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsekutive Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsekutive Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konservierungsmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionell verzögerte Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Hyperbilirubinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Leberdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Panhämozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Panmyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Panmyelophthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Pubertätsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Thrombopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle Thrombopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutionelle sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutioneller Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutioneller Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutioneller Riesenwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutioneller Status lymphaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstitutioneller Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konstriktive Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z47'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation mit dem Hausarzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z46'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation wegen Bescheinigungen für Verwaltungszwecke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konsultation zur Befunderläuterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit AIDS-Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Akariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit HIV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Parasiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Pocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Tollwut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Viruskrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit durch Geschlechtsverkehr übertragene Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit einer Geschlechtskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit infektiösen Darmbakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit infektiöser Darmkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit infektiöser Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit parasitärer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt mit übertragbarer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakt-Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis auf Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Detergenzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Mehl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis durch organische Lösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktdermatitis/allergisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch ein organisches Lösungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktekzem durch Öl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontakthämorrhagie nach Geschlechtsverkehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktlinsen Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktlinsenintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontaktstörung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontinenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontinenzschwäche der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontinuierliche Gastrosukkorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontinuitätsunterbrechung der Gehörknöchelchenkette',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrakte Präputialnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrakter Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktionsring als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktionsring als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktur der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktur des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktur des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktur des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontraktur des inneren Muttermundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrakturen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeption, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeptionsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeptionsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeptive Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeptive Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrazeptive Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle der Batterie eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle einer äußeren Schiene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Gipsverbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Impulsgenerators',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Intrauterinpessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Kirschner-Drahtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines Verdachtsbefundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle eines kontrazeptiven Mittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle ohne Notwendigkeit weiterer medizinischer Betreuung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolle von Verbänden und Nähten nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrollierter Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolluntersuchung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolluntersuchung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolluntersuchung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolluntersuchung bei Ovulationshemmeranwendung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontrolluntersuchung bei medikamentöser Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konträres Sexualempfinden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusion der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusion der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusion des lumbalen Rückenmarks mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusion/Blutung Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusionskatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kontusionsrosette der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konusmyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvergenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionshysterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsstörung mit Hysterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konversionsstörung mit Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvexitätsmeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsionen bei Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsionen beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsionstetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsionstetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsiv-idiopathischer Status',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsive Epilepsia major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konvulsives abdominales Äquivalent',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzentrationsstarre (Harn)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzentrationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzentrische Einengung des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzentrische Linksherzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzentrische Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeptionsverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeptionsverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Konzeptionsverhütung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koordinationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopferfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopferfrierung mit Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopferysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopffurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfgneis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfgrind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfgrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautdermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfhautspinaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopflausbefall/Pediculose/anderer Hautbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfläusebefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfnickerhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfphlegmone a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfplatzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen durch Medikamenteneinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen durch Spinal- und Periduralanästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen nach Liquorverlust durch Punktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen nach Lumbalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen nach Spinalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen unklarer Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzen unklarer Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschmerzsyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschuppen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschuppen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschußverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschwartenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfschwartenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfseborrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopftetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverletzung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kopfwundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koplik-Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprolagnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprolith der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koprostase der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korakohumerale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korakoklavikulare Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korallenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korbhenkelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korbhenkelriß des Meniskus des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korbhenkelriß des Semilunarknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koreanisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkarbeiterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkenzieherspeiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkrindenschälerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkrindenschälerlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korkstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korn-Krätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneagangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneainfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneakatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneakeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kornealanästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kornealepra [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kornealfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kornealhypoästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kornealhypästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneanekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaneovaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaperforation durch Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneasklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneatuberkulose [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaundurchsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korneaödem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koro',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienanomalie bei Bland-White-Garland-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterieninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterieninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterieninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararteriensklerose bei Syphilis [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararteriensklerose bei Syphilis [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararterienverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronararteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronaratheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Atherosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Drei-Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Dreigefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Ein-Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Eingefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Fünfgefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Herzkrankheit mit Ventrikelaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Herzkrankheit mit eingeschränkter linksventrikulärer Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Mangeldurchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Mangeldurchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Thromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Viergefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Zwei- bis Dreigefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Zwei-Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronare Zweigefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronares Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronares Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronares Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronargefäßstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronargerinnsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronariitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarsinusrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenthromboembolie ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarvenenverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koronarverschluß ohne nachfolgenden Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korpulenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korpulenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korpusgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korrigierte Transposition der großen Gefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsakow-Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsakow-Alkoholpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsakow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsakow-Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsakow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Korsika-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortexmotoneuronenschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Hämorrhagie im Gehirn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Nekrose bei Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Nekrose bei Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikale intrazerebrale Blutung der Großhirnhemisphäre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikaler fokaler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikoadrenale Hypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikoadrenale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikoadrenale Unterfunktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikobasale Degeneration [CBD] [kodiere zusätzlich F02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikosteroidglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikosteroidinduziertes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortikostriatospinale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortisolhypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kortisonglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koryza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koshewnikoff-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koshewnikoff-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kostale Verletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kostmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kosto-Klavikular-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kostochondrale Verletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kostochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koteinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotgeschwür des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotimpaktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotstein der Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kotälchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose 1.-2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxarthrose als Folge einer Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Koxitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krabbe-III-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krabbe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krabbe-Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krabbe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krabbenframbösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraftlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraftlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krallenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krallenhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krallennagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krallenzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf beim Schwimmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf der oberen Gliedmaßen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf der unteren Gliedmaßen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampf durch Salzverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfaderbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfadergeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfadern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfadern in Anus oder Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfbereitschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfbereitschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfhafter laryngealer Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfwehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krampfwehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniale Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniale Hydromeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniale Neuralgie nach Herpes zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranielle Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranieller Gefäßprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniopharyngeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniorhachischisis totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranioschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniotabes bei Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniotabes bei Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniotabes beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniotabes unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniovertebrales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraniumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankengymnastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker Sinusknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kranker in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhaft vermehrte Schweißabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Muskelermüdbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Muskelschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafte Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankhafter Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Atemwege in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Bauchspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Gelenkbänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Haut und der Unterhaut in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Kniescheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Nervi olfactorii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der Zahnhartsubstanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der blutbildenden Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der hämatopoetischen Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit der weißen Blutkörperchen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Blutes in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Corpus geniculatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Eierstocks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Harnsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Harntraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Kreislaufsystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Mastoids nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Nervus glossopharyngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Nervus hypoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Nervus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Nervus vagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Parodontium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Patellofemoralbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Speicheldrüsenausführungsganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Tränenapparates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Verdauungskanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des Verdauungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des endokrinen Systems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des neuromuskulären Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des peripheren Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des sympathischen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des vorderen Uvealtraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des zahnlosen Alveolarkamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit des äußeren Ohres a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Anti-GBM-Antikörper [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Blasenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Hantavirus [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Heringswurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Herpes-simiae-Virus [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Hundebandwurm a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Hydatiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Katheter a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Madenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Mangel an Koagulationsfaktoren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Peitschenwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Sandwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Saugwurm a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Schädigung der tubulären Nierenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Springwurm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Spulwurm a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Trematoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Vibration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch glomeruläre Basalmembranantikörper [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch großen Leberegel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit durch humanes T-Zell-lymphotropes Virus Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit in der Schwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit mehrerer Herzklappen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheit von Magen und Zwölffingerdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitsfurcht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitsträger NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krankheitswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kratz-Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kraushaarsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Cauda pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Cervix vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Columna vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Flexura coli dextra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Flexura coli hepatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Flexura coli lienalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Flexura coli sinistra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Fossa tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula parathyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula pituitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glandula suprarenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Harnleitermündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Kardia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Langerhans-Inseln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Mamma im Zentrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Mamma im Zentrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Pleura parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Pleura pulmonalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Plica aryepiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Retromolarregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Rückenmarkhäute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Uterusadnexe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Uterusbänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Vallecula epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Verbindungszone des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Zungentonsille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der Zungenunterfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der hinteren Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der hinteren Rachenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der inneren Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der inneren Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der inneren Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der kleinen Magenkurvatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der paraurethralen Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der seitlichen Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der vorderen Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der weiblichen Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der äußeren Oberlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs der äußeren Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Antrum pyloricum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Blasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Blasenscheitels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Brustfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Caput pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Colon ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Colon descendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Colon transversum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Corpus cavernosum des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Corpus ciliare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Corpus pancreatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Corpus pineale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Corpus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Ductus pancreaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Fundus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Glomus caroticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Hauptbronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Isthmus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Kolons und Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Ligamentum teres uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Lobus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Lobus temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Mediastinum anterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Mediastinum posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Mundrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Recessus piriformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Retroperitonealraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Sinus ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Sinus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Sinus maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Sinus sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Trigonum vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Waldeyer-Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Wurmfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Zungenrandes und der Zungenspitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des Zäkums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des extrahepatischen Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des hinteren Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des hinteren Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des intrahepatischen Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des kraniopharyngealen Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des oberen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des oberen Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des postkrikoidalen Hypopharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des seitlichen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des seitlichen Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des seitlichen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des unteren Zahnfleisches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des vorderen Kehldeckels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des vorderen Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des vorderen Teils des Mundbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des vorderen Teils des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des weiblichen Warzenhofes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebs einer endokrine Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebsfrüherkennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebsnachsorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krebsvorsorgeuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufdysfunktion bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufdysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufinsuffizienz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufkollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislauflabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislauflabilität bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufstauung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kretapneumonie [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kretinismus ohne Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbandelongation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbandläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeindislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeindistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinfraktur mit Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeintuberkulose [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbeinverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kreuzschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kribbeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kribbeln Finger/Füße/Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kribbeln der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kribbeln im Bein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kriegsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kriegsopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kriegsopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kriegsopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kriminelle Verhaltensweise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krimineller Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krippentod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krippentod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krisenzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristall-induzierte Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristall-induzierte Synovitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristall-induzierte Tenosynovitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristallarthopathien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristallarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristallarthropathie bei Hyperparathyreoidismus [kodiere zusätzlich M14.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristalline Ablagerung im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristalline Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kristallurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krokodil-Chagrin-Hornhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krukenberg-Axenfeld-Spindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krukenberg-Spindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krukenberg-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krupp - s.a. Laryngitis, obstruktiv, akut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kruppöse Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kruppöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kruppöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kruppöser Stridor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kruppöses Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryoglobulinämie mit Lungenbeteiligung [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryoglobulinämie mit Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryoglobulinämie mit Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryoglobulinämische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryoglobulinämische Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptentonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptogene Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptogene sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptogenetische Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptokokkose der Hirnhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptokokkose durch Cryptococcus neoformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptopapillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptopapillitis des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptophthalmussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kryptozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kräfteverfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kräfteverfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krämerkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krämpfe/Zuckungen/Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krätze/andere Milbenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kräuterpollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Krötenhaut [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuchenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kufs-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kufs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kugelberg-Welander-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kugelberg-Welander-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kugelzellenanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kugelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuhmilchproteinintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuhnt-Junius-Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuhpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuhpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuhpocken des Augenlids [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturell bedingter schmerzlicher Verlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturell bedingter schmerzlicher Verlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturell bedingtes Schockerlebnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturell bedingtes Schockerlebnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kulturschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kumaon-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kunjin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kunkel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kupfermangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kupferschmied-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kupferstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kupffer-Zell-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuru',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuru-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kuru-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzatmigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzatmigkeit/Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzdarmsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzdarmsyndrom nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzdauernde depressive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzdauernde schizophrene Episode a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurze Nabelschnur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurze Nabelschnur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurze reaktive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurze schizophreniforme Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurze schizophreniforme Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzfristiger Bewußtseinsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzhals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzrippen-Polydaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kurzzykler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Atmung bei diabetischem Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Atmung bei diabetischem Koma bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Koma bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Koma bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Landry-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Maier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kussmaul-Maier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Ablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Bartonellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Blastomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Bläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Chromomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Kokzidioidomykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Kryptokokkose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Mukormykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Myiasis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Nokardiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane Strongyloidiasis [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane amerikanische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane asiatische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane städtische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutane äthiopische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutaneotendinöse Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutaner Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutaner Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kutanes Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kwashiorkor-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyasanur-Wald-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyasanur-forest-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyasanur-forest-disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose als Haltungsschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose als Spätfolgen nach Rachitis [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphose nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphoskoliose als Spätfolgen nach Rachitis [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphoskoliose bei Morbus Scheuermann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphotische Fehlhaltung der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphotische Fehlstellung der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphotische Haltungsstörung beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyphotischer Knick im HWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyrle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kyrle-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kystadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälte-Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälte-Hämagglutinin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälte-Nässe-Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälte-Nässe-Schaden der Füße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälte-Nässe-Schaden der Hände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälteagglutinin-Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälteagglutininkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kältegefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kältegefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kältehämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälteschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kältetrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kälteurtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsewäscherlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige Perikarditis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige Peritonitis [kodiere zusätzlich K67.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Käsige tuberkulöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Köbner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Köhler-I-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Köhler-II-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Köhler-Mouchet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'König-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'König-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperdysmorphophobe Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Funktionsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z39'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Mißhandlung durch Bekannten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Mißhandlung durch Ehegatten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Mißhandlung durch Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Mißhandlung durch Freund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Mißhandlung durch Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Retardierung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliche Retardierung durch Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Abbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Abbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperlicher Verfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperliches Zurückbleiben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperläusebefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körpermykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Körperverletzung a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Verneuil-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Verneuil-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Verneuil-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kümmell-Verneuil-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Künstliche Augenlinse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Künstliche Befruchtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Künstliche Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Künstliche Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Künstliche Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kürschnerlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kürzlich erworbene symptomatische Syphilis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Kürzlich erworbene symptomatische Syphilis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'L-förmige Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LADA [Latent (or late-onset) autoimmune diabetes of adulthood]-Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LDL-Hyperlipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LFA [Lymphozytenfunktion-Antigen]-1-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LGA [Large for gestational age]-Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LGL [Lown-Ganong-Levine]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LSB [Left septal block]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LSD [Lysergsäurediäthylamid]-Rausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LWS-Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LWS-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LWS-Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LWS-Prellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'La-Crosse-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labialer Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labialhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiensynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labientumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverschmelzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labienödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labile Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiler Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiler Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiler Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiler Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiler Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labiles vasomotorisches System',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labioglossale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labium fissum leporinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laborhinweis auf Humanes Immundefizienz-Virus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laborparameteruntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinth-Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrintheiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthhydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthitis circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthitis des inneren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Labyrinthüberempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lachkrankheit (atypische ZNS-Virusinfektion)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lacksprungmyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lafora-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lafora-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageabhängige Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageanomalie des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lagebedingte Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lagebedingter Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageveränderung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lageveränderung des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lagophthalmische Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lagophthalmus durch Fazialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lakrimale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktatazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktationshyperinvolution des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktationspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktoseintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laktoseintoleranzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lakunärer Schädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lakunäres Syndrom a.n.k. [kodiere zusätzlich G46.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lallen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lambliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lamblien-Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lambliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lamelläre Hornhautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landau-Kleffner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landblutegelbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landkartenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landkartenzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landouzy-Déjerine-Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landouzy-Déjerine-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landouzy-Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landry-Guillain-Barré-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landry-Guillain-Barré-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landry-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landsteiner-Fanconi-Andersen-Syndrom [Mukoviszidose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landstreicher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landstreicher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landstreicher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Landstreicher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langat-Virus-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langdauernde depressive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langdauerndes Schreien beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langdon-Down-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lange-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langerhans-Zell-Granulomatose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langerhans-Zell-Histiozytose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langerhans-Zell-Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langhans-Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langzeitdialyse bei Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Langzeitinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lannelongue-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lanois-Bensaude-Adenolipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lanuginöse Hypertrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lanugobehaarung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lappenbildung der Milz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lappenbildung der fetalen Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Large-for-date-Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Large-for-date-Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Large-for-date-Säugling a.n.k',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larsen-Johansson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larsen-Johansson-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larsen-Johansson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larsen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larva migrans cutanea a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larvierte Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larvierte Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngeale Myiasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngealer Stridor congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngeusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngismus stridulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis durch Borrelia vincenti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis stridulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngocele ventricularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngofissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngopharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngophthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngostenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis durch Borrelia vincenti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchitis beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchitis beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngotracheobronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laryngozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynx-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxamyloidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxchondromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxdiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxerysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxfixation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxgumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxgumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxhistoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxhyperästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxlipoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxmyxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxpachydermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxschleimhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxstriktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxurtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxvernarbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverschluß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxwundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Larynxzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lassitudo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lassitudo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latah',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Late-onset-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Late-onset-Form des 21-Hydroxylase-Defektes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Late-onset-Form des 21-Hydroxylase-Mangels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latent hyperthyreote Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Hyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Kieferknochenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Labyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Spätlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Spätlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Frühlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Lues im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Lues im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente konnatale Syphilis im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latente schizophrene Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter Diabetes mellitus bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter Rektumprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latenter autoimmun-assoziierter Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Frühstadium der Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Frühstadium der Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Frühstadium der Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Frühstadium der Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Innenschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Schielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latentes Sinusknotensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale Halsfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale Halszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale Kompressionsfraktur des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale Lageveränderung des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale parodontale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterale periodontale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laterales medulläres Syndrom [kodiere zusätzlich G46.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lateralparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lateralsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lateroflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lateropositio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lateroversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lathyrismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lathyrismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Latrodektismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Launenhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Launenhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laurell-Eriksson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laurence-Moon-Bardet-Biedl-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lautheitsausgleich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lavy-Palmer-Merritt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laxanzienabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laxanziengewöhnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laxanzienmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration der Chordae tendineae a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration des Frenulum labiorum pudendi als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration des Frenulum labiorum pudendi als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazeration mit Abort im Nachbehandlungszeitraum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazerationsektropium der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lazy bladder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laënnec-Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Laënnec-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Le-Fort-I-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Le-Fort-II-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeborener Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeborener Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeborenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeborenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeburt eines Einlings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeburt nach komplizierter Entbindung: manuell oder apparativ unterstützte Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebendgeburt von Zwillingen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensabschnittsproblem Erwachsener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelvergiftung durch Clostridium botulinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebensmittelvergiftung durch Clostridium perfringens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leber-Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leber-Optikusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberaffektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberamyloidose [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberamöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberangiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberapoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberarteriensyphilis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberarteriensyphilis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberatrophie mit akuter Gelbsucht bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebercirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebercirrhosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberdystopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberegel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberembryom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberenzymerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebererkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebererkrankungen ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberfiliae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergangkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergangstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergranulom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergranulome bei Berylliose [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergranulome bei Sarkoidose [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergumma [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebergumma [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberinduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberinfektion durch Echinococcus granulosus [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberinfektion durch Echinococcus multilocularis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkapselblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkapselfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebermelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebermelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebermetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebermetastase bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebermißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebernekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberparenchymnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberparenchymschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberparenchymschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberphosphorylasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebersarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberstauungsatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberstauungsinduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebersteatose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebert-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebertoxoplasmose [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebertransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebertuberkulose [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebertyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenblockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervenenverschlußsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lebervergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzelldegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzellnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzirrhose nach Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leberzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lecithin-Cholesterin-Acyltransferase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leckage einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leckekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ledderhose-Kontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ledderhose-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lederbeutelmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lederer-Brill-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lederhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lederhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lederhautkrankheit des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legale Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legale Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legaler Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legaler Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legaler Schwangerschaftsabbruch mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legionellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legionellose ohne Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legionärskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legionärskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Legionärspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lehrerknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leibschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichdorn [Klavus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Asphyxie unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Dysplasiehüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Gedächtnislücke nach organischer Hirnschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Hyperemesis bei Frühgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Hüftdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Hüftgelenkdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Imbezillität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Intelligenzminderung mit Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Intelligenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Maroteaux-Lamy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte geistige Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte geistige Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte kombinierte Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte mentale Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte reaktive Depression als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte statisch nicht relevante Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichte ängstliche Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichter Hospitalismus beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichter Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichtes Maroteaux-Lamy-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichtgradige Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leichtkettenproteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leimohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiofibromyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyofibrom der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyofibrom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoma cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoma cellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoma sarcomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyoma teleangiectaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyomatose - s. Neubildung, Bindegewebe, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyosarkom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyosarkom des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leiomyosarkom des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniase der Mittelmeerländer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniase der Mund- und Nasen-Schleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniase-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis tegumentaria diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniasis tropica major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmaniose - s.a. Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leishmanoid nach Kala-Azar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeugenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeugenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeugenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbeugenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch mit Inkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch mit Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenbruch mit Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistendermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistendrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistendrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenhernienrezidiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leistenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leitungsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leitungsunterbrechung des His-Bündels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leitveneninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lejeune-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lemming-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lemmoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lemmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenlordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenwirbelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenwirbelfraktur mit Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenwirbelsäulensyndrom bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lendenwirbelsäulenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lennert-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lennox-Gastaut-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lennox-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lenticonus anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lenticonus posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentiglobus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentiglobus posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentigo aestiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentigo benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentigo maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentigo senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentikonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentikuläre Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentikuläres Dermatofibrom - s. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentogene Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lentogenes Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leontiasis ossea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepothrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra - s.a. Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra asturica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra dimorpha',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra indeterminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra interpolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra lazarina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra lepromatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra lombardica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra mit Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra mit Polyneuritis [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra mixta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra nervosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepra tuberculoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leprechaunismussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leprom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepromatöse Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepromatöser Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lepröse Chorioiditis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningealfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningealsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeningopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeninxblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeninxgumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeninxgumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptomeninxtuberkulose [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirochätale Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirose durch Leptospira interrogans serovar icterohaemorrhagiae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirosis autumnalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirosis canicola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirosis icterohaemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptospirosis pomona',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptothrikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptothrix-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leptothrix-Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lequesne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leriche-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leriche-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lermoyez-Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lermoyez-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lernbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lerndefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lernschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lernstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lese-Rechtschreib-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lese-Rechtschreib-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leser-Trélat-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leserückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leseschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leseschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lesestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lethargie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lethargie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lethargie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Letterer-Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Letterer-Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Letterer-Siwe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leucaemia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuchtgasvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leucoma corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoblastose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoderm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoderma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukodermie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoenzephalopathie nach Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoerythroblastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoerythroblastose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoerythrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukokeratosis nicotina palati',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukokraurosis vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukonychia punctata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukonychia striata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopathia unguinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopathia unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopathia universalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopenie mit Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopenie nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukopenie nach Zytostatikatherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoplakia buccalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoplakia oris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoplakie der Portio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukoplakie des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukorrhoe durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukosarkom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukose - s.a. Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukotomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozytenkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozytenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozytoklastische Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämie in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämische Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämische Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämische Retikuloendotheliose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämisches Lymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuködem der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuködem des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuködem des Mundhöhlenepithels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuzin-Abbaustörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuzinbedingte Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leuzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Levator-ani-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Levi-Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Levurid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Levurinosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leyden-Moebius-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Leydig-Zell-Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidoabnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidohemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidomangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidominderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidosteigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidostörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidoverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libidoverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libman-Sacks-Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libman-Sacks-Krankheit [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Libman-Sacks-Syndrom [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen Vidal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen albus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen amyloidosus [kodiere zusätzlich L99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen atrophicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen corneus disseminatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen myxoedematosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen obtusus corneus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen pilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen planus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen planus tropicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber acuminatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber anularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber atrophicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber chronicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber decalvans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber mucosae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber obtusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber planus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber striatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen ruber verrucosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen sclerosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen sclerosus et atrophicans der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen sclerosus et atrophicans des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen simplex chronicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen simplex chronicus circumscriptus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen spinulosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichen urticatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenifizierte Dermatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenoide Parapsoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenoide Pityriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichenoides Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichtdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichtempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichtkeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichtscheu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lichtschädigung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidavulsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidchloasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liddefekt nach Exzision',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liddegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liddermoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liddrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liderkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidexanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidfehlstellung bei Fazialisparese ohne Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidhautxeroderma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidherpes [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidhypertrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidknorpelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidlymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidmadarosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandborken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandfollikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidrandzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidschließdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidschlußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidspaltenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidspaltenfleck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidspaltenverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidsyringom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidtrachom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidverruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidvitiligo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidwinkelulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidxanthelasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidxeroderma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lidödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lien accessorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lien migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lien mobilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lienitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lienomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ligamentlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ligamentlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ligamentopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ligamentose der Fußwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ligamentose des Iliolumbalbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Light-for-date-Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lightwood-Albright-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lignac-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Limbale obere Keratokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Limit-Dextrinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lindau-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lindau-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linea corneae senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lineare Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua hypertrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua scrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua scrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua villosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua villosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua villosa nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingua villosa nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linguale Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingualer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingualer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingualer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lingualer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linguatulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linguatulosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linitis plastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linitis plastica bei szirrhösem Magenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linker Doppelausstromventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkherzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksanteriorer Hemiblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzbelastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzdekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzhypoplasiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz mit Beschwerden bei leichterer Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz mit Beschwerden bei stärkerer Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz ohne Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz, NYHA-Stadium I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz, NYHA-Stadium II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz, NYHA-Stadium III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzinsuffizienz, NYHA-Stadium IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksherzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe BWS-LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe HWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linkskonvexe Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksposteriorer Hemiblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksseitiger Faszikelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksseitiger Hemiblock a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksthorakale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksthorakale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linksventrikuläre Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenchalkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenfremdkörper der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linseninduzierte Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenkernsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenlosigkeit - s.a. Aphakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsensubluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsensubluxationsglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsentrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenundurchsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Linsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidgranulom bei Pfeifer-Weber-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidreiches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidreiches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoangioleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipocainmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipochondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipodermoid der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipodystrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipodystrophia intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoiddermatoarthritis [kodiere zusätzlich M14.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidgranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidhistiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidnekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidnephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoma sarcomatodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomatosis dolorosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomatosis renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomelanotische Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipomyxosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipophages Granulom bei Pfeifer-Weber-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoplastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoproteinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipoproteinämie mit breiter Beta-Bande [Floating-Betalipoproteinämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liporetikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liposynovitis praepatellaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipothymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippen-Gaumen-Spalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippen-Kiefer-Gaumen-Spalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippen-Kiefer-Spalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippendrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippeneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenhautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenhautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenherpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenkiefergaumenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenschrunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippensyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippensyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenzyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lippenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipurie bei Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lipödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liquor-cerebrospinalis-Shunt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liquorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Liquorventildysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lispeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Herdparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Herdparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissauer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lissenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lithopädion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Little-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Little-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Littreitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Littré-Drüsen-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Littré-Drüsen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Littré-Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Livedo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Livedo anularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Livedo racemosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Livedo reticularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Loa-loa-Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Loa-loa-Filariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Loa-loa-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobotomiesyndrom [Postlobotomiesyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobstein-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobuläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobuläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobulärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobus venae azygos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobärpneumonie durch Streptococcus pneumoniae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lobärpneumonie durch Streptokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lochialstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lochiometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lockerung einer Hüftgelenktotalendoprothese [TEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lockerung einer TEP [Totalendoprothese] des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Logopädische Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Loiasis des Augenlids [kodiere zusätzlich H03.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Loiasis mit Konjunktivabefall [kodiere zusätzlich H13.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalanästhetikaunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Haut- und Unterhautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Hautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Hautinfektion durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Hautinfektion durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Infektion des Unterhautzellgewebes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Injektion/Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z55'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Neurodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Odontodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Vaccinia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Wundinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokale subkutane Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokaler Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokaler Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokaler vaskulärer Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokales Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisationsbezogene Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Arzneimitteldermatitis durch ein eingenommenes Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Bauchfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Dermatosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Fettpolster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Gingivaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Sepsis einer Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierte degenerative Ticstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierter Abszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisierter Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokalisiertes Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokomotorische syphilitische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lokomotorische syphilitische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Longitudinale Furchen der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Longitudinale Streifen der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Looser-Milkman-Debray-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lorain-Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lorain-Levi-Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lorain-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lorain-Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordose als Haltungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordose als Spätfolgen nach Rachitis [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordose nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordotische Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lordotischer Knick L5/S1',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lose Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lost IUP [Intrauterinpessar]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Louis-Bar-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Louping-ill-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Louping-ill-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Low-T3 [Trijodthyronin]-Low-T4 [Thyroxin]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lowe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lowe-Syndrom mit Fanconi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lown-Ganong-Levine-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lubarsch-Pick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ludwig-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues - s.a. Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues - s.a. Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Dementia paralytica juvenilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Dementia paralytica juvenilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Keratitis parenchymatosa [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Keratitis parenchymatosa [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit gastrischer Krise [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit gastrischer Krise [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit primärem Genitalaffekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues mit primärem Genitalaffekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues/Syphilis, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lues/Syphilis, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortendilatation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortendilatation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortenklappenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortenklappenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortitis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Aortitis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetische Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetisches Aortenaneurysma [kodiere zusätzlich I79.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luetisches Aortenaneurysma [kodiere zusätzlich I79.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftdruckkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftdruckschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftdruckschaden der Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftdruckschaden des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftembolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftembolie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftembolie in der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftharnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftharnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lufthungergefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftnot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftröhrenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luftwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbago bei Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbago bei Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbago bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Markraumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Markraumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Nucleus-pulposus-Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Nucleus-pulposus-Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbale tuberkulöse Fistel [kodiere zusätzlich M49.06*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler BSV [Bandscheibenvorfall]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler BSV [Bandscheibenvorfall]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenschaden bei Radikulopathie [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenschaden bei Radikulopathie [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler NPP [Nucleus-pulposus-Prolaps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler NPP [Nucleus-pulposus-Prolaps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbaler Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbales Nervenwurzelreizsyndrom [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbales Nervenwurzelreizsyndrom [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbales Postdiskektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbales vertebragenes lokales Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie bei Iliosakralgelenkirritation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie durch Bandscheibenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie durch Bandscheibenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalgie mit Facettenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbalplexusneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumboischialgie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumboischialgie durch Bandscheibenschaden [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumboischialgie durch Bandscheibenschaden [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumboischialgie mit Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Chondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Diskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Osteochondrose mit Retrolisthese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Spina bifida mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrale Wurzelläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakraler Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakrales Postdiskektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakralgelenkanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakralgelenkverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lumbosakralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lunatummalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lunatummalazie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenabsiedelung eines Tumors',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenabszeß durch Amöben [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenabszeß mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaluminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenalveolaradenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenalveolenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenamyloidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenamöbiasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenanschoppung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenanthrakose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenarterienarrosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenasbestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaspergillose a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenasthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenbauxitfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenberylliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenblähung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenchondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungendystopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenegelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie in der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie mit akutem Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenembolie ohne akutes Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenentzündung - s.a. Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfibrose nach Strahleneinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfiliae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenflügelatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengefäßruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengefäßstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengefäßstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengefäßveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengeotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengerüsterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungengranulomatose [kodiere zusätzlich J99.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhepatisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhilusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhistoplasmose a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhypostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhämosiderose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenhämosiderotische Anämie [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfektion durch Echinococcus granulosus [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfektion durch Mycobacterium avium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfektion durch Mycobacterium intracellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfektion durch Mycobacterium kansasii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkandidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkarzinom des Mittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkarzinom des Oberlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkarzinom des Unterlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkaverne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkokzidioidomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkomplikation aufgrund anderer Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrankheit durch Eisen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrebs des Mittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrebs des Oberlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkrebs des Unterlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkreislaufkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenkryptokokkose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenlappenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmetastase bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmoniliasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmukormykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenmykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenoberlappenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenornithose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenoxyuriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenparakokzidioidomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenparenchymblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenparenchymmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenparenchymnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenphthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenproteinosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenrundherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenschatten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenschwindsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensequestration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensilikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensoor [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenspitzentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensporotrichose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenstrahlenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentorulose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentoxoplasmose [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentrichinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungentyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenumbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenunreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenunterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenvenenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenzygomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lungenödem durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupoide Hepatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus bei chronischer Nephritis [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus des Augenlids [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematodes Zellenphänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematodes des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematodes discoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematodes disseminatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus erythematosus discoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus exedens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus pernio (Besnier)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus vulgaris des Lids [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lupus-Pannikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luteinisiertes Thekom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luteinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luteinzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lutembacher-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lutembacher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lutz-Miescher-Elastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lutz-Splendore-de-Almeida-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxatio bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxatio bulbi bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxatio coxae congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation der Symphysenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation des Akromioklavikulargelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxation einer Hüftgelenktotalendoprothese [TEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Luxierbare Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyell-Syndrom der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyell-Syndrom mit Befall von 30% der Körperoberfläche und mehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyell-Syndrom mit Schleimhautbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyme Disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyme-Borreliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphabflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis bei Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis colli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis durch Brugia malayi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis, akute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenitis, chronische/unspezifische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenoider Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenopathie mit/ohne Schmerz/Überempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphadenosis cutis benigna [Morbus Bäfverstedt] [Bäfverstedt-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiektasie der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiektasie des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiektatische Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioendotheliales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioendothelioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioma capillare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioma cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangioma cysticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiomatöse Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiomyomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangiosis carcinomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangitis durch Brugia malayi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangitis durch Wuchereria bancrofti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangitis epizootica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphangitis post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphaszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Filariose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Infiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatische Stase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphatisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphdrüsen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphdrüsengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphdrüsenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphdrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßobliteration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphgefäßverschluß nach Mastektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknoten vergrößert/schmerzend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenfiliae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknoteninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknoteninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknoteninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase der Leistenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase des Halses bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenmetastase des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphknotenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastische zytologische hereditäre Dysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastisches Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastisches diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoblastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphocytosis infectiosa acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoedema praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoepitheliale Mundweichteilzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoepithelialzyste des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogene Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogener Leberabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranulom durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranulom durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma inguinale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma inguinale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma venereum durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranuloma venereum durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphogranulomatosis benigna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Appendixhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Hypertrophie der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Pharynxhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Rhinopharynxhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoide Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom der Mantelschicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom vom Mischzelltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom vom histiozytären Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom vom undifferenzierten Non-Burkitt-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphom vom undifferenzierten Zelltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphomata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphomatöse Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphomatöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphonoduläre Pharyngitis durch Enteroviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphopathia venerea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphopathia venerea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphopenische Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoplasmozytoides Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoproliferative Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphoretikulosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphosarkomatöse Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphosarkomzellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphosarkomzellenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytenarme Form der Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytenfunktion-Antigen-1 [LFA-1]-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytenreiche Form der Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytenspender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytom Spiegler-Fendt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Chorioenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Choriomeningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Immunthyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Meningoenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Meningoradikulitis (Bannwarth)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäre leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphozytäres diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphsystem-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödem des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödem nach Ablatio mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödem nach chirurgischem Eingriff a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lymphödemsyndrom nach Brustamputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lynch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lysinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lyssa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung beider Arme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung beider Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung beider oberer Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung der unteren Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung des Hirnnerven VII',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung des Nervus peronaeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung des peripheren autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung eines Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung eines Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmung/Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmungsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmungsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lähmungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Längsverengtes Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärmempfindlichkeit des Gehörs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärminduzierte Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärminduzierte Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärmschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärmschädigung des Innenohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lärmüberempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion der Rotatorenmanschette',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion der Rotatorenmanschette des Schultergelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion des Lumbosakralplexus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion des Nervus axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion des Nervus fibularis communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion des Nervus peronaeus communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läsion des Plexus brachialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läuse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läusebefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läusefleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läusekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läuserückfallfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Läusetyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lävotransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Léri-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Léri-Joanny-Syndrom [Melorheostose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Léri-Weill-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffelhand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffelnagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffler-Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffler-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffler-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffler-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löffler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löfgren-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Löhr-Léon-Kindberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lösungsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lösungsmittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lösungsmittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lückenschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lügensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Lügensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'M. Pfeiffer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MALT [Mucosa Associated Lymphoid Tissue]-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MALT [Mucosa Associated Lymphoid Tissue]-Lymphom des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MCLS [Mukokutanes Lymphknotensyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MCS [Multiple-Chemical-Sensitivity]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MEN [Multiple endokrine Neoplasie] - s.a. Neoplasie, endokrin, multipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MHC [Haupthistokompatibilitätskomplex]-Klasse-I-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MHC [Haupthistokompatibilitätskomplex]-Klasse-II-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MODY [Maturity onset diabetes of young people]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MS [Encephalomyelitis disseminata]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'MSV [Mutterschaftsvorsorge]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macrogenitosomia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macrogenitosomia praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macrogenitosomia praecox beim Knaben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macrogenitosomia praecox beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macrogenitosomia praecox masculina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macula matricis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maculadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maculae atrophicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maculae caeruleae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maculae corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Macular pucker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madarosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madarosis ciliaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madarosis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madelung-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madelung-Fetthals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madelung-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madenbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Madurafuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maduramykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maduramykotisches Myzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maduramyzetom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mafucci-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-/Gastrojejunal-/Anastomosenulcus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Grippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Spasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magen-Darm-Trakt-Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenamyloidose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenandauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenausgangskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenausgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenausgangsverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenausgußblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenbezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendistension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendurchbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mageneingangskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mageneingangskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenfrühkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenfunktionsstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magengeschwür mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magengrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhypermobilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhypomotilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mageninertia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkarzinom der Kardiaregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenlues [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenlues [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenlymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenmotorikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenpförtnerkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenphytobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhauthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschleimhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensekretionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenstumpfkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensyphilis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magensäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magentransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magentrichobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magentrichophytobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenverstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenvolvulus durch Verlust des Ligamentum gastrocolicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenwanddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magenübersäuerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magitot-Krankheit [Parodontitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magnesiummangelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Magnesiumstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mailänder Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maiskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maisonneuve-Fraktur des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Majocchi-Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Majocchi-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Majocchi-Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makakusohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrodaktylie der Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrodaktylie des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrodaktylie eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrofollikuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrogenitosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makroglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makroglobulinämie Waldenström',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makroglobulinämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrogyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrohydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrohämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrokolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrokornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrokornea mit Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makromastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makromastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makronoduläre Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrophthalmus bei angeborenem Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makroprolaktinomsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makropsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrosigma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrosigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrotie des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makrozytäre Anämie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulafalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulaforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulafältelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulaleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulaloch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulanarbe durch Sonnenexposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulaveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makuloanästhetische Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makuläre Heredodegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makuläre Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Makuläre Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mal de Meleda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mal de Pinto',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabar-Flechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Galaktose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Isomaltose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Kalzium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Kohlenhydraten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Laktose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Monosaccharid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Protein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorption von Stärke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorptionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malabsorptionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malakoplakie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malakoplakie der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malakoplakie des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malakoplakie des Ureters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria algida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria biliosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria durch Mischinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria falciparum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria malariae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria mit Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria mit Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria quartana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria quartana durch Plasmodium malariae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria quartana mit Nephropathie [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria quotidiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tertiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tertiana durch Plasmodium vivax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tertiana maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tertiana mit Milzruptur [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tropica durch Plasmodium falciparum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria tropica mit zerebraler Komplikation [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria vivax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria-Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria-Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria-Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malaria-Rückfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malariaanämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malariafieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malarialeber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malayische Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malazie der Knochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malazie der Knochen im Erwachsenenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maldescensus des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maldescensus des Zökums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maldescensus testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maldigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Male pattern-Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malgaigne-Beckenringfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malherbe-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maliasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Bluterkrankungen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Granulozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Histiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Hyperthermie in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Hypertonie mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Leukopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Mastozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Muskeldystrophie (Typ Duchenne)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Neoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Nierenhypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Polyadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Prostataerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Retikuloendotheliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Retikulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Splenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne Zystinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne hydatidiforme Mole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne hypertensive Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne kardiorenale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne primäre Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligne renale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Aderhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Analrandtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Analtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Augentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Brenner-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Chorioideatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Harnblasentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Hirnnerventumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Hodentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Hornhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Iristumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Karunkeltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Lidhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Mastzellentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Nasennebenhöhlentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Nebennierenrindentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Nebennierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Netzhauttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Optikustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Orbitatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Ovarialtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Polyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Prozeß der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Retinatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Skleratumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tränendrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tränenwegtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tumor der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tumor des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Tumor des Lids und Kanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Weichteiltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maligner Ziliarkörpertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Adamantinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Aderhautmelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Bindehautmelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Cholangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Chorioideamelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Chromaffinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Epitheliom - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Follikulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Gastrinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Gliom des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Glukagonom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Granulom des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Hepatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Histiozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Hämangioendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Immunoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Lymphogranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Mastozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Axilla',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Leistenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Lende',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Schläfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der Wange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der äußeren Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom der äußeren Wange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Augenwinkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Kanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Stamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Unterbauches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des Vorfußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Melanom in Sommersprossen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Mesonephrom - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Nephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Nierenbeckenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Orbitamelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Phäochromozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Pinealom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Plasmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Plasmom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Teratoblastom - s. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Unterernährungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Weichteilmelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Ziliarkörpermelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes Ziliarkörperringmelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes akrolentiginöses Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes amelanotisches Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes knotiges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes neuroleptisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes noduläres Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes superfiziell spreitendes Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignes superfiziell spreitendes Melanom des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignom der Bronchien und der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignom der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignom des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malignomangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mallory-Körperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mallory-Weiss Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch Magen-Darm-Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch mangelnde Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch mangelnde Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition durch mangelnde Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malnutrition in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malocclusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malrotation des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malrotation des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malrotation des Zökums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malta-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum Potti [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum coxae senile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum perforans pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malum vertebrale suboccipitale [kodiere zusätzlich M49.01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Malzarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenabszeß im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenabszeß in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamilleneinziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamilleneinziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamilleninfektion in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillenretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamillodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamma pendulans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mamma pendulans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaabsonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaabszeß in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaasymmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaasymmetrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaeiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaeiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibroadenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafibrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammafurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammageschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammageschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammahypotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainfektion in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammainvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakalkherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des Recessus axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des Recessus axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des Zentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des Zentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des oberen inneren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des oberen inneren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des oberen äußeren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des oberen äußeren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des unteren inneren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des unteren inneren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des unteren äußeren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom des unteren äußeren Quadranten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakarzinom in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammalipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammalipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammamalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammamalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammasekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammasekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammastriae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammatransplantatabstoßung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammatransplantatversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammatuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverdichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammaverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammazellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammazellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mammographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Managerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandeleiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelentzündung - s.a. Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelentzündung/Tonsillitis, akute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandelstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandeltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibulaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuladislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuladistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibulahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibulakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibulofaziale Mißbildungskombination [Franceschetti-I-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuläre Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuläre Makrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuläre Mikrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuläre Prognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mandibuläre Retrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manganpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Entspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Freizeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Galaktose-1-Phosphat-Uridyltransferase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Heizmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Heizmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Heizmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Heizmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Lernerfahrung in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Moral',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Nahrungsbestandteilen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Nebenschilddrüsenhormon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Pellagraschutzstoff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Pflege eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Pyridoxin-Derivaten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Spielerfahrung in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Tränenflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an Vitamin A mit Xerosis corneae [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an adäquater Nahrung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an adäquater Nahrung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an adäquater Nahrung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an adäquater Nahrung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an antihämophilem Globulin a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an einer Person, die Pflege übernehmen kann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an energieliefernden Stoffen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an essentielle Fettsäuren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an finanziellen Mitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an finanziellen Mitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an finanziellen Mitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an finanziellen Mitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an humoralen Antikörpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an häuslicher Pflegemöglichkeit für Kranken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an körperlicher Bewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an körperlicher Bewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an materiellen Gütern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an materiellen Gütern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an materiellen Gütern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an materiellen Gütern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an sexuellem Verlangen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel an zirkulierenden Enzymen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel des Erinnerungsvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangel mehrerer Nahrungsbestandteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangeldurchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelernährung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelernährung in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Anzahl an Zähnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Beatmung der Lunge beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Erektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Glykogenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Körperhaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Mammarückbildung nach Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte Mammarückbildung nach Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte kraniofaziale Achse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafte persönliche Hygiene in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhafter Descensus testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhaftes Wachstum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelhaftes fetales Wachstum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Betreuung eines Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Betreuung eines Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Betreuung eines Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Blutgerinnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Gewichtszunahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Ich-Identifikation beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde Thymusinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelnde sexuelle Befriedigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mangelödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manie mit parathymen psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manie mit synthymen psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manifeste Hyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressive Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressive Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressiver Mischzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressives Irresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manisch-depressives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Erregung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Form der manisch-depressiven Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische schizoaffektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manische schizophreniforme Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manischer Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manischer Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mannosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manon-Nieren-Dysembryom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mansonellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mantelpneu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mantelpneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Manus valga',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Map-Dot-Fingerprint-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marasmus durch Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marasmus senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marchesani-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marchiafava-Bignami-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marchiafava-Bignami-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marchiafava-Micheli-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marchiafava-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marcumar-Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marcus-Gunn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marfan Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marginale Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marginale kristalline Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marginaler Abszeß des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marginales Hornhautulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marginales Ulcus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marie-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marie-Bamberger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marie-Pierre-I-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marie-Pierre-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marion-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marisken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marisken als Hämorrhoidenfolge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marker-Heterochromatin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Markfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Markschwammniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marmorhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marmorknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marokkanisches Sommerfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marschfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marschfieberanämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marschfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marschhämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marseille-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Marseiller Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern mit Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern mit Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern mit Otitis [kodiere zusätzlich H67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern mit Pneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern-Mumps-Röteln-Vakzination [MMR]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern-Mumps-Vakzination [MM]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masern-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maskulinisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masochismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massenhämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masseterikomandibulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive Nabelhämorrhagie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive Osteochondrose der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive Osteochondrose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive hämorrhagische Gangrän des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive silikotische Lungenfibrose durch Quarzstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massive silikotische Lungenfibrose durch Talkumstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Massiver Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masson-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarm-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmtuberkulose mit Abszeß [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastdarmvorfall bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masters-Allen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis (nicht beim Stillen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis adolescentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis adolescentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis bei Gestation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis bei Laktation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis lactantium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis nonpuerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis nonpuerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis phlegmonosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis phlegmonosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoidalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoidfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoiditis mit Einschmelzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoiditis nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia chronica cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia fibrocystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia fibrosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia fibrosa cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia oestrogenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathia oestrogenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathie ovarialen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastopathie ovarialen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastozytose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Masturbation beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastzellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastzellensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mastzellentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maternaler Distreß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maternaler Distreß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maternitätstetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maternofetales Transfusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mattigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mattigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mattigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maturity onset diabetes of young people',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mauclaire-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mauclaire-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maul- und Klauenseuche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maulbeernävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mauriac-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillabruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilladeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillaschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilläre Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilläre Makrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilläre Mikrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilläre Prognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxilläre Retrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Maxillärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'May-Hegglin-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mayaro-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mayer-Rokitansky-Küster-Hauser-Syndrom [Kongenitale Anomalie des weiblichen Genitales]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mazeration des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mazeration des Fetus ohne Hinweis auf die Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'McArdle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'McArdle-Schmidt-Pearson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'McBride-Stewart-Syndrom [Granuloma gangraenescens]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meatusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meatusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisch behinderte Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisch behinderte Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisch behinderte Geburt durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisch behinderte Geburt durch Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Erstickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Harnabflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Komplikation durch Harnwegskatheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Motilitätsstörung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Motilitätsstörung des Auges durch Blow-out-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanische Pupillenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Darmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Dickdarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Dünndarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Ileumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Ileus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Intestinumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Jejunumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Kolonverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanischer Zökumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisches Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisches Implantatversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisches Problem bei Augenprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisches Problem mit Implantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mechanisches Transplantatversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meckel''sches Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meckel-Dünndarmdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meckel-Gruber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediainfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediainfarkt des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Kapseltendinose des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Kniegelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Meniskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Meniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Meniskusreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediale Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medialer Sinus des Halses und des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediane Gaumenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediane Halsfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediane Halszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medianopalatinale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medianuslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediasklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinalabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinale Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinale LK [Lymphknoten]-Metastasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinale Lymphknoten-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinale TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinalemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinalerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinalkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinobronchiale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinuminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediastinumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamenteninduzierter Parkisonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenmissbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamententoxische Keratopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamententoxische Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentenvergiftung durch Überdosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentös bedingte Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Akkommodationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Mydriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Pupillenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Schüttellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöse Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöser Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikamentöses Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Erneuerung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medikation/Verschreibung/Wiederverschreibung/Injektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A50'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediotarsale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediterrane Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mediterrane Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Behandlung in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medizinische Maßnahme/Beratung mit primär/sekundär präventiver Absicht einschließlich genetischer Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medullitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medullomyoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulläre Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulläre Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulläre Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Medulläres Schilddrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mees-Nagelband',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megacolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaduodenum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryoblastische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytische Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytische Osteomyelosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytoide Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytäre Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytäre Myelosklerose mit myeloider Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakaryozytäre Myelosklerose mit myeloischer Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakolon bei Chagas-Krankheit [kodiere zusätzlich K93.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakolon bei Hirschsprung-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megakolon, nicht durch Hirschsprung-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalerythema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalerythema epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloappendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre Anämie, resistent gegenüber Folsäure-Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre Anämie, resistent gegenüber Vitamin-B12-Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre alimentäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre hereditäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloblastäre refraktäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalodaktylie der Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalodaktylie des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalodaktylie eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaloduodenum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalokornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalokornea mit Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalosplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalourethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalozephalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalozephalus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megalozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megarektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megasigma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megasigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megavesica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megazystis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Megaösophagus bei Chagas-Krankheit [kodiere zusätzlich K23.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrere Distorsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrere Infektionen durch HIV-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrere offene Wunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrfache Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrfachverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrgebärende',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrkeimige Gravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrknolliger Uterus myomatosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrknotige Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrknotige zystische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrlingsfrühgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrlingsgravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrlingsschwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrlingsschwangerschaft mit Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrmangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mehrstufiges Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meibom''sche Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meibom-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meibomitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meige-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meigs-Cass-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meigs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekonium im Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekonium-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumblockade [kodiere zusätzlich P75*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumileus [kodiere zusätzlich P75*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumileus-Syndrom [kodiere zusätzlich P75*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniuminhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumobstruktion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mekoniumpfropfsyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melancholia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melancholia agitata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melaninanreicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanineinlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melaninhyperpigmentation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melaninspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoakanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanodontoklasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanom-Hautmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanom-Metastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanom-Rezidiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Brustdrüsenweichteilgewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Nasenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Ohrhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des Kanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanoma in situ des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanose des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanosis coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanosis corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanosis lenticularis progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanotischer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanotisches Ameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanotisches Neurofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanotisches Progonom - s. Neubildung, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanotisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus der Augenlidhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytennävus des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytisches Schwannom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytom der Papille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanozytom des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melas-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melasma suprarenale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meleda-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meleda-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meleney-Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meleney-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melioidose mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melioidose mit Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melioidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melioidosis mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melkerknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melkerknoten durch Paravaccinia a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melkerschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melliturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melorheostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melorheostose der Knochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Melotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meläna mit Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membran der hinteren Linsenkapsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranenveränderung der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranoproliferative Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membransyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Glomerulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Membranöse sekundäre Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mendelson-Syndrom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mendelson-Syndrom in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealarterienruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealblutung des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeale Adhäsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeale Kryptokokkose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeale Sarkomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeales Angiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeales Hämangioperizytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeales Tuberkulom [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealkarzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningenerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningengumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningengumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningenkokzidioidomykose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningensyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningensyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeom des Frontallappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeom des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeomatose - s. Neubildung, Meningen, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningeosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningiom - s.a. Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningismus bei Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningismus durch Impfstoffe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningismus durch Serum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis basalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Aktinomykose [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Kokzidioidomykose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Lyme-Krankheit [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Neurosyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Neurosyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Rubella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Röteln [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Sporotrichose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Viruskrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei Windpocken [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei afrikanischer Trypanosomiasis [kodiere zusätzlich G02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei chronischer Chagas-Krankheit [kodiere zusätzlich G02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei infektiöser Mononukleose [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei klarem Liquor cerebrospinalis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei konnataler Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei konnataler Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei parasitärer Krankheit a.n.k. [kodiere zusätzlich G02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei sekundärer Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis bei sekundärer Syphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis cerebrospinalis epidemica [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Adenoviren [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Arboviren [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Coxsackieviren [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Diplokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch ECHO-Virus [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Enteroviren [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Friedländer-Bazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Gonokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Gonokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Herpesviren [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Kandidose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Klebsiella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Kryptokokken [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Listeria monocytogenes [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Listerien [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Meningokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Mykoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Neisseria meningitidis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Pilze a.n.k. [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Poliovirus [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Präventivmaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Salmonellen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Schutzimpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Viren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch Yersinia pestis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch gramnegative Kokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis durch grampositive Kokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis epidemica [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis ossificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis serosa circumscripta a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningitis/Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis bei Blastomykose a.n.k. [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis bei Herpes [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis bei Naegleriasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis bei Röteln [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Adenoviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Herpesviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Listeria monocytogenes [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Listerien [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Naegleria [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Parastrongylus cantonensis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Toxoplasmen [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalitis durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalomyelitis bei Aktinomykose [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalomyelitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalomyelitis durch Torula histolytica [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalomyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoenzephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelitis durch Kryptokokken [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelitis durch Meningokokken [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelitis durch Torula histolytica [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyeloneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningomyelozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningoradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningothelialsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningotheliomatöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Neurosyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Neurosyphilis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningovaskuläre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningozerebrale Kryptokokkose [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meningozystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskozytenanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusabriß des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskuseinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusganglion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskushypermobilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskuskalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskuslazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusschädigung durch alte Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusschädigung durch alten Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meniskusüberrest des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menkes-I-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menkes-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menkes-II-Krankheit [Kupferstoffwechselstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menkes-II-Syndrom [Kupferstoffwechselstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menometrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Arthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Paraphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Psychose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausale paranoide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausendepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenmelancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenmenorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenmetrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenmigräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausensymptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menopausensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menorrhagie in der Prämenopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mensesretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruale Dermatose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruation bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsmigräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruelle Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruelle Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruelle Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruelle Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Menstruelle Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mentale Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mentale Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Merkel-Zell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Merkel-Zell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Merkstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Merkurialismus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meryzismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meryzismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymales Chondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymales Nephroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymoma benignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenchymtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialarterienembolie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialarteriensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialdrüsen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Lymphknotentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Saponifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriale Venenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriales Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriallymphknoteninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialvenenembolie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenterium ileocolicum commune',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenteriummalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenzephalische Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesialbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesiodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesoblastisches Nephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesogastriumtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesokolonkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesometriummalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesonephrisches Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesonephrisches Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesonephrom - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesonephroma - s.a. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesonephroma benignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesopharynxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesostromale Dysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheleinschlußzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom des Mesokolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom des Peritoneum parietale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesotheliom des Peritoneum viscerale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesothelioma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesothelioma benigne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mesothelzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerschnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerschnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerschnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerstichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerstichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Messerstichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolische Alkalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolische Azidose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolische Kardiomyopathie [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metabolisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metachromatische Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metachromatische Leukoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metagonimiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metakarpalknochenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metakarpusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metallentfernung nach Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metallische Ablagerung in der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metallosis lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metallpigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metamorphopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metaplasie der apokrinen Drüsen der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metaplasie der squamösen Harnblasenzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastase bei unbekanntem Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastase der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastase des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastase des Schienbeinkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasenausbreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierende Herdenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierende Mammaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierende Mammaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierende Neoplasie der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierender Hodentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierender Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierender neuroendokriner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Blasenkarzinom (Harnblase)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Karzinoid des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Kollumkarzinom (Collum uteri)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastasierendes Prostatakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Absiedelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Fraktur [kodiere zusätzlich M90.79*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Herdenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatische Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastatisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metastrongyliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsalfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsalknochenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsophalangeale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsophalangeale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatarsus primus varus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatropischer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metatypisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meteorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meteorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methioninmalabsorptionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methioninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methylmalonazidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Methämoglobinämie-Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metropathia haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metroperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie in der Prämenopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie nach Ausstoßung der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrorrhagie post partum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Metrovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meulengracht-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mexikanische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meyer-Schwickerath-Weyers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Meynert-Amentia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mibelli-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mibelli-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Microlithiasis alveolaris pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Midlife crisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mietens-Weber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migraine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migraine accompagnée',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne durch Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne im Basilarisgebiet',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne mit Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne mit Aura ohne Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne mit akut einsetzender Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne mit prolongierter Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne ohne Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne-Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne-Status',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne-Variante',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne-Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräne-Äquivalent',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräneanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migräneartige Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migränesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Migränoide Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikity-Wilson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroalbuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroangiopathische hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobielles Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/Immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrobiologische/immunologische Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F33'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrodrepanozyten-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrodrepanozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroelliptopoikilozytäre Anämie [Rietti-Greppi-Micheli]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroembolie der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrofollikuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrogastrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrogenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrogenie-Glossoptose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroglossie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrogyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroherzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroherzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrohämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrokalkherd der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrokalzifikation der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrokolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrokornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroleukozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikromastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikromastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikromelie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikromyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikronoduläre Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikropapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrophakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroplazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikropsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikroretrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrosporie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrosporosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrosporosis nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrostrabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrostrabismus convergens mit latenter Komponente',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrostrabismus divergens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrothrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrotie des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozelluläres Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozystische Cogan-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozystisches Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozystoide Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozystoide Retinadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozystoide äquatoriale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mikrozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miktionsbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miktionsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miktionsproblem, anderes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miktionsstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miktionssymptom/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milben-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milbenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milbenbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milbenfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milch-Alkali-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchdrüsenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchdrüsenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchdrüsensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchdrüsensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchfieber im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchfluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchgangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchiger Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchintoleranz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchschorf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchschorf beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchschorf beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchtrinkersyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milchzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliaraneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliare Eingeweidetuberkulose a.n.k. [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliare Gekrösetuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliare Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliare Lungen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliares Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliaria alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliaria epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliaria tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliarlupoid Boeck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miliartuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milk sickness',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milkman-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milkman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Millard-Gubler-Foville-Paralyse [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Millard-Gubler-Paralyse [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Millard-Gubler-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miller-Dieker-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miller-Fisher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milz-TBC [Tuberkulose] [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzarterienverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand des Magen-Darm-Traktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand mit Pneumonie [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand-Karbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrand-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzbrandmeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzinfarzierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzkapselhyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzlogenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milznekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzruptur, traumatische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzsyphilis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzsyphilis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milztorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milztuberkulose [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milztumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzvenenthrombose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Milzzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mimea-polymorpha-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minamata-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minderbegabung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minderung des Hörvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minderwertigkeitskomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minderwuchs vom Laron-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minen-Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mineralokortikoid-Exzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mineralstoffmangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mineralstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minicore-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimal linkskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimal linkskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimal rechtskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimal rechtskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimale zerebrale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minimalglomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minkowski-Chauffard-Gänsslen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minkowski-Chauffard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minor-Krankheit [Hereditärer Tremor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minor-Krankheit [Hämatomyelie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minor-Oppenheim-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Minor-Syndrom [Hereditärer Tremor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miotische Pupillenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mirizzi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform der Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform der Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform der Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform des Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform des Mißbrauchs von Personen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform eines Liposarkoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform intestinaler Helminthosen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischform von Pedikulose und Phthiriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischinfektion durch Helminthen des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischkollagenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischstaubpneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischsyndrom der Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischtumor der Mundspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischzelladenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mischzelliges Karzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miserere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Miserere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Missed Abortion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Missed labor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitchell-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitchell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitesser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitochondriale Myopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitral',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitral- und Aortenklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralaortenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenprolas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralstenose mit Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralstenose mit Mitralinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralstenose mit Regurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitralvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelbauchkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelbauchtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mitteleuropäische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfellabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfellverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfingerendgliedfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelfußknochenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgesichtsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgesichtshypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgesichtstrümmerbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgesichtstrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige Koronararteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige Vulvadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige geistige Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelgradige reaktive Depression als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhand- und Fingerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhandanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhandbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhanddistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhandfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhandhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhirngliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelhirnsyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittellappen-syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittellappenatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittellappenpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittellappensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittellinien-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeer-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeer-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeer-Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelmeeranämie mit Hämoglobinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohradhäsivprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrcholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrdiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohreiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrentzündung NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrentzündung mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrlues [kodiere zusätzlich H75.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrlues [kodiere zusätzlich H75.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrsyphilis [kodiere zusätzlich H75.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrsyphilis [kodiere zusätzlich H75.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrtuberkulose [kodiere zusätzlich H67.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelohrverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittelschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittendorf-Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mittesser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mixed Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mixed connective tissue disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbildung am Schädel/im Gesicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbildungsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch einer Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch einer psychoaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch einer psychoaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch einer verschreibungspflichtigen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch vom Amphetamintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch vom Kokaintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißbrauch vom Morphintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißhandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißhandlung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißhandlungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Aborteinleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Aborteinleitung mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Aborteinleitung mit Komplikation durch Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Aborteinleitung mit Komplikation durch Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Aborteinleitung mit Komplikation durch verstärkte Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Geburtseinleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Geburtseinleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungene Intubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißlungener Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißtrauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißtrauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißtrauisches Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißverhältnis bei kombinierter mütterlicher und fetaler Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißverhältnis durch fetalen Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißverhältnis durch großen Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißverhältnis durch Übergröße des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mißverhältnis zwischen Fetus und Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mljet-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mmyalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobbing',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobbing',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobile Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobilitätsbeeinträchtigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobilitätseinschränkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobitz-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobitz-Block vom Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mobitz-Block vom Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moebius-Krankheit [Ophthalmoplegische Migräne]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moebius-Syndrom [Kernaplasie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mohr-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mola destruens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mola hydatidosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mola hydatidosa accreta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mola hydatidosa intravenosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mola maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molarisation der Prämolaren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molenei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molengravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molenschwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molimina menstrualia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mollaret-Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molluscum contagiosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molluscum contagiosum des Augenlids [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molluscum contagiosum epithelialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Molybdänmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monarthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mondbeinfraktur des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mondgesicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mondor-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mondor-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mondsüchtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monge-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mongolismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mongolismus, Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monilethrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monilethrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monilia intertrigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monilia-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moniliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monilieninfektion der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monobrachius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monochromasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monokelhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoklonale Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monokulare Diplopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monokulare Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monokulare Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monokulares Einwärtsschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monolobuläre Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monomorphes Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monomyelozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus cutaneus femoris lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus ischiadicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus medianus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus peronaeus communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus popliteus medialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus tibialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuritis des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuropathie der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononeuropathie der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononucleosis infectiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononukleose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononukleose durch Epstein-Barr-Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononukleose durch Gamma-Herpes-Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mononukleosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monophasischer Zyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoplegie der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoplegie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoplegie eines Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monoplegie eines Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monopodie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monopolare Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monopolare Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monorchie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monorchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monostotisches Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytenangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytoide Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytoide Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytoides B-Zell-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytäre Naegeli-Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytäre Naegeli-Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytäre leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytäres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monozytäres Sarkom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monstrozelluläres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monstrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monteggia-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Monteggia-Luxationsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moore-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mooren-Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moralisch defekte Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moralischer Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morax-Axenfeld-Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbilli - s.a. Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbilli mit Pneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Abortus Bang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Addison',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Alzheimer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Baastrup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Baastrup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Bang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow mit endokriner Orbitopathie [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow mit endokriner Orbitopathie und Esotropie [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow mit endokriner Orbitopathie und Hypotropie [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Basedow mit endokriner Orbitopathie und Lidretraktion [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Behçet',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Besnier-Boeck-Schaumann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Biermer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Binswanger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Bleuler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Boeck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Bowen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Bowen der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Bowen des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Brill-Zinsser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Brocq',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Calvé-Legg-Perthes [Osteochondrosis deformans coxae juvenilis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Chagas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Coats',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Conn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn des Dickdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crohn des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Crouzon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Cushing',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Darier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Down',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Duhring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Dupuytren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Eales',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Favre-Racouchot [Elastoidosis cutis nodularis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Forestier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Forestier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Fothergill [Trigeminusneuralgie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Frey',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Gaucher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Hallopeau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Herxheimer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Hirschprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Hirschsprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Hodgkin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Hodgkin/Lmphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Horton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Huntington',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Icenko-Cushing',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kahler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kahler in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kimmelstiel-Wilson [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kimmelstiel-Wilson bei Typ-I-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kimmelstiel-Wilson bei Typ-II-Diabetes mellitus [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Koch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Kyrieleisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Köhler I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Köhler II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Laënnec',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Ledderhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Lyme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Meulengracht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Moebius [Ophthalmoplegische Migräne]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Mondor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Moyamoya',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Ménière',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Ménière',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Neisser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Neisser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Ormond',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Osgood-Schlatter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Osgood-Schlatter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Osler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Paget',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Paget der Mamille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Paget der Mamille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Paget des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Parkinson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Parkinson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Perthes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Pfeiffer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Pompe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Pott [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Purtscher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Raynaud',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Reiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Reiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Schaudinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Schaudinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Schaumann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Scheuermann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Scheuermann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Schlatter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Schoenlein-Henoch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Sheehan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Sinding-Larsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Stargardt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Sudeck [Neurogene posttraumatische Knochenatrophie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Tsutsugamushi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Waldenström',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Waldenström in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Wassermann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Wassermann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Wegener',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Werlhof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Whipple [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus Wilson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus americanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus aphrodisiacus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus aphrodisiacus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus caducus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus caeruleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus de Quervain [Tendovaginitis stenosans]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus gallicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus gallicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus haemolyticus neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus haemorrhagicus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus maculosus haemorrhagicus Werlhof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus phoenicius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus sacer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus von Bechterew bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus von Recklinghausen [Neurofibromatose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morbus von-Hippel-Lindau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morgagni-Adams-Stokes-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morgagni-Adams-Stokes-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morgagni-Hydatide bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morgagni-Hydatide beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morgagni-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morphaea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morphinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morphiumabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morphiummißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morquio-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morquio-Ullrich-Brailsford-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morquio-Ullrich-Brailsford-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Metatarsalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Neurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morton-Vorfußneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morvan-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Morvan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mosaik der Portio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moschkowitz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moschkowitz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moskito-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mossmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motilitätsstörung bei Orbitabodenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motoneuronkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Ausfälle einer Extremität bei Gipsbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Entwicklungsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische Unruhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorische und sensorische Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Motorischer Entwicklungsrückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mottled teeth',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouches volantes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouches volantes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouchet-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouchetée-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouldy hay disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouldy hay-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mouldy hay-Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mounier-Kuhn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Moyamoya-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mucambo-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mucha-Habermann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mucinosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mucinosis papulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mucor-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoassoziiertes Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoassoziiertes Lymphom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoides Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoidzelladenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoidzelladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoidzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukokutan-lymphangitische Parakokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukokutane Bartonellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukokutane Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukolipidose I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukolipidose II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukolipidose III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukolipidose IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ VI',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopolysaccharidose Typ VII',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukopurulente chronische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukormykose der Unterhaut [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukormykose des Magen-Darm-Traktes [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukosaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoserotympanon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukotympanon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoviszidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukoviszidose mit Mekoniumileus [kodiere zusätzlich P75*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mukozele des Tränensacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköse Extravasationszyste einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköse Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköse Rektumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköse Retentionszyste einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköser Zervixpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muköses Zystadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mulcahy-Syndrom [Myelosklerose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multicore-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multifokale Autonomie bei Struma mit Euthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multifokale Leukenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multifokale Schilddrüsenautonomie bei Struma mit Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multifokaler Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiinfarktdemenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiinfarktgeschehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiinfarktsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multilokuläre ovariale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multinoduläre Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multinodulärer zystischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiorganversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiparität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Abszesse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Aneurysmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Anomalien a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Avitaminose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Bilirubin-Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Blockierungen der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Cholelithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Divertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Divertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Eingeweideverletzungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Embolie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Enchondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Epistaxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Fehlbildungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Gallensteine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Gehirnanomalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Gravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Hirnnervenlähmung bei Sarkoidose [kodiere zusätzlich G53.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Hirnnervenparesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Infektion durch HIV-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Krebsbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Lipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Luxationen des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Mittelgesichtsfrakturen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Papillome bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Prellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Quetschungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Rumpffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Serositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Skerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Sklerose des Hirnstamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Sklerose des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Stichwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Syndrome der präzerebralen Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Traumen/Verletzungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Verletzungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Verletzungen der Viszera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Verletzungen des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple WS-Blockierungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple Warzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple adenomatöse Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple adenomatöse Polyposis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple adenomatöse Schleimhautpolypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple endokrine Adenomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple endokrine Neoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple evanescent white dot syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple innere Verletzungen NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple nichttraumatische Hautbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple oberflächliche Verletzungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple offene Unterarmwunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple offene Unterschenkelwunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple peritoneale Serositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple psychosomatische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple zerebrospinale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiple-Chemical-Sensitivity [MCS]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler Läusebefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler Verschluß präzerebraler Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler Vitaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler primärer Alveolarzelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler primärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler sekundärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler syphilitischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multipler syphilitischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Beschwerde-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Myelom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Myelom mit Osteoporose [kodiere zusätzlich M82.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Plasmazellenmyelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Plasmazellenmyelom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples Xanthom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multiples hämorrhagisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multisystematrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multisystemdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multizentrische Retikulohistiozytose [kodiere zusätzlich M14.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multizentrische adenomatöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Multizentrisches Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps mit Meningitis/Orchitis/Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Arthritis [kodiere zusätzlich M01.59*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Enzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Komplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Meningoenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Myelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Myokarditis [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Oophoritis [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Pankreatitis [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mumps-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mund-/Zungen-/Lippenbeschwerden/-symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mund-/Zungen-/Lippenerkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundantrumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbodenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbodenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbodenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbodenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbodenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundfäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundfäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundgeruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlensyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundhöhlentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundkandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundnoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautaphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautkandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschleimhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundtrockenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundtrockenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundtuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelcheilitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelcheilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundwinkelschrunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mundzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murines Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murray-Valley-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Murri-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Musikinduzierte Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskatnußleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskel-Carnitin-Palmitoyltransferase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskel-Skelett-Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelatrophie Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelatrophie/-steifheit/-verspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelbedingte Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskeldysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelfaserriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelfaserriß der Wade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelfaserriß des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelkalzifikation bei Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelkalzifikation bei Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelnekrose durch Clostridien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelossifikation bei Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelossifikation bei Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelparalyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelphosphorylasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelstarre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelstarre-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelsyphilis [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelsyphilis [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskeltonusstörung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskeltuberkulose [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelverletzung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelverletzung des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerfallssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung der Wade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung des Oberarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung im HWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung im Kniebereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung im LWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung im LWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskelzerrung im LWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuloskelettäre Erkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuloskelettäre Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskulotendinöses HWS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Gowers-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Inkoordination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläre Werdnig-Hoffmann-Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskulärer Schiefhals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskulärer Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muskuläres HWS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Musterungsuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutismus bei erworbener Taubheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutismus bei kongenitaler Taubheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutisurditas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutitas surdorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mutterbandvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttereffloreszenz bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttermal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttermundatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttermundkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttermundmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muttermundstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinproduzierendes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinsezernierendes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöser Tumor mit geringem Malignitätspotential',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Zystadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Zystadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Muzinöses Zystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myalgia cervicalis epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myalgia epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myalgie bei Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenia gravis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenia gravis pseudoparalytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenia pseudoparalytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenieptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myasthenisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myatonia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myatrophe Lateralsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myatrophia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycetoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycetoma pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycosis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycosis barbae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycosis capillitii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mycosis corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mydriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelatelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelindegeneration des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Masern [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Naegleriainfektion [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Röteln [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Spätsyphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei Toxoplasmose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei afrikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei amerikanischer Trypanosomiasis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei chronischer Chagas-Krankheit [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis bei konnataler Syphilis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis durch Adenoviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis durch Enteroviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis durch Herpesviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis durch Zytomegalieviren [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis nach Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis transversa acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelitis transversa acuta bei demyelinisierender Krankheit des Zentralnervensystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelodysplasie mit Blastenschub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelodysplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelodysplastisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloenzephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelofibrose mit myeloider Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelofibrose mit myeloischer Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelofibrosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelofibröse Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelogene Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelogene Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelogene Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelogene Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloide Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloide megakaryozytäre Hepatosplenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische Knochenmarksaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische bulbäre Polioenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloische leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloisches Sarkom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelokompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloleukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomatose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomeningozele des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelomeningozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Bandscheibenschaden [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Bandscheibenschaden [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Degeneration der Bandscheiben a.n.k. [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Degeneration der Bandscheiben a.n.k. [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Neubildung a.n.k. [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Verlagerung der Bandscheibe a.n.k. [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Verlagerung der Bandscheibe a.n.k. [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie bei Vitamin-B12-Mangel [kodiere zusätzlich G32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie durch Strahlenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathie durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelopathische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelophthisische Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloproliferative Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloproliferative Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloproliferatives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloradikulodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloradikulodysplasie des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myeloretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelosklerose mit myeloider Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelosklerose mit myeloischer Metaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozystozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozytom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myelozytäre leukämoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myiasis des Mittelohres [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myiasis des äußeren Ohres [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykobakterielle Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykobakterielle Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykobakteriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykose - s.a. Mycosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykose der Leistenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykose der männlichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykose der weiblichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykose durch opportunistisch-pathogene Pilze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Arthritis a.n.k. [kodiere zusätzlich M01.69*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Diarrhoe a.n.k. [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Fußflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Kolpitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Meningitis [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Panophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Sykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Sykosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Sykosis contagiosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Vaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotische Vulvovaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotischer Fluor [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotischer Fußpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotischer Madurafuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotisches Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotisches Knochenmyzetom [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mykotisches Myzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoblastenmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myodegeneratio cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofasziitis der Lumbalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibromatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibrosis cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibrosis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myofibrositis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoglobulinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myohyperplasie des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarddystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarderschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardgumma [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardgumma [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Erweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Hypoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiale Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardialer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardialer Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiales Atherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiales Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardinfarktnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardinfarktschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardiopathie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Fleckfieber a.n.k. [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Grippe [Influenza] [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Grippe [Influenza], Influenzavirus nachgewiesen [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Sarkoid [kodiere zusätzlich I41.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Sarkoidose [kodiere zusätzlich I41.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei Scharlach [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis bei chronischer Polyarthritis [kodiere zusätzlich I41.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Coxsackieviren [kodiere zusätzlich I41.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Gonokokken [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Gonokokken [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Meningokokken [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch Toxoplasmen [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis durch epidemisches Läusefleckfieber [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokarditis mit Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardschwäche mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardsyphilis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardsyphilis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardtuberkulose [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myokardveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonische Zuckungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoklonus simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoma laevicellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoma sarcomatosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoma uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myomalacia cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myometriumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myometriumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myometriumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myomknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myonekrose durch Clostridien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoneurale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoneurale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathia osteoplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Addison-Krankheit [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Amyloidose [kodiere zusätzlich G73.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Cushing-Syndrom [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Glykogenspeicherkrankheit [kodiere zusätzlich G73.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hyperadrenokortizismus [kodiere zusätzlich G73.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hyperparathyreoidismus a.n.k. [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hyperthyreose [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hypoparathyreoidismus [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hypopituitarismus [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Hypothyreoidismus [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Infektionskrankheit a.n.k. [kodiere zusätzlich G73.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Kretinismus [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Lipidspeicherkrankheit [kodiere zusätzlich G73.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Myxödem [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Panarteriitis nodosa [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Riesenzellarteriitis [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Sarkoidose [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Sicca-Syndrom [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Sjögren-Syndrom [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Sklerodermie [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Stoffwechselkrankheit a.n.k. [kodiere zusätzlich G73.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei Thyreotoxikose [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei bösartiger Neubildung [kodiere zusätzlich M63.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei chronischer Polyarthritis [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei endokriner Krankheit a.n.k. [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei malignem Tumor a.n.k. [kodiere zusätzlich M63.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei parasitärer Krankheit a.n.k. [kodiere zusätzlich G73.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie bei systemischem Lupus erythematodes [kodiere zusätzlich G73.7*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathie der äußeren Augenmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopathischer Strabismus von Graefe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myophosphorylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopia magna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myopische Retinaveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myorenales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis bei Lepra [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis bei Sarkoid [kodiere zusätzlich M63.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis bei Schistosomiasis [kodiere zusätzlich M63.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis bei Trichinellose [kodiere zusätzlich M63.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis bei Zystizerkose [kodiere zusätzlich M63.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis durch Clostridien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis durch Toxoplasmen [kodiere zusätzlich M63.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis durch Zytomegalieviren [kodiere zusätzlich M63.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis ossificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis ossificans circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myositis ossificans progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotendinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonia atrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonia hypertrophica congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische Katarakt [kodiere zusätzlich H28.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische Pupille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotonische periodische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotubuläre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myotubuläre zentronukleäre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myriapodiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myringitis granulomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mysophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mytilotoxismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxochondrofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxochondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxochondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoedema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoedema cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoedema papulatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxofibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoides Chondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoides Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoides Leiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoides Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoliposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoma sarcomatosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxomatöses Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxopapilläres Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxoplastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myzetismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Myzetom durch Nocardia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Algopareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Fertilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Genitalentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Harnblasenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Infertilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Infertilität nach Vasektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Kohabitationsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Makrogenitosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Mikrogenitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Pelveoperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Unfruchtbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Urethrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche Zystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche psychogene Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliche sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männlicher Eunuchismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männlicher Harnblasenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männlicher Hypergonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männlicher Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männlicher schmerzhafter Koitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Männliches Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßig erhöhter Augeninnendruck als Restzustand nach Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßige Asphyxie unter der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßige Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßige Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßige mentale Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßiger Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mäßiggradige Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménière-Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménière-Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménière-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménière-Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménétrier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ménétrier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Barlow-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Boeck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Hunter-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Möller-Hunter-Glossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mönckeberg-Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mönckeberg-Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mönckeberg-Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mönckeberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mörtelniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müde Augen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müdigkeitssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Mühsame Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müller-Gang-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müller-Mischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Müller-Weiss-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Münchhausen Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Münchhausen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Münchmeyer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Münchmeyer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'NADH-Methämoglobinreduktase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'NHL [Non-Hodgkin-Lymphom] - s.a. Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'NIDDM [Non-insulin-dependent diabetes mellitus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'NPP [Nucleus-pulposus-Prolaps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'NPP [Nucleus-pulposus-Prolaps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabeladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabeldiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelekzem beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelentzündung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelinfektion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelphlegmone beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurblutung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurblutung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurhämatom als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurhämatom als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurknoten als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurknoten als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurkomplikation als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurkomplikation als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurkompression als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurkompression als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurprolaps als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurprolaps als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurquetschung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurquetschung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurruptur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurruptur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnursepsis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurthrombose als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurthrombose als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurtorsion als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurtorsion als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurtorsion beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurtorsion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurumschlingung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurumschlingung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverdrehung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverdrehung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverschlingung bei monoamniotischen Zwillingen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverschlingung bei monoamniotischen Zwillingen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverwicklung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurverwicklung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurveränderung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurveränderung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurvorfall als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschnurvorfall als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschwamm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelvenenthrombose als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelvenenthrombose als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nabelwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naboth-Follikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nach dem Termin Geborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachbehandlung nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachblutung bei Plazentaretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachgeburtsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachhallzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachhallzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachlassende Merkfähigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachtangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachtblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachteinnässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachtschweiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachtschweiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachtwandeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachuntersuchung nach Chemotherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachuntersuchung nach Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachuntersuchung nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachwehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachweis eines abnormen Lithium-Blutwertes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachweis im Blut, einer normalerweise im Blut nicht vorhandenen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachweis von abnormen Schwermetall-Blutwerten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nachweis von psychotropen Drogen im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenschmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nackenzerrung mit Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nadelstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nadelstichgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nadelstichgefühl der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naegele-Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naegeli-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naegleriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus achromicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus albus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus apigmentosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus araneus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus coeruleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus comedonicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus depigmentosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus flammeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus flammeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus giganto-pigmentosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus magnocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus malignus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus naevocellularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus papillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus pigmentosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus pilosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus sebaceus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus stellatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus syringocystadenosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus teleangiectaticus lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus unius lateris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus vasculosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naevus verrucosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naffziger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naga-Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagel-Patella-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelabstoßung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelausriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nageldemineralisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nageldermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelkandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelpsoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelquerfurchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelverfärbung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nagelwachstumsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahexophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelbedingte Infektion durch Listerien - s.a. Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelbedingte Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsmittelverweigerung im frühen Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahrungsverweigerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtdehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtdehiszenz der Dammrißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtdehiszenz der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtdehiszenz der Sektiowunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtdehiszenz nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtruptur mit Hornhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtruptur mit Skleraprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtruptur ohne Hornhautprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtruptur ohne Skleraprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nahtwechsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nairobi-Schafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nairobi-Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nanismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nanophyetiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nanosomia renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nanosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nanukayami',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe der Labia pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des Alveolarfortsatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des Gebärmutterhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des hinteren Augenpols',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des hinteren Pols der Macula lutea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des hinteren Pols der Macula lutea nach Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbe des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenentropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenirritation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenkeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenneurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenstrang der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbenwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbig bedingte Lidfehlstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbig bedingter Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbige Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbige Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbige Hautveränderung bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbige Veränderung des Nierenpols',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbiges Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narbiges Pemphigoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narkolepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narkoleptisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narkomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narkomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narkosetod während der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narzißmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narzißtische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Narzißtische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Halbsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Vestibulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Vestibulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasale Vestibulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasebohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasebohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasebohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenbluten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenbluten/Epistaxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasendiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangsfollikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseneingangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfurche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasengangtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasengumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasengumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhistoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlensynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlensynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlensynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenhöhlenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenlochatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenlochfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheldeflexion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheldegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheldegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheldegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheleinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheleinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuscheleinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelpyozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmuschelzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenmyiasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlen-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlencholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlencholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlencholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenpyozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennebenhöhlenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenosteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraum-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenrauminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenrachenraumveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewanddeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewanddislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenscheidewandverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschleimhautüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumdestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumdestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumdestruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumsporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumsporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumsporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensinusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensinusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensinusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenspinaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasenxanthogranulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasoalveoläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasoethmoidale Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasolabiale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasoorale Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopalatinale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngeale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngeale Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngeale Myiasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngealer Polyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngeales Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasopharynxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasoziliarneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nasus incurvus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natalbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriumverarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriumverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriumvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriumüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Natriurese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naturheilmittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Naturheilmittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nausea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nausea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nausea marina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neapolitan-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhoden-Hoden-Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodengonorrhoe [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodengonorrhoe [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenkopffibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenkopftumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenkopfzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenlues [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenlues [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenmesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenorchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodensyphilis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodensyphilis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodentorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodentuberkulose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhodenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenentzündung/Sinusitis, akute/chronische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennieren-TBC [Tuberkulose] [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenapoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenapoplexie durch Meningokokken-Sepsis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenblutung durch Meningokokken-Sepsis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenniereninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenniereninfarzierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenniereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenniereninsult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenlues [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenlues [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenmelasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenneuroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenparagangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenraumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenrinden- und Nebennierenmarkunterfunktion nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenrindenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenrindenkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenrindenüberaktivität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierensyphilis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierensyphilis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierensyphilis mit Rindenunterfunktion [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierensyphilis mit Rindenunterfunktion [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierentuberkulose [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebennierenüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenplazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsentuberkulose [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenschilddrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenwirkung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenwirkung oraler Kontrazeptiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenwirkung von Kälte/Hitze/Blitzschlag/Bewegung/Druck/Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenwirkung/Allergie/Anaphylaxie bei Medikation in korrekter Dosierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebenwirkungen eines Medikaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nebula corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Necrobiosis lipoidica a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Necrosis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Negative Vertikaldivergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Negativismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Negerpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neigung zu habituellem Abort bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neigung zur Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neigung zur Selbsttötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobazillose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrobiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose der Gehörknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose der Herzmuskelfasern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose der Herzmuskelgruppen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose des Unterhautfettgewebes beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose des Zentralnervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrose des subkutanen Gewebes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Plaut-Vincent-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Stomatitis ulzerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische agranulozytische Mukositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotische Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierend-ulzeröse Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierend-ulzeröse Gingivostomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Enteritis beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Enteritis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Enterokolitis beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Enterokolitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Fasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Glomerulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Granulomatose im Bereich der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Periarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Sialometaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrotisierende Vaskulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nekrozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nelaton-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nelson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nemalin-Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nemalinkörper-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nematoden-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nematoden-Infektion des Darmes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nematodiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Aspirationspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Hypermagnesiämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Hypomagnesiämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Hypothermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Moniliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Struma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Tetanie ohne Kalzium- oder Magnesiummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Zahnschmelzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale benigne Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonatale nichtinfektiöse Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonataler Kropf a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonataler Tod a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neonataler transitorischer Hypoparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Gallensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Mundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie eines Verdauungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasie eines großen Gefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasma der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplasma der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastische Geschwulst - s.a. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastische Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastische Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastischer Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastischer Prozeß der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neoplastisches Wachstum - s.a. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisation der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisation der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisationsglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisationsglaukom bei diabetischer Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisationsglaukom bei diabetischer Retinopathie bei Typ-I-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisationsglaukom bei diabetischer Retinopathie bei Typ-II-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neovaskularisationsglaukom nach Zentralvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis bei Gicht [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis desquamata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch Anti-GBM-Antikörper bei Goodpasture-Syndrom [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch Nierensteine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch antiglomeruläre Basalmembranantikörper bei Goodpasture-Syndrom [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis durch zirkulierende Immunkomplexe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis lipomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritis saturnina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritisches Goodpasture-Syndrom [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephritisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephroangionekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephroangiosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephroangiosklerose mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogene Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogene Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogene Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogener Diabetes insipidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogener Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrogenes Dysembryom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrokalzinose [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrolithiasis bei Gicht [kodiere zusätzlich N22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrolithiasis bei Harnsäurestein [kodiere zusätzlich N22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrolithiasis des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathia gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathie bei Gicht [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathie bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropathie bei Sichelzellenkrankheit [kodiere zusätzlich N08.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephroptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephropyosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose bei Malaria [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose bei systemischem Lupus erythematodes [kodiere zusätzlich N08.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose mit Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose mit glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose bei Gicht [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose bei Zystinspeicherkrankheit [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrosklerose mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrostoma-Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrotisch-glykosurischer Zwergwuchs mit hypophosphatämischer Rachitis [kodiere zusätzlich N16.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrotisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrotisches Syndrom mit fokaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrotisches Syndrom mit segmentaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nephrozirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervendurchtrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenhyperregeneration [Narbenneurom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenhüllenmyxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenkernagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenkernaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenschmerzen des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervensystemtuberkulose a.n.k. [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nerventuberkulose [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenverletzung in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenwurzelaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenwurzelverletzung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenwurzelverletzung der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenzucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervenzusammenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervloser Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervus-radialis-Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervus-ulnaris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Dysphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Enkopresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Eßstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Instabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Kephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Reizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Spannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöse Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöser Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöser Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöser Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöser Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöser Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöses Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nervöses Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesidioblastom des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesidiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesidiom des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesselausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesselausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesselfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesselsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nesselsucht/Urticaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nettleship-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautabhebung mit Schichtenabhebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautablösung mit Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautablösung ohne Netzhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautastrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdegeneration ohne Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdurchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautdystrophie bei Lipidspeicherkrankheit [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauterkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautexsudation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautfalten, nicht postoperativ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautfragment ohne Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautgefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauthufeisenriß ohne Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauthämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautloch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautpseudozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautrundloch ohne Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautschichtenlösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautsklerose [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautstreifenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauttraktionsablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauttuberkulose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhauttumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautvenenastgefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Netzhautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung Atemwege, nicht spezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung Auge/Adnexen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung Blut nicht als gut- oder bösartig spezifiziert/Testergebnis nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung NNB der Blase/Niere/Harnleiter/Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung der Harnwege ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung der Haut nicht als gut- oder bösartig spezifiziert/Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung im/am Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung kardiovaskulär',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung mit Metastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildung weibliches Genitale, andere/nicht spezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildungen des Nervensystem, nicht spezifiziert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neubildungen im Verdauungssystem, benigne/unspezifische',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neue Geschwulst - s.a. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenengelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenhyperbilirubinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenikterus bei vorzeitiger Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenikterus durch gesteigerte Hämolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenkonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenlisteriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenspasmophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenentetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenentoxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborener Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborener Einling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes mit Alkoholschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neugeborenes mit Brustdrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neumann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurale Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuraler Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurales Fibroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgia facialis vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Hirnnerven III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Hirnnerven IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Hirnnerven VI',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Nervus glossopharyngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Nervus laryngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgie des Nervus ophthalmicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgische Schmerzen des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralgismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuralrohrdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurasthenie/Erschöpfung/Burnout',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurastheniesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurasthenische Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurasthenische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurasthenisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurilemmosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurinom des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurinom eines Hirnnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis der Nervi olfactorii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Ganglion geniculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Hirnnerven III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Hirnnerven IV',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus abducens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus ischiadicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus oculomotorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus ophthalmicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus statoacusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus trochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis des Nervus vestibulocochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis diabetica [kodiere zusätzlich G59.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis hypertrophicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis multiplex endemica [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis nach Herpes zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuritis vestibularitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroavitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroborreliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurochorioretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodegenerative Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermatitis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis atopica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis chronica circularis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis chronica circularis verrucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis chronica circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis der Beugeseite',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis der Streckseite',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodermitis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroencephalomyelopathia optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroendokrines Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroepitheliom der Nervi olfactorii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibrolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibrom der Pseudotastkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibrom des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurofibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Achlorhydrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blasenatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blasenentleerungsstörung bei Cauda-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blasenentleerungsstörung bei Cauda-equina-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Blasenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Harnblasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Harnblaseninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Harnblasenträgheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Harninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Miktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Obstipation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Paralyse des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Reflexblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene Restharnretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene autonome Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene orthostatische Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene orthostatische Hypotonie mit Multisystematrophie [Shy-Drager-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene posttraumatische Knochenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene tabische Knochenatrophie [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogene tabische Knochenatrophie [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogener Gastrospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogener Ileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogener Olfaktoriustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogener Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogenes Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogenes Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurogoniom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurohormonale Reizblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolathyrismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolemmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroleptika-Akathisie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroleptikainduzierte Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroleptisches Parkinsonoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurologische Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurologische Ausfälle einer Extremität bei Gipsbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurologische Erkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurologische Infektionen, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurologische Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolues paralytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurolues paralytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Blasendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Blasenentleerungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Blasenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Erregungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre toxische Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromuskuläre toxische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyelitis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyopathische Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuromyotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuronale Lipofuszinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuronale Lipofuszinose mit Zeroidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuronitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuronitis vestibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuronävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropapillitis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathia peripherica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathia vestibulocochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie bei Engpaß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie bei Vitamin-B12-Mangel [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie des Nervus ischiadicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie des Nervus opticus, ausgenommen ischämisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie durch Schnüffeln von Klebstoffen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie mit hereditärer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathie peripherer Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Marie-Charcot-Tooth-Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Spondylopathie bei Syringobulbie [kodiere zusätzlich M49.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Spondylopathie bei Syringomyelie [kodiere zusätzlich M49.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Spondylopathie bei Tabes dorsalis [kodiere zusätzlich M49.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuropathische Spondylopathie bei Tabes dorsalis [kodiere zusätzlich M49.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neuroretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosarkoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurose NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosemischform a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis der Dura mater [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis der Dura mater [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit Optikusatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit Optikusatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit Sehnervatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit Sehnervatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit akuter Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit akuter Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit lokomotorischer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit lokomotorischer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit progressiver Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit progressiver Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit spastischer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit spastischer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit spinaler Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit spinaler Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit tabischer Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit tabischer Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebellarer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebellarer Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebralem Aneurysma [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebralem Aneurysma [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebraler Arteriitis [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebraler Arteriitis [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebraler Thrombose [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis mit zerebraler Thrombose [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis paralytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilis paralytica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilitisches Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurosyphilitisches Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurothekom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisch depressive Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisch-depressive Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisch-depressiver Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Delinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Delinquenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Derealisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Exkoriation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Fehlentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Fehlsteuerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Hautabschürfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Reaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Rumination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotischer Angstzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotischer Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotischer Zustand mit depressiven Phasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisches Depersonalisationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotisches Fehlverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurotrophes bösartiges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurouveoparotitissyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Labilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Prostatabeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurovegetatives Prostatasyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neurozystizerkose [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neutropenische Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Neutrozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Newcastle-Keratokonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Newcastle-Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Newcastle-Krankheit [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niazin-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niazinamid-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht abgestiegener Hoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht durch Geschlechtsverkehr übertragene Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht makuläre chorioretinale Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht maligne Pustula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht medikamentöse chemische Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nicht näher bezeichnete Lernschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtabgekapselter sklerosierender Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtadrenalinbildendes Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtakkommodativer Konvergenzexzeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholbedingte Korsakow-Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholinduziertes Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholisch bedingte Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholische chronische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholisches Delir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtalkoholisches Korsakow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtallergische Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtallergisches Asthma bronchiale durch ein Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtallergisches arzneimittelbedingtes Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtallergisches intrinsisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtallopathische Schädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtanhaltende ängstliche Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtarzneimittelinduzierte reaktive Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtautoimmun hämolytische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtbakterielle Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtbakterielle Gastroenteritis im Säuglingsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtbakterielle Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtbefolgung ärztlicher Anordnungen in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtbösartige Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtchromaffines Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdarstellung der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdarstellung der Gallenblase bei bildgebender Diagnostik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdiabetischer hypoglykämischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdiabetisches hypoglykämisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdiphtherischer Croup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdiphtherischer Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdrogeninduziertes Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdurchgeführte Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdurchgeführte Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtdurchlässiger Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteindeutiger HIV-Test beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteintreten der Menarche im Pubertätsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Arthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Hirnvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Mastitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Meningitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Pansinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Thrombose des intrakraniellen venösen Sinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige intrakranielle Sinusthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige intraspinale Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitrige intraspinale Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteitriger Paukenerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtendokrine Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtendokrine Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtendokrine Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtendokrine Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentbundene Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentfaltung der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentfaltung der Lunge beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentwicklungsbedingte Porenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Eileiterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Krankheit der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Krankheit der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Krankheit des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Ovarkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Parametriumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Perineumerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Uteruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Vaginakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Vulvaerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Vulvakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche Zervixkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündliche tuboovariale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündlicher Perikarderguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtentzündlicher Vaginalausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtepidemische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtepidemische Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtepidemische Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtepileptischer Nickkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtepileptischer Salaam-Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichterhaltungswürdiger Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteröffneter Muttermund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichteröffneter Muttermund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtexanthematisches Zeckenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtexsudative Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtfamiliäre Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtfamiliäre Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtfunktionierende Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtfunktionierende Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtfunktionierendes Labyrinth',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgeburtshilfliche Perineumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgeburtshilfliches Hämatom eines Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgeburtshilfliches Hämatom eines Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgeburtshilfliches Vulvahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgonorrhoische Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgonorrhoische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtgranulomatöse Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtheilender Stumpf nach Amputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtimmunologischer Hydrops fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtimplantation des befruchteten Eies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Liddermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Sigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinfektiöse Sigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Diabetes mellitus Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Diabetes mellitus beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Diabetes mellitus in Verbindung mit Fehl- oder Mangelernährung [Malnutrition]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinsulinabhängiger Typ-II-Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtinvasives Komedokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtjuvenile Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtketotische Hyperglyzinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtleukämische Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtmaligne Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtobliterierende Otosklerose mit Beteiligung der Fenestra vestibuli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtobstruktive Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtobstruktives Lungenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Enuresis nocturna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Erektionsstörung beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Harninkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Hyposomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Pica beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Somnolenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische Stuhlinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische erektile Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische erektile Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische primäre Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische sekundäre Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische sexuelle Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganische spezifische Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtorganisches Herzgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtossifizierendes Knochenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtovulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtparalytischer Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtparetische latente Vertikaldeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtparetische manifeste Vertikaldeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtpigmentierter Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinabhängiger Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinpflichtiger Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtprimär insulinpflichtiger Diabetes mellitus mit mehreren Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtpuerperale Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtpuerperale Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtpuerperale Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Aortenklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Aortenklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Aortenklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Endokarditis der Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Herzklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Herzklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Mitralklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Mitralklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Mitralklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Pulmonalklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Pulmonalklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Trikuspidalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Trikuspidalklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische chronische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatische verruköse Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrheumatischer Aortenklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrupturierte intrakranielle Arteriendissektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtrupturiertes zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtseßhaftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsozialisierte aggressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsozialisierte aggressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtspezifische Duodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtspezifische Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtspezifische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitische Aortenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitische Aortitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitische Arteriitis der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitische Charcot-Krankheit a.n.k. [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitische Keratitis interstitialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitisches Aneurysma der Aorta thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitisches Aneurysma des Truncus brachiocephalicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtsyphilitisches Schniefen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtthrombopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtthrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Knotenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma congenita parenchymatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma diffusa colloides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische Struma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische adenomatöse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische einknotige Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische endemische Knotenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische multinoduläre Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxische uninoduläre Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer Schilddrüsenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer endemischer Knotenkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer multinodulärer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer nodulärer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttoxischer uninodulärer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttransmuraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Blutung mit Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Dislokation des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Epiphysenlösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Erosion der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Harnblasenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Harnleiterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Hämorrhagie der Fossa cranii posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Hämorrhagie des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Ileumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Iliosakralgelenkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Intestinalruptur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Jejunumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Kleinhirnblutung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Kleinhirnblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Kleinhirnhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Kolonruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Mesenteriumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Milzruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Milzschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Otorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Pankreasruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Perineumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Rektumruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Schulterschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Schädigung des Hypothalamus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Sigmaruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Subarachnoidalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Subarachnoidalblutung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Subarachnoidalblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Trommelfellruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Ureterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Urethraruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische Verschiebung des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische epidurale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische epidurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische extradurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische miliare Gehirnhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische osteolytische Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische spontane Magenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische subarachnoidale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische unbeabsichtigte Hymenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische unvollständige Ruptur der Supraspinatussehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische vollständige Ruptur der Supraspinatussehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatische zerebellare Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Analriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Augapfelprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Gehirnschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Knochenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatischer Leberschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Augenhöhlenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Brusthämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Brusthämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Epididymishämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Gleiten des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom der Mesosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom des Uterusbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Hämatom des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Mammahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Mammahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Mutterbandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Testishämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Vaginahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches Vulvahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches epidurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches extradurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches peripheres Netzhautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches retroperitoneales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches subkapsuläres Leberhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttraumatisches vaskuläres Rückenmarködem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttropische Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttuberkulöse Phlyktäne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttuberkulöse Phlyktänenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttuberkulöser Hämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttuberkulöses Erythema nodosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttumorbedingte Interkostalneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttumorbedingte Pleuraschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttumoröser Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttödliche Auswirkungen durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttödlicher Schaden durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichttödliches Untertauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtulzeröse Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtulzeröse Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvaskuläre Kollagenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvaskuläre Kollagenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvaskulärer Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvenerische Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvenerische Gryposis penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvenerische Penisverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvenerische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvenerische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtvereinigung der Frakturenden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit eines Betts in einer medizinischen Einrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit eines Betts in einer medizinischen Einrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit medizinischer Betreuungsmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit medizinischer Betreuungsmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit von Gesundheitsfürsorgediensten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit von Gesundheitsfürsorgediensten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit von Schulunterricht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit von Sozialhilfestellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtverfügbarkeit von Sozialhilfestellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtwahnhafte Dysmorphophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtzusagende Arbeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtzusagende Arbeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nichtzystoides Makulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nickelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nickkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niederdruck (Blutdruck)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niederdruckglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedergeschlagenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedergeschlagenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriger Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriger Blutdruck ohne hypotone Regulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriger Blutdruck ohne hypotone Regulationsstörung als einmaliger Meßwert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriger Grundumsatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriger RR [Riva-Rocci]-Blutdruckwert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriges Hämoglobin a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niedriggradige Vulvadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niemann-Pick-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niemann-Pick-Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niemann-Pick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nieren-TBC [Tuberkulose] [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenamyloidose [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenangiolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienabgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienatherosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarteriendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienursprungsstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarteriolosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenarteriosklerose mit Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenausgußstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenabgangsenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenabgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenausgangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenausgußstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenfibrolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenfibrolipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckeninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkelchentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkelchkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkelchstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenlipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckensolitärstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbeckenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenblockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenbuckel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendoppelsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendysmorphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierendystopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenembryom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfehldrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfettembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfibrolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengefäßanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengonorrhoe [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengonorrhoe [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengrießabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengumma [kodiere zusätzlich N29.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierengumma [kodiere zusätzlich N29.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhohlsystemdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenhöcker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfektion bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niereninsuffizienz im Stadium der kompensierten Retention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkalziumoxalatstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkapselabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkapseladenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkapselfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkapselödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchdeformierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchelongation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchhalsstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchhydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchverplumpung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkelchzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkolik durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkrankheit bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkrankheit mit Ureterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenlipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmalformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmalrotation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmarkzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmyelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenmyelom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenneurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenoberkelchkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenoberkelchstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpapillenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenparenchymkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenparenchymstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenparenchymtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenparenchymverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenparenchymverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpetechien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenplasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenplasmozytom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpollipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpoltuberkulose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpoltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolvernarbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpolzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenpositionsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindeninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenkrankheit bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenlipoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenrindenverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenschaden nach Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensolitärzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenstauungsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensteatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenstein der oberen Kelchgruppe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensteinabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensteingrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensteinkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierensymptom/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenteilinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentransplantatabstoßung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentransplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentuberkulose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentubulusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenunreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenunterkelchkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenunterkelchstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvenenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvenenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvenenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenverkleinerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenvernarbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenversagen mit Tubulonekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenversagen nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nierenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Niesen/verstopfte Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotin-Entwöhnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotin-Konsum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotinabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotinentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotinmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotinsäure-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nikotinsäureamid-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nitrit-Krise bei ordnungsgemäßer Verabreichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nitrit-Krise bei Überdosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nitrit-Krise durch gegebene falsche Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nitrosohämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Njovera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Njovera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nocardia-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nodale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduli cutanei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nodulus vocalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nodulär-sklerosierende Form der Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre Fasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre Form der Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre Frambösie im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre Prostatahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre ulzeröse Frambösie im Spätstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläre ulzeröse Spätframbösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläres Hidradenom - s.a. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläres Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläres Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläres Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noduläres Retikulolymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nokardiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nokardiose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noma pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noma vulvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nomade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nomade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nomade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nomade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Non-A-Non-B-Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Non-Compliance in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Non-Hodgkin-Lymphom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nondescensus testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nonne-Milroy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nonne-Milroy-Meige-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Noonan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nordamerikanische Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nordasiatisches Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Norethistosteron-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normaldruckglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normaldruckhydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normale Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normale Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normokaliämische paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normokaliämische periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normokaliämische periodische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normosensorisches Spätschielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Normozytäre Blutungsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Norwegische Krätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nosokomialinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nosomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nosophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nostalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nothnagel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nothnagel-Syndrom II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notstandsamenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notstandssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Hilfestellung bei der Körperpflege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Cholera mit Typhus-Paratyphus [Cholera+TAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Pertussis-Tetanus [DPT] [DTPa] [DaPT]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Pertussis-Tetanus mit Poliomyelitis [DPT-IPV] [DTPa-IPV] [DaPT-IPV]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Pertussis-Tetanus mit Typhus-Paratyphus [DPT+TAB] [DTPa+TAB] [DaPT-TAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Pertussis-Tetanus-Haemophilus influenzae Typ b [DPT-Hib] [DTPa-Hib] [DaPT-Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Tetanus [TD] [Td]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Diphtherie-Tetanus-Haemophilus influenzae Typ b [TD-Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Haemophilus influenzae Typ b [Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Hepatitis A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Hepatitis B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Masern-Mumps [MM]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Masern-Mumps-Röteln [MMR]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Mumps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Pneumokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Poliomyelitis [IPV (Inaktivierte Polio-Vakzine)]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Tetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Tuberkulose [BCG (Bacille Calmette-Guérin)]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Typhus-Paratyphus [TAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der Impfung gegen Varizellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der ständigen Beaufsichtigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Notwendigkeit der trivalenten Poliomyelitis-Schluckimpfung [OPV (Orale Polio-Vakzine)]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nuck-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nucleus-pulposus-Hernie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nucleus-pulposus-Hernie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nukleuskatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nukleäre Divergenzparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nutritive Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nutritive Hypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nutritive Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nyktalopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nykteralopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nykturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nykturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nymphomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus durch Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus durch Deprivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus mit Blockierung in der Nähe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus mit Kopfzwangshaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nystagmus mit wechselnder Kopfzwangshaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliche Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliche Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliche Polyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliche Unruhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliche paroxysmale Hämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtlicher Angstanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtlicher Harnabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtlicher Wadenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nächtliches Einnässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelbeißen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelbeißen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelbeißen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nägelkauen beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nässeekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nässender Nabel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nässendes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävoide Lentigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävozelluläre Nävusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus - s.a. Naevus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Achselfalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Bauchwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Brustwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Leistenbeuge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Lippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Schläfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus der Wange',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Dammes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Kanthus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Nabels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävus/Muttermal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävusdysplasiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävuszellnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävuszellnävus mit Entzündungsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Nävuszellnävusdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'O-Bein-Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'O-Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'OPCA [Olivio-ponto-zerebellare Atrophie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'OPLL [Ossification of Posterior Longitudinal Ligament]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'OPLL [Ossification of Posterior Longitudinal Ligament]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oast-house-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oat-cell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachloser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachloser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachloser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachloser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obdachlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmkopfbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmkopffraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmlymphödem nach Mastektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberarmzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchmeteorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchperitonealverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberbauchverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obere Diplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächenduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächengastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlich spreitendes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlich spreitendes Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Erfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Erfrierung des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Fingernagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Fingernagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Fingernagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Hautschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Keratitis mit Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Keratitis ohne Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Konjunktivaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Mammaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Mammaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Mammaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Mykose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Penisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Penisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebitis des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebitis des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebitis migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebothrombose des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebothrombose des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Phlebothrombose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Pilzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombophlebitis des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombophlebitis des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombophlebitis des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombophlebitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombophlebitis post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombose des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombose des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Thrombose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Unterschenkelphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Venenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der Bauchdecke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der äußeren Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung der äußeren Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des hinteren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des hinteren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des hinteren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des vorderen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des vorderen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Verletzung des vorderen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Zehennagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Zehennagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche Zehennagelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche bösartige Neubildung der dorsalen Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche intrazerebrale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliche lokalisierte Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlicher Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlicher Bindehautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlicher Fremdkörper der Hornhaut mit Rosthof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlicher Fremdkörper der Hornhaut ohne Rosthof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächlicher dorsaler Zungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliches Hämatom beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliches Hämatom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliches Karzinom der ventralen Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliches dorsales Zungenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberflächliches seröses Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkiefer-Le-Fort-I-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkiefer-Le-Fort-II-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkiefer-Le-Fort-III-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferadenoameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferalveolarfortsatzatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferalveolarfortsatzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferameloblastenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberkieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlappenpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlidentropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlidherpes [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlidneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlidtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlidzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlippenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlippenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberlippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelhalsbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelphlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelschaftbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelschürfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelschürfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelschürfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkeltrümmerbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkeltrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oberschenkelzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obesitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obesitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Parese und Obliquus-superior-Überfunktion des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Parese und Obliquus-superior-Überfunktion mit A-Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Parese und Obliquus-superior-Überfunktion mit A-Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Überfunktion und Obliquus-superior-Parese des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Überfunktion und Obliquus-superior-Parese mit V-Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliquus-inferior-Überfunktion und Obliquus-superior-Parese mit V-Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliteration der Hornhautgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliteration der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliteration der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliteration des Appendixlumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliteration plazentarer Blutgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterative Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Bronchiolitis durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Bronchiolitis durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Bronchiolitis durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Bronchiolitis durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Otosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obliterierende Otosklerose mit Beteiligung der Fenestra vestibuli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Nierenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Unterkieferdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der vesikourethralen Öffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion der Übergangsstelle des Colon sigmoideum in das Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Ductus choledochus nicht durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Ductus hepaticus nicht durch Steine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Harnblasenkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Magenausganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion des durch Tracheotomie geschaffenen Luftweges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion durch Apparat, Implantat oder Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion einer Retinaarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktion einer Retinavene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktionsikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktionsileus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Bronchitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Duodenumnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Emphysembronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Myokardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Nephrotubulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Pyelonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Schlafapnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Tubulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Uropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Ventilationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktive eitrige Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktiver Ikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktives Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktives Prostataadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obstruktives Schlafapnoesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obturationsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obturatoriushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obturierendes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Obturierendes Zerumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Occlusio pupillae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ochlophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ochronose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ochronose mit Chloasma des Augenlids [kodiere zusätzlich H03.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ochronotische Arthritis [kodiere zusätzlich M14.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ocytocin-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odelberg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontoameloblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontoameloblastom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogene Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogene Keratozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogene Plattenepithelgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogene Plattenepithelgeschwulst des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogener Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Myxofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Myxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenes Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenesestörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenesis hypoplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontogenesis imperfecta sive hypoplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Odontosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oedema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oesophagostomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oestriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oestridiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Axillarwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Bauchdeckenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Beckenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Daumenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Ellenbogenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Epiglottiswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Epiglottiswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Fersenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Fingerwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Fingerwunde mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Fingerwunde ohne Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Flankenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Fußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Gesäßwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Halswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Halswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Handflächenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Handwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Harnleiterverletzung [kodiere zusätzlich S31.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Hautwunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Hautwunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Hautwunde a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Hodenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Hymenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Jochbeinfraktur [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Kehlkopfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Kehlkopfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Klitoriswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Kniewunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Kopfwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Korneawunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Larynxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Larynxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Lendenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Lidwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Lidwunde mit Tränenwegverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Maxillafraktur [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Metatarsalfraktur [kodiere zusätzlich S91.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Nackenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Nackenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Nasenbeinfraktur [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Oberkieferfraktur [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Oberschenkelwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Olekranonfraktur [kodiere zusätzlich S51.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Orbitawunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Peniswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Perinealwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Pharynxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Pharynxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rachenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rachenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Radiusschaftfraktur [kodiere zusätzlich S51.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rückenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Rückenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Skrotalwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Thoraxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Thoraxwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Thyreoideawunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Thyreoideawunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Trachealwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Trachealwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Trommelfellwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Unterschenkelfraktur [kodiere zusätzlich S81.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Unterschenkelwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Ureterverletzung [kodiere zusätzlich S31.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Vaginalwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung mit Hämatothorax [kodiere zusätzlich S21.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung mit Hämatothorax [kodiere zusätzlich S21.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung mit Pneumothorax [kodiere zusätzlich S21.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Verletzung mit Pneumothorax [kodiere zusätzlich S21.83!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Vulvawunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Augenanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Brustbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Brustbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Darmbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Epididymis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Interskapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Interskapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Kniekehle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Kreuzbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Lumbalgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Lumbosakralregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Nabelgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Oberbauchgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Periokularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Pudenda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Pudenda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Regio inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Rippengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Rippengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Sakroiliakalgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Schienbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Schulterblattregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Schultergegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Supraklavikularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Supraklavikularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Unterbauchgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der Wade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der extraokulären Augenmuskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Brustwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Brustwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Genitalorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Geschlechtsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde der äußeren Geschlechtsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Augenwinkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Hypochondrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Präputiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Rumpfes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Spanns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Tränenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des behaarten Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des hinteren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des hinteren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des skrotalen Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des thorakalen Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des thorakalen Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des vorderen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde des vorderen Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch penetrierenden Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch penetrierenden Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Wunde durch penetrierenden Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Zehenwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Zehenwunde mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene Zehenwunde ohne Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene distale Radiusfraktur [kodiere zusätzlich S51.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene okuläre Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene perforierende Lidwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene proximale Radiusfraktur [kodiere zusätzlich S51.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offene transzervikale Schenkelhalsfraktur [kodiere zusätzlich S71.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Ductus arteriosus Botalli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Ductus omphaloentericus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Ductus vitellinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Jochbeinbruch [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Nasenbeinbruch [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Nuck-Kanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Oberkieferbruch [kodiere zusätzlich S01.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Processus vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Processus vaginalis peritonei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener Urachus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offener transzervikaler Schenkelhalsbruch [kodiere zusätzlich S71.87!]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offenes Foramen ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offenes Ostium primum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offenes Ostium secundum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Offenes Vorhofseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ogilvie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oguchi-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oguchi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohara-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohne Befund [o.B.]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohnmacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohnmacht/Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohnmachtsanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohnmachtsgefühl/Benommenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohnmachtssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohr-/Mastoiderkrankung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohr-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohraffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenklingen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenkrankheit in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrensausen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrensymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrenverletzung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrerysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrhautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrkanalobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrknöchelchenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrlaufen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrlochstechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrlues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrlues [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuscheldermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuscheldysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelelefantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelnoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmuschelverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrmykose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrpfropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrrauschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrschmalzpfropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrspeicheldrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrspeicheldrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrspeicheldrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrspinaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrsyphilis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtiefstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtrompetenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtrompetenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtrompetenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtrompetenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtrompetenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtubenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ohrwundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okklusale Zahnabnutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okklusive Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okkulte Darmblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okkulte Hämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okkulte Intestinalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okkultes Blut im Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okkultes Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulare Zystizerkose [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulo-glanduläre Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulo-glanduläres Syndrom (Parinaud)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulo-mandibulo-faziale Dysostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulodentodigitale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuloglanduläre Listeriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulogyre Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulogyrer Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulokutaner Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomotorische Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomotorische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomotoriusparese [III. Hirnnerv]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomotoriusparese mit Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomotoriussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulomyiasis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopathie bei Spätsyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopathie bei Spätsyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopathie bei sekundärer Frühsyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopathie bei sekundärer Frühsyphilis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopharyngeale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopharyngeale Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulopharyngeale Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Hypertension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Myiasis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläre Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulärer Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okulärer Hypertelorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläres Pemphigoid [kodiere zusätzlich H13.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okuläres Retraktionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okzipitalisneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okzipitalneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Okzipitozervikales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olekranonfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktogenitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktorische Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktoriusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktoriuskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktoriusneuroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olfaktoriusneuroepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligo-Anurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligo-Astheno-Teratozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligo-Astheno-Zoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligo-Azoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligoastrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligodendroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligodendrogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligoglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligohidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligophrenia phenylpyruvica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligotrichie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oligämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olivopontozerebellare Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ollier-Chondrodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ollier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ollier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Olympkrankheit [Q-Fieber]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentalthrombose mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentuminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omentumtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalitis mit leichter Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalitis, nicht beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalophlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalophlegmone beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalorrhagie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Omphalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onchozerkiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onchozerkose des Augenlids [kodiere zusätzlich H03.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onchozerkose des Auges a.n.k. [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oneirophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onkologische Nachsorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onkozytäres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onkozytäres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychauxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychauxis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychie durch Candidaarten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychie durch Dermatophyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychie durch Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychocryptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychogryphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychogryphosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychogrypose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onycholyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onycholysis foliacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomadesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomykose der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomykose der Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychomykose durch Candida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychonosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophagie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychophosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychoptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Onychoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oophoroma folliculare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opacitas corneae [Hornhauttrübung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opake Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opake Zahnflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opazität des Zahnschmelzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opazität des Zahnschmelzes durch Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opazität des Zahnschmelzes, nicht durch Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Operationskomplikation durch versehentliche Lazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Operationskomplikation durch versehentliche Punktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Operativ verursachte Vorderkammerblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer körperlicher Gewalt, Vergewaltigung, sexueller Belästigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer von Folterung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer von Folterung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opfer von Folterung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia actinica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia electrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia neonatorum durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia neonatorum durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmia photoelectrica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmie durch Ultraviolettstrahlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmikusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmikusneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmische Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmische Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmische Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoblennorrhoe [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmomyiasis [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoneuromyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmophthisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia chronica progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia externa a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia interna totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegia plus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegie-Ataxie-Areflexie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmoplegische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ophthalmozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opioidabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opioidintoxikation bei Abhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opioidmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opisthogenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opisthognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opisthorchiasis felineus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opisthorchiasis veverrini',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opistognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opitz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opitz-Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opiumsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oppenheim-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oppenheim-Urbach-Krankheit [Lipoidnekrobiose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oppenheim-Urbach-Syndrom [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opportunistische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Opportunistische Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikopathie durch Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikopathie durch Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusatrophie bei Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusatrophie bei Leukodystrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusatrophie bei Vitaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikuserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikuskompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusmeningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusneuropathie bei entzündlicher Allgemeinerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusscheidenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikusstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikustumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optikustumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optische Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Optische Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Aphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale aphthöse Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orale rezidivierende Aphthen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oralsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oralsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orangefarbene Zahnauflagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orangefarbener Zahnbelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbicularis-Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbikularis-Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitabodenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitadachfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitadeformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaexostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitafurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitagranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitagumma [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitagumma [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitale Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaler Hypertelorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitalues [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitalues [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitalymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitalymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitameningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitamukormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitamyiasis [kodiere zusätzlich H06.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitamyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitanekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaneurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitasequester',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitasyphilis [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitasyphilis [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatenonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatrichinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitatumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitavarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitavarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orbitopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchelefantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis bei Parotitis epidemica [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis durch Chlamydien [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis durch Gonokokken [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis durch Gonokokken [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis durch Herpesviren [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis durch Herpesviren [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis mit Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis ohne Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchitis/Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orchoepididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orfvirus-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingte pseudoretardierte Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingtes Lidzucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingtes halluzinatorisches Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingtes nichtalkoholisches halluzinatorisches Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingtes paranoid-halluzinatorisches Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch bedingtes paranoides Zustandsbild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisch fixierte neuromuskuläre Low-compliance-Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Aphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Gehirnerkrankung mit Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Hirnstörung mit Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Hypersomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Hyposomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Pseudopsychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose bei Ernährungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose bei Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose bei Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose bei Syphilis des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Psychose durch intrakranielle Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Schlaflosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische Wesensänderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische affektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische emotional labile Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische erektile Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische erektile Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische präsenile Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische senile Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organische wahnhafte Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organischer Graphospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organischer Graphospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organischer Schreibkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organischer Schreibkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisches Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organisches Psychosyndrom, anderes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose der Muskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose des endokrinen Systems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organneurose eines Sinnesorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organspender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organtransplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Organverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orgasmusschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orgasmusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orientalische Leberegel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orientbeule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orientfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orientgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orientierungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ormond-Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ormond-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ormond-Krankheit mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ormond-Krankheit mit Ureterobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ormond-Syndrom mit Ureterobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithin-Transcarbamylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithinämie Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithinämie Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ornithose mit Pneumonie [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oro-fazio-digitales Syndrom Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oro-fazio-digitales Syndrom Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orofaziale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orofaziale Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orofazialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oronasale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oropharynxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oropharynxstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oropouche-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orotazidurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oroya-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthopnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthopnoea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthoptische Übungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthopädische Endoprothese mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthopädische Nachbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostasesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Albuminurie/Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Dysregulation bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Dysregulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Kreislaufbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatische Regulationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatischer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Orthostatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ortner-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ortolani-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Os-metacarpale-I-Basisfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osgood-Schlatter-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osgood-Schlatter-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osgood-Schlatter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osler-Knötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osmidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osmotische Diurese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation der Falx cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation der spinalen Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation der zerebralen Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation des Glaskörperwassers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation des Ligamentum longitudinale posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation des Ligamentum longitudinale posterius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifikation des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossifizierendes Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossäre Kryptokokkose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossäre Spätsyphilis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossäre Spätsyphilis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ossäre Tuberkulose [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostafrikanische Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostafrikanische Trypanosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostasiatische Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostealgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthritis deformans endemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthritis des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose/Osteoarthritis der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrose/Synovitis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrosis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoarthrosis deformans alkaptonurica [kodiere zusätzlich M36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondritis dissecans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondritis dissecans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondritis syphilitica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondritis syphilitica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondroarthrosis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrodysplasie mit Wachstumsstörungen der Röhrenknochen und der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrodystrophia deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondromatose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondromatosis articularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondromyxosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondropathia ischiopubica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondropathie der WS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der LWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Lenden- und Sakralwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Synchondrosis ischiopubica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der Wirbelsäule beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose der unteren Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose des Capitulum humeri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrose des Talus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrosis deformans coxae juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteochondrosis dissecans des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoclastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoclastoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophia deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophia deformans des Schädelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophia fibrosa cystica generalisata (von Recklinghausen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteodystrophie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteofibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteofibrozystische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteogenes Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoidosteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteokartilaginäre Exostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoklastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoma osteoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalaze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie durch Fehlernährung im Erwachsenenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie durch Malabsorption im Erwachsenenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie durch Mangelernährung im Erwachsenenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie im Erwachsenenalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie im Jugendalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomalazie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis durch Echinokokken [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis durch Gonokokken [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis durch Gonokokken [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelitis durch Salmonellen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelofibrosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyeloretikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyeloretikulosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteomyelosklerosesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteonekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoonychodysostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopathia condensans disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopathia hyperostotica multiplex infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopathia hypertrophicans toxica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopathie nach Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoperiostitis ossificans toxica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopetrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopetrosis familiaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoplastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopoikilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopoikilose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose bei endokriner Krankheit a.n.k. [kodiere zusätzlich M82.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose bei multipler Myelomatose [kodiere zusätzlich M82.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose durch postoperative Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose mit Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose mit Wirbelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose mit pathologischer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose mit pathologischer Fraktur durch postoperative Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose nach Ovarektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoporose-Osteomalazie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopsathyrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopsathyrosis idiopathica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteopulmonale Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoradionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoradionekrose des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteoradionekrose des Unterkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosarkom bei Paget-Krankheit des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosclerosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosclerosis congenita diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosclerosis fragilitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosis cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosis eburnisata monomelica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosklerose bei Myelofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosklerotische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Osteosklerotische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostiofolliculitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostiofolliculitis impetiginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis bei Frambösie [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis condensans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis cystica multiplex tuberculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis deformans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis fibrosa a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis fragilitans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis mastoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis multiplex cystoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis multiplex cystoides Fleischner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostitis tuberculosa [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostium atrioventriculare commune',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostium-primum-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ostium-secundum-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ota-Nävus der Gesichtshaut (ohne Auge)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ota-Nävus der Haut des Augenlides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ota-Nävus der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Othämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa bei Aspergillose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa bei Kandidose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa bei Zoster [kodiere zusätzlich H62.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis externa sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis interna vasomotorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media bei Masern [kodiere zusätzlich H67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media mit Myringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media mit nichteitrigem Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis media serosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oto-palato-digitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otogen fortgeleitete Enzephalitis a.n.k. [kodiere zusätzlich G05.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otogene Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otogener Gehirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otogener Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otolithenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otomyiasis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otomykose [kodiere zusätzlich H62.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otoneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otopexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose der Labyrinthknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose mit Beteiligung der Fenestra cochleae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose mit Beteiligung des knöchernen Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose mit nichtobliteriertem ovalem Fenster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otosklerose mit obliteriertem ovalem Fenster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otospongiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ototoxische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ototoxische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otto-Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Otto-Chrobak-Becken [Protrusio acetabuli]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovale hereditäre Erythrozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovalozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovaranomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovargonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovargonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialdysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialdysgerminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Androgenhypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Androgenvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Androgenüberproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Dysfunktion mit Androgenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Dysfunktion mit Östrogenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Hyperstimulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Hyposekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Überfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariale Überstimulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialer Androgenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialer Hypergonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialer Lipoidzelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariales Strumakarzinoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialhämatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialhämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialkalkherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialkystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialmesonephrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialseminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialstielrotation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialstrangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialtorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialtuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialvarikozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarialzystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarienreste in der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovariozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarstreifen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovarzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Overlapsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Overstressedsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovotestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovotestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovula Nabothi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationshemmernebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationshemmerunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationshämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationsschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ovulationsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Owren-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Owren-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalat-Nephrolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalat-Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalat-Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalatstein in den Harnwegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalatsteinabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalsäure-Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalsäure-Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxalurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxyphiles Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxyphiles Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxyuriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxyzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Oxyzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ozaena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PAH [Periarthropathia humeroscapularis] - s.a. Periarthropathia humeroscapularis oder s.a. Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PAVK [Periphere arterielle Verschlußkrankheit] - s.a. Periphere arterielle Verschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCO [Polyzystisches Ovar]-Syndrom mit Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCP [Primär-chronische Polyarthritis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCP-Abusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCP-Abusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCP-Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PCP-Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PDS [Postdiskektomiesyndrom] - s. Postdiskektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PFC [Persistent fetal circulation]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PHS [Periarthropathia humeroscapularis] - s.a. Periarthropathia humeroscapularis oder s.a. Periarthrosis humeroscapularis oder s.a. Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PHS [Periarthropathia humeroscapularis]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PKU [Phenylketonurie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PML [Progressive multifokale Leukoenzephalopathie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PN [Pyelonephritis] - s.a. Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PNP [Purinnukleosid-Phosphorylase]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'POEMS-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PP-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PRIND [Prolongiertes reversibles ischämisches neurologisches Defizit]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PTA [Plasma thromboplastin antecedent]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'PTC [Plasma-thromboplastin-component]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermia laryngis verrucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermoperiostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachydermoperiostose mit Trommelschlegelfingern [kodiere zusätzlich L62.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachygyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pachyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Page-Niere mit Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-Krankheit des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-Schroetter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paget-von-Schroetter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palatoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palatoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palilalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palindromer Rheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palisadenartige Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palisadenförmige Retinadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palliative Betreuung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pallidostriäres Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pallidumsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pallor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmaraponeurosenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmares Frambösiepapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmarfaszienkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmarfaszienretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmarfibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palmarwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpable Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpable Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpables Zökum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpebrale Trichiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpitatio cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpitation/Herzstolpern/Bewußte Wahrnehmung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palpitationen des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paludale Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paludales Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paludismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Palvant-Tal-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panalgesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panama-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panangiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panaritium durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panarteriitis nodosa des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panarteriitis nodosa mit Lungenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panazinöses Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panchondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pancoast-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pancoast-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pancreas accessorium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panfaziale Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panhypopituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panhämozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikattacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikreaktion auf außergewöhnlichen Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paniksyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panikzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasachylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasfettgewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasgangabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasganganomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasgangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreashyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreashypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreashämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasinsulinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskopfkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskopfkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskopfmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskopftumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaslipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasparenchymunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaspseudozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasschwanzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreassklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreastuberkulose [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreastumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreaszirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreasüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatikoduodenale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatischer Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatischer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatitis durch Toxoplasmen [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatitis durch Zytomegalieviren [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatoduodenaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pankreopriver Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panmyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panmyelophthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panmyelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panmyelose in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panmyokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panner-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panneuritis endemica [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panniculus adiposus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panniculus adiposus abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannus degenerativus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannus der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pannus inflammatorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pansinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pantothensäuremangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panuveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panvalvuläre Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzerherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzerpleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzystitis [Cystitis parenchymatosa]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzytolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Panzytopenie mit Fehlbildungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papageien-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papanicolaou-Abstrich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papanicolaou-Abstrich der Zervix bei Verdacht auf Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papeln bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papeln/Knoten/Schwellungen an mehreren Stellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillarmuskelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillarmuskelruptur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenabblassung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenblässe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillendrusen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenexkavation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenkolobom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenkonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenunschärfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenunschärfe bei Hyperopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillitis des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillitis necroticans der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der Blasenvorderwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der Blasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der Harnblasenvorderwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der Harnblasenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom der prostatischen Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillom des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilloma acuminatum sive venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilloma acuminatum sive venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatosis confluens et reticularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöse Urothelwucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöse Wucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöse Wucherung der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöser Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöser Tumor der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöser Tumor der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöser Urotheltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöses Gewächs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillomatöses Gewächs der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillon-Léage-Psaume-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillotubuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillozystisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillär-zystisches Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläre Nekrose bei Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläre Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Ependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Hidradenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Schilddrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Syringadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Syringozystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papilläres Zystadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papillärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulonekrotisches Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulopustulöse Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulosis atrophicans maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulosquamöse Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulöse Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulöse Muzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulöse Schwangerschaftsdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Papulöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraalbuminämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraamyloidablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paracoccidioidosis brasiliensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paradentose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paradoxe Embolie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paradoxe Pupillenreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraffingranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraffinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parafollikuläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraganglienkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraganglienkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraganglioma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parahämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parainfluenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakeratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakeratosis variegata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakokzidioidales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakokzidioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parakolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus levator palpebrae superioris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus obliquus inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus obliquus superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus rectus des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus sternocleidomastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Musculus trapezius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus abducens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus glossopharyngeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus laryngeus recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus laryngeus superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus oculomotorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus peronaeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus phrenicus durch Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des Nervus trochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse des äußeren Augenmuskels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse durch Druckluft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse durch Zeckenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse mit Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse mit Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralyse-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis acuta infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis agitans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis laryngolabioglossalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis saturnina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis spinalis ascendens acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralysis-agitans-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Assoziation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische Uveoparotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytische bulbäre Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Darmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Dickdarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Dünndarmverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Ileumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Intestinumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Jejunumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Kolonverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Lagophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Schlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytischer Zökumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytisches Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytisches Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paralytisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramandibulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramedianes Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametrischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametriumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametriumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametriumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametriumtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathia spastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parametropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramolar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramyoclonus multiplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramyotonia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paramyotonia congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraneoplastische Neuromyopathie [kodiere zusätzlich G13.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraneoplastische Neuropathie [kodiere zusätzlich G13.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraneoplastische limbische Enzephalopathie [kodiere zusätzlich G13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraneoplastisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranephritischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoia durch Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoia querulans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoid-halluzinatorische Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoid-halluzinatorische Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoid-halluzinatorische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoid-halluzinatorische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoid-schizophrene Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Charakterneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Drogenpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Neigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide Schizophrenie mit Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoide senile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoider Charakterzug',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoider Typ einer psychopathische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoider Wahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoider Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoides Irresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoides Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoides Zustandsbild bei Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoides Zustandsbild im Involutionsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paranoische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapharyngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapharyngeale Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphrene Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraplegie der unteren Extremitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraplegische Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapoliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraproktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraprostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraprostatische Knötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraproteinnephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis en plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis lichenoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis retiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis varioliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parapsoriasis varioliformis acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pararektaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pararenaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasiten-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitenbefall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitenbefall der Orbita a.n.k. [kodiere zusätzlich H06.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitologisch bestätigte Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Bartflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Endophthalmitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Enteritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Epilepsie a.n.k. [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Iriszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Krankheit in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Meningoenzephalitis a.n.k. [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Netzhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Retinazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Sykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Vorderkammerzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Ziliarkörperzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasitäre Zyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraspadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraspasmus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasplenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parastomale Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasuizid in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parasympathisches Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreogene Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoid-thymische Aplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoideaadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoideaamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoideahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoideatuberkulose [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoiditis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoiditis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoiditis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parathyreoprive Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratonsillarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratrachom [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratubale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratubarzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratyphlitischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratyphus abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratyphus-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paratyphöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraumbilikalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethraler Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethrales Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethrales malignes Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethralzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parauteriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paravaccinia-Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paravaginaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paravaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paravariola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paravertebrale Tendomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parazephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parazystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paraösophagealhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Mastitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Nephrolithiasis [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse degenerative Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse degenerative Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymatöse endemische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenchymtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Nervus hypoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Nervus peronaeus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Nervus radialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des Plexus brachialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parese des äußeren Augenmuskels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paresis vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paretische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paretische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paretische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paretische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parietale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parietalhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parietoalveolare Pneumopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parietoalveolare Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parinaud-Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parinaud-Krankheit [Ophthalmoplegie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parinaud-Ophthalmoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parinaud-Syndrom [Ophthalmoplegie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parinaud-okulo-glanduläres-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson-Demenz [kodiere zusätzlich F02.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson-Syndrom durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinson-Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinsonismus bei idiopathischer orthostatischer Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinsonismus bei symptomatischer orthostatischer Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parkinsonoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontale Pyorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontale Schädigung durch traumatische Okklusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis chronica purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis complex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis marginalis superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontitis superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontopathia dystrophica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontopathia inflammata superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parodontopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paronychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paronychie durch Candida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paronychie durch Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroophoronzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parorexie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parostales Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotisinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotiskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotiskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotismischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotistuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotistumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotiszystadenolymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotiszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotitis epidemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parotitis, nicht durch Mumps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmal familiäre Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Bewußtseinstrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Choreoathetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Diplopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Fingerzyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Hämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Knotentachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Kältehämoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale Vorhoftachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmale idiopathische Automatismen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmaler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmaler Lageschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paroxysmales Gesichtsschmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Kaufmann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Pseudoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parrot-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parry-Romberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parsonage-Aldren-Turner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parsonage-Turner-Syndrom [Neuralgische Schulteramyotrophie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partiell inkarzerierte epigastrische Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partiell maligner Brenner-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Dyslalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Epilepsie mit Bewußtseinsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Epilepsie ohne Bewußtseinsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Iridoparalysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Iridoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Obstruktion der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Plazentaretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partielle Trisomie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller Albinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller Descensus uteri et vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller Linksschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller Verlust der Gehörknöchelchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller arterieller Gefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller arterieller retinaler Gefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller uterovaginaler Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller uterovaginaler Vorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller venöser Gefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partieller venöser retinaler Gefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftliche Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsbeziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partnerschaftsprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partus praecipitatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partus praecipitatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partus praematurus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Partusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parulis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Parästhesien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pasini-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pasini-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pasqualini-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passiv-aggressive Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passiv-aggressive Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Algolagnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Lungenhyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Lungenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive pulmonale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passive pulmonale Hypostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Passives obstruktives Glottisödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pasteurella-Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patau-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patella bipartita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellachondropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patelladistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patelladysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellagleiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellarsehnenabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellartendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaspitzensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellastörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Patellaverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paterson-Brown-Kelly-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisch erhöhter AFP [Alpha-Fetoprotein]-Wert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisch erniedrigter AFP [Alpha-Fetoprotein]-Wert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Anoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Blendungsempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Brandstiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Dislokation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Dunkeladaptation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Eizelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Emotionalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Fraktur bei Osteoporose nach Ovarektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Glukosetoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Nierenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Sexualität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Subluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische Trunkenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische VEP [Visuell evozierte Potentiale]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologische visuell evozierte Potentiale [VEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Drogenrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Drogenrausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Glukosetoleranztest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Harnbefund a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Rausch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Retraktionsring des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Retraktionsring des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Sonographiebefund der Gallenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Sonographiebefund der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Sonographiebefund der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Sonographiebefund des Verdauungstraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer Zustand der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologischer alkoholischer Rausch a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches CTG [Kardiotokogramm] bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches EOG [Elektrookulogramm]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches ERG [Elektroretinogramm]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Funktionsprüfungsergebnis der Sinnesorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Funktionsprüfungsergebnis des Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Geschlechtsleben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Glücksspiel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Haarausreißen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Harnsediment',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches KTG [Kardiotokogramm] bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Kardiotokogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pathologisches Stehlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paukenerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paukengranulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paukenhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paukenhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pautrier-Woringer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Paxton-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Payr-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pechstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pectoralis-major-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pediculosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pediculosis capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pediculosis corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pediculosis pubis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pediculosis vestimenti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pedikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pedikulose durch Pediculus humanus capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pedroso-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peitschenhieb-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektanginöse Herzbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektanginöse Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektanginöser Beschwerdenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektorale Lymphknotenmetastasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektoralisabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pektoralphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pel-Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pel-Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelger-Huët-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelger-Huët-Kernanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peliosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peliosis rheumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelizaeus-Merzbacher-Aplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelizaeus-Merzbacher-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelizaeus-Merzbacher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pellagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pellagra-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pellagröse Enzephalopathie [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pellagröse Gingivitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelveoperitonitis bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvic-congestion-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvikoabdominaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvine Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviner Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviner Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviolithiasis [Nierenbeckenstein]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvipathia spastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvipathia vegetativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvipathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvipathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvipathiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviperitoneale Verwachsung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviperitonitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviperitonitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvis angusta mit Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvisschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvisschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvisschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelviureterale Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvivarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelvoureterale Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pelzigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigoid ocularis [kodiere zusätzlich H13.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigoidkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus acutus febrilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus acutus gravis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus brasiliensis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus conjunctivae [kodiere zusätzlich H13.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus familiaris chronicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus hystericus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus ocularis [kodiere zusätzlich H13.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphigus seborrhoicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pemphiguskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pena-Shokeir-Syndrom I [Autosomal-rezessive fetale Akinesie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pena-Shokeir-Syndrom II [(autosomal-rezessives) Zerebro-okulo-fazio-skeletales Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pendelhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pendelndes Abdomen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pendelnystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pendred-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penetrierende Augapfelwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penetrierende Wunde der Orbita mit Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penetrierende Wunde der Orbita ohne Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penicilliosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisablederung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisbulbitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisdorsalverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisdécollement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniselefantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniselephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniserysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniserythroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisfibrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisfibrosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgumma [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisgumma [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penishämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penishämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisinfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskavernitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskraurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penislymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penismetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penismißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penissklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisstriktur durch Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penissymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penissyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penissyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penistumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverkrümmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniswundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peniszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penisödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penizillin-Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penizillin-Allergie in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penoskrotalhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pensionsschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Penta-X-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pentalogie von Fallot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pentasomie-X-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pentosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peptische Duodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peptische Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peptisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peptisches Ulkus, anderes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peptisches kardia-ösophageales Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perakute Sepsis durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peregrinating patient',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforanteninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforantenvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation Trommelfell',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation bei Endoskopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation der Pars flaccida des Trommelfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation durch IUD [Intrauterine device]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation eines Sigmadivertikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforation eines Zäkumdivertikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Augapfelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Hornhautverletzung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Orbitaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Verletzung mit Fremdkörper des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierende Verletzung ohne Fremdkörper des Augapfels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierender Hornhautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierendes Elastoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierte Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierte Otitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierte Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierte Spätsyphilis der Uvula [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierte Spätsyphilis der Uvula [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforierter Peritonealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforiertes Bauchaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforiertes Ulcus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforiertes Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforiertes Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perforiertes Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perfusionskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pergamentkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periadenitis mucosa necrotica recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periamygdalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periamygdalitis phlegmonosa abscedens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Hautzipfel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Herpes-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Herpes-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Marisken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianale Pilzinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianalekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianaler Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianaler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianalkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianalmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perianalthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikale Gewebekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikale zemento-ossale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periapikales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periappendikale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periappendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periappendizitischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis calcificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis coxae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis calcarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis mit Bewegungseinschränkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis mit Kalkablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis mit Teilsteife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis mit einseitigem Kopfhochstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathia humeroscapularis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periarthrosis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peribronchialfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peribronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peribronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis adhaesiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis calcarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis constrictiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis constrictiva chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericarditis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericementitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericholangiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pericholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perichondritis auricularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perichondritis des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridentale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridivertikulitis des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridontale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridontale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridontaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peridontitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periduodenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periepididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perifolliculitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perifolliculitis capitis abscedens et suffodiens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perifolliculitis superficialis pustularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perifollikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perigastrische Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perihepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perihepatitis chronica hyperplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikanalikuläres Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikanalikuläres Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarderguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarderkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardgumma [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardgumma [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardiale Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardiale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardiale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardialer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis (nicht rheumatische)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis bei systemischem Lupus erythematodes [kodiere zusätzlich I32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Coxsackieviren [kodiere zusätzlich I32.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Gonokokken [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Gonokokken [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Meningokokken [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis mit Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditis mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikarditische Pseudoleberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardkarzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardmesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardpetechien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardsyphilis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardsyphilis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardtamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardtuberkulose [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikardzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikoronarzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikoronitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perikranielle Eiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perilabyrinthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perilymphfistel des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimandibulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimenopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimetrischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimetritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimetrosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perimyokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinatale Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinatale Hirnschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinatale Klavikulafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinatale Störung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinataler Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinatales Pneumomediastinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Fistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Fistel mit Beteiligung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineale Schmerzen und perianale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinealer Spasmus bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineallazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinealprolaps bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinealrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinealriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perinephritischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumfibrose bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumhämatom bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumhämatom bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineuminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumreizung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumtumor bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumvarizen bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumvarizen im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineumverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perineurales Fibroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisch-wiederkehrende Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Lähmung des Ophthalmikus [Ophthalmoplegische Migräne]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Polyserositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Somnolenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische Trunksucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodische familiäre Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodischer Ptyalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisches Mittelmeer-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisches psychogenes Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodontale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodontitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodontitis complex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periodontitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periokulare Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perionychie durch Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perioophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorale Flechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorale Pyodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorales Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorales superinfiziertes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorbitale Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorbitale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorbitalphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periorchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostales Chondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostales Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostales Fibrosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis bei früher Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis bei später Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis der Ferse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis mit Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostitis tibiae durch Überlastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostose mit Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periostverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periovariale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripankreatische Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripapilläre Aderhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripharyngealer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Angiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Enthesopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Fazialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Gefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Gesichtsfeldkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Halbseitenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Hemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Nervenparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Nervenverletzung des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Neuritis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Neuritis/Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere Vertigo a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere arterielle DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere arterielle Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere arterielle Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphere arterielle Verschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Angiospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Arterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Gefäßkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Gefäßspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Lagerungsnystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Nervenschädigung des Arms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Nervenschädigung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer Vasospasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer degenerativer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripherer vaskulärer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripheres Aneurysma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripheres Aneurysma racemosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periphlebitis umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periporitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periportale Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periproktischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periproktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periprostatische Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periprostatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periprostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peripyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirektale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirektale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirektaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirenale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirenale Fasziitis mit Ureterobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirenale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirenaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perirenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perisalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perisigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perisigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perispermatozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perisplenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perithyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealdialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Adhäsion des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Reizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneale Splenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealhyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealkarzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealmesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealmyxom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealperlsucht durch übertragbare Rindertuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealsarkomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealsyphilis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealsyphilis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealtuberkulose a.n.k. [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumlazeration als Geburtsverletzung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumlazeration als Geburtsverletzung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritoneumnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis bei Darmdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis carcinomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis durch Chlamydien [kodiere zusätzlich K67.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis durch Gonokokken [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis durch Gonokokken [kodiere zusätzlich K67.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis durch Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis durch Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis puerperalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonitis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonsillarabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonsilläre Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonsilläres Infiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritonsilläres Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peritubäre Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perityphlitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perityphlitischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periureterale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periureterale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periureteraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periureteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periurethraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periurethraler Abszeß durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periurethraler Abszeß durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periurethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periuterine Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periuterine Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Periuteriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikale Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikulitis der Bläschendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perivesikuläre Adhäsion der Samenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perizellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perizytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perlgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perlman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perlèche a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perlèche bei Vitamin-B2-Mangel [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perlèche-Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Permigrationsperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perniciosa haemoglobinurica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pernio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pernioerythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perniones',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perniziöse Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perniziöse Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perniziöse Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perobrachius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peromelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peronäale Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peronäusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peroxidasedefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perseveration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistenz der linken Vena cardinalis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistenz einer zilioretinalen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistenz einer zilioretinalen Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistenz von pankreatischem Gewebe im Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistieren der Dentes decidui',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierend-posttraumatische Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Ablatio retinae nach Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Analmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Arteria hyaloidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Arteria stapedia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Fistel der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Gefäßkonvolute im Bereich des Aortenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie bei fokaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie bei segmentaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit Dense-deposit-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit Glomerulonephritis mit diffuser Halbmondbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit diffuser endokapillär-proliferativer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit diffuser membranöser Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit diffuser mesangiokapillärer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Hämaturie mit diffuser mesangioproliferativer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Kloake',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Lanugo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Lichtreaktion der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Milchzähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Ovarienreste in der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Pupillarmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Pupillenmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Tunica vasculosa lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende Ureterfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende fetale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende linke hintere Kardinalvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierende psychogene Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Atrioventrikularkanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Bulbus arteriosus des linken Ventrikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Cloquet-Kanal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Ductus arteriosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Ductus omphaloentericus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Ductus thyreoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Ductus thyreoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Ductus vitellinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Gartner-Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Kiemenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Meckel-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Truncus arteriosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender Urachus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender abnormer Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender doppelter Aortenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender hyperplastischer primärer Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierender rechter Aortenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Corpus luteum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Foramen ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Hymen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Ostium primum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persistierendes Ostium secundum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Person ohne festen Wohnsitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Person ohne festen Wohnsitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Person ohne festen Wohnsitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Person ohne festen Wohnsitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitskrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsstörung bei limbischer Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitswandel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderung nach Folter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderung nach Konzentrationslagererfahrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderung nach einer Katastrophe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderung nach längerer lebensbedrohlicher Situation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderungen eines Opfers von Terrorismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Persönlichkeitsänderungen nach andauernder Gefangenschaft mit unmittelbarer Todesgefahr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perthes-Calvé-Legg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perthes-Jüngling-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perthes-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perthes-Legg-Calvé-Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perthes-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertrochantäre Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertrochantäre Oberschenkelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussiforme Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis durch Bordetella parapertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis durch Bordetella pertussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pertussis-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peru-Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perverser Appetit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perverser Geruchssinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perverser Geschmackssinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pervigilium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perzeptionsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perzeptionstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Perzeptiver Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes adductus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes adductus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes calcaneus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes equinovalgus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes equinovarus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes equinus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes excavatus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes planovalgus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes planus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes transversus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes valgus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes varus congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pes-anserinus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pessareinlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pessareinlage zur Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pessimismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pessimistische gedrückte Stimmungslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pest-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pest-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestbakterien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestis fulminans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestis minor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestis siderans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestmeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pestpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petechein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petechiale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petechien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petechien beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petechien beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peters-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petges-Cléjat-Jacobi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petit mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petit mal mit Grand-mal-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petit-mal-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petit-mal-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petriellidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Petzetakis-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Peutz-Jeghers-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfannenlockerung einer Hüftgelenktotalendoprothese [TEP]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfannenlockerung einer TEP [Totalendoprothese] des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfaundler-Hurler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeifende Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeifendes Atemgeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeifer-Weber-Christian-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeifer-Weber-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeiffer-Drüsenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeiffer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfeilerzellgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pferdeenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflanzenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflanzenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflanzenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflasterallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflastersteindegeneration der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflastersteinförmige Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflege einer künstlichen Körperöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflegebedürftigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pflugscharbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderblockade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderhochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderhypertonie durch chronische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderpyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortadersyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortadersyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfortaderverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pfropf-Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phaeohyphomycosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedäna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedänische Pyodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedänischer Abszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedänischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedänischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phagedänisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phakolytisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phakoma des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phakomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phakomatoseglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantom-Glieder-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantom-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantomglied',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantomschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantomschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phantomtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngeale Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngeale Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngealer Myoklonus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Coxsackieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Fusospirochäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis granulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis granulosa chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngitis vesiculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngokonjunktivales epidemisches Fieber [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngokonjunktivalfieber [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngokonjunktivalfieber durch Viren [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngolaryngitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngolaryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngolaryngotracheitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngolaryngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngorhinolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotonsillitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotonsillitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotonsillitis herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotonsillitis herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharyngotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxdiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxgumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxhyperästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynximperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxtuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxwandzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pharynxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenacetin-Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylalanin-Hydroxylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylcyclidinabusus (oder vergleichbare Substanzen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylcyclidinabusus (oder vergleichbare Substanzen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylcyclidinmißbrauch (oder vergleichbare Substanzen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylcyclidinmißbrauch (oder vergleichbare Substanzen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylketonurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phenylketonurie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phimose durch Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phimose/überschüssige Vorhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phimosis palpebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebektasie der Vena spermatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebektasie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis bei medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis der Vena saphena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis der hepatischen Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis einer intraspinalen Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis eines intraspinalen Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis nach Infusion, therapeutischer Injektion oder Transfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis portalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis suppurativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebitis/Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebopathie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebopathie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebothrombose bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlebotomus-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmasia alba dolens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmasia coerulea dolens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone der äußeren Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone durch Clostridien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone durch Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmone mit Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmonöse Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmonöse Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlegmonöses Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlyktäne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlyktänenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phlyktänenbildung der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobie/Zwangsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobisch-neurotische Überlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobisch-vegetatives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobische Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobischer Zustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phobisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phokomelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phonologische Entwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosgen-Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphat-Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphat-Stau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphat-Urolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphatasemangel bei Rachitis [kodiere zusätzlich M90.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphatid-Thesaurismose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphatstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphoenolpyruvat-Carboxykinase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphofruktokinasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phosphornekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photoallergie mit Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photoallergische Reaktion durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photoallergisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photodermatitis durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photodermatitis durch andere als Sonnenstrahlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photodermatitis pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photodermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photoelektrische Keratokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photokeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photoretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensibilität der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensibilität der Haut durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensibilität der Haut durch andere als Sonnenstrahlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensitive Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Photosensitivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phototoxische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phototoxische Reaktion durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phrenikusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phrenische Ampulle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phrynodermie [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthiriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthiriasis des Augenlids [kodiere zusätzlich H03.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthiriasis pubis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthise des Augapfels durch Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthisis bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthisis bulbi oculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthisis dolorosa (Augapfel)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phthisis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phykomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phykomyzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phykomyzetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phyllodes Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phyllodes Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phylloides Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phylloides Fibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phylloidestumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phylloidestumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physalopteriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physikalische Therapie/Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z57'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physiologische Anisokorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physiologische fetale Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physiologische neonatale Gelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physische Überforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Physischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phytobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phytobezoar des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phytophotodermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phäochromoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phäochromozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phäohyphomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Phäomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pian',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pianom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pica bei Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pica-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pick-Demenz [kodiere zusätzlich F02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pick-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pick-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pickel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pickel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pickwick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pickwick-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Piedra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Piedra alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Piedra nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pierre-Robin-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pierson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pierson-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentationsanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentblattabhebung der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentblattdefekt der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentdegeneration der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentdegeneration der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentdegeneration des Pallidums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentdispersionsglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentepithelverschiebung der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentfleckenpolyposis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierte Irisdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierte Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierte Pallidumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierte vitelliforme Albipunctata-Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierter Becker-Haarnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierter Naevus pilosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierter Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentiertes Basaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentiertes Basalzellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentiertes Basalzellpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentiertes Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentiertes Schwannom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierung des Limbus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentierung durch Eisenablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentmal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentnävus und Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentstörung der Haut bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentverschiebung der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentzellnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pigmentzirrhose der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pikazismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilarzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pili anulati',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pili incarnati',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pili torti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pille danach',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pille danach/Postkoitale Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pillendrehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pillenikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pillenrezept (Kontrazeptivum)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilomatrixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidal-Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidalabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidalsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilonidalzyste/-fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzartige Geschwulst - s.a. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbefall der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbefall des Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbefall des Nagels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzbefall/Mykose der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzgrind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion der Leiste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion der Scheide [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion des Nagels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzinfektion des Sputums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzmyzetom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pilzsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pindborg-Tumor [Gutartiger kalzifizierender epithelialer odontogener Tumor]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pindborg-Tumor [Gutartiger kalzifizierender epithelialer odontogener Tumor] des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinealoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinealom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinealozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pineoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pineozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinguecula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pink disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinkus-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinselhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinselzellgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pinta-Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pintide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pipekolinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pipekolinämische Azidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pipkin-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Piroplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Piry-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pithiatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pithokoides Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pithokoides Becken mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis Hebra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis amiantacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis furfuracea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis lichenoides et varioliformis acuta (Mucha-Habermann)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis maculata et circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis nigra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis rosea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis rotunda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis seborrhoica capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis seborrhoica simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis simplex capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis varioliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pityriasis versicolor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pixuna-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta accreta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta adhaerens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta bipartita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta circumvallata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta fenestrata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta increta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta membranacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta multilobulata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta multipartita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta percreta mit postpartaler Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia marginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia marginalis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia marginalis mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia marginalis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia ohne Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia partialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta praevia totalis mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta succenturiata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta tripartita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placenta triplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Placentahämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plagiozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plakopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantare Hyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarer Fersensporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantares Frambösiepapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarfaszienkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarfasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plantarwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasma-Thromboplastin-Komponente-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasma-thromboplastin-antecedent-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasma-thromboplastin-component-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmahämosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmaproteinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmavolumenverringerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmazellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmazellsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmazelluläre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmazelluläres Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmazytoides Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmozytom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plasmozytäres Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plastische Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plateauphänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plateauphänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepitheldysplasie der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepitheliales Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepitheliales Epitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Unterlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom der Wangenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattenepithelkarzinom des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plattnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platybasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platyspondylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platz-/Riss-/Schnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platzangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platzbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Platzwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plaut-Vincent-Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazenta mit randständigem Nabelschnuransatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaabnormität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentadysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentafehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentafibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentagefäßvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentahämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentahämorrhagie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentainfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentainsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentakrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentanekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentarest nach Spontangeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentarest ohne Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentarest ohne Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaretention ohne Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentaretention ohne Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentastörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentatuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentavarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plazentom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleiochrome Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Adenom der Parotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Adenom der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Rhabdomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleomorphes Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plethora sanguinea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plethora vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraabszeß mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraamyloidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurabelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraempyem mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraerguß bei Grippe [Influenza], Influenzavirus nachgewiesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurafibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurahyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurahydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurahöhlenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurainfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurakalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurakalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurakarzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurakuppelschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuramesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraplaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraschwarte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraschwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurastauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurastein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurasynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuravernarbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuraverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis calcarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis calcificata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis exsudativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis mit Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis mit Verwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis purulenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis putrida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritis tuberculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuritische Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurobronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurodynie durch Coxsackieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuroperikardiale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuroperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuroperitoneale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pleurorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexiformes Angiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexiformes Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexiformes Neurofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexiformes Neurom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexusläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexusneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plexusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plica tonsillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plummer-Krankheit [Toxische Struma multinodosa]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plummer-Syndrom [Toxische Struma multinodosa]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plummer-Vinson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plummer-Vinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pluriendokrine Adenomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pluriglanduläre Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pluriglanduläres Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzliche idiopathische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzliche idiopathische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Exitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Herztod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Sehverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Tod unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Tod unbekannter Ursache bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Tod unbekannter Ursache im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzlicher Tod unbekannter Ursache während der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Plötzliches Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumatosis cystoides intestini',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumatosis peritonei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumo-lymphonodal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumocystis-Pneumonie [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumohydroperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumohydrothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumohämatothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumohämoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Aluminium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Asbest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Baumwollstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Bauxit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Beryllium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Diatomit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Glimmer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Kaolin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Kieselsäure a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Quarzstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch Silikate a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose durch anorganische Stäube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose mit Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumokoniose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumomediastinum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonia alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonia alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonia migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Askaridose [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Keuchhusten [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Nokardiose [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Pertussis [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Q-Fieber [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Schistosomiasis [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Spirochäteninfektion [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Toxoplasmose [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Tularämie [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie bei Typhus [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Amöben [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Aspiration von Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Eaton-Agens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Enterobacter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Fruchtwasseraspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Gonokokken [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Gonokokken [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Inhalation von Erbrochenem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Inhalation von Nahrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Kandidose [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Kryptokokken [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Mycoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch PPLO [Pleuropneumonia-like-organism]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Pleuropneumonia-like-organism',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Pneumocystis carinii [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Proteus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Salmonellen [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Serratia marcescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Spirochäten a.n.k. [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Spulwurm [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Toxoplasmen [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Yersinia pestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch Zytomegalieviren [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie durch anorganische Fasern a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonie nach medizinischen Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Allergie/Chemikalien/Staub/Dämpfe/Schimmel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Aspiration von Erbrochenem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Aspiration von Lipoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Aspiration von Nahrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Aspiration von Ölextrakten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonitis durch Toxoplasmose [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonomykose a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumonose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumopathie durch organischen Staub a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumoperikard beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumopleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumopyoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumopyothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumothorax durch Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumothorax durch eine operative Verletzung der Brustwand oder Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumothorax in der Perinatalperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumozystose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumozystosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pneumozystosis mit Pneumonie [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pockenfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Podagra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Podenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Podenzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Podopompholyx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilodermatomyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilodermia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilodermia atrophicans vascularis Jacobi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilodermia reticularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poikilozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poland-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poland-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polare bösartige Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polare gutartige Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polarer bösartiger Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polarer gutartiger Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalitis bei Grippe [Influenza] [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalitis haemorrhagica superior [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalitis inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalomyelitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polioenzephalomyelitis bei Beriberi [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis anterior acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis epidemica anterior acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis mit Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitis-Vakzination [IPV]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliomyelitisfolgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliosis der Augenbraue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poliosis der Wimpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Politische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Politische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polka-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pollakisurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pollenrhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pollinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyangiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyangiitis-Overlap-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarteritis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthritis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthritis chronica progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthritis enterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthritis rheumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthropathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthrose der Fingergelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyarthrose der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyartikuläre Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyartikuläre Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polychondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polycythaemia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polycythaemia primaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polycythaemia rubra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polycythaemia rubra vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polydaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polydipsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläre Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläre Dyskrasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläre Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglandulärer Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglanduläres Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglobulie durch Erythropoetin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyglobulie durch Hämokonzentration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyhydramnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polykarenzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyklonale Gammopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polykorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphe Beschwerden, wahrscheinlich nichtorganisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphe Kardiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphe Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorpher Lichtausschlag durch Sonnenbestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphes Gliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphes Spongioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphzelliges Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphzelliges Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphzelliges Rhabdomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymorphzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyalges Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyalgia arteriitica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyalgia arteriitica mit Riesenzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyalgia rheumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyositis mit Hautbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyositis ossificans generalisata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polymyositis ossificans progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritis bei Feer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritis bei Vitaminmangel a.n.k. [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritis cranialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritis gestationis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuritische alkoholische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathia cranialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Avitaminose a.n.k. [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Beriberi [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Diphtherie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Hypoglykämie [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Infektionskrankheit a.n.k. [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Kollagengefäßkrankheit a.n.k. [kodiere zusätzlich G63.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Kollagenose a.n.k. [kodiere zusätzlich G63.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Lepra [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Lyme-Krankheit [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Neubildung a.n.k. [kodiere zusätzlich G63.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Panarteriitis nodosa [kodiere zusätzlich G63.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Pellagra [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Porphyrie [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Stoffwechselkrankheit a.n.k. [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Systemkrankheit des Bindegewebes [kodiere zusätzlich G63.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Tuberkulose [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Urämie [kodiere zusätzlich G63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Vitamin-B-Mangel [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Vitamin-B12-Mangel [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Vitaminmangel a.n.k. [kodiere zusätzlich G63.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei Zoster [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei bösartigem Tumor a.n.k. [kodiere zusätzlich G63.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei chronischer Polyarthritis [kodiere zusätzlich G63.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei endokriner Krankheit a.n.k. [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei familiärer Amyloidose [kodiere zusätzlich G63.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei infektiöser Mononukleose [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei konnataler Spätsyphilis [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei konnataler Spätsyphilis [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei parasitärer Krankheit a.n.k. [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie bei systemischem Lupus erythematodes [kodiere zusätzlich G63.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Antitetanusserum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Arsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Drogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Organophosphate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Strahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch Triorthokresylphosphat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch ein Medikament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathie durch toxisches Agens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyneuropathisches Erythrödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyonychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyorchidie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyorchie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyostotische Jaffé-Lichtenstein-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyostotische fibröse Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der Pars prostatica der Urethra im Sinne der Harnröhrenkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der Pars prostatica der Urethra im Sinne einer Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der prostatische Harnröhre im Sinne der Harnröhrenkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der prostatischen Harnröhre im Sinne einer Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Antrum pyloricum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Colliculus seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Harnblasensphinkterbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyp des weiblichen Genitaltraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypapillomatöse Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypen des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypen des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyploidie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypoide Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypoide Sinusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypoides Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis der Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis des Sinus ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis des Sinus maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis des Sinus sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyposis nasi et sinuum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypöse Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypöse Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypöse Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polypöses adenoides Gewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyradikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyradikuloneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polysklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polysplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polythelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polythelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie einschließlich Morphintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie einschließlich Morphintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie ohne Morphintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytoxikomanie ohne Morphintyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polytrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyvesikulärer Dottersacktumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyvesikulärer Dottersacktumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyvesikulärer Vitellustumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyvesikulärer Vitellustumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Niere vom Erwachsenentyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Niere vom infantilen Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Nierendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystische Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Polyzystisches-Ovar-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pompe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pompe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pompholyx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poncet-Krankheit [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pontiac-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pontine Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pontines Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poplitealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poplitealarterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Popliteale Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poplitealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poradenitis inguinalis sive venerea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poradenitis inguinalis sive venerea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porak-Durante-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porenzephalische Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porokeratosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porokeratosis Mibelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porozephalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyria hepatocutanea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyria variegata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrinkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porphyrinurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porrigo favosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portale Hypertension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portale Hypertonie bei Schistosomiasis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portale Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portio-uteri-Malignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiofibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiopolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiotransformationszone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portioulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portiozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portokavale Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portwein-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Portweinflecken [Naevus flammeus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Porzellangallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positive Serumreaktion auf Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positive Serumreaktion auf Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positive Vertikaldivergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positive Wassermann-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positive Wassermann-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver Anti-E-Titer bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver HIV-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver Haemoccult-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver VDRL-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver VDRL-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver serologischer Befund auf Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positiver serologischer Befund auf Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Positives Hepatitisantigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posner-Schlossmann-Syndrom [Zyklitisches Glaukom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Post-Pill-Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Post-zoster Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postablative testikuläre Unterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postablatives Nachlassen der ovarialen Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postantibiotische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postantibiotischer Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postartifizielles Menopausensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postaurikuläre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postbranchiale Getzowa-Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postcholezystektomiebeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postcholezystektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postdiskektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postduktale Aortenisthmusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postduktale Aortenkoarktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postduktale Coarctatio aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postdysenterische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postdysenterisches Syndrom [Reiter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postenteritische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postenteritische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postentzündliche Irishämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postentzündliche Narbe der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postenzephalitischer Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postepileptische Todd-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteriore Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteriore linguale Okklusion der Unterkieferzähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteriorer Faszikelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteriorer offener Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteriores Staphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posteruptive Farbänderung der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postexpositionelle Simultanimpfung gegen Hepatitis B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postexpositionelle Simultanimpfung gegen Tetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postexpositionelle Simultanimpfung gegen Tollwut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgastrektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Spermatozystitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Spermatozystitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoische Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoisches Genitalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoisches Urethrareizsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoisches Urethrareizsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postgonorrhoisches Urogenitalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posthemiplegische Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posthepatitische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postherpetische Neuralgie a.n.k. [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postherpetische Neuritis [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postherpetische Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postherpetische Trigeminusneuralgie [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posthypoglykämische Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posthämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postiktale Todd-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postikuslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postikusparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiös Urethraleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Ablatio chorioideae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Alopezie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Arthropathie a.n.k. [kodiere zusätzlich M03.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Arthropathie bei Virushepatitis a.n.k. [kodiere zusätzlich M03.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Bandscheibenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Bandscheibenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Darmobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Enzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Enzephalomyelitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Gingivaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Harnblasenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Hodendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Hypotrichose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Irishämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Knorpelkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Kontraktur der ureterovesikalen Öffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Kontraktur des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Lateroversion des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Leukenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Leukoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Lungenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Lymphangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Lymphknotenkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Myelitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Neuromyasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Pneumonie a.n.k. [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Polyradikuloneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Retinaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Ureterleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöse Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöser Hypothyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinfektiöses Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postinflammatorische Hyperpigmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkanalikuläre Tränenwegstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postklimakterische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkoitale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkoitale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkoitale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkoitale Kontaktblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkoitale vaginale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkommissurotomie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkommotioenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkommotionelle Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkommotionelles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkontusionelle Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postkontusionelles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postlaminektomiesyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postlaryngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postleukotomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmastektomie-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmastektomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmastoidektomie-Komplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Osteoporose mit pathologischer Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausale Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausen-Endometrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausenkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenopausensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmenstruelle Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmyokardinfarktsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postmyokardinfarktsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnarkotische Ateminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnasale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnasaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnatale Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnatale Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnatale Zahnschmelzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnatale infantile Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnatales Screening auf Chromosomenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnekrotische Leberzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnekrotische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postnukleotomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Augenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Bauchfellverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Dehiszenz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Gelenksteife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Gingivaretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Glaskörperblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Harnröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Hypoinsulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Iriseinklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Komplikation der Harnorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Kontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Lungenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Lungeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Nachbehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Narbe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Ohrenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Resorptionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Streßinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Vaginaladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Wundheilungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Wundruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Zervixnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative infektiöse Wundheilungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperative Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Hypothyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Insulinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Irispigmentdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Prolaps von Scheidengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Schädeldefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer Vorfall von Scheidengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperativer kardiovaskulärer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Fieber durch Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Nahtgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Sekundärglaukom durch intraokular verbliebene Substanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Serom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postoperatives zystoides Makulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Afibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Betreuung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Betreuung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Blutungsneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Eklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Fibrinolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Galaktophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Gerinnungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Hypophysennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Infektion der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Infektion der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Infektion des Harntraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Inversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Inversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Lateroversion des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Lazeration der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Mamillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Nachblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Narbe der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Neuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Phlegmasia alba dolens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Thrombose einer Beckenvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Untersuchung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Untersuchung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Zervixnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale Zystopyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartale tiefe Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Abszeß der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Narkosetod a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Panhypopituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Tetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Zustandsbefund a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler Zustandsbefund a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartaler plötzlicher Tod unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartales Effluvium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartales Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartales Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpartales Mendelson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpharyngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postphlebitisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpneumonische Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postpylorische Duodenumerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postrenales Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postrenales akutes Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poststreptokokken-Glomerulonephritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Poststreptokokken-Nephritis a.n.k',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postthrombotisches Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Arthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Belastungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Belastungsstörung [PTBS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Hodenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Hodenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Hodenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Lungeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Mydriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Narbe der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Narbe des hinteren Pols der Macula lutea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Optikusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Polyarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Schiefnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Spondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische Wundinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische parakondyläre Femurossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische subperiostale Ossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatische vordere Synechie mit Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatischer Hydrozephalus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatisches Pneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatisches Psychosyndrom nichtpsychotischer Ausprägung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatisches Sekundärglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatisches Strabismus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttraumatisches Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Posttyphoider Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvagotomiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvakzinale Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvakzinale Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvakzinale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvakzinale Leukoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvakzinale Pyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvalvulotomie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvirale Enzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvirales Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Postvirales Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potatorium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potenzverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott''sche Fraktur (komplizierter Schenkelhalsbruch)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Buckel [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Geschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Gibbus [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Krankheit [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Lähmung [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Paraplegie [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pott-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potter-Fazies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Potter-Sequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Powassan-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prader-Willi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pragmatagnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preiser-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preiser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Darmbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Interskapulargegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Interskapulargegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Interskapulargegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kleinzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kleinzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kleinzehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kostalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kostalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kostalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Kreuzbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Lendengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Lumbalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Periokularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Regio scapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Regio scapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Regio scapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Sakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Sternalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Sternalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Sternalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Supraklavikulargrube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Supraklavikulargrube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Supraklavikulargrube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der äußeren Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung der äußeren Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Epigastriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Musculus quadriceps femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Musculus quadriceps femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Musculus quadriceps femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Orbitabindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Pars cervicalis der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Pars cervicalis der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Pars cervicalis der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Periokularbezirks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Präputiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Präputiums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des Testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prellung/Kontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Presbykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Presbyophrene Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Presbyophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Presbyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preßluftbohrer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preßluftbohrer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preßlufthammer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Preßlufthammer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Priapismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prickeln der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primitives polares Spongioblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primordiale Kieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primordiale odontogene Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär chronisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär degenerative Demenz vom Alzheimer-Typ mit präsenilem Beginn [kodiere zusätzlich F00.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär degenerative Demenz vom Alzheimer-Typ mit senilem Beginn [kodiere zusätzlich F00.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär idiopathische Hämochromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinabhängiger Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinpflichtiger Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär insulinpflichtiger Diabetes mellitus mit mehreren Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär lichenoide Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär membranöse Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär obstruktiver Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär obstruktiver Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär progrediente Aphasie [PPA] [kodiere zusätzlich F02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär refluxiver Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär refluxiver Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär schmerzhafte Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär tuberkulöses Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär-chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär-chronische Polyarthropathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primär-progressive Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäraffekt bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäraffekt bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäraffekt bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäraffekt bei Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäraffekt bei Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Aknitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Amyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Amöben-Meningoenzephalitis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Arthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Blastomykose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Erythrothermalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Granulozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hyperchylomikronämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hyperoxalurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hypersomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Hypomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Karzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Kryoglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Lateralsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Lebervenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Lungenpest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Makroglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Myoglobinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Myoglobulinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Papeln bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Papeln bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Parkinson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Pestpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Pneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Polyarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Steatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Syphilis der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Syphilis der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Tuberculosis indurativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Tuberkulose der Subkutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Tuberkulose des Unterhautgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre beidseitige Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre bösartige Neubildung der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre cholangiolitische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre cholangitische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre cholestatische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre degenerative Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre familiäre Hyperurikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre generalisierte Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre hereditäre Hornhautamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre idiopathische Hypoventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre isolierte aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre papulonekrotische Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre splenogene Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre splenogene Panhämozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre splenogene Panzytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tubare Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Entzündung des Unterhautzellgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Lichen scrofulosorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Paronychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Verruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Verruca necrogenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre tuberkulöse Zellgewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre weibliche Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäre ziliare Dyskinesie [PCD] [Angeborene bronchiale Ziliendyskinesie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Aldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Aldosteronismus durch Nebennierenrindenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Aldosteronismus durch beidseitige Nebennierenrindenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Blepharospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Hydroureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Hypoadrenalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Hypoadrenokortizismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Leberkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Megaureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer Schanker bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer ovarialer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer syphilitischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer syphilitischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärer testikulärer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Cholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Karzinom der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Magenlymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Nachlassen der ovarialen Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Offenwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Ovarialversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Skrofuloderm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Winkelblockglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres Xanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres juveniles Cholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres lichenoides Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres progressives kokzidioidales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primäres tuberkulöses Ulkus der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärläsion bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärläsion bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärmedaillon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Primärtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pringle-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pringle-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prinzmetal-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prionen-Krankheit des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prionen-Krankheit des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Privinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem Kenntnisse zu erwerben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei Haushalts- und Wohnverhältnissen, die die Versorgung beeinflussen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei Haushalts- und Wohnverhältnissen, die die Versorgung beeinflussen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei Haushalts- und Wohnverhältnissen, die die Versorgung beeinflussen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei Haushalts- und Wohnverhältnissen, die die Versorgung beeinflussen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Berufswahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Berufswahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensbewältigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensführung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem bei der Lebensführung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem beim Gehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem beim Tragen einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch Apparat, Implantat oder Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch Intubation bei Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch Kindersorgerechts- oder Unterhaltsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch Kindersorgerechts- oder Unterhaltsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch Kindersorgerechts- oder Unterhaltsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch angsterregende Erlebnisse in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein Pflegekind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch ein adoptiertes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch negative Kindheitserlebnisse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem durch unangebrachten elterlichen Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem eines Kindes mit einem neuen Elternteil',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem eines Kindes wegen Geburt eines Geschwisters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem eines Kindes wegen Kindesmißhandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem im engeren Familienkreis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Alkoholismus in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Ehepartner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Einfluß auf den Gesundheitsstatus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Gefängnisstrafe oder Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Gefängnisstrafe oder Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Gefängnisstrafe oder Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Lese-Schreib-Vermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Sozialleistungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Studium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Zwangsvollstreckung einer Darlehensschuld',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Zwangsvollstreckung einer Darlehensschuld',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Zwangsvollstreckung einer Darlehensschuld',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit Zwangsvollstreckung einer Darlehensschuld',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Geruchssinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Geschmackssinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Gläubiger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Gläubiger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Gläubiger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Gläubiger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Harnsystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Kauvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit dem Sehvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Arbeitsbedingungen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Arbeitsbedingungen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Wohnverhältnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Wohnverhältnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Wohnverhältnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit den Wohnverhältnissen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Bezugsperson im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Erziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Gesundheitsversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Gesundheitsversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Hochschulausbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Kaubewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Kindererziehung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der Unterkunft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der kulturellen Eingewöhnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der kulturellen Eingewöhnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit der persönlichen Hygiene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einem Bewährungshelfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einem Bewährungshelfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einem Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einem Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einer Beratungsperson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit einer Beratungsperson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit inadäquatem bildungsbezogenen Unterricht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit kommunaler Umwelt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit kommunaler Umwelt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem mit nicht bestandenen Prüfungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Arbeitslosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Arbeitslosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Multiparität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Pensionierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Pensionierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Verurteilung in Rechtsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Verurteilung in Rechtsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen Verurteilung in Rechtsverfahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen atypischer Familiensituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen atypischer Familiensituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen des Todes eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen elterlicher Überprotektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen sozialen Umfeldes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen sozialen Umfeldes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem wegen unerwünschter Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem, weil alleinlebend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Problem, weil alleinlebend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme beim Füttern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Arbeitslosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Compliance/Kranksein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Erkrankung Elternteil/Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Erkrankung des Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Erkrankung des Partners',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Ernährung/Wasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Gewalttätigkeit/Übergriffen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Schwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Verlust/Tod Elternteil/Familienmitglied',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Verlust/Tod des Partners',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Verlust/Tod des Partners',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit Zahnersatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit dem Eßverhalten von Kindern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit dem Gesundheitssystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme mit der Arbeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme wegen Brille, die Struktur, Funktion oder Empfinden des Auges beeinflusst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme wegen Kontaktlinse, die Struktur, Funktion oder Empfinden des Auges beeinflusst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Probleme wegen diagnostischer/therapeutischer Bestrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Procidentia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Procidentia uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proctalgia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proctalgia fugax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proctalgia fugax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prodromale Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progerie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progesteron-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progonom - s. Neubildung, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progredient-chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progrediente Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progrediente Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progrediente Glomerulonephritis mit Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progrediente posthämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Bulbärparalyse im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Irisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Linsenkerndegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Myoklonusepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Myopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Pigmentdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Rückenmarksklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive bulbäre Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive diaphysäre Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive isolierte Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive kortikale Gehirndegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive lentikuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive multifokale Leukoenzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive myopische Chorioretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive polyglanduläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive psychische tabische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive psychische tabische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive septische Granulomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive spinale Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive stroke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive supranukleäre Ophthalmoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive syphilitische Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive systemische Sklerose mit Calcinosis cutis, Raynaud-Phänomen, Ösophagusdysfunktion, Sklerodaktylie und Teleangiektasie [CREST-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive zerebrale Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressive äußere Ophthalmoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressiver Torsionsspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressives Lentikulärsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Progressives rezidivierendes Dermatofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Herpesviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Herpesviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktoparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktosigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proktozele beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolabierte Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolabierte innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolabierte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaktinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der Zwischenwirbelscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der Zwischenwirbelscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der hinteren Scheidenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der vorderen Scheidenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps des weiblichen Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps einer Augenprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps fetaler Gliedmaßen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolaps von Gebärmutter und Scheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolapsus genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolapsus partialis uteri et vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolapsus vaginae et uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolapsus vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferative Retinopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferative Sichelzellenretinopathie [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferative Vitreoretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferative Vitreoretinopathie mit Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proliferierender Brenner-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolongiertes reversibles ischämisches neurologisches Defizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prolymphozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Promiskuität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Promyelozytenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Promyelozytenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Antibiotikagabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Chemotherapeutikagabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Chemotherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Immunglobulingabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Immuntherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Operation wegen Neoplasmas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Organentfernung wegen Neoplasiebehandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Untersuchung auf Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaktische Verabreichung von Gammaglobulinen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prophylaxe von Karies und Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Propionatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Propionazidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proptosis des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prosopalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prosopalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prosopodiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prosopoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenom Stadium I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenom Stadium II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenom Stadium III',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataadenomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatabeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatabeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatabettentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatadilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatafibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatageschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatagonorrhoe [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatagonorrhoe [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatagranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatahöcker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatainduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatainfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakapselinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakaverne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakongestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatalappenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatalappeninduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatalithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatamalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatamegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatamyoadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatamyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataneoplasma-Rezidiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatapapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatarandblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatarhabdomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataseitenlappentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatastörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatastörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatasymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatatuberkulose [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatavarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatavergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostataverschluß durch Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatawandblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatische Via falsa der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Enterokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Gonokokken [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Gonokokken [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Herpesviren [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Herpesviren [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Mykoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Trichomonaden [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Trichomonaden [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Trichomonas vaginalis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Trichomonas vaginalis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis durch Zytomegalieviren [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis mit Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatitis/Samenblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatovesikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prostatozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protanopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protein-Erythrozyturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protein-Kalorie-Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protein-Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinintoleranz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinmangel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinmangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteintransportanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinurie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinurie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proteinurie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prothrombinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protoplasmatisches Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protozoen-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protozoen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protozoeninfektion der Lunge (ohne Pneumonie)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protozoonose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahiert verlaufende Austreibungsperiode beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahiert verlaufende Austreibungsperiode beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt beim 2. Zwilling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt nach Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Geburt nach Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierte Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahierter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahiertes Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrahiertes primäres Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrusio bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Protrusionskoxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Provitamin-D-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proximal femoral focal deficiency',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proximale Oberarmfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proximale Radiusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Proximale Ulnafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prune-belly-Syndrom [Bauchdeckenaplasie-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruriginöse Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruriginöse Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruriginöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo Hebra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo aestivalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo chronica Hebra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo ferox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo gestationis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo mitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo multiformis chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo nodularis Hyde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prurigo simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus analis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus anogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus aurium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus capillitii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus generalisatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus sine materia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus universalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pruritus vulvae et ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prä-AIDS [Erworbenes Immundefektsyndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präapoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präarthrose der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präarthrose des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präaurikularanhänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präaurikuläre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präaurikuläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präaurikulärer Sinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präbetalipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prädelir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prädescemet-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prädiabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prädiabetes bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präduktale Aortenisthmusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präduktale Aortenkoarktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präduktale Coarctatio aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklampsie bei schon früher bestehender Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklampsie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklampsie mit Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklamptische Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklamptische Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklamptische Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präeklamptische Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präexzitationssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präinfarkt-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präinfarktsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkalizielle Tubuloektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkanzerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkanzerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkanzerose der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkanzeröse Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklimakterische Blutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklimakterische Hypermenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklimakterische Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklimakterische Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präklinische Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkordiales Reiben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkordialschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkordialschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präkoxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präleukämiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präleukämisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prälungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämaturität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämaturität mit weniger als 28 vollendeten Wochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenopausale Menorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenopausale Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenopausenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenopausensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle Schmierblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle Spannungserscheinung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle neurovegetative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelle psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelles Spannungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämenstruelles Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prämolarisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Asphyxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Chromosomenanalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Chromosomendiagnostik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Fruchtwasseruntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Vorsorge während normaler Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Vorsorgeuntersuchung bei normal verlaufender Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Zahnschmelzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale gonorrhoische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale gonorrhoische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatale Überwachung einer normalen Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening auf Chromosomenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening auf Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening auf Fehlbildung mittels Ultraschall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening auf fetale Wachstumsretardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pränatales Screening mittels Amniozentese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präoperativer Konflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpartale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpartale Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpartale Verbrauchskoagulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpartale oberflächliche Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpatellarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpathologischer Mammographiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpsychotische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präpubertärer Panhypopituitarismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputialblattverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputialschürze der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputialschürze des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputialverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputialverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumtuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präputiumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prärenale Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prärenales Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prärenales akutes Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präretinale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Demenz bei Morbus Alzheimer [kodiere zusätzlich F00.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Demenz vom Alzheimertyp [kodiere zusätzlich F00.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Form der Alzheimer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Korneamelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenile Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präsenilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präspondylolisthesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präterminale Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prätibiales Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prätibiales Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präurämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prävarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfung/Medikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präventive Impfungen/Medikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A44'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prävesikale Abflußbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prävesikale Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prävesikaler Harnleiterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prävesikaler Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präzerebrale Arterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präzerebrale Arterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Präzerebraler Arterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Prüfungsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psammom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psammöses Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psellismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudarthrose nach Arthrodese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudarthrose nach Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Biermer-Anämie des Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Biermer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Fröhlich-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Hurler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Hurler-Polydystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Turner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-Ullrich-Turner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudo-obliquus-superior-Parese des Auges [Brown-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoamenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoappendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudobulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocholesteatom des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocholesteatom des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocholinesterasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudochromhidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocirrhosis hepatis pericardiaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocoarctatio aortae [Kinking]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudocroup',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudodivertikel der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudodivertikel der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudodivertikel der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudodivertikel der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoencephalitis acuta haemorrhagica superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoencephalitis haemorrhagica superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoenophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoerysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoexfoliatio lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoexfoliation der Linsenkapsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoexfoliationsglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoexophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoforamen maculae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudogicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudogicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudogravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus femininus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus femininus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus masculinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohermaphroditismus masculinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohypertrophie des Musculus gastrocnemius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohypertrophische Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohypertrophische Muskelparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohypertrophische Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohypokaliämiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohämophilie Typ B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohämophilie vom Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudohämorrhagische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoinflammatorische Sorsby-Fovea-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudokoxitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudokrupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudokuhpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudokyesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoleukämisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoleukämisches Sarkom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudolobärpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudolymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Trigonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomembranöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomenstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomenstruation beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomonas-Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomuskuläre Hypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomuzinöse Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomuzinöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomuzinöses Zystadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomuzinöses Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomyasthenisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomyotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomyxoma peritonei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudomyxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoneurasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoneurasthenisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoneurotische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoobstruktionsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopapillenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopapillom der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopapillomatöse Urothelveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopapillomatöse Urothelwucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopapillomatöse Veränderung der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopelade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoperitonealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoperniziöse Anämie des Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudophakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopolyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopolyposis coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopolyzythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopsychopathische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopterygium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoptosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopubertas interrenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudopubertas praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoradikuläres Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoretardierte Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudorotz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudorubella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudorubeola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudosarcomatosis haemorrhagica pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudosarkomatöse Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudosklerem beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudostauungspapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotrichinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotruncus arteriosus communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotuberculosis enterocolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotuberkulosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotuberkulöse Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotumor cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotumor der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudotumor der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudovariola [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudovitamin-D-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudoxanthoma elasticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pseudozyste der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psilosis linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psilosis, nicht durch Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psittakose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psittakose mit Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psittakose-Pneumonie [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoastendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasiformer Windelausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis anularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis arthropathica [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis capillitii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis corporis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis der Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis des behaarten Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis flexurarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis geographica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis gyrata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis inversa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis nummularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis palmoplantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis pustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis serpiginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis vulgaris exsudativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasis-Arthropathie [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasisarthritis (auch als S91 kodieren)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasisarthritis [kodiere zusätzlich M07.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriasisähnliche Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriatiformes Bild',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriatische Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psoriatische Balanoposthitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychasthenische Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychasthenische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrische Untersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrisches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychiatrisches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Faktoren, die körperliche Störungen bewirken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Krankheiten in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Lernstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Störung a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Störung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Störung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychische Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Ausnahmezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Restschaden in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychischer Streß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Borderline-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Borderline-Syndrom bei Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Lallen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Lispeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Problem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Problem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychisches Trauma a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psycho-Syndrom im Climacterium virile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psycho-neurovegetative Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psycho-sexuelle Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoanalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychobiologischer Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychodynamische Therapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Anaesthesia sexualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Anorexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Anorgasmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Aphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Aphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Arthralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Arthrodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Asthenopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Belastungsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Blutsystemstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Colitis mucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Colitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Depression als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dysbasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dysphagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Enkopresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Enuresis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Erregung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Eßattacken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Freßsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Gastralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Geruchstäuschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Hautreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Hypersomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Insomnie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Lymphsystemstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Mastalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Mastodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Metrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Miktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Myalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Nykturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Orientierungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Parageusie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Parorexie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Parosmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Polyarthralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Potenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Prostatareizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Reaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Reaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Restharnretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Rumination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Schlaflosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Schlafumkehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Sexualfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Sexualschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Sexualstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Sinnesorganstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Sterilität bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Störung der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Störung des Bewegungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Störung endokrines System',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Tetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Umkehr des 24-Stunden-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Umkehr des Nacht-Tag-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Umkehr des Schlafrhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Umkehr des zirkadianen Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Urogenitalstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene Wirbelsäulenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene depressive Psychose als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene endokrine Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene körperliche Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene mukomembranöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogene paranoide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Appetitverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Dämmerzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Erregungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Prurigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Pruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Präkordialschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Rheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Rückenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Schiefhals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Sprachfehler beim Kind a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Sprachfehler beim Kind a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Sprachfehler beim Kind a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Vaginismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogener Vomitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Beard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Lidzucken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Magenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Stammeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Stottern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychogenes Zähneknirschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoinfantile Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psycholabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychologische Störung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychologische Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Aktivität mit katatonen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Störung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorische Unruhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorisches Anfallsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychomotorisches Defizit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychonervöse Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychonervöse Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Angst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Persönlichkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoneurotischer Angstzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoorganisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychopathische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychophysiologische Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychophysiologische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoreaktive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychoreaktives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose bei Hirntumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose bei Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose bei Krampfleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose bei organischer Hirnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose durch Drogenintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose durch Drogenintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose durch endokrine Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose unbekannter Ätiologie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychose, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosensorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosexuelle Identitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosexuelle Identitätsstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Potenzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Potenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Stigmatisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatische gynäkologische Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatischer Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosomatogene Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziale Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziale Wirkung des Arbeitsplatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziale Wirkung des Arbeitsplatzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosozialer Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosozialer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosozialer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziales Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziales Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosoziales Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychosyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Depression als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Cannabinoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Halluzinogenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Opioiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotische Störung nach Gebrauch von Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychotisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Fehlsteuerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Imbalance',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Labilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Prostatabeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetative Störung in der Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetativer Erregungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetativer Unruhezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetatives Prostatasyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Psychovegetatives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygium colli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygium der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygium des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygiumrezidiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygiumsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pterygomandibulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptilosis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptosis bei Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptosis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptosis mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptosis mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptyalismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ptyalismus gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertas praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertas tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsfettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätskrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmagersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmammahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmammahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsmenorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pubertätsverhalten Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperaldepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Anämie durch Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Galaktophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Infektion der Dammnaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Infektion der Episiotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Infektion der Schnittentbindungswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Infektion einer geburtshilflichen Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Lungenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Mamillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Milchfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Pelviperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Subinvolutio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Subinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Uterushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale interstitielle Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperale oberflächliche Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalendometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperaler Brustdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperaler Mammaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperaler Narkosetod a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperaler Wahnsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperales Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperales Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperales Mendelson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalphlebopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Puerperalthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonal-',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienarrosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienthromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienthromboembolie mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienthrombose mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalarterienverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Adenomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Amyloidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Aspergillose a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Blastomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Distomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Distomiase [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Dysmaturität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Eosinophilie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Geburtskomplikation durch Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Gefäßstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Gefäßstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Hepatisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Herzkrankheit bei Schistosomiasis [kodiere zusätzlich I52.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Hypostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Infundibulumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Kandidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Kokzidioidomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Kryptokokkose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Mukormykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Parakokzidioidomykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Schistosomiasis a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Sklerodermie [kodiere zusätzlich J99.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Sporotrichose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Spätsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Spätsyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Stase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Thromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Thromboembolie mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Thrombose mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Toxoplasmose [kodiere zusätzlich J17.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale arterielle Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale idiopathisch Hämosiderose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonale idiopathische Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonaler Bluthochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonaler Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonaler Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonaler Kollaps durch Anästhesie bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonales Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonales Blastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonales Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalgefäßverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenregurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalklappenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalvenenthromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalvenenthromboembolie mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonalvenenthrombose mit Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonarvenen-/arterieninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmonarödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulmoperitoneale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpaamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpagangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpahyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpakalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpakrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpasiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpastein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulpaverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulseless disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsierender Exophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsionsdivertikel der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsionsdivertikel des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsus alternans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsus bigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pulsus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Punchdrunk-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Punktblutung als diabetische Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Punktblutung als diabetische Augenkomplikation bei Typ-I-Diabetes mellitus [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Punktblutung als diabetische Augenkomplikation bei Typ-II-Diabetes mellitus [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillarmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillarsaumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillarsaumdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillarsaumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillendifferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenentrundung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenmyotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenokklusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupillotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pupilläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pure red cell aplasia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purinnukleosid-Phosphorylase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura Schoenlein-Henoch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura anularis teleangiectodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura bei Skorbut [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura durch idiopathische Kapillarbrüchigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura fulminans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura haemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura kryoglobulinaemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura mit viszeralen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura nervosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura pigmentosa progressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura rheumatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura scorbutica [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura symptomatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura thrombasthenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura variolosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purpura/Gerinnungsstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Augeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Chondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Gonorrhoe der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Gonorrhoe der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Purulente Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustula maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulosis herpetica infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulosis palmaris et plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulosis palmoplantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulosis subcornealis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulosis varioliformis acuta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulöse Follikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulöse Nephrozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulöses Bakterid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulöses Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pustulöses Vulvaekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Putride Lochien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Putride Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Putrider Miliarabszeß der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyarthros',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelitis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelitis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis bei Syphilis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis bei Syphilis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritis/Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephritische Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephrose bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelonephrose mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyeloureteritis cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelozystitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyelozystitis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pygopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyknodysostose-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyknolepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyle-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylephlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylephlebitischer Leberabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylethrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorospasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorospasmus beim Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusachalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyloruskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyloruskonstriktion im Säuglingsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyloruskontraktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyloruskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pylorusverschluß beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermatitis vegetans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermia vegetans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyodermie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Hautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogene Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogenes Granulom der Gingiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyogenes Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyohydronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyokolpos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyonephritis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyoophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyoperikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyopneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyopneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyopneumothorax mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyorrhoea alveolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyoseptikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyotympanon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyoureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyovesica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyozele des Processus mastoideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyramideneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie durch Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrexie unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrgozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxalmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxinmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxinsensible Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyridoxinsensible sideroachrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrimidinmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrimidinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyroglobulinämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyromanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyruvat-Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyruvatcarboxylasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyruvatdehydrogenasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyämische Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pyämische Embolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Pädatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Päderastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Q-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'QT-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quaddelausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quaddelfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quaddeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quaddelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadrantenanopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadrantenanopsie des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadrantenhemianopsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadrantensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadrikuspidale Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadriplegie - s.a. Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quadriplegische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Qualitativer Thrombozytendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quaranfil-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quartalssäufer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quartana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quarzlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quecksilber-Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queensland-Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queenslandfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queenslandzeckenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querbarre des Harnblasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queres Vaginalseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querkolonkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querlage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querlage vor den Wehen mit Schädigung des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittmyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittverletzung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittverletzung in Höhe des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querschnittverletzung in Höhe des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querulantenwahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querulatorische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querulatorische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Querverengtes Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Query-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der Skapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der äußeren männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der äußeren männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der äußeren weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung der äußeren weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung des unteren Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung im Sinne von Crush',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung im Sinne von Crush',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung innerer Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung innerer Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschung mit Hauteinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschwunde beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quetschwunde beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queyrat-Erythroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queyrat-Erythroplasie des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Queyrat-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quincke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quincke-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Quintus-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'RDS [Respiratory distress syndrome] beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'RIVA [Ramus intraventricularis anterior]-Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'RR [Riva-Rocci]-Blutdruckwert-Erhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'RSB [Rechtsschenkelblock]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rabies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenaussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenbräune',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachendachhypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachendachhypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenentzündung durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenhypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenhypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenhöhlengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenhöhlengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Racheninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Racheninfektion durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenlepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmandelwucherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenringkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenringkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachensepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenwandzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachischisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachischisis mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis bei Skorbut [kodiere zusätzlich M90.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis bei Zöliakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis der Brustwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitis tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische Deformität der Wirbelsäule als Spätfolge [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische Hühnerbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische Kielbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische O-Beinstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitische Skoliose als Spätfolge [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitisches Becken als Spätfolge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitisches Genu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rachitisprophylaxe durch Vitamin-D-Gabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiale Epikondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiale Klumphand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radialisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radialisneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenprolaps [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenprolaps [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenruptur [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenruptur [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenverlagerung [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulitis durch Bandscheibenverlagerung [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikulomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikuloneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radikuläre Zahnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiodermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiogene Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiohumerale Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiologische Untersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radionekrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiotherapiesitzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radioulnararthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radioulnare Agenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radioulnare Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radioulnare Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiumblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiumschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusdeflexion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusfraktur loco typico',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusfraktur mit Ulnafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusgrünholzfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiuskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusköpfchenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusköpfchenluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiussarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Radiusverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raillietiniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ramsay-Hunt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ramsay-Hunt-Syndrom [Dyssynergia cerebellaris myoclonica]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Randkeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Randsinusblutung der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Randsinusblutung der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rankenangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ranula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid cycler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid-progressive Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid-progressive Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid-progressives nephritisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid-progressives nephritisches Syndrom mit fokaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rapid-progressives nephritisches Syndrom mit segmentaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasche Austreibungsphase bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasche Austreibungsphase bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raserei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasmussen-Aneurysma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasselgeräusch über der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasselgeräusch über der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasselgeräusch über der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rasselgeräusch über der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rassische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rassische Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rastlosigkeit NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rathbun-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenbiß-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenbiß-Fieber durch Streptobazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenbiß-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenbiß-Krankheit durch Spirillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenbiß-Krankheit durch Streptobazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rattenfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raucher-Leukokeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raucherbein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raucherentwöhnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauchergaumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raucherhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raucherpharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauchintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauchvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung des Nierenpol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung im Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung im Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung im Blasenbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raumforderung in der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raupenhaar-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rausch durch eine psychotrope Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rausch durch eine psychotrope Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauschgiftentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rauschgiftentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raynaud Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raynaud-Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raynaud-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Raynaud-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Re-Sectio caesarea a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Re-Sectio caesarea a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reactive airways dysfunction syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion auf Insektenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion auf LSD',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion bei Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion bei schwerer Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion nach Lumbalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion nach Rückenmarkpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion nach Spinalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktion nach zerebrospinalem Flüssigkeitsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktiv-depressives Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Atemwegserkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Atemwegskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Bindungsstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Bindungsstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Dorsolumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Erregung durch emotionalen Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Erregung durch seelisches Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Konversionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Melancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Situationspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive Verwirrtheit durch emotionale Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive depressive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive depressive Psychose als Einzelepisode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive depressive Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive lymphoide Bindehautinfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktive psychische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktiver Angstzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktiver Erregungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reaktiver psychotischer Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reanimationsfolgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechter Doppelausstromventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtliche Probleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechts-hemisphärische organische affektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtschreib-Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtschreib-Störung bei einer Lesestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsherzversagen als Folge einer Linksherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe BWS-LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe BWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe HWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe Kyphoskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtskonvexe Thorakalskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsschenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rechtsseitiger Faszikelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Recklinghausen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Recruitment',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rectosigmoiditis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduktion der Spermatogenese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduktionsdefekt der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduktionsdefekt der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierte Nierenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierte Spermienmobilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierter Allgemeinzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierter Allgemeinzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierter Ernährungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduzierter Harnfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduziertes Eßverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduziertes Konzentrationsvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduziertes Konzentrationsvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reduziertes Konzentrationsvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflektorische Pupillenstarre [Argyll-Robertson-Phänomen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflektorische Pupillenstarre [Argyll-Robertson-Phänomen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflektorischer Diaphragmaspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflektorischer Fließschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflektorischer Vaginismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflex-Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexdyspepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexgastrospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexkardiospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexpylorospasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexspasmus des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflexstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reflux im Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxiver Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxiver Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxnephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxpyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refluxösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktionsamblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktionsanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktionsfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refraktäre hypoproliferative Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Refsum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelmäßige intermenstruelle Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelmäßige intermenstruelle Schmierblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regeltempostörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regelwidrige Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regenbogenhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regenbogenhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regenbogenhautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regionale Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regionale Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regionale Odontodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regionale nichtbakterielle Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regressiver Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regressives bösartiges Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regulativer Hyperparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regulierung der Menstruation (zur Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regulierung der Menstruation (zur Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regurgitation durch die Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regurgitation von Mageninhalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regurgitation von Mageninhalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regurgitation von Nahrungsmitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Regurgitation von Nahrungsmitteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation bei Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation bei Arzneimittelmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation bei Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation bei Mißbrauch einer Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitation bei Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitationsmaßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitationsmaßnahmen bei Arzneimittelabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitationsmaßnahmen bei Drogenabhängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitationsmaßnahmen in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehabilitative Maßnahmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rehinopathie infolge Diabetes oder Hypertonie, sonstige',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Brustkorb',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reibungsgeräusch im Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reichel-Jones-Henderson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reichel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifes Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifes gesundes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifes gesundes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reifzelliges Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reine Cholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reinke-Ödem der Stimmlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reinke-Ödem des Stimmbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reisediarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reisediarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiseimpfberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reisekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reisesser-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiskörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiskörperchen des Knie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiskörperchen eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reitende Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiter-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiter-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiter-Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reiterknochen-Ossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reithosenadipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reitknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizbare Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizbares Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizbarkeit beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizblasensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizdarm mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizdarm ohne Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizdarmsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizdarmsyndrom/Colon irritabile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizhüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizknie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizkolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizleitungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizleitungsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung des Lumbosakralplexus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung des Nervus cutaneus femoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung des peripheren autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizung des sympathischen Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand des Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reizzustand eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekonstruktive Operation nach abgeheilter Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekonvaleszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekonvaleszenz nach Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekonvaleszenz nach chirurgischem Eingriff a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Kryptitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Marisken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektale/anale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektaler Tenesmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektalsphinkterfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektaltuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektolabiale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidale Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidale Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidales Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoides Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektosigmoidschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektoureterale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektourethrale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovaginales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovesikaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovesikales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovesikovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektovulväre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektozele bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektozele beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektozystozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektum-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektum-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektum-Sigma-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumimperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumirritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektummalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumpapillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumrhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumsphinkterhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumsphinkterinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumsphinkterrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumsphinkterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumsphinkterstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumtuberkulose mit Abszeß [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumtuberkulose mit Fistel [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektusscheidenhämatom bei Marcumar-Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rektusscheidenhämatom infolge Bauchwandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrensfieber - s.a. Rückfallfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrenslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrensparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrente Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrente Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rekurrente Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Relative Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Relaxatio diaphragmatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Relaxation des Fußgewölbes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reliefschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Religiöse Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Religiöse Diskriminierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Remittierende Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Remittierendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren arcuatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren bifidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren mobilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren scutulatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren trifidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ren unguliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Abflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Arterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Ausscheidungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Dialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Ektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Glukosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Glyzinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Hypertonie bei Schwangerschaft, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Hypophosphatämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Osteodystrophie mit Osteopathie [kodiere zusätzlich M90.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Osteopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Retinitis [kodiere zusätzlich H32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Tuberkulose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Wassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Hyperaldosteronismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Kleinwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renaler Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renales Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renales Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renales Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rendu-Osler-Weber-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rendu-Weber-Osler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reninom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renoparenchymatöse Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renoparenchymatöser Hochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renovaskuläre Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Renovaskuläre Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rentenneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residual ovary syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuale Epididymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuale Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuale Zahnzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuale hämorrhoidale Hautzipfel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuale radikuläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residualharn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Residuen eines Schlaganfalls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Resorptionsatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Affektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Affektion durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Alkalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Anpassungsstörung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Arrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Dekompensation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Globalinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorische Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorischer Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratorischer Distreß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratory Distress Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratory-distress-Syndrom beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Respiratory-distress-Syndrom beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restesotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restharn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restharnbildung bei Prostataadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restharnretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restless legs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restless legs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restless legs Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restless-legs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restless-legs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restriktive Kardiomyopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restriktive Ventilationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines Pigmentglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines akuten Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines akuten primären Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines chronischen Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines chronischen primären Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines intermittierenden Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines intermittierenden primären Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines kapsulären primären Glaukoms mit Pseudoexfoliation der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines primären Pigmentglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines protrahierten Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Restzustand eines protrahierten primären Engwinkelglaukoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retardierung des enchondralen Knochenwachstums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retardierung des intrauterinen Wachstums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentio alvi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentio testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentio urinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention Eihautreste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention der Dezidua mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention der Milchzähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention des toten Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention eines Intrauterinpessars bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retention von Plazentaresten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionsmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionsmembran als Entbindungskomplikation mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionszyste der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionszyste der Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionszyste der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retentionszyste des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reticulosis maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reticulosis plasmacellularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reticulosis plasmacellularis in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulo-leukämische maligne Erythrodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloangiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliale Hyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliale Zytomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliose Xanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliose ohne Lipidspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendotheliose ohne Lipoidspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuloendothelsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulohistiozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulohistiozytäres Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulolymphosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulosarkom mit plasmazellulärer Differenzierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulosarkom mit plasmazellulärer Differenzierung in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulosarkom vom pleomorphen Zelltyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulose ohne Lipidspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulose ohne Lipoidspeicherung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikulumzellsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuläre Dysgenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuläre Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuläre Retinadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retikuläre Varikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinachalkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinadegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinadrusen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinadurchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinadystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinagefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinahyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinainfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinakongestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Gefäßeinscheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Gefäßneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Neovaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Perivaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinale anomale Korrespondenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaler Arterienastverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaler Venenastverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinales Exsudat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinales Mikroaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaloch ohne Netzhautablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaperiphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinapseudozyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinastauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinathrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinatuberkulose [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinavarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinavaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinavasospasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinazyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter Zahn mit abnormer Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter Zahn mit abnormer Stellung benachbarter Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter und verlagerter Eckzahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter und verlagerter Weisheitszahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinierter und verlagerter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis albuminurica [kodiere zusätzlich H32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis centralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis centralis serosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis diabetica [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis disciformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis durch Zytomegalieviren [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis juxtapapillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa bei Cockayne-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa bei Laurence-Moon-Bardet-Biedl-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa bei Refsum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa bei Senior-Loken-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa bei Usher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis pigmentosa ohne Pigment',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinitis punctata albescens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinoblastom mit echten Rosetten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinoblastom ohne Rosetten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinochorioiditis disseminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinochorioiditis juxtapapillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinogliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia arteriosclerotica [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia centralis serosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia diabetica [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia diabetica proliferans [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia diabetica simplex [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia pigmentosa - s.a. Retinitis pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathia solaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinopathie durch Lichtstrahlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retinoschisis mit Schichtforamen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retraktion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retraktion des Bulbus oculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retraktionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroaurikularneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroaurikuläre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbärabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbäre Neuritis bei Multipler Sklerose [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbäre Neuritis durch Meningokokken [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbäre Neuritis optica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbäre Optikusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbärer Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbärer Fremdkörper nach perforierender Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrobulbärneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrogenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrograde Ejakulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrograde Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrokavaler Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrokavaler Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrolaryngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrolentale Fibroplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retromaxillärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retromikrognathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retronasale Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropatellararthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropatellare Arthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropatellare Chondromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropatellarpathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperinealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperineale Phlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale Fibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneale inguinale Lymphknotenmetastasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonealzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitoneummetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropharyngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropharyngeale Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retropositio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrosternale Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrosternale Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrosternale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrosternale Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrosternale Struma mit Tracheaeinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrotonsillarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrotonsilläres Infiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrouterine Hämatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrouteriner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroversio testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroversion der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retroversion der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrovertierter Uterus durch Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrovesikaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrozökale Appendix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrozökale Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Retrozökaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Revision von Narbengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Reye-Sheehan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezeptiver Typ einer entwicklungsbedingten Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezeptiver Typ einer entwicklungsbedingten Dysphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezeptverschreibung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezessiv vererbte sensible Neuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezessive Myotonia congenita (Becker)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende BKS [Blutkörperchensenkungsgeschwindigkeit]-Erhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Blinddarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Dorsolumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Erosio corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Femoroinguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Genitalmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Gleithernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Gleithernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Harnwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia directa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia indirecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinalis directa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinalis indirecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinalis mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinalis obliqua',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia inguinoscrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia labialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia labialis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia obliqua',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernia scrotalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hornhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit Dense-deposit-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit Glomerulonephritis mit diffuser Halbmondbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit diffuser endokapillär-proliferativer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit diffuser membranöser Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit diffuser mesangiokapillärer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit diffuser mesangioproliferativer Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit fokaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit minimaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Hämaturie mit segmentaler glomerulärer Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie mit Inkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie mit Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Inguinalhernie mit Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Labialhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Nephrolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Pannikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Polychondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Skrotalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Thyreotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Uteruszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Uveitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Zyste des Corpus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende beidseitige Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende beidseitige Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende depressive Störung als leichte Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende depressive Störung als mittelgradige Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende depressive Störung als schwere Episode mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende direkte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende doppelseitige Hernia inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende doppelseitige Hernia inguinalis mit Einklemmung ohne Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende doppelseitige Hernia inguinalis mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende doppelseitige Hernia inguinalis ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende doppelseitige Leistenhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende einseitige Hernia inguinalis ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende einseitige Inguinalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende einseitige Leistenhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende indirekte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende inkarzerierte Leistenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende kurze depressive Episoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende leichte Episoden einer depressiven Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende leichte Episoden einer psychogenen Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende leichte Episoden einer reaktiven Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende majore Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende manische Episoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende mittelgradige Episoden einer depressiven Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende mittelgradige Episoden einer psychogenen Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende mittelgradige Episoden einer reaktiven Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende obstruktive Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende schwere Episoden einer majoren Depression mit psychotischen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende schwere Episoden einer psychogenen depressiven Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende schwere Episoden einer psychotischen Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende schwere Episoden einer reaktiven depressiven Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende vitale Depression ohne psychotische Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierende weiche Leiste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Gleitbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Harnwegsinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Herpes simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Hodenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Infekt der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Infekt der oberen Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Infekt der unteren Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch mit Inkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch mit Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Leistenbruch mit Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Myokardinfarkt der Seitenwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender anteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender anteroapikaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender anterolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender anteroseptaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender apikolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender basolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender depressiver Verstimmungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender diaphragmaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender hochlateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender indirekter Leistenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender inferiorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender inferolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender inferoposteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender lateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender posteriorer Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender posterobasaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender posterolateraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender posteroseptaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender renaler Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierender septaler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Blasenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Cholesteatom der Mastoidhöhle nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Engwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Hordeolum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Lungenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes aphthöses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivierendes primäres Winkelblockglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rezidivinfarkt - s.a. Infarkt, Myokard, rezidivierend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rh [Rhesus]-Isoimmunisierung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rh [Rhesus]-Isoimmunisierung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rh-Antikörper bei der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdoides Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyoblastisches Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyosarkom der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdomyosarkom vom Mischtyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhabdosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhachischisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhagadiforme Hyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhegmatogene Ablatio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhegmatogene Amotio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumaherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumalunge [kodiere zusätzlich J99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aorteninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortenklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortenklappenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortenstenose mit Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortenstenose mit Regurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Aortitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea mit Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea mit Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea mit Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea mit Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Chorea mit mehrfacher Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Endokarditis der Aortenklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Endokardkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Herzklappendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Herzklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Herzklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Mitralklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Mitralklappenobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Pankarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Perikardverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Pulmonalklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Pulmonalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Pulmonalklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Trikuspidalklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Trikuspidalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Trikuspidalklappenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatische valvuläre Pulmonalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatischer Herzfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatischer Herzklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatischer Perikarderguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatischer Pulmonalklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatischer Trikuspidalklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber mit Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber mit Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber mit Pneumonie [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Fieber/Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Herzklappenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Hornhautringulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatisches Pulmonalklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatismus mit Pneumonie [kodiere zusätzlich J17.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Karditis [kodiere zusätzlich I52.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Lungenkrankheit [kodiere zusätzlich J99.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Myokarditis [kodiere zusätzlich I41.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Perikarditis bei chronischer seropositiver Polyarthritis [kodiere zusätzlich I32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoide/seropositive Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rheumatoider Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis anaphylactica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis durch Pollen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis sicca anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis vasomotorica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinitis vasomotorica allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinits allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoblennorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinobronchialer Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinobronchitis allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinocladium-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoconjunctivitis allergica saisonalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoconjunctivitis pollinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinodakryolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinodiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinodymie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinokyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolalia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolalia aperta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolalia clausa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolalia mixta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolaryngobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolith der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinolordose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinomyiasis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathia allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathia pollinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathia sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngitis mutilans [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharyngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharynxatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharynxnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharynxulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinopharynxzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophasia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophasia aperta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophasia clausa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophasia mixta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophonia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophonia aperta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophonia clausa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophonia mixta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinophym',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinorrhoe von Zerebrospinalflüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoseptumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinoseptumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinosinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinosinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinosinutracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinosklerom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinotrachealkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinotracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhinozerebrale Mukormykose [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhonchopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhonchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhus-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhythmusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhytidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rhytidosis facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riboflavinmangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsienpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiose durch Ehrlichia sennetsu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiose durch Rickettsia akari',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiose durch Zecken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rickettsiosis varicelliformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riddoch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riedel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riedel-Leberlappen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riedel-Struma [Eisenharte Thyreoiditis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riedel-Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rieger-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rieger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riehl-Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riehl-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenfibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenfibroadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenfollikellymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenharnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenhohlzyste der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenkondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenkondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenpapillenkonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenthrombozyten-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzell-Epulis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellarteriitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellarteriitis bei rheumatischer Polymyalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzelleinschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellen-Retikulohistiozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellengranuloarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzelliges Sarkom (ausgenommen Knochen)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzelliges Zementom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riesenzellthyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rietti-Greppi-Micheli-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rietti-Greppi-Micheli-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rietti-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rift-Valley-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rifttal-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rigider Rundrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rigides Hymen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riley-Day-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riley-Smith-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rindenepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rindenstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rindentaubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ring-Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringchromosom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringelförmiger Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringelhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringelröteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringelröteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringelröteln-Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmige Kontraktur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmige Kontraktur als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmige Zervixabtrennung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmige Zervixabtrennung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmiges Chromosom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmiges Skotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringförmiges Ulcus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringknorpelagenesie des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringknorpelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringknorpelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringknorpelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringknorpelstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringskotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringskotom des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ringstar nach Soemmering',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rio-Bravo-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfellabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfelladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfellempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfelltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenknorpeldislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenknorpeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenknorpelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenserienbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenserienfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenverschiebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenwinkelschwarte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rippenzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktor Sexualverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktor Sexualverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktoren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktoren für bösartige Neubildungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktoren für kardiovaskuläre Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikofaktoren in der Anamnese a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikogravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Risikoschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riskantes Sexualverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riskantes Sexualverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rissigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ritter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ritter-von-Rittershain-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rituelle Beschneidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rituelle Zahnabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rivalität in der Peer-Gruppe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rizinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß des inneren Meniskus des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß des seitlichen Meniskus des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß des ulnaren Ellenbogenseitenbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß von periurethralem Gewebe bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß von periurethralem Gewebe bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Riß-/Quetschwunde der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißquetschwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißquetschwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißquetschwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißverletzung des Auges mit Prolaps und Verlust intraokulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißverletzung des Auges ohne Prolaps und ohne Verlust intraokulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rißwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Robert-Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Robert-Becken mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roberts-Syndrom [Pseudothalidomid-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Robinow-Silverman-Smith-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Robinson-Miller-Bensimon-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roble-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rocky mountain spottet fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rocky-Mountain-Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roggenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Romano-Ward-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Romberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosa-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea erythematosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea lupoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea papulopustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea papulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosacea pustulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosai-Dorfman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosazea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosenbach-Erysipeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosenbach-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosenpollenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosenthal-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosenthal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roseola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roseola infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roseolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rosettenstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ross-River-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rostring der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rot-Grün-Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rot-Grün-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotationsblockierung im HWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorenmanschettenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorenmanschettenruptur der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorenmanschettensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorenmanschettensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorenmanschettenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotatorischer Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roth-Bernhardt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rothmund-Thomson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotlauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotor-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotor-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rotz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roussy-Lévy-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Roussy-Lévy-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Beschneidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Mammographie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Nachsorgeuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Röntgenuntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Röntgenuntersuchung des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßige Untersuchung des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßiger Papanicolaou-Abstrich der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routinemäßiges Mammogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Routineuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubella bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubella mit Komplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeola scarlatinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeolenembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeosis diabetica [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeosis diabetica bei Typ-I-Diabetes mellitus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeosis diabetica bei Typ-II-Diabetes mellitus [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeosis faciei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubeosis iridis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubinikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rubinstein-Taybi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rucknystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentäre Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentäre Patella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentäre Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentärer Arm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentärer Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentärer Trachealbronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentärer Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentäres Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rudimentäres Ohrläppchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruheangina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhelosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhr durch Shiga-Kruse-Bakterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhrbakterien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruhrrheumatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumination beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumination im Kleinkindalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpffurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfgürtel-Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfhautbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfquetschung an multiplen Lokalisationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rumpfverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundforamen der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundrücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundrücken als Haltungsschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundrücken als Spätfolgen nach Rachitis [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundrücken mit Keilwirbeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundzellengliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundzelliges Liposarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rundzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupia connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupia connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Chordae tendineae a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Descemet-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Fontanelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Operationswunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Tuba uterina a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Auges mit Prolaps und Verlust intraokulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Auges ohne Vorfall intraokulären Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Circulus arteriosus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Ductus thoracicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Duodenalstumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur des plazentaren Randsinus mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur einer Baker-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur einer Pyosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur einer Synovialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur einer arteriovenösen Fistel des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur einer zerebralen arteriovenösen Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur eines Divertikels des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruptur eines zerebralen Aneurysmas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte Lungenbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte Zyste der Naboth-Follikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte hämorrhagische Zyste des Graaf-Follikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierte zerebrale Aneurysmen mehrerer intrakranieller Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierter Peritonealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturierter Sinus marginalis placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Aorta abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Aorta thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Arteria iliaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Arteria subclavia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma der Milzgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma des Sinus Valsalvae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma dissecans aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aneurysma einer Arterie der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Arterienaneurysma der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Brustaortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Hüftarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Karotisaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Leberarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Leistenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes Nierenarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes aortothorakales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes mediastinales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes peripheres Aneurysma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes thorakales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes thorakoabdominales Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes variköses Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes zerebrales Aneurysma einer Arteria communicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes zerebrales Aneurysma einer Hirnarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rupturiertes zerebrales sackförmiges Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Russische Frühsommer-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Russische Frühsommer-Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Russisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rust-Krankheit [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rust-Syndrom [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ruvalcaba-Myhre-Smith-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Räude',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Räusperzwang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgendermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgenstrahlennephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgenuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgenuntersuchung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röntgenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln - s.a. Rubella oder s.a. Rubeola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln mit neurologischer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Röteln-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötelnarthritis [kodiere zusätzlich M01.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötelnarthropathie [kodiere zusätzlich M01.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötelnpneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rötung an mehreren Stellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückbildungsmelancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkabszeß durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkgumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkgumma [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarklazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarklues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarklues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarklähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkmyelodysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarknekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkschock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarksverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarksyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarksyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarktuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarkzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenmarködem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenschmerz (lumal/sakroiliakal) Coccydynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenschmerzen NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückensyndrom mit Schmerzausstrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückensyndrom ohne Schmerzausstrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverspannung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückfallfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückfallfieber durch Borrelia recurrentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückfallfieber durch Borrelien, ausgenommen durch Borrelia recurrentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückfluß von Magensaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückgrattuberkulose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückstand in der Sprachentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückstauniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rückwärts- und Vorwärtsversagen bei Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rülpsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rüsselbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Rüsselbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'S-förmige LWS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'S1-Ischialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SAB [Subarachnoidalblutung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SAB [Subarachnoidalblutung] durch rupturiertes zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SCID [Severe combined immunodeficiency] - s. Immundefekt, schwer, kombiniert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SHT [Schädelhirntrauma]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SIADH [Syndrome of inappropriate ADH]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SIDS [Sudden infant death syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SIDS [Sudden infant death syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SIRS [Systemic inflammatory response syndrome]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SPCA [Serum prothrombin convertin accelerator]-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SSF [Senk-Spreizfuß] - s. Senk-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SSPE [Subakute sklerosierende Panenzephalitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SSS [Staphylococcal scalded skin]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SSS [Staphylococcal scalded skin]-Syndrom mit Befall von 30% der Körperoberfläche und mehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SSS [Staphylococcal scalded skin]-Syndrom mit Schleimhautbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'STD [Sexually transmitted disease]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'SVES [Supraventrikuläre Extrasystolie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sabouraud-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saccharasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saccharopinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saccharose-Isomaltose-Malabsorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sackförmige Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sackförmiges Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sacklunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sackniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sacrum arcuatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Safranleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sagittale Frontzahnstufe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sagittales Scheidenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sagittales Vaginalseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sagomilz [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saint-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saisonale Rhinokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saisonale depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakralplexusneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrokokzygeale Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrokokzygeale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrumanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrumdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrumdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sakrumtuberkulose [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saktosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salaamanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salaamkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salizylismus bei Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salizylismus bei Überdosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salmonellen-Dauerausscheider',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salmonellen-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salmonellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salmonellose-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingitis der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingitis durch Chlamydien [kodiere zusätzlich N74.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingitis nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingo-Oophoritis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingo-Oophoritis mit Ruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingoperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingovaritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salpingozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzmangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzmann-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzmann-Hornhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzverarmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzverlust-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzverlustniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Salzödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasendivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasengonorrhoe [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasengonorrhoe [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblaseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblaseninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenkongestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasentuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenblasenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samengangobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiteragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiteratrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleitergeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleitergonorrhoe [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleitergonorrhoe [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleitertuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenleiterödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenspender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranganomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranggeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranghydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranghydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranghypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstranghämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangtorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangtuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenstrangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsinfektion durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsinfektion durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samenwegsverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Samoapocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sampson-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sampson-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'San Joaquin-Fieber [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanagapocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanders-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sandfliegen-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sandfly fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sandhoff-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sandstrahlgebläsearbeiter-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanduhrgallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanduhrmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanduhrstenose des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanduhrstriktur des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanfilippo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanfilippo-Krankheit Typ B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanfilippo-Krankheit Typ C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanfilippo-Krankheit Typ D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanfilippo-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanger-Brown-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanierungsbedürftiges Gebiß bei ambulant behandlungsunfähigem Patienten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sanierungsbedürftiges Gebiß bei gleichzeitiger Antikoagulanzientherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saphenaphlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saponifikation des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saprophytäre Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma angiolithicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma botryoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma clarocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma deciduocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma fusocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma gigantocellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma idiopathicum haemorrhagicum multiplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcoma rhabdomyoblasticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarcomatosis Kaposi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkoidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Columna vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Fibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Kniescheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Mandibula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Nasenmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Tibia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Uterusschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom der Weichteile des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Beckenknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes der oberen Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes der unteren Gliedmaßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes des Rückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes und der Weichteile des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes und der Weichteile des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Bindegewebes und der Weichteile des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Femur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Gesichtsknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Oberschenkelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os ethmoidale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os frontale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os nasale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os occipitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os parietale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os sphenoidale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os temporale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Os zygomaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Schienbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Schulterblattes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Schädelknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Vomer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom des Wadenbeins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkom eines Gelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkosinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkosporidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sarkozystose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sattelembolie der Aortenbifurkation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sattelembolie der Bifurcatio aortae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sattelnase durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sattelnase durch Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saturnismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Satyriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sauerstoffmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sauerstoffmangel in großer Höhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saure-Phosphatase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Saures Aufstoßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scalenus-anterior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scarabiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scarlatina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Hochdruckflüssigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Hunger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Hungersnot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Röntgenstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch Wasserdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaden durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schafblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schafleberegel-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schafpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaftlockerung einer TEP [Totalendoprothese] des Hüftgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schalleitungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schalleitungsschwerhörigkeit mit Innenohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schalleitungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schallempfindungsschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schambeinabtrennung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schambeinabtrennung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schambeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schambeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamberg-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamberg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamberg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schamlippenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Adenitis durch Haemophilus ducreyi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Adenitis durch Haemophilus ducreyi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Phimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröse Phimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schankröses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Cholangitis [kodiere zusätzlich K87.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Nephritis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlach-Otitis [kodiere zusätzlich H67.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlachartige Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scharlachkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schattensehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaufelförmiger Schneidezahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaukelbewegungskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaumann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schaumzellpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheibenmeniskus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheiden-Blasen-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 1. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 1. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 2. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 2. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 3. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 3. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 4. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendammriß 4. Grades bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidendysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenenterozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidengonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidengranulationspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenmykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidensenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenstumpfgranulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenstumpfprolaps nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidentuberkulose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenulkus durch Pessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenwandvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheidung wegen Familienzerrüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheingravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheinschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheinschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheintod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheinzwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheinzwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheitelbeinabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheitelbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheitelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheitelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenk-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkel-/Narben-/Nabel-/Bauchwandhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhalsbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhernie links',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schenkelhernie rechts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scherpilzflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schetismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheu und Abkapselung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheuerekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheuermann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheuermann-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheuermann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scheuthauer-Marie-Sainton-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schichtarbeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schichtarbeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schichtenthrombus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schichtloch der Makula',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schichtstar bei Cataracta congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schief-Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schiefhals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schiefnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schiefwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schielamblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schielfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schienbeinkantensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schienbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schießscheibenzell-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsen-TBC [Tuberkulose] [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenaplasie mit Myxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenautonomie bei Struma mit Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsendysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüseneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenfehlfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenfunktionsstörung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenhormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenhyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüseninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüseninfarkt bei Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüseninfarzierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüseninfektion durch Echinococcus granulosus [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsentuberkulose [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenunterfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenvergrößerung/Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenüberaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilddrüsenüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilder-Addison-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilder-Foix-Heubner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilder-Foix-Heubner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilder-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilder-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpeldislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpeldistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schildknorpelspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schilling-Typ der monozytären Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schinkenmilz [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schisisablatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis bovis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis der Lunge a.n.k. [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis durch Schistosoma haematobium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis durch Schistosoma japonicum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis durch Schistosoma mansoni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis intercalatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis mattheei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis orientalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis spindale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis urogenitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schistosomiasis von Leber und Milz [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizoaffektive Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizoaffektive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizodepressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizoide Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizoide Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizoide Störung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizomanische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizonychia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Episode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Flexibilitas cerea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Katalepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Katatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Psychose vom affektiven Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrene und affektive Mischpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrener Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrener Residualzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrener Restzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenes Syndrom beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenie mit Affektpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenie und Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophrenie-Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophreniforme Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophreniforme Psychose bei Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophreniforme Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizophreniformer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizothymie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizotype Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizotype Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizotypie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizotypische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schizozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlachthaus-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaf-Wach-Rhythmus-Störung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafapnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafapnoesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Diaphragmaparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Halbseitenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Hemiparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Paraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Tetraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaffe Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaflosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaflosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafmittelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafmittelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafrhythmusumkehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaftablettenvergiftung mit Suizidabsicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaftherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafwandeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlafwandeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlag durch Elektrizität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlag durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlagaderverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaganfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlaganfall/zerebrovaskulärer Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlagfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlammfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlangenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlecht heilende Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlechte Compliance',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlechte Haltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlechte Stellung von Frakturenden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlechter Allgemeinzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlechter Allgemeinzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleichende Nabelinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleichende Nabelinfektion beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleifer-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleim im Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimbeutelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimbeutelentzündung im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimbildender karzinoider Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimbildendes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautblutung der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautcolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautframbösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautpolyp der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautproktokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautriß der Kardiaregion mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautzyste in der Mastoidhöhle nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimhautödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimiges Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimiges Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleiminspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimpfropf in den Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleimpfropf in der Luftröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schleudertrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlotterkamm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlotterkammatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluck-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlucklähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlucksen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schluckstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlundblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlundverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlupfbrustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlupfbrustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenbeinosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schläfenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeinagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeindislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schlüsselbeinsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmales Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmales Becken mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmelzflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmelzperlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz generalisiert/ an mehreren Stellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz in Hoden/Skrotum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz, der der Wirbelsäule/dem muskulären/knöchernen System zugeschrieben wird',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz/Druckgefühl in einer Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz/Versteifung/Schwäche im Gelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerz/Überempfindlicheit der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen Atmungssystem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen bei Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen beim Geschlechtsverkehr, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen beim Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen der männlichen Genitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen der vorderen Brustwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen der weiblichen Genitalien a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen des Nervus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen des Xiphoids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen im Becken/ in der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen im Epigastrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen im Epigastrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen im Halswirbelsäulenbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen im Perineum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Herzgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Herzgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Lendengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Lumbalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen in der Steißbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen nach Thoraxtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzen, die dem Herzen zugeschrieben werden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzende Hautnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Blähungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Darmgase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Dauererektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Ejakulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Erektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Harnentleerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Kiefergelenkdysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Lippenrötung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Lippenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafte Regel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafter Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafter Koitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafter Koitus bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafter Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhafter weiblicher Koitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhaftes Durchatmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhaftes Harnlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhaftes Urinieren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhypersensibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzhypersensibilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmerzmittelabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmetterlingsbruch des Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmetterlingswirbel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmidt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmierblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmierblutung bei Frühschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmincke-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmincke-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmitz-Stutzer-Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmorl-Knorpelknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmorl-Knorpelknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schmorl-Knorpelknötchen bei Scheuermann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnappatmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnappende Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnappender Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnappender Kiefer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnappendes Knie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnarchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnarchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schneckenohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schneeblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schneeblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schneider-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schneider-Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnellender Daumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnellendes Knie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schniefen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Abruptio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Abruptio placentae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Anteversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Beckentumor a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Cerclage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Einstellungsanomalie des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Eklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Gesichtslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Hydrozephalus des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Kinnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Lageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Lateroversion des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Mekonium im Fruchtwasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Nabelschnurvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Nabelschnurvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Nichteintreten des Kopfes beim Termin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Placenta praevia mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Querlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Rektozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Sackbildung am graviden Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Schräglage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Schulterlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Shirodkar-Naht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Steißlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Stenose der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Stirnlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Striktur der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Uterusatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Uterusatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Uterusinkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Uterusverlagerung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Wehenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Wehenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Zervixpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei Zystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei allgemein verengtem Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei anomaler Kindslage a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei fetomaternaler Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei mangelnder Eröffnung des Muttermundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei mangelnder Eröffnung des Muttermundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei plazentarer Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei präpartaler Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei retrovertiertem Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei ungewöhnlich großem Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei unkoordinierte Uterustätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei unkoordinierte Uterustätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei verlängerter Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittentbindung bei verlängerter Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittverletzung des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittverletzung des Fußrückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnupftabak-Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnüffeln eines Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnüffeln von Flugzeugkleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnüffeln von Kokain',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schnüffelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock (psychisch)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock bei Geburtshilfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock bei Geburtshilfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch Blitzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch Elektrizität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch Nahrungsmittelunverträglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock durch therapeutischen Unglücksfall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock nach Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schock nach chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schocklunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schockniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schoenlein-Henoch-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schoenlein-Henoch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schokoladenzyste des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scholz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schornsteinfegerkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schraubenentfernung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schreibkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schreibneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schreiendes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schreiknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrittmacher-Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfgallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfharnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfmagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schräglage des Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schuldzuweisung an ein Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulisch-pädagogische Rehabilitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen in der Kindheit mit Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen in der Kindheit mit Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen in der Kindheit ohne Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulschwänzen in der Kindheit ohne Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulter-Hand-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulteradhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulteragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblattabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblattfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblatthypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblattkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblattknarren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterblattverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultereckgelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultereckgelenksprengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergelenktuberkulose [kodiere zusätzlich M01.11*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtel-Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelmyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultergürtelverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultersymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultersyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterversteifung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schulterzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schultze-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schuppenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schuppenflechte/Psoriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schuppenröschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schusterbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schutzimpfung - s.a. Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schußwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwache Atmung durch Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwache Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwache schulische Leistung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwacher Harnstrahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwacher Puls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwacher Puls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwacher Puls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwacher Puls',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwaches Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwachsichtigkeit - s.a. Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwachsinn mit deutlicher Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwalbe-Ziehen-Oppenheim-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwalbe-Ziehen-Oppenheim-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwammlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwammniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwanenhalsdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft als Nebenbefund festgestellt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft außerhalb der Gebärmutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Beckenringlockerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Fibroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Hirnvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Symphysendehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Symphysendehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Symphysenlockerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Symphysenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Symphysensubluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit oberflächlicher Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft mit tiefer Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft noch nicht bestätigt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft noch nicht bestätigt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaft noch nicht bestätigt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschafts-Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsabbruch - s.a. Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbedingte Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbedingte Phlebopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbedingte Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbedingte Übelkeit/Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbedingter Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsblutung im 1. Trimenon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsdiabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsfeststellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsfeststellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsfeststellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsgestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsgingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftshydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftshypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation durch Amnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation durch Blasenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation durch Pergamentkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation durch Plazentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskomplikation durch hydatidiforme Mole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsnephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsphlebopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftspigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsprophylaxe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftspruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftspsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftspyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsspättoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsstreifen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftssymptom/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsthrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftstoxämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsunterbrechung - s.a. Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsverdacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsverdacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsverdacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsvermutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsödem mit Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsüberwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwangerschaftsüberwachung bei älterer Erstgebärender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwankende Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwankende Esotropie bei kongenitalem Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwankender Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwannom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwartz-Bartter-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwartz-Jampel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Haarknötchen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Haarzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Haarzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Piedra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarze Zahnauflagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarzer Zahnbelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarzes Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarzruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwarzwasserfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwedische Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweinebrucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweinerotlauf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweissdrüsenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweizer Typ der Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißausbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenadenom - s.a. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißfriesel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweißneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellkörperentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellkörperfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellung Parotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellung Tonsillen/Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwellung des Nebenhodenbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweninger-Buzzi-Anetodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Beta-Thalassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Dysplasiehüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Form der Malaria tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Hüftdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Hüftgelenkdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Intelligenzminderung mit deutlich behandlungsbedürftiger Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Maroteaux-Lamy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Osteochondrose der LWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Osteoporose mit Wirbelsinterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Protein-Kalorie-Malnutrition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Quetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Quetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Rotationsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Streßreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Zerquetschung bei Verschüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere Zerquetschung bei Verschüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere geistige Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere kombinierte Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwere reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerer Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerer Kalorienmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerer Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerer kombinierter Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweres Maroteaux-Lamy-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schweres Trauma in der Anamnese, das die Schwangerschaftsvorsorge beeinflußt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerfälligkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit durch Anomalie der Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit durch Schallempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit durch die Einwirkung großer Höhe auf die Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit durch toxisches Agens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit für hohe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit für hohe und tiefe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerhörigkeit für tiefe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwermetallinduzierte Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwermut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerste Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerste Intelligenzminderung mit deutlich behandlungsbedürftiger Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerste Oligophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwerste geistige Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwertfortsatzdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwiele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwierige Arbeitsbedingungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwierige Arbeitsbedingungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwierige Intubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwierigkeiten Kenntnisse zu erwerben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwierigkeiten bei Brusternährung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmbad-Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmbadgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmhautbildung der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmhautbildung der Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmhosen-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwimmkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel durch Infraschall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel durch Vibration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel unklarer Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindel/Schwindelgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindelattacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindelgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwindsucht - s.a. Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwäche/ allgemeine Müdigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwächezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schwächezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisfissur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisringbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisringfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisscharnierbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbasisscharnierfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeldachbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeldeformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeldurchschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeleindellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelfraktur durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelhirntrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelhöhlenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelkalottenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelkalottenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelknochenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelknochenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelknochenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelknochenverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeltrümmerbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädeltrümmerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelverletzung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädelzertrümmerung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schäden durch abnorme Gravitationskräfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schäden durch Überanstrengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung der Chorda tympani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung der Fossulae tonsillares',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung der Spermatogenese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung der tubulorenalen Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Chiasma opticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Feten durch Bandl-Ring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Feten durch Kontraktionsring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Gasser-Ganglions',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Meniscus lateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Meniscus medialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Naseninneren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Naseninneren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Naseninneren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Nervus ischiadicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Nervus laryngeus recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Nervus vestibulocochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei Fünflingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei Mehrlingsgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei Sechslingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei Vierlingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei Zwillingsgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen bei multipler Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Alkoholkonsum der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Amnionitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Analgesie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Anästhesie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Dystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Eklampsie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Entbindungsoperation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Ernährungsmangelkrankheit der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Ernährungsstörungen der Mutter (Zustände unter E40-E64)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Geburtshindernis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Geburtsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Gesichtslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Hepatitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Hydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Hyperemesis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Hypertonie der Mutter (Zustände unter O10-O11, O13-O16)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Hysterotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Kontraktionsring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Kortikalnekrose der Niere der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Krankheit der Mutter a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Lebernekrose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Malaria der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Malnutrition der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Narkose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Nephritis der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Nephrose der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Nierenkrankheit der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Nierenrindennekrose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Nierenversagen der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Oligohydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Operation der Mutter ohne Zusammenhang mit der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Plazentitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Polyhydramnion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Proteinurie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Präeklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Pyelitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Pyelonephritis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Röteln der Mutter (Zustände unter B06)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Schnittentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Schnittentbindung post mortem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Schwangerschaftskomplikationen der Mutter a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Stenose der Vagina der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Striktur der Vagina der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Sturz der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Sturzgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Syphilis der Mutter (Zustände unter A50-A53)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Tabakkonsum der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Thrombophlebitis der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Tod der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Toxikose der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Toxoplasmose der Mutter (Zustände unter B58.-)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Urämie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Vakuum-Extraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Verletzung der Mutter während der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch Zangengeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch akute gelbe Leberatrophie der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch anhaltendes Erbrechen der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch anomale Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch forcierte Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch glomeruläre Krankheiten der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch infektiöse Krankheit der Mutter (Zustände unter A00-B99, J10-J11)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch instrumentelle Geburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch kongenitale Herzkrankheit der Mutter (Zustände unter Q20-Q24)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch künstlich eingeleitete Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch nephrotisches Syndrom der Mutter (Zustände unter N00-N08)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch parasitäre Krankheit der Mutter (Zustände unter A00-B99, J10-J11)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch pendelndes Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch rheumatische Herzkrankheit der Mutter (Zustände unter I05-I09)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch schwierige Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch tiefen Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des Neugeborenen durch tiefsitzende Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung des inneren Ellenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung durch Blitzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung durch Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung durch Wassermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädigung durch intrakranielle Raumforderung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Effekte physikalischer Faktoren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung einer radioaktiven Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von Bestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von Radium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von Röntgenstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von Teleröntgentherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von radioaktivem Fallout a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädliche Wirkung von radioaktivem Niederschlag a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädlicher Gebrauch eines flüchtigen Lösungsmittels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädlicher Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schädlicher Gebrauch von Sedativa und Hypnotika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schälblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüller-Christian-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüller-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schürfwunde/Schramme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelfrost in Malaria-Regionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelkrankheit (atypische ZNS-Virusinfektion)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelkrämpfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schüttelparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schützengrabenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Schützengrabenfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scimitar-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scimitar-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerema adiposum neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerema adultorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerema oedematosum neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia - s.a. Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia en Band',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia en Coup de sabre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclerodermia linearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scleromalacia perforans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sclérose en plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Alkoholismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Aufnahme einer radioaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Blasenneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Bluthochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Candida-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Cervix-uteri-Neoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Chagas-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Chlamydien-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Chromosomenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Darmneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Dengue-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Drogengebrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Fehlernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Fettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Filariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Galaktosämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Gelbfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Geschlechtskrankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf HIV [Humanes Immundefizienz-Virus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Harnblasenneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Hautaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Hodgkin-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Hormone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Hämoglobulinopathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Immunkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Ingestion einer radioaktiven Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Keuchhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Kontamination a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Krankheit oder Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Leptospirose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Lungenemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Lymphome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Mammaneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Mangelernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Mukoviszidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Mykosen-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Nierenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Phenylketonurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Sichelzellen-Erbanlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Spirochäten-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Stimulanziengebrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Strahlenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Tetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Trachom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Trypanosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Zahnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf angeborene Hüftgelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf angeborene Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf asymptomatische Bakteriurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf chronische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf entwicklungsbedingte Behinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf geistige Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf intestinale Helminthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf intestinale Würmer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf kardiovaskuläre Affektionen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf kongenitale Anomalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf neurologische Affektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf respiratorische Affektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf zystische Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Screening auf Übergewichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Scrub Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoea oleosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoea sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoea sicca capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoides Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoides Kopfekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Akanthose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Crusta lactea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Dermatitis beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Dermatitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoische Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoischer Milchschorf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoisches Ekzem beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seborrhoisches Ekzematoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sebostase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sebostatisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sebozystomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sechsfingrigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sechslingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sechslingsschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sechste Krankheit [Exanthema subitum]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seckel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seclusio pupillae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sedativaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sedativaabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sedativamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sedativamißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seekrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seelenblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seelentaubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seelische Grausamkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seelische Grausamkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seelische Störung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seemannshaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentale Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentale Fettgewebsnekrose der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentale Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentale Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentationsfehler mit Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Segmentpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehbahnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehbehinderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehbehinderung ohne Refraktionsanomalie und ohne Amblyopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehdefekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehkraftverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenlazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenscheidenxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenverletzung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenverletzung des Kopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenverletzung in Halshöhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnenxanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnerventzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervmeningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervtuberkulose [kodiere zusätzlich H48.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehnervverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehrindenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehrindenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehschule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehstrahlungskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehstrahlungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehstörung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehvermögensdefekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sehvermögensverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seifenabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seifenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seifenintoxikation nach Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenastvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenstechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenstrangangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenstrangentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenstrangsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seitenwandinfarkt des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekretionsstörung von Glukagon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekretorische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekretorisches Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekretorisches Mammakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundenherztod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär infizierte Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär insulinpflichtiger Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär obstruktiver Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär obstruktiver Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär refluxiver Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär refluxiver Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär schmerzhafte Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär verheilende Wunde nach Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundär-/metastatische Neubildung bei unbekannter Lokalisation des Primärtumors',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Achlorhydrie nach Vagotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Amyloidose bei Hämodialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Arthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Atelektase beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Coxarthrose nach Dysplasie/Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Eingeweidelues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Eingeweidelues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Eingeweidesyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Eingeweidesyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Erythrodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Erythrodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Erythrämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Frühsyphilis der Retina [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Frühsyphilis der Retina [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Frühsyphilis eines Lymphknotens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Frühsyphilis eines Lymphknotens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Gicht a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Gonarthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Gonarthrose nach Dysplasie/Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hydronephrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hyperoxalurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hypertonie bei Nierenkrankheit bei Gravidität, bereits vorher bestehend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hypomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Hämochromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Impetiginisation einer Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Karzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Katarakt bei Augenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Kryoglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Kyphose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Knochen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Knochen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lues des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Lungenpest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Mundlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Mundlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Mundsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Mundsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Nachblutung nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Nachblutung nach traumatisch bedingter Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Nierenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Paraproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Paraproteinämie bei maligner Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Periarthritis humeroscapularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Pestpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Polyzythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Rechtsherzinsuffizienz nach Linksherzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Rhizarthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Schleimhautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Schleimhautlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Schleimhautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Schleimhautsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Sectio caesarea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Sektio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Skoliose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Strephosymbolie durch organische Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Chorioidea [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Chorioidea [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Iris [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Iris [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Knochen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Knochen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Uvealtraktes [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Syphilis des Uvealtraktes [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Wundheilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Ziliarkörpersyphilis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre Ziliarkörpersyphilis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre benigne Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre cholestatische Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre frühsyphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre frühsyphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre frühsyphilitische Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre frühsyphilitische Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre funktionelle Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre hypertrophische Osteoarthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre hypotone uterine Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre maligne Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre mukokutane Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre mukokutane Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre nichttraumatische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre sideroachrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Chorioiditis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Chorioiditis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Chorioretinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Chorioretinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Entzündung des weiblichen Beckens [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Entzündung des weiblichen Beckens [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Myositis [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Myositis [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Uveitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre syphilitische Uveitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre tubare Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäre weibliche Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäreffekte eines Traumas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Blepharospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Dammriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Hyperparathyreoidismus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Krebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Morbus Parkinson',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Parkinsonismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer Vaginismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer hoher Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer maligner Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärer renaler Hyperparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Dentin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Fanconi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Lymphödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Parkinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Raynaud-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres Wachstum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres syphilitisches Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres syphilitisches Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres syphilitisches nephrotisches Syndrom [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundäres syphilitisches nephrotisches Syndrom [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei Augenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei Fuchs-Heterochromiezyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei Seclusio pupillae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei erhöhtem episkleralem Venendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei lokaler Mydriatikatherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei lokaler Steroidtherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei postoperativer Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei systemischer Mydriatikatherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei systemischer Steroidtherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom bei traumatischer Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom durch Augentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom nach Augenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom nach Bulbuskontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom nach Bulbusprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärglaukom nach Kammerwinkeleinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärheilung einer Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärheilung eines Dammrisses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärläsion der Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sekundärläsion der Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstbeschädigung in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstmordneigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstmordversuch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstschädigende Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstschädigendes Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstschädigendes Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbsttötung in der Eigenanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbsttötungsgefahr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbsttötungstendenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstunsichere Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstvergiftungsversuch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selbstverstümmelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selektiver Mutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selektiver Mutismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seltene Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seltene Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seltener Lidschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selter-Swift-Feer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Selter-Swift-Feer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seltsames Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Semantische Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Semantische Demenz [SD] [kodiere zusätzlich F02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Semilunarknorpelriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Semilunarknorpelruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seminalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Semiplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senear-Usher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seneszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seneszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seneszenz ohne Angabe einer Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Asthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Atrophie des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Atrophodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz bei Morbus Alzheimer [kodiere zusätzlich F00.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz mit akuter Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz vom Alzheimertyp [kodiere zusätzlich F00.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz vom depressiven Typus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Demenz vom paranoiden Typus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Dermatolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Endometriumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Ermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Erschöpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Form der Alzheimer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Gebrechlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Herzdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Hirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Hyalinflecken der Sklera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Hyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Hyperpigmentierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Keratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Knochenatrophie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Knorpelossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Kolpitis mit Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Konjunktivaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Korneamelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Larynxkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Lassitudo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Linsenkernsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Melancholie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Myokarddegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Myometriumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Osteomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Ovarialinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Paranoia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Psychose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Retinasklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Retinoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Synchysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Vaginaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Zungenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile Zungenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile arteriosklerotische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile atrophische Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile atrophische Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile atrophische Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile chronische Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile exsudative Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile feuchte Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile feuchte Makulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile intellektuelle Leistungsminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile subkapsuläre Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile subkapsuläre anteriore Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile subkapsuläre posteriore Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile trockene Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senile zerebrale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniler Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniler Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Angiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Ektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Herz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seniles Keratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senilität, sich alt fühlen/benehmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senior-Loken-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senk-Knick-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senk-Knickfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senk-Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senkfuß/Plattfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senkniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Senkwehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilisierung des Sinus caroticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilitätsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilitätsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilitätsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibilitätsstörung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensible Störung einzelner peripherer Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensible Störung einzelner peripherer Nervenwurzeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibles C6-C8-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensibles C6-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitiv paranoide Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitiv paranoide Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitiv paranoische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitiver Beziehungswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitivitätstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitivitätstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensitivitätstest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F32'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensomotorische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensorineuraler Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensorisch-motorischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sensorischer Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis acutissima hyperergica fulminans [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis als Impfkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis bei Aktinomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis bei Malleus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis bei Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis bei Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Anaerobier beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Apparat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Bacillus anthracis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Erysipeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Erysipelothrix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Escherichia coli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Escherichia coli beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Implantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Kolibazillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Listerien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Pasteurella multocida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Staphylococcus aureus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Streptokokken Gruppe A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Streptokokken Gruppe B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Streptokokken Gruppe B beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Streptokokken Gruppe D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch Yersinia pestis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch extraintestinale Yersiniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch gramnegative Erreger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis durch koagulasenegative Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis lenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis nach Infusion, therapeutischer Injektion oder Transfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis nach Tracheotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sepsis post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septikopyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Angina durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Appendixthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Embolie bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Gebärmutterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Halsentzündung durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Orchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Phlegmone a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Pleuropneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Tuberkulose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Uterusphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septische Zystitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septischer Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septischer Spontanabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septum des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septum des Sylvius-Aquäduktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septumdeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Septumverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sequestration der Nasennebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sequoiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serinstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serofibrinöse Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serofibrinöse Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serologische Neurosyphilis ohne Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serologische Neurosyphilis ohne Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seromukotympanon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seromuköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seronegative chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seronegativer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seronegativer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seropneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seropositive chronische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seropositiver Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seropositiver Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seropurulente Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serotympanon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serpiginöse Chorioideopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serratus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Leydig-Zell-Tumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Leydig-Zell-Tumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Adenom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Adenom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Karzinom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Karzinom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Tumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sertoli-Zell-Tumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumausschlag a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumdermatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumexanthem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumgelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumhepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumurtikaria a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Serumvergiftung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Chorioenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Choriomeningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Netzhautablösung ohne Netzhautriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse Saktosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröse epidemische Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröser Gehirnerguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröser Tumor mit geringem Malignitätsgrad',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Adenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Zystadenofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Zystadenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Seröses Zystom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sesamoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sever-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sever-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sever-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualerziehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualhormonstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexually transmitted disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualstörung bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexualstörung bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Abnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Anhedonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Aversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Beziehungsstörung durch Bisexualität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Deviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Erregungsstörung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Frühreife bei Nebennierenrindenhyperplasie beim Knaben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Frühreife bei Nebennierenrindenhyperplasie beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Funktionssymptome/-beschwerden, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Hyperaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Hypoaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Impotenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Perversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Psychopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Unreife nach der Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Unterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Verhaltensabweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexuelle psychogene Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexueller Masochismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sexueller Sadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sezernierende Mamille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sezernierende Mamille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sezernierende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sezernierende Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sezernierende Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sharp-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sheehan-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sheehan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shiga-Kruse-Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shiga-Kruse-Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigella-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigella-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigella boydii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigella dysenteriae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigella flexneri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigella sonnei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigellen der Gruppe A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigellen der Gruppe B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigellen der Gruppe C',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shigellose durch Shigellen der Gruppe D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shin Splints durch Überlastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shipyard-Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shirodkar-Naht bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Short-bowel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shuddering Attacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shuddering Attacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shuntverschluß bei terminaler Niereninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Shy-Drager-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialadenitis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialadenitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialoadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialoadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialodochitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialodochitis fibrinosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialodocholithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialolith',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialolith einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialolith eines Speicheldrüsenausführungsganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sialose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sibirisches Zeckenbißfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sicard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sicca-Syndrom der Augen im Sinne des Sjögren-Syndroms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sicca-Syndrom des Auges im Sinne des Syndroms des trockenen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellen-Beta-Thalassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellen-Hämoglobinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellen-Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellen-Thalassämie-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellenanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellenerbanlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellenheterozygotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellenstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichelzellträger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sichtbare Darmbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sick sinus Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sick-Sinus-Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideroachrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideroblastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideropenische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideropenisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sideroprive Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderosilikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderosis bulbi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderosis lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siderosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhleneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlensinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinhöhlenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebbeinzellenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siebentagefieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siegelringzelladenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siegelringzellenkarzinom des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siemens-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigma-Scheiden-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigma-Vagina-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmadivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmadivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmadivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaeinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaelongation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmatismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmatismus interdentalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmaverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmavolvulus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoideumadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoideumobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoideumtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sigmoidulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silbenstolpern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silbervergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silent menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikose mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikotische Lungenfibrose durch Quarzstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikotische Lungenfibrose durch Talkumstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silikotuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silofüllerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silofüllersyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Silver-Russell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simmonds-Kachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simmonds-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simmonds-Sheehan-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simons-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simons-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simulant',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simulantentum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simulieren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simultane Wahrnehmung ohne Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Simultanperzeption ohne Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinding-Larsen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Single ventricle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Singuläre Arteria umbilicalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Singulärer Ventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Singulärer Vorhof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinistroflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinistropositio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinistroversio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinnesorgananomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuatriale Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuatrialer Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuatrialer Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuaurikuläre Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuaurikulärer Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuaurikulärer Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchiales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchitis beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchitis beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinubronchitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinupharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus der Kiemenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus pericranii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus pilonidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus-Vorhof-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus-cavernosus-Defekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinus-coronarius-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusarrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusbradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinushistiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinushistiozytose mit massiver Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinushyalinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis der Nebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis durch Barotrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris chronica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris et ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris frontalis et ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris mit Sinusitis frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris mit akuter Sinusitis ethmoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis maxillaris mit chronischer Sinusitis frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusitis sphenoidalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusknotenblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinusknotensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinuslipomatose der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinustachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sinutracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sirenomelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sirenomelie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Siti',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sitophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situationsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situationsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situs inversus sive transversus abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situs inversus sive transversus cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situs inversus sive transversus thoracalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situs inversus sive transversus viscerum totalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Situs transversus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sitzbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sjögren Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sjögren-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sjögren-Larsson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sjögren-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skabies mit postskabiösem Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skalenussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skalpellwunde beim Neugeborenen durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skaphozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skaphozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapulaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapulaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuladislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuladistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapulafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapulalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapulo-humerale Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuloperonäale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuloperonäale Form der spinalen Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuloperonäale Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skapuloperonäalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skarabiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skelett-Tuberkulose a.n.k. [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skelettfluorose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skelettneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skerljevo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skerljevo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerakalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleramelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleranekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraperforation ohne Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerastaphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerastaphyloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleratuberkulose [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleratumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleratumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraverletzung ohne Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleraverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerem beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerenikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleritis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleritis anularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleritis bei Zoster [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleritis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerochorioiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerodermie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerodermie der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleroedema adultorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleroedema beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerokeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerokonjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleroma respiratorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleromalacia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleromyxödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skleronychie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose der Membrana tympani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose des His-Bündels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose einer peripheren Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerose eines Herzkranzgefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Adenose der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Garré-Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Gefäßveränderung des Auges [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Hinterstranglues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Hinterstranglues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Hinterstrangsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Hinterstrangsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende Leukenzephalopathie Bogaert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende nichteitrige Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierende nichteitrige Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierender stromaler Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierendes Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierendes Lipogranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerosierendes nichtabgekapseltes Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerotenonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerotische Makulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerotische Plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerotische Retinopathie [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerozystisches Ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sklerödem beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliose nach Strahlentherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliotische Fehlhaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliotische Haltungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skoliotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skorbut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skorbut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skorbutisches Zahnfleisch [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skotom und Blendung bei auf das Auge beschränkter Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofuloderm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöse Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöse Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöse tuberkulöse Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöse tuberkulöse Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöser Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöses Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrofulöses Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotalnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotalpruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotalzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotalzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotum-/Hodensymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumhydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotummykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumphlebektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumtuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Skrotumödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slim disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slipping patella',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slow Virus Infection',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slow-Virus-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slow-Virus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Slow-Virus-Infektion des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sluder-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sluder-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Small-and-light-for-date-Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Small-and-light-for-date-Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Small-for-date-Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Small-for-date-Säugling',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Small-vessel-Disease',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Smegmaretention der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Smith-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Smith-Lemli-Opitz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Smith-Strang-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Snail fever - s.a. Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sneddon-Wilkinson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sodbrennen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sodoku',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sodomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solides Teratom - s. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäre Knochenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäre Tuberkel des Gehirns [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitärer Plasmazelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäres Analulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäres Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäres Myelom in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitäres Plasmozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitärknoten der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Solitärzyste der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatische Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatische Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatisierte Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatisierungsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatisierungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatoforme Schmerzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatoforme Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatomotorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somatosensorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommer-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommer-Meningoenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommerbeine bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommerdiarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommerdiarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommergrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommerkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommersprossen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sommersprossen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somnambulismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Somnolenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonderform der Morquio-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenbedingte Schuppung/Sonnenbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenblumenartige Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenbrand 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenbrand 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenbrand 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenlichtallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenlichtbedingte Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenlichtschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sonnenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor der männlichen Genitalien [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor der männlichen Genitalien [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor der männlichen Genitalien [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor der weiblichen Genitalien [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor des Gesäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor mit Einbeziehung der Nägel/Perianalregion/Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soor mit Windeldermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorbalanitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorbronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorbronchopneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soordermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorglossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorinfektion des Genitalbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorinfektion des Genitalbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorinfektion des Genitalbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorintertrigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorkolpitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soormeningitis [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soormykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soormykose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soormykose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soormykose der Glans penis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorpneumonie [kodiere zusätzlich J17.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorpyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorpyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorpyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorsepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorstomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soortracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorvaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorvulvitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soorvulvovaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge um Aussehen der weiblichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge um schwangerschaftbedingtes Aussehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge um/Angst vor einem sozialen Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Arbeitslosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Arbeitslosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Arbeitsplatzverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Arbeitsplatzverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Bankrotts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Entlassung aus dem Gefängnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Freiheitsstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Inhaftierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Jobwechsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Jobwechsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Migration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Migration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Rechtsstreitigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Rechtsstreitigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Rechtsstreitigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Strafverfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Strafverfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Strafverfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Verurteilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Verurteilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorge wegen Verurteilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sorgen wegen des Alterns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sotos-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozial unzulängliche Fähigkeiten a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Ablehnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Anpassungsstörung mit emotionaler Beeinträchtigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Ausgrenzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Ausgrenzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Funktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Isolierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Isolierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Probleme ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Verfolgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziale Ängstlichkeit im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialer Rollenkonflikt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sozialkonflikt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziokulturelle Probleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziopathische Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Soziopathische Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalding-Zeichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des Processus alveolaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten Gaumens mit Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten Gaumens mit einseitiger Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten und weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten und weichen Gaumens mit Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten und weichen Gaumens mit beidseitiger Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des harten und weichen Gaumens mit einseitiger Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des weichen Gaumens mit Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spalte des weichen Gaumens mit einseitiger Lippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltung der Herztöne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltung der Nägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltung des Os scaphoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltungsirresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltwirbel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltzunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spaltzyste des Mundbereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spanischer Kragen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spannungskopfschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spannungskopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spannungspneu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spannungspneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spannungszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmodische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmodische Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmodische Rhinorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus der Cervix uteri als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus der Cervix uteri als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus der Flexura coli sigmoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus der Vater-Papille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus des Musculus levator palpebrae superioris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus des Musculus obliquus inferior oculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus des Nervus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus glottidis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus hemifacialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmus nutans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spasmusinduzierte Angina pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bronchitis beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bronchitis beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bronchitis beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Dysphonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Einwärtskehrung des Lids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Emphysembronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Halbseitenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Hemiparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Obstipation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Paraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Parese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Proktalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Pseudosklerose mit Demenz [kodiere zusätzlich F02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Quadriplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Querschnittlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Spinalparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Tetraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastische familiäre Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Blitzkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Dickdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Krupp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Senkfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastischer Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastisches Entropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spastisches Kolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spatelfinger [Trommelschlegelfinger]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speckleber [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speckmilz [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speckniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsen-Virus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenausführungsgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenausführungsgangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüseneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenhypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüseninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüseninvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenlipomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenmukozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsensekretionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speicheldrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelgangstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelstein einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelstein eines Speicheldrüsenausführungsganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichelsteinleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speichensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseaspiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrendivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrendyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhreneinengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenerkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Speiseröhrenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatikusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatocele testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatocystitis tuberculosa [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatogenetische Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatogramm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatohydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermatozytäres Seminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermienzählung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermienzählung nach Vasektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spermienzählung nach Vasektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielle Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezieller bakterieller Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Augenkrankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Chromosomenanomalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Deformitäten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Ernährungsstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf HIV [Humanes Immundefizienz-Virus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Lungentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung des Darmtraktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Neubildung des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Ohrenkrankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf Verhaltensstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf angeborene Fehlbildungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf bestimmte Entwicklungsstörungen in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf infektiöse Darmkrankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf kardiovaskuläre Krankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezielles Screening auf psychische Krankheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische Lernstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische Phobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische emotionale Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische syphilitische Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische syphilitische Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische ulzeröse Balanoposthitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spezifische ulzeröse Balanoposthitis [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphakelus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphenoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphenopalatinale Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphenozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spherocytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphincter-urethrae-Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphincter-vesicae-Myasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphincter-vesicae-Relaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphincter-vesicae-Schwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphingolipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphingolipoidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphingomyelinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphingomyelinspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphingomyelinthesaurismose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphinkterkrampf des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphinkterspasmus der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphinkterspasmus des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphinkterverletzung der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphäroidale Hornhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphärozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphärozytose bei Sichelzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sphärozytose mit Hämoglobinkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spider naevus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spider-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spieghel-Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spiegler-Syringadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spieglertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spielmeyer-Vogt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spielmeyer-Vogt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spielsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida aperta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida mit Hydrozephalus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina bifida occulta [Okkulte spinale Dysraphie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spina ventosa [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalbedingte Reflexblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Heterotopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Hydromeningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Kyphose [kodiere zusätzlich M49.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Meningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Muskelatrophie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale juvenile Muskelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale meningeale Adhäsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale progressive Amyotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinale tuberkulöse Leptomeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinaler Muskelschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinales Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinaliom der Haut [Plattenepithelkarzinom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalnervenwurzelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spindelhaare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spindelzelliger Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spindelzelliges Lipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spindelzelliges Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spindelzelliges Synovialsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinnenfingerigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinnengliedrigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinnenmal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinnennävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinnenzellgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spinozelluläres Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spintheropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spiradenom - s. Neubildung, Haut, gutartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirillose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirochaetosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirochaetosis icterohaemorrhagica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirochäten-Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirochäten-Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirochätose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirometrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spirometrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitz-Klumpfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzes Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzes Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spitzwinklige Anteflexio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splanchnoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenitis bei Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenogene Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenogene Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenomegale Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenomegalia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenomegalie bei Malaria [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenopathische Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splenozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Splitternder Nagel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis bei Brucellose [kodiere zusätzlich M49.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis bei Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis bei Tuberkulose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis brucellosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis durch Enterobakterien [kodiere zusätzlich M49.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis durch Gonokokken [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis durch Gonokokken [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis hyperostotica [Forestier-Ott-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis hyperostotica [Forestier-Ott-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis psoriatica [kodiere zusätzlich M07.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylitis typhosa [kodiere zusätzlich M49.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylogener Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylolisthesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylolisthesis mit fetopelvinem Mißverhältnis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylopathia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spondylosr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spongioblastoma multiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spongioblastoma polare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spongioblastosis centralis circumscripta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spongioforme Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Ablatio chorioideae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Dislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Ekchymose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Hämorrhagie der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontane Leberruptur als Komplikation bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner Abort mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner Geburtsbeginn vor der vollendeten 37. Schwangerschaftswoche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner Geburtsbeginn vor der vollendeten 37. Schwangerschaftswoche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner habitueller Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner inkompletter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner kompletter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner unvollständiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontaner vollständiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontangeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontangeburt aus Beckenendlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontangeburt aus Schädellage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontankeloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontannystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanpneumothorax a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanruptur einer Beugesehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spontanruptur von Strecksehnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadisch zystische adenomatöse Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Schilddrüsenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Struma diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Struma nodosa simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Struma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische hyperplastische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische kolloide Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadische parenchymatöse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer Kretinismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer adenomatöser Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer einfacher Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer kolloider Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer nichttoxischer Knotenkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporadischer zystischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sporozoa-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sportlerherz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sportuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spotting',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachbildungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachdefekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachfehler a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachproblem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprachverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprechproblem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprechstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprechtherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spreizfuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprengel-Deformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprengel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprengung der Symphyse bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprengung der Symphyse bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spring- und Dreh-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spritzenkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprue-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprungbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprunggelenks-/Knöchelsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprühinjektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprühinjektion durch Farblösungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprühinjektion durch Luft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sprühinjektion durch Wasser',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spurenelementmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sputum mit Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spät beginnendes Marie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte Blutung nach Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte Nachblutung nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte Neurosyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte Thelarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte traumatische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späte traumatische Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Späterbrechen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolge einer Gehirnerschütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Hirngefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer TBC [Tuberkulose] der Harn- und Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer TBC [Tuberkulose] der Knochen und Gelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer TBC [Tuberkulose] des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen einer akuten Poliomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen eines Trachoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen von Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen von Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen von Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätfolgen von Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätform der amaurotischen Idiotie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätframbösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätgeburt des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätgeburt des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätgestose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätlues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätlues mit Frühstadiumsymptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätlues mit Frühstadiumsymptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätlähmung des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätläsion der Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätläsion der Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätparalyse des Nervus medianus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätparalyse des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätparaphrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätparese des Nervus ulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätrachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätrezidiv bei Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätrezidiv bei Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätstadium der Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätstadium der Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Atemwege [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Atemwege [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Bauchhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Bauchhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Blase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Blase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Cervix uteri [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Cervix uteri [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Eingeweide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Eingeweide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Epiglottis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Epiglottis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Gallenblase [kodiere zusätzlich K87.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Gallenblase [kodiere zusätzlich K87.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Harnblase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Harnblase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Kornea [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Kornea [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Lingualtonsillen [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Lingualtonsillen [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Nase [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Nase [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Niere [kodiere zusätzlich N29.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Niere [kodiere zusätzlich N29.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Orbita [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Orbita [kodiere zusätzlich H06.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Pleura [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Pleura [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Prostata [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Prostata [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Sklera [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Sklera [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Thyreoidea [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Thyreoidea [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Trachea [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Trachea [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Tuba uterina [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Tuba uterina [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Tunica vaginalis testis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Tunica vaginalis testis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Urethra [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Urethra [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Vesica urinaria [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Vesica urinaria [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Zervix [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Zervix [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Zunge [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis der Zunge [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Augenlids mit Gumma [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Augenlids mit Gumma [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Auges [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Auges [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Darmes [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Darmes [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Eileiters [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Eileiters [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Felsenbeins [kodiere zusätzlich M90.28*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Felsenbeins [kodiere zusätzlich M90.28*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Gaumens [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Gaumens [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Glaskörpers [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Glaskörpers [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Kolons [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Kolons [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Larynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Larynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Mediastinums [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Mediastinums [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Nebenhodens [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Nebenhodens [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Ovars [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Ovars [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Pankreas [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Pankreas [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Periost [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Periost [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Pharynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Pharynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Rektums [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Rektums [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Samenleiters [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Samenleiters [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Skrotums [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Skrotums [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Thymus [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Thymus [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Tränenapparates [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Tränenapparates [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Uterus [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Uterus [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Ösophagus [kodiere zusätzlich K23.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis des Ösophagus [kodiere zusätzlich K23.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis einer Bursa [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis einer Bursa [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis einer Sehne [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis einer Sehne [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis eines Gelenks [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilis eines Gelenks [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Arthritis [kodiere zusätzlich M01.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Augenkrankheit [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Bursitis [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Bursitis [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Chorioretinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Chorioretinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Dakryozystitis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Dakryozystitis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Entzündung des weiblichen Beckens [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Entzündung des weiblichen Beckens [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Episkleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Episkleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Glaskörpertrübung [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Glaskörpertrübung [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hyalitis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hyalitis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hydrarthrose [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Hydrarthrose [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Laryngitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Laryngitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Laryngotracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Laryngotracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Leontiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Leontiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Leukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Leukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Mediastinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Mediastinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Nephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Nephrose [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Nephrose [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Neuritis des Nervus vestibulocochlearis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Neuritis des Nervus vestibulocochlearis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Optikusatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Optikusatrophie [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Ostitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Ostitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Perichondritis des Larynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Perichondritis des Larynx [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Peritonitis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Peritonitis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Pyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Pyelonephritis [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Sinusitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Sinusitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Skleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Skleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Tracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Tracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Zervizitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Zervizitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische Zystitis [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische retrobulbäre Neuritis [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische retrobulbäre Neuritis [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische sternförmige Hyalosis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitische sternförmige Hyalosis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitisches Leukoderm [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Spätsyphilitisches Leukoderm [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Squamöse Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Squamöse Vaginalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Squamöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'St.-Joachimstal-Fieber [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stabiler Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stabsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stabsichtigkeit, jede Art',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stafne-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stafne-Zyste des Unterkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stagnationspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stahlohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stakkatoartiger Harnstrahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stamm- und Seitenastvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammadipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammadipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammeln/Stottern/Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammfettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammfettsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammganglienblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammganglienikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammganglienschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammhirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvarikose bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvarikose der Vena saphena magna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvarikose der Vena saphena parva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvarikose des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammvenenvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammzellenleukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stammzellenleukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Standunsicherheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stangler-Zuschrott-Divergenzlähmung mit Fernesotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stannose mit Tuberkulose der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stapesankylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stapesfixation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylococcal scalded skin syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylodermia superior impetiginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylodermia superior vesiculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylokokken-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphyloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphyloma corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphyloma posticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staphyloma posticum ohne degenerative Myopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stargardt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stargardt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Starke Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Starker Schwachsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Starrer Hymenalring',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Starrkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stasis duodenalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statisch-dynamische Haltungsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statische Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statische Dysmenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statische Lumbalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statische Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Statomotorische Retardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status anginosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status asthmaticus bei Asthma bronchiale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status epilepticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status epilepticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status epilepticus mit komplexfokalem Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status epilepticus partialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status febrilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status febrilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status marmoratus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach Cholezystektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach Laryngektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach Pankreatektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach Thyreoidektomie mit Hypothyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach Zystektomie der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach einseitiger oder beidseitiger Mastektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Gastrektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Kolektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Nephrektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Pneumonektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Salpingo-Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Salpingo-Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Salpingo-Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status nach teilweiser oder vollständiger Salpingo-Oophorektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status post Commotio cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status thymico-lymphaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status typhoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Status varicosus des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staubinhalations-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staublunge durch Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staublunge durch Steinstaub',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Staublungen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauchung der Halswirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauchung/Zerrung anderer Gelenke/Bänder',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsbronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsdermatitis bei Ulcus cruris varicosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsgallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsherzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungslunge bei Herzinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsmilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungspapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungspapille bei intrakranieller Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungspapille bei zerebralem Pseudotumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungspapille e vacuo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungstracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stauungszirrhose der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steatosis hepatis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steele-Richardson-Olszewski-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steele-Richardson-Olszewsky-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steell-Geräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steely-hair-Syndrom [Menkes-II-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steifer Nacken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steigerung der Schweißsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein der Ohrspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein der Parotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein der Vesicula seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein des Stensen-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein im Bauchspeicheldrüsengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein im Wharton-Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein in der Vater-Papille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stein-Leventhal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinbedingte Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinbildung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinbildung im Tränendrüsengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steine oder Gries in Blase/ Niere/ Harnleiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steiner-Voerner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinert-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinhauerkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinhauerlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinmetz-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinmetz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinmetzlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steinstaublunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steintragende Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steiß-Fuß-Lage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeindermoid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeindislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeindistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinfraktur bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinfraktur bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinschädigung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinschädigung als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinstörung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißbeinverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißlage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißlage mit Wendung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steißteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenokardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Aorta ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria carotis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria pulmonalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Foramina intervertebralia durch Bandscheiben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Stammganglienarterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der hinteren Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der hinteren Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der hinteren Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der oberen Hohlvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der unteren Hohlvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der vorderen Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der vorderen Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose der vorderen Nasenöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Aquaeductus cerebri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Canaliculus lacrimalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Fornix vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Ostium urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Punctum lacrimale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des Zervikalkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose des linken Hauptstammes der Koronararterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose durch Apparat, Implantat oder Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose einer Enterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose einer Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenose einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenosierende Cholangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenosierende Koronararteriensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenosis urethrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stenozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stensen-Gang-Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterbefall während der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stereoagnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stereotype Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stereotype abnorme Gewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stereotypie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterile Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterile Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterile Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisation bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisation bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisation beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisation beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisationsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisationsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisationswunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisationswunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisierung, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisierung, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisierungswunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilisierungswunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität bei Anorexie bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität bei depressiver Verstimmung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität bei der Frau im Zusammenhang mit Partner-Faktoren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität bei neurotischem Kinderwunsch bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität uterinen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilität zervikalen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilitätsberatung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterilitätskonflikt bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterkorales Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterkorales Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterkoralgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sterkoralulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternalknorpeldislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternförmige Hyalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternförmige Hyalosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternförmiger Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternoklavikulargelenkluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternoklavikularsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternokostalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternum bifidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumdistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternumverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sternzellgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steroidabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steroidakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steroidmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Steroidosteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stertor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stevens-Johnson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stewart-Morel-Morgagni-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stich durch Arthropoden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stich durch Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stich durch Skorpion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stich durch giftiges Insekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stichwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sticker-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sticker-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stickhusten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stickler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stieda-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stieda-Pellegrini-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stieda-Pellegrini-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stiff-man-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stiff-man-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Still-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stiller-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stiller-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillicidium urinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stilling-Türk-Duane-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillproblem beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillstand bei tiefem Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillstand bei tiefem Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillstand des Epiphysenwachstums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillstand in der aktiven Wehenphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stillstand in der aktiven Wehenphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandfixation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandhyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandleukokeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandparakeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbandödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenfixation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippengranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenhyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenkeratose [Stimmbandkeratose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenknötchen [Stimmbandknötchen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenleukokeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenparakeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenpolyp [Stimmbandpolyp]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenzyste [Stimmbandzyste]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlippenödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmritzenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmsymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmungslabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimmveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stimulanzienentzugssyndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stinknase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stippchengallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stippled epiphyses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnbeinanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhirnatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhirnsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlensinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenwandbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenwandfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnhöhlenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnlappenhämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stirnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stock-Spielmeyer-Vogt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselentgleisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselstörung bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselstörung bei Wehen und Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselstörung nach Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselstörung schwefelhaltiger Aminosäuren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stoffwechselversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis angularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis aphthosa herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis aphthosa herpetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis bei Moniliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis candidomycetica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis durch Geotricha',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis durch Herpesviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis durch Prothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis gangraenosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis herpetiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis vesicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis vesiculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatitis-vesicularis-Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stomatozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Storchenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Storchenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stottern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus accommodativus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus bei Muskeldystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus bei Stilling-Türk-Duane-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus bei orbitaler Myositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus concomitans a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus convergens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus convergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus convergens intermittens unilateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus convergens unilateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus deorsoadductorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus divergens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus divergens alternans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus divergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus divergens intermittens unilateralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus durch Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus durch Narben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus durch Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus paralyticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus sursoadductorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strabismus sursoadductorius et deorsoadductorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strafbare Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strafbare Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strafbarer Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlendermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenerythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenfolgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlengeschädigter Zahnschmelz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahleninduzierte Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenkatarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenkolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenkörperentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenmyelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlennephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenpilzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenpneumonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenreaktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenschaden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenschaden der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlentherapiesitzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlenwirkung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strahlungsinduzierte Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulation des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulation des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulation des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulationsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulierte Hämorrhoiden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulierte innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangulierte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strangurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streak-ovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strecksehnenriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streifenatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streifenkeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streitsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strephosymbolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptodermia cutanea lymphatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptodermia superior bullosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptodermia superior crustosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptodermia superior impetiginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptodermia superior vesiculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptogene Pityriasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptogenes Erythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptokokkeninfekt Hals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptokokkeninfektion der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streptotrichose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stress/Trauer/Heimweh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stressinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßamenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßinkontinenz der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßpolyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsituation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Streßulkus des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae adolescentium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae albicantes atrophicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae albicantes atrophicae der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae albicantes distensae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae albicantes distensae der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae atrophicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae atrophicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae cutis distensae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae distensae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striae rubrae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stridor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stridor congenitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stridulöse Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Flexura coli sigmoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Sigmaflexur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Vena cava inferior a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der Vena cava superior a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der hinteren Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der vesikourethralen Öffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur der vorderen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Os uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Ostium urethrae internum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Punctum lacrimale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striktur des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striopallidäre Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Striopallidäre Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strohkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromaendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromale Endometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromale Hornhautvaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromale Myose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromales Sarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromunfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stromverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strongyloidiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strophulus infantum pruriginosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma Rezidiv',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma adenomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma bei Enzymdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma congenita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma congenita parenchymatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma endemica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma gangliosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma hyperplastica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma lymphomatosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma maligna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma mit Schilddrüsenautonomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma multinodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma nodosa colloides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma nodosa diffusa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma nodosa mit Euthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma ovarii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Struma uninodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strumaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Strumitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuart-Bras-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuart-Prower-Faktor-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stufe 9 der Sehbeeinträchtigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlschmiere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlträgheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhluntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z36'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlverhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlverhaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlverstopfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuhlveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumme Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumme Thrombose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stummheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfes Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfes Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfes Bauchtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfes Thoraxtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfgastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfschmerzen nach traumatischer Armamputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stumpfschmerzen nach traumatischer Beinamputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stupor mit katatonen Symptomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sturge-Weber-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sturge-Weber-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sturzattacken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sturzgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sturzgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stuttgarter Hundeseuche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Styloiditis radii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Styloiditis ulnae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stäbchen-Zapfen-Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stähli-Linie der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stähli-Pigmentlinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stähli-Pigmentlinie der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ständiger Tablettenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ständiger Tablettenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ständiges Harnträufeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stärkeintoleranz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung Schwangerschaft/Entbindung, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung bei Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung beim Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung beim Zahnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Augenbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Augenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Biosynthese der testikulären Androgene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Eustachi-Röhre a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Immunmechanismen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Impulskontrolle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Impulskontrolle mit intermittierend auftretender Reizbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Muskelansätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Nahrungsverwertung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Protein-Energie-Balance',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Protein-Energie-Bilanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Schilddrüsenfunktion mit Exophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Sehbahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Sexualpräferenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Speichelsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Sprachentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Sprechentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Temperaturregulation beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Thyreokalzitoninsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der Vestibularfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der akustischen Diskrimination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der binokularen Augenbewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der blutbildenden Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der inneren Bauchspeicheldrüsensekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der inneren Pankreassekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der intestinalen Kohlenhydratabsorption a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der parasympathischen Uterusinnervation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der späten Lutealphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der sympathischen Uterusinnervation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung der transepidermalen Elimination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Binokularsehens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Chiasma opticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Corpus geniculatum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Elektrolytgleichgewichtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Elektrolythaushaltes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Erinnerungsvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Gamma-Glutamylzyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Harnsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Hörnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Immunsystems in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Kaliumgleichgewichtes beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Kauvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Mundepithels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Natriumgleichgewichtes beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Schlaf-Wach-Rhythmus durch Flugreisen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sehvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens bei fehlender sozialer Bindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens bei fehlender sozialer Bindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens in der Gruppe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens in der Gruppe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit Sozialisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit Zwangscharakter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Störung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit emotionaler Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit neurotischer Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit neurotischer Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit oppositionellem aufsässigem Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit oppositionellem aufsässigem Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit sozialer Bindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Sozialverhaltens mit sozialer Bindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Tractus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Verdauungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des Wasser- und Elektrolythaushaltes beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des kortikalen Sehzentrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des peripheren Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung des sympathischen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung durch Schädigung der tubulären Nierenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung im Patellofemoralbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung im Schlaf-Wach-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung im Wasserhaushalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung mit sozialer Ängstlichkeit im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung mit Überängstlichkeit im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störung von Haut und Unterhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Störungen der Kniescheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stürmischer Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Stürze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakromiale Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakut sklerosierende Leukoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Arthritis bei rheumatischem Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Bronchitis mit Bronchospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Dakryoperizystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Dakryophlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endocarditis lenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endocarditis ulcerosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Glomerulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Iritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Kanalikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Karditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Leukämie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Melioidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Myelose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Myoendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Pankreatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Peridakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Periendokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Psychose bei Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Psychose bei endokriner Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Uveitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Verwirrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute allergische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute allergische blutige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute allergische muköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute allergische seröse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute bakterielle Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute blutige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute chemische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute chronische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute eitrige Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute exsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute fibrinöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute gelbe Leberatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute infektiöse Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute interstitielle Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute katarrhalische Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute kombinierte Rückenmarkdegeneration bei Vitamin-B12-Mangel [kodiere zusätzlich G32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute lymphatische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute lymphozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute lymphozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute maligne Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute membranöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute mesenteriale Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute monozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute monozytäre Leukämie in kompletter Remission',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute mukoide Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute muköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute myeloische Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute nekrotisierende Myelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute nekrotisierende Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute nichteitrige Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute obliterierende Bronchiolitis durch Einatmen einer chemischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute obliterierende Bronchiolitis durch Einatmen von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute obliterierende Bronchiolitis durch Einatmen von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute obliterierende Bronchiolitis durch Einatmen von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute organische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute phlegmonöse Dakryozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Arthritis mit mehrfacher Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute rheumatische Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute septische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute septische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute seromuköse Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute sezernierende Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute spongioforme Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute transsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute virale Bronchitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakute virale Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakuter Lichen ruber planus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakuter Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakuter nichtalkoholbedingter Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes Delir',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes Delir bei hirnorganischem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes Delir bei psychoorganischem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes Delir vom exogenen Reaktionstyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes Ulkus mit Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes psychoorganisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subakutes rheumatisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subaortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung aus einer Arteria communicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung aus einer Hirnarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung aus mehreren intrakraniellen Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung der Arteria communicans anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung der Arteria communicans posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalblutung durch rupturiertes zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidale Zyste der hinteren Schädelgrube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidales Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subarachnoidalhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subareolärabszeß im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subareoläre Milchgangpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subareoläre Milchgangpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subareolärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subareolärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subazidität des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subclavian-steal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdiaphragmatische Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdiaphragmatische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdiaphragmatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subduralblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subduraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subduraler intraspinaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdurales Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdurales intrakranielles Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subdurales intraspinales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subduralhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subendokardiale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subendokardiale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subendokardiale Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subependymales Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subependymalgliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subependymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subepidermale noduläre Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subepiglottische Verdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subepitheliale Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suberosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suberosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subgingivaler Zahnstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglossitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottische Amyloidose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottische Kehlkopfmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottische Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottische Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottische Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subglottiskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subhepatischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subhyaloidale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subhyaloidale Netzhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subinvolutio uteri bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subinvolution der Brustdrüse nach der Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subinvolution der Brustdrüse nach der Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektiv feuchtes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektiv vermindertes Dämmerungssehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektive Epiphora',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektive Hörstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektive Sehstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektiver Gesichtsfeldausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subjektiver Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkapitale Humerusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkapsuläre Glaukomflecken bei Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subklaviastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subklinischer Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subklinischer jodmangelbedingter Hypothyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkonjunktivale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkonjunktivale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkonjunktivale Prellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkonjunktivale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkorakoid-Pectoralis-minor-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkortikale Hämorrhagie des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkortikale intrazerebrale Blutung der Großhirnhemisphäre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Chromomykose mit Abszeß [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Chromomykose mit Zyste [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Lungenhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane Mukormykose [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutane chromomykotische Zyste [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutaner Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutaner Knoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subkutanes Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sublimatnephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sublingualabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxation der Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxation des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxationsstenose der Foramina intervertebralia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxationsstenose des Spinalkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subluxierbare Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submammäre Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submammäre Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submandibulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submandibulärstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submaxillare Tuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submaxillarer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submaxilläre Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submaxilläre Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submentale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submentale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submentaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submuköse Zungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submuköse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Submuköses Leiomyosarkom des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subnormale Erregungsleitung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subpelvine Harnleiterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subpelvine Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subpelvine Ureterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subperiostale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subperiostaler Knochenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subphrenische Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subphrenischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subpulmonalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subretinale Aderhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subretinale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subsepsis hyperergica sive allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subseröses Leiomyosarkom des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subskapuläre Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Substernale Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Substernale Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Substernaler Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtarsaler Bindehautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtentoriale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtertian-Malaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtotaler Prolaps von Uterus und Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtrochantäre Femurfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subtrochantäre Oberschenkelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subunguale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subunguale Verbrennung einer Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subunguale Verbrennung eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Subunguale Verätzung der Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suburethrale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suburethraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suburethraler Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suburämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Succinatsemialdehyd-Dehydrogenase-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suchtstoffabhängigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suchtstoffabhängigkeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudamina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudan-Blindheit durch Onchocerca volvulus [kodiere zusätzlich H45.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudanophile Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudden infant death syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudden infant death syndrome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudeck-Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudeck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudeck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sudor anglicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suffokation durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suffokation durch Schleim',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suffusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sugillation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizid/Suizidversuch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizidale Gefahr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizidgefahr - kodiere Diagnose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizidneigung - kodiere Diagnose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizidversuch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suizidversuch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulcus-ulnaris-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulfatasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulfatide Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulfhämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulfhämoglobinämie mit Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sulfitoxidasemangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sumpffieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sumpffieberanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superazidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superfecundatio',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superfekundation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superfetation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superficial spreading Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superficial spreading Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superfiziale Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superfizielle Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfizierte Exsikkationsdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfizierte Mykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfizierte Stauungsdermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfizierte Tinea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfizierte spastische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinfiziertes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Superinvolutio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supinatorlogensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supinatorsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppression des Binokularsehens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supprimierte Masern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Cholezystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Kieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Mastoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Orchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Osteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Osteoradionekrose des Kiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Phlegmone a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Prostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppurative Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suppuratives Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supra- und Infraspinatustendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supradiaphragmales Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supragingivaler Zahnstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraglottisches Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraglottisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraglottiskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraklavikuläre Lymphknotenmetastasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraklavikulärer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprakondyläre Ellenbogenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprakondyläre Humerusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supranukleäre Konvergenzstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supranukleäre Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraorbitale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraorbitale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraorbitalneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprapubischer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenale Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenale Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenaler Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suprarenales Melasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraspinatus- und Subskapularistendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraspinatussehnensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraspinatussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraspinatussyndrom im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraspinatustendinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supratentorielle Hirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supravalvuläre Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supravalvuläre Aortenstenose mit multiplen Anomalien [Williams-Beuren-Syndrom] [Idiopathische infantile Hyperkalzämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraventrikuläre Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraventrikuläre Extrasystolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraventrikuläre Extrasystolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supraventrikuläre paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supravesikale Obstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Supravesikale Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Surditas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Surdomutitas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter Endometriumbefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter Mammabefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter Mammographiebefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter Prostatabefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter Prostatabefund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter zervixzytologischer Papanicolaou-Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Suspekter zytologischer Befund aus weiblichen Genitalorganen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sutton-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sweet-Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sweet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Swift-Feer-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Swimmer`s itch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sydenham-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sydenham-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sydenham-Syndrom mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis barbae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis lupoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis non parasitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis parasitaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sykosis vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sylvatisches Gelbfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sylvest-Bornholm-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symbiotisch Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symbiotische Psychose im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symblepharon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symbolische Dysfunktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symmetrische Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symmetrische Keratodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathikoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathikotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathikovasaler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathikusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathikusschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Augapfelreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Chorioideareizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Gleichgewichtsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Iridozyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Irritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Ophthalmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Panuveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Reflexdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathische Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympathisches Paragangliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symphalangie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symphatikogoniom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symphysenabtrennung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symphysenabtrennung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symphysentuberkulose [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympodie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptom/Beschwerden der Vorhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Lymphozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Monozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Myotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Polyglobulie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatische frühzeitige myoklonische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptomatisches Chloasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptome/Beschwerden des Lymph-/Immunsystems, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptome/Beschwerden durch das Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Symptome/Beschwerden im Bereich Familienplanung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sympus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synchondrosenabnormität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synchrone hysteroskopische Insemination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synchysis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synchysis des Glaskörpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synchysis scintillans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syncytioma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der alveolären Hypoventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der alveolären Hypoventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der blauen Windeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der blinden Schlinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der chronischen Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der einseitig hellen Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der funktionellen Darmstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der langen QT-Zeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der thyreoadrenokortikalen Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der unruhigen Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der unruhigen Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der verzögerten Schlafphasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der vorderen Spinalarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der vorzeitigen Senilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom der zuführenden Schlinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des Colon irritabile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des ersten Kiemenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des fragilen X-Chromosoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des irritablen Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des leeren Nestes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des leeren Nestes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des leeren Nestes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des operierten Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des pharyngobranchialen Kiemenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des plötzlichen Kindstodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des plötzlichen Kindstodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des plötzlichen Todes im Säuglingsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des plötzlichen Todes im Säuglingsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des raschen Zeitzonenwechsels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des toxischen Schocks bei Tamponbenutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des trockenen Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des ungeschickten Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des unteren Nucleus ruber [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des unteren roten Kerns [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom des vierten Kiemenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom gonadotropinresistenter Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrom resistenter Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndroma mucooculocutaneum acutum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syndrome mit/ohne Schmerzausstrahlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synechie der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synechie der Pupille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synechie des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synechie des Cavum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syngamose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syngamosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkopaler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkope bei Druck auf den Sinus caroticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkope bei Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkope mit Vasokonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synkope nach Lumbalpunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synorchidie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synostosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synostosis radioulnaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synoviale Osteochondromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovialisruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovialom - s.a. Neubildung, Bindegewebe, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovialsarkom - s.a. Neubildung, Bindegewebe, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovialzyste im Kniekehlenbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis bei Gicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis bei Spätsyphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis bei Spätsyphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis bei Syphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis bei Syphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis crepitans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis durch Beanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis durch Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis durch Gonokokken [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis durch Gonokokken [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synovitis durch Überbeanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syntaktische Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synzephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synzytiales Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Synästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilid beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilid beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis bei Kindern unter 2 Jahren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis bei Kindern unter 2 Jahren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis beim Säugling a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis beim Säugling a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis connata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis connata tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis connata tarda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Aorta abdominalis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Aorta abdominalis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Aorta thoracica [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Aorta thoracica [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Dura mater [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Dura mater [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Eustachi-Röhre [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Eustachi-Röhre [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Synovialmembran [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis der Synovialmembran [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Skelett-Systems [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Skelett-Systems [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Testis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Testis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis durch Bluttransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis durch Bluttransfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis eines peripheren Nervs [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis eines peripheren Nervs [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis im Tertiärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis im Tertiärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis jeglicher Lokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis jeglicher Lokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis mit primärem Genitalaffekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilis mit primärem Genitalaffekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Alopezie [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Alopezie [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortendilatation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortendilatation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aorteninsuffizienz [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aorteninsuffizienz [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenklappenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenklappenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenregurgitation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenregurgitation [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortenstenose [kodiere zusätzlich I39.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortitis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Aortitis [kodiere zusätzlich I79.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Atrophoderma maculatum [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Atrophoderma maculatum [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Bulbärparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Bursitis [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Bursitis [kodiere zusätzlich M73.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Claudicatio intermittens [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Claudicatio intermittens [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dakryozystitis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dakryozystitis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Daktylitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Daktylitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dementia paralytica [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dementia paralytica [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dementia paralytica juvenilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Dementia paralytica juvenilis [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Duchenne-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Duchenne-Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endarteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endarteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endarteriitis obliterans der Hirngefäße [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endarteriitis obliterans der Hirngefäße [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endokarditis a.n.k. [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Endokarditis a.n.k. [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalomyelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalomyelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Exostose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Exostose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Fraktur [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Fraktur [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Gicht [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Gicht [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Halbseitenblindheit [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Halbseitenblindheit [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemianopsie [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemianopsie [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemianästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemianästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemiparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemiparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Herzklappenentzündung [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Herzklappenentzündung [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hirnnervenlähmung [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hirnnervenlähmung [kodiere zusätzlich G53.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hyalitis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Hyalitis [kodiere zusätzlich H45.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Karies [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Karies [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratitis parenchymatosa [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratitis parenchymatosa [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratoiritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Keratoiritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Knochenkaries [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Knochenkaries [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Komplikation bei Entbindung oder im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Komplikation bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Kraniotabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Kreislaufkrankheit a.n.k. [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Kreislaufkrankheit a.n.k. [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Labyrinthitis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Labyrinthitis [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Leberkrankheit [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Leberkrankheit [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Leukodermie a.n.k. [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Leukodermie a.n.k. [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Lissauer-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Lissauer-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Läsion des Pons cerebri [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Läsion des Pons cerebri [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mediastinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mediastinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningoenzephalozele [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningoenzephalozele [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningomyelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningomyelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningomyelozele [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Meningomyelozele [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mesarteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mesarteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Milzentzündung [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Milzentzündung [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mitralstenose [kodiere zusätzlich I39.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Mitralstenose [kodiere zusätzlich I39.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Monoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Myelitis transversa [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Myelitis transversa [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Myokarditis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Myokarditis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Nervenparalyse [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Nervenparalyse [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Neuritis [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Neuritis [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Neuroretinitis [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Neuroretinitis [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Okulopathie a.n.k. [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Okulopathie a.n.k. [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Ophthalmoplegie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Ophthalmoplegie [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Osteomyelitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Osteomyelitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Osteoporose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Osteoporose [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Pankreatitis [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Pankreatitis [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Parkinson-Krankheit [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Parkinson-Krankheit [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Parästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Perikarditis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Perikarditis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Periostitis [kodiere zusätzlich M90.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Peritonitis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Peritonitis [kodiere zusätzlich K67.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Phlebitis [kodiere zusätzlich I98.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Phlebitis [kodiere zusätzlich I98.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Psychose a.n.k. bei progressiver Paralyse [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Psychose a.n.k. bei progressiver Paralyse [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Ptose [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Ptose [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Pulmonalklappeninsuffizienz [kodiere zusätzlich I39.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Pulmonalklappeninsuffizienz [kodiere zusätzlich I39.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Radikulitis [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Radikulitis [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rhinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rhinitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rupia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rückenmarkblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rückenmarkblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rückenmarkdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Rückenmarkdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Salpingitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Salpingitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Sarkozele [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Sarkozele [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Sattelnase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Schleimhautpapeln [Plaques muqueuses]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Schleimhautpapeln [Plaques muqueuses]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Schwerhörigkeit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Schwerhörigkeit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Skleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Skleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Splenitis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Splenitis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Splenomegalie [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Splenomegalie [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Spondylitis [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Spondylitis [kodiere zusätzlich M49.39*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Striae atrophicae [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Striae atrophicae [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Striktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Striktur a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Synoviitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Synoviitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Synovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Synovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Säbelscheidentibia [kodiere zusätzlich M90.26*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Säbelscheidentibia [kodiere zusätzlich M90.26*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tachykardie [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tachykardie [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tarsitis [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tarsitis [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Taubheit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Taubheit [kodiere zusätzlich H94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tenosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tenosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Tracheitis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Valvulitis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Valvulitis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Verengung der Koronararterien a.n.k. [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Verengung der Koronararterien a.n.k. [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Zervizitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische Zervizitis [kodiere zusätzlich N74.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische adhäsive Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische adhäsive Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische arterielle Verschlußkrankheit [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische arterielle Verschlußkrankheit [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische chronische Hodenfibrose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische chronische Hodenfibrose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische kardiale Dekompensation [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische kardiale Dekompensation [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische makulöse Hautatrophie [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische makulöse Hautatrophie [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische muköse Plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische muköse Plaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische paroxysmale Tachykardie [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische paroxysmale Tachykardie [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische retrobulbäre Neuritis [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische retrobulbäre Neuritis [kodiere zusätzlich H48.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische spinale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spastische spinale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spinale Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische spinale Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische zerebrale Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische zerebrale Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische zerebrale Arteriitis [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitische zerebrale Arteriitis [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Gehirntumor [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Gehirntumor [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Parkinsonismus [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Parkinsonismus [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schnupfen beim Kleinkind [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer Schnupfen beim Kleinkind [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer konnataler Hydrozephalus [kodiere zusätzlich G94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitischer konnataler Hydrozephalus [kodiere zusätzlich G94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Aortenaneurysma [kodiere zusätzlich I79.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Aortenaneurysma [kodiere zusätzlich I79.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Argyll-Robertson-Syndrom [kodiere zusätzlich H58.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Argyll-Robertson-Syndrom [kodiere zusätzlich H58.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Condyloma latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Condyloma latum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Glaukom [kodiere zusätzlich H42.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Glaukom [kodiere zusätzlich H42.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Gumma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Gumma a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Gumma des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Gumma des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Hepar lobatum [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Hepar lobatum [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Malum perforans pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Malum perforans pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Neurorezidiv der Retina [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Neurorezidiv der Retina [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Papillenödem [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Papillenödem [kodiere zusätzlich H48.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Parkinson-Syndrom [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Parkinson-Syndrom [kodiere zusätzlich G22*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Staphylom [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Staphylom [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Säbelbein [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Säbelbein [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Vorhofflimmern [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches Vorhofflimmern [kodiere zusätzlich I52.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches intermittierendes Hinken [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches intermittierendes Hinken [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches zentrales Skotom [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilitisches zentrales Skotom [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom des Kreislaufsystems [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom des Kreislaufsystems [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilom des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syphilophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringitis der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringitis des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringoadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringobulbie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringomyelitische Arthropathie [kodiere zusätzlich M49.49*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringomyelozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringomyelozele mit Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringopontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Syringozystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systematisierte erbliche Osteosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systematisierter Wahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemic inflammatory response syndrome [SIRS]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Autoimmunkrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Bindegewebetuberkulose [kodiere zusätzlich M36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Chondromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Hämangiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Infektion durch Haemophilus aegyptius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Krankheit der Gewebsmastzellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Mastzellenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Panuveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemische Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemischer Lupus erythematodes [SLE]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemkrankheit des Bindegewebes bei Hypogammaglobulinämie [kodiere zusätzlich M36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemkrankheit des Bindegewebes bei Ochronose [kodiere zusätzlich M36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systemmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Systolikum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Szirrhöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'São-Paulo-Fleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säbelscheidentrachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sämisch-Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sämisch-Geschwür der Kornea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sängerknötchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuberung einer künstlichen Körperöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuferleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsdiarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsdiarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsdiarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsdiarrhoe mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsgastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsgastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsgastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsgastroenteritis mit Exsikkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingskolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säuglingsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säure-Indigestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Säureverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sézary-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Sézary-Retikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Südafrikanische Porphyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Südamerikanische Blastomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Südamerikanische Haut-Schleimhaut-Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Südamerikanisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Südostgrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'T-Zell-Lymphom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'T-Zellen-Leukämie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'T-Zonenlymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'T-förmiger Schneidezahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TAR-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] - s.a. Tuberculosis oder s.a. Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] bei Silikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] der peripheren Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] der tracheobronchialen Drüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose] des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose]-Erstinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TBC [Tuberkulose]-Primärinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TGA [Transposition der großen Arterien]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TIA [Transitorische ischämische Attacke] - s.a. transitorische ischämische Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'TSH [Thyreoideastimulierendes Hormon]-Überproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabak-Abhängigkeitssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabak-Konsum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakentzugssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakmissbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakmißbrauch in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabakvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabardillo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabardillofieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabardillofieber durch Flöhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes cerebrospinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes cerebrospinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes dorsalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes infantum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabes mesenterica [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Arthritis [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Arthropathie [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Arthropathie [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Charcot-Arthropathie [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Charcot-Arthropathie [kodiere zusätzlich M14.6*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Krise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Neurolues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Organkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Organkrise',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische zerebrospinale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabische zerebrospinale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenbehandelter Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenbehandelter Typ-II-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tabletteningestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tablettensucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taboparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tachykarde Herzrhythmusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tachykardie-Bradykardie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tachypnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taenia-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taeniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taeniasis intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tagblindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tageseinnässen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tahyna-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Takahara-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Takahara-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Takayasu-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Takayasu-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taktile Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taktile Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talgzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talkose der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talus verticalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talus-Navikulare-Fusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talus-Navikulare-Synostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talusdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Talusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tamoxifen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tanapocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tanapocken-Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tangier-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tangier-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapetoretinale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapetoretinale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapetoretinale Leber-Amaurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapetoretinale Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapetoretinale hereditäre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tapia-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Targetzellen-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsal coalition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsometatarsale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsusanomalie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tarsusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taschenbildung des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taschenbildung des Pharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taschenbildung eines Bronchus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tastleistenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tastsinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tastsinnstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tastsinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tastsinnverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tattoo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubenzüchterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubenzüchterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit auf einem Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit durch Anomalie der Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit durch Schallempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit durch die Einwirkung großer Höhe auf die Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit durch toxisches Agens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit für hohe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit für hohe und tiefe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheit für tiefe Frequenzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubheitsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taubstummheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taucher-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taucherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tauchkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taumel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taumelnder Gang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taurodontismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taussig-Bing-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Taussig-Bing-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tay-Sachs-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tay-Sachs-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerfarbiger Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teermelanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerstuhl/Melaena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teerzyste des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tegmentale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tegmentum-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilagenesie des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilaplasie des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilmotorische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilung der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilung des äußeren Muttermundes in zwei Öffnungen durch ein Frenulum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Agenesie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Anodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Durchtrennung eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Durchtrennung eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Muskeldurchtrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Obstruktion der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise Zahnlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teilweise retinierter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teleangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teleangiektatische Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teleangiektatisches Osteosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temperaturempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temperaturempfindungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temperaturentgleisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temperaturentgleisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporale Papillenabblassung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporale Restinsel des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporales Astrozytom 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporalhirnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporallappenastrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporallappenepilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporallappensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporomandibuläre Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporomandibuläre Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporomandibuläre Luxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporosphenoidaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Temporäre Situationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis der Glutäussehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis der Iliopsoassehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis der Peronäussehne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis durch Beanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis durch Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis durch Überbeanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis tibialis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis tibialis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinitis trochanterica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendinosis calcarea der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendomyopathie des Schultergürtels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendomyopathie im Schulterbereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendomyose des Schultergürtels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendopathia nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendopathie des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendopathie des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendopathie mit diffuser Enthesopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendoperiostopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tendovaginitis stenosans (de Quervain)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenesmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tennisellenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tennisellenbogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenonitis der Augapfelkapsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis bei Spätsyphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis bei Spätsyphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis bei Syphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis bei Syphilis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis des Bizeps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis durch Beanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis durch Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis durch Gonokokken [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis durch Gonokokken [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tenosynovitis durch Überbeanspruchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tension headache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tentoriumblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tentoriumhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tentoriummeningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tentoriumpetechien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoblastom - s. Neubildung, bösartig',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoides Medulloepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratokarzinom der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratom - s. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratom der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratom mit maligner Transformation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoma - s. Neubildung, unsicheres Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoma benignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoma cysticum adultum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratotumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teratozoospermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terminale Makrohämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terminale renale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terminales chronisches Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ternidensiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terrien-Degeneration der Hornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terrorismusopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terrorismusopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terrorismusopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Terson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Rupia [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Rupia [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre syphilitische Aphasie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tertiäre syphilitische Aphasie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Test auf Arzneimittel im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Test auf Drogen im Blut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Test eines Laborparameters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikelhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikelmaldeszension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikeltuberkulose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Androgenhypersekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Androgenvermehrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Androgenüberproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläre Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikulärer Androgenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikulärer Hypergonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikulärer Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikulärer stromaler Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläres Adenom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testikuläres Adenom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testishypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testiskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testistuberkulose [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testistumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testisverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testiszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testosteronmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultat/ Ergebnis einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Testresultate/ Ergebnisse einer Maßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A60'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetania bei Alkalose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanie bei Hypoparathyreoidismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanie bei Rachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanie beim Neugeborenen ohne Kalzium- oder Magnesiummangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanie nach Entfernung der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanie nach Thyreoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanisches Achsen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanisches Achsen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus bei Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus bei Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus bei Omphalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus-Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetanus/Wundstarrkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tethered-cord-Syndrom [Adhäsionssyndrom des unteren Rückenmarks]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetra-X-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetramastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetramastie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetraparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetraplegie bei spastischer infantiler Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetraplegie beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tetraspastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Teufelsgriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamisches Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamusmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalamussyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassaemia intermedia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassaemia major',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassaemia minor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassaemie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassämie mit Retinopathie [kodiere zusätzlich H36.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassämie-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalassämievarianten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thalliumvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thanatophorer Minderwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thanatophorer Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thaysen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thecoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thecoma malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Theka-Granulosazell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekalutein-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekazell-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekazellkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thekomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelaziasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thelorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Beratung/Zuhören',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z58'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Malaria-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutische Übung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapeutischer Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapiebedürftige HIV-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapieresistente Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapieresistente Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Therapieresistenter vaginaler Fluor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thermale Urtikaria durch Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thermale Urtikaria durch Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thermoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiaminhydrochloridmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thibièrge-Weissenbach-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thibièrge-Weissenbach-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiel-Behnke-Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiemann-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiemann-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thiemann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thomsen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thomsen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thomson-Komplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thomson-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thomson-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoracic-outlet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Hiatushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Nervenwurzelschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Wurzelläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Ösophagusprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakale Ösophagusprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakaler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakaler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakales Aneurysma dissecans aortae Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakales Aneurysma dissecans aortae Typ B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakales Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakales Ösophaguskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakalkyphose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoabdominale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoabdominales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoabdominales Aneurysma dissecans aortae Typ A',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoabdominales Aneurysma dissecans aortae Typ B',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoabdominales Aortenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakogastrische Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakogastroschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakointestinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbale Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbale Spina bifida',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbale Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakolumbalskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorakoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxabszeß mit Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxbedingte Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxdistorsion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxerfrierung mit Gewebsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxinstabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxkollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxwandfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxwandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxwandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxwandhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxwandmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thoraxzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thornwaldt-Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thornwaldt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thornwaldt-Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorotrastfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorotrastleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorotrastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorotrastorgan',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thorotrastschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Threoninstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombangiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombangiitis obliterans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolie in der Gestationsperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolie nach Infusion, therapeutischer Injektion oder Transfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboembolieangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombolytische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombopenia splenica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombopenische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis der Pfortader',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis der hepatischen Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis des Beins bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis des Sinus cavernosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis des Sinus transversus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis einer intraspinalen Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis eines intraspinalen Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis nach Infusion, therapeutischer Injektion oder Transfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis nach ärztlichen Maßnahmen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombophlebitis während einer ärztlichen Maßnahme a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose bei Hämorrhoiden 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Aorta abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Aorta thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria carotis communis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria carotis interna',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria cerebri anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria cerebri media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria cerebri posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria iliaca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Arteriae cerebelli',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Extremitätenarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Vena cava inferior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Vena cava superior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Vena femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der Vena saphena',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Bulbus venae jugularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Corpus cavernosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose durch Apparat, Implantat oder Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose einer Herzkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose einer intraspinalen Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose einer peripheren Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose eines Herzvorhofs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose eines intraspinalen Venensinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose extrakranieller hirnversorgender Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose mesenterialer Arterien mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombose ohne Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboseangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thromboseneinengung einer Vene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombosierte Hämorrhoiden a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombosierte Varikozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombosierte innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombosierte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotisch-thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Hemiplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Monoplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotische Tetraplegie als aktuelles Ereignis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotischer Hämorrhoidalknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotischer Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotischer Lungeninfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombotischer Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytasthenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytenaggregationshemmertherapie (z.B. Acetylsalicylsäure)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytendefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozythämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopathie mit Granulozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenie mit Radiusaplasie [TAR]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenie-Radiusaplasie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytopenische Purpura idiopathica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thrombozytäre Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thygesson-Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymischer Basophilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymolipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymus persistens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusaberration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusalymphoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusamyloidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusaplasie mit Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusdrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusdysplasie mit Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuseiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymushyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymushypoplasie mit Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuslipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuslymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusparenchymblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thymuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoglossale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoglossale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoglossale Fistel/Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoglossuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoglossuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoid storms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideadysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideatuberkulose [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoideazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoiditis durch Kryptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreoiditis durch Zytomegalieviren [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreostatika-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxicosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxicosis factitia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxikose durch Schilddrüsengewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxikose mit Herzkrankheit [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxikose mit Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxische Herzkrankheit [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxische Kardiomyopathie [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxische Myopathie [kodiere zusätzlich G73.5*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotoxischer Exophthalmus [kodiere zusätzlich H06.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotroper Exophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyreotropin-Überproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Thyroiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibia vara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiakantensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibialisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiapilonfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiaschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiatorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiaverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiaverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tibiofibulare Agenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tic douloureux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tic douloureux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tic organischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tic-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tick - s.a. Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ticstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ticstörung bei Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ticstörung mit Spasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Augenlidentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Beinvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Hornhautverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Lidinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Phlebothrombose bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Sensibilitätsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Sensibilitätsstörung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Thrombophlebitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Thrombophlebitis im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Venenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe Verletzung der Tränenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe antepartale Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe intrazerebrale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe postpartale Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefe puerperale Phlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Bindehautfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Hornhautfremdkörper ohne Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Plazentasitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Plazentasitz mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefer Überbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefgreifende Entwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebitis der untere Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebitis des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebitis des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebitis des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebothrombose der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebothrombose des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebothrombose des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Phlebothrombose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombophlebitis der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombophlebitis des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombophlebitis des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombophlebitis des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombose der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombose des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombose des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefliegende Thrombose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzende Dermatophytose [Dermatophytie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzende Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzende Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzender Darmabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzender Harnleiterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tiefsitzender Ureterstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tieftonschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tieftontaubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tier-/Menschenbiss',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierbißverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierfellnävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierhaarallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tierphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tietze-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tietze-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tilted disc [Schräger Sehnerveneintritt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea amiantacea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea asbestina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea barbae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea blanca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea capillitii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea circinata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea corporis superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea der Fußsohle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea der Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea des Bartes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea durch Mikrosporum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea durch Trichophyton',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea faciei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea favosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea flava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea genitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea inguinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea interdigitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea interdigitalis der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea interdigitalis des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea intersecta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea intertriginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea intertriginosa pedis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea manuum et pedum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea mit Sykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea perianalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea tarsi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea tonsurans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea tropica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinea versicolor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tinnitus, Klingeln, Brummen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod durch Gravidität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod durch Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod durch gestationsbedingte Ursachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod innerhalb von 24 Stunden nach Symptombeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod ohne Anzeichen einer Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod unbekannter Ursache ohne ärztliche Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tod, nicht in Anwesenheit anderer Personen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Todd-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Todd-Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Todgeborener Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tokelau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tokopherolmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tollwut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tollwut-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tolosa-Hunt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonisch-klonische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonisch-klonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonische Perseveration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillarabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenaspergillose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillendiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsilleneiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenfokaltoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillengumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillengumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsilleninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlues im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenlymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenmischtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillensyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillensyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillensyphilis im Primärstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenteratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillentuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillenüberrest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis catarrhalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis diphtherica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis durch Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis durch Viren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis lacunaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis lingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillitis phlegmonosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillopharyngealabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsilläre Pest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tonsillärer Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tophus arthriticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tophus des Herzens [kodiere zusätzlich I43.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion des Omentums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion einer Morgagni-Hydatide bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion einer Morgagni-Hydatide beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsion einer akzessorischen Tube',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsionsdystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsionsileus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsionsskoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsionsskoliose der Brust- und Lendenwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torsionsskoliose der Brustwirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torticollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torticollis - s.a. Tortikollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torticollis spasmodicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tortikollis bei chronischer Polyarthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tortikollis durch Geburtsverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tortipelvis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tortuositas einer Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torulameningitis [kodiere zusätzlich G02.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torulosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torus mandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Torus palatinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totalatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Erschöpfung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Hornhauttrübung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Hornhautvaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Makrohämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Pankreasinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totale äußere Ophthalmoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totaler AV [Atrioventrikular]-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totaler Descensus uteri et vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totaler Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totalprolaps von Uterus und Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totgeburt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Totgeburt nach komplizierter Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Touraine-Solente-Golé-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tourette-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tourette-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tourniquet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Towey-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxic goitre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Erysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Malaria a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikose bei Stasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisch bedingtes aplastisches Anämiesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisch bedingtes aplastisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisch nutritive Hepatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisch-degeneratives Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Akkommodationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Alopezie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Amblyopie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Arthritis der Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Detergenzienwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Effekte einer nichtmedizinischen Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Enzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Fluorgaswirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Fluorwasserstoffwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Granulozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Hepatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Innenohrschwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Irishämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Knochenmarkdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Knotenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Kontaktdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Kontaktdermatitis durch Hautkontakt durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Leberschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Makulaerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Makulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Melanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Meningoenzephalitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Methämoglobinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Myokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Nephropathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Neuritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Neuropathie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Optikopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Polyarthritis der Menopause a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Porphyrie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Radikulomyelitis durch Corynebacterium diphtheriae [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Seifenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Torsionsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung einer ätzenden Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Alkohol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von FCKW [Fluorchlorkohlenwasserstoffe]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Fluorchlorkohlenwasserstoffen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Fungiziden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Giftpflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Herbiziden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Metallen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Nikotin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Phenol',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Phenol-Homologen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Strychnin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Strychninsalz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Wirkung von Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische aplastische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische diffuse Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische epidermale Nekrolyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische epidermale Nekrolyse mit Befall von 30% der Körperoberfläche und mehr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische epidermale Nekrolyse mit Schleimhautbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische multinoduläre Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische tubuläre Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische uninoduläre Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxische Ölkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxischer Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxischer Knotenkropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxischer adenomatöser Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Bäckerekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Kontaktekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Megakolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Struma nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxisches Ödem a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxocariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxokariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmen-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Adrenalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Enzephalitis [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Gastritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Hypophysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Lymphadenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Myokarditis [kodiere zusätzlich I41.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Myositis [kodiere zusätzlich M63.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Pankreatitis [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmose-Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxoplasmosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Toxämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trabekelblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trabekelzirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trabekuläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trabekuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaausgußblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheachondrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheadeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheadiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheadislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheadivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheadyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheafibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheageschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheagumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheagumma [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheakalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheakompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheakrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachealer Katarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachealkollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachealues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachealues [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheamykose [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheanekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheapapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaperichondritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheasyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheasyphilis [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheatuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaverletzung der Pars thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaverletzung der Pars thoracica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheazerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheitis durch Pneumokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchiale Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchiale Dyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchiale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchiale Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchialer Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchiales Kollaps-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis bei Grippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis bei Influenza',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis bei Kindern unter 15 Jahren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis sicca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchitis, 15 Jahre und älter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheobronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheolaryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheostomapflege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheostomaversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheoösophageale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tracheoösophagealfistel nach Tracheotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachom im Narbenstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachoma dubium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöse Einschlußkonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöse Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöse Konjunktivakontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöse Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöse follikuläre Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomatöser Pannus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trachomkonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tractus-iliotibialis-Scheuersyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tractus-iliotibialis-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traditionelle Zahnabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tragzeitüberschreitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio bei alter Ablatio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio bei diabetischer Retinopathie [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio bei diabetischer Retinopathie bei Typ-I-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio bei diabetischer Retinopathie bei Typ-II-Diabetes mellitus [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsablatio retinae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsdivertikel der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traktionsdivertikel des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trance',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trancezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tranquilizerabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tranquilizerabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tranquilizermißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tranquilizermißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transcobalamin-II-Mangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsgelbsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionshepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionshämosiderose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsreaktion durch Rh-Faktor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre Werlhof-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre Werlhof-Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre allergische Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre essentielle Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre idiopathische thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre kongenitale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre kongenitale thrombozytopenische Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre medikamentöse Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre megakaryozytische Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre sekundäre Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäre thrombozytopenische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktärer Blutplättchenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionsrefraktäres Evans-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transfusionszwischenfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transient akantholytische Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transiente cerebrale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transiente globale Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transiente ischämische Attacken (TIA)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzelliges Carcinoma in situ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzelliges Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzellkarzinom der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzellkarzinom der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzellkarzinom des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzellpapillom der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitionalzellpapillom des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Hashitoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Hypertonie bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Hypogammaglobulinämie im Säuglingsalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Hypoglykämie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Hypoprothrombinämie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Störung des Kalziumstoffwechsels beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Störung des Magnesiumstoffwechsels beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische Thyreotoxikose mit chronischer Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische akantholytische Dermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische ischämische Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische ischämische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische ischämische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische neonatale Hypoglykämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische neonatale Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorische neonatale Thyreotoxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorischer Hypothyreoidismus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transitorischer neonataler Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transmuraler Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplantatabstoßung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplantatversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplantatversagen bei Zustand nach Lebertransplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplantatversagen bei Zustand nach Nierentransplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplazentares Transfusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transplazentares Transfusionssyndrom bei der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transposition der Baucheingeweide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transposition der großen Arterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transposition des Viscerum abdominalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transposition des Viscerum thoracalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transsudative Otitis media',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transtrochantär Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transurethrale Sphinktersklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transurethraler Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvaginaler Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvaginaler intratubarer Spermientransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transversale Spinalsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transversale syphilitische Myelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transversale syphilitische Myelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transversalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transversumkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvestismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvestitischer Fetischismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvestitismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transvestitismus mit Beibehaltung beider Geschlechtsrollen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transzervikale Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transzervikaler Schenkelhalsbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Transzervikaler transuteriner Gametentransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traubenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traubensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauerprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauerreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma als Entbindungskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma als Entbindungskomplikation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trauma/Verletzung ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation beider Arme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation beider Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation der Arme und Beine, jede Kombination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation der Hand in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Fußes in Höhe des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Oberarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Oberschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation einer Zehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation eines Fingers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation eines Thoraxteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation in Höhe des Ellenbogens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation in Höhe des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation mehrerer Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Amputation mehrerer Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Asphyxie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Augenlidptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Blutung ante partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Bulbusluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Dermatitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ekchymose des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ekchymose des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Erosio corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Eviszeration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Fasziitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Fettembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Fistel des Sinus cavernosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Glaskörperblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Harnröhrenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Harnröhrenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hautmyiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hernia lentis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hirnblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hornhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hämatomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Hämorrhagie des Tentorium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Iridodialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Irishernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Kastration beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Kastration beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Kieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Myalgie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Myalgie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Myalgie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Myiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Myositis ossificans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Nervenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Netzhautblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Neurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ohramputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Penisruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Querschnittlähmung in der akuten Phase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Reizung der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Retinaruptur ohne Ablösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Rotatorenmanschettenruptur der Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ruptur der lumbalen Bandscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ruptur der zervikalen Bandscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Schädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Schädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Schädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Sehnendurchtrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Semikastration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Semikastration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spinalläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spinalläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spinalläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spondylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Spondylose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Stichwunde des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Symphysenruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Symphysenruptur bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Symphysenruptur bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Symphysensprengung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Symphysensprengung bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Tetraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Tränenwegruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ureterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Uterusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Zephalhämatozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Ziliarkörperhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Zungenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Zungenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische Zyste des Kieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische arteriovenöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische epidurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische extradurale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische flüchtige Monoplegie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatische flüchtige Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Abriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Abriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Angiospasmus des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Angiospasmus des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Gingivaverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hydropneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hydropneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hydrothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hydrothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Hämothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Irisprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Linsenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Mundschleimhautulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Symphyseneinriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Symphyseneinriß bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Symphyseneinriß bei der Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Uvealprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatischer Ziliarkörperprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Berlin-Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Bindegewebeemphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Emphysem des Unterhautzellgewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Gehirnhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Hyphäma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Hyposphagma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Oberschenkelhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Oberschenkelhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Oberschenkelhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Orbitahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Pneumoperikard',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Vasospasmus-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Zephalhämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Zungenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches Zungenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches epidurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches hämorrhagisches Glaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches subarachnoidales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traumatisches subdurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Traurige Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treacher-Collins-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trematodiasis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tremor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tremor durch Quecksilber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tremor durch Quecksilberverbindungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trench-Fever',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungsangst im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trennungskind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treponematosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treponematosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treponematosis durch Treponema pallidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treponematosis durch Treponema pallidum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Treponematosis durch Treponema pertenue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trias aus Urethritis, Konjunktivitis und Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tribadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tribasilarsynostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichiasis als Spätfolge eines Trachoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichiasis bei Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichiasis des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichilemmalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichinella-spiralis-Befall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichinella-spiralis-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichinelliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichinenbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichlormethanintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichlormethanvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichocephaliasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichodermalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichoepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichofollikulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichoklasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tricholemmom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomonaden-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomonas-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Harnblase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Harnblase [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Prostata [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Prostata [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Samenblase [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Urethra [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Urethra [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Vagina [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Vagina [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Vulva [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Vulva [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Zervix [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis der Zervix [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomoniasis intestinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomycosis axillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomycosis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomycosis nodularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichomycosis palmellina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichonodosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytia capitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytia follicularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytia profunda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytia superficialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytobezoar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichophytosis unguium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichopoliodystrophie [Menkes-II-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichoptilose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichoptilosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichorrhexis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichorrhexis invaginata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichosporosis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichostasis spinulosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichostrongyliasis des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trichterbrust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triebneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triefauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminus-Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminus-Neuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminusneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminusneuralgie nach Zoster [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigeminusneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triglyzerid-Speicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigonitis der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigonozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigonozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trigonummetaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenatherom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenfehler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trikuspidalklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trilogie von Fallot',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trimenonkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trimethylaminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trinkschwierigkeiten beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trinkschwäche beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triphalanger Daumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triphalangie des Daumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Triploidie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tripper - s.a. Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tripper - s.a. Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tripper/Gonorrhoe, Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tripper/Gonorrhoe, Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trismus beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trismus neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trismus-Pseudokamptodaktylie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 13',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 13, Mosaik, mitotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 13, Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 13, meiotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 18',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 18, Mosaik, mitotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 18, Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 18, meiotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 20',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 21',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 21',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 21, Mosaik, mitotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 21, Translokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 21, meiotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie 22',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie eines ganzen Chromosoms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trisomie-Syndrom a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tritanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tritanopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trochantermassivexostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trochantertendinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trochantertendopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trochlearisparese [IV. Hirnnerv]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockendermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Form der Beriberi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Lippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Nasenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Scheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene Zahnalveole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockene sklerotische Makulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockener Mund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenes Zahnfach',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenes phagedänisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenflechte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trockenheit der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Troisier-Hanot-Chauffard-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trombidiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trombikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfelldefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellgranulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellperforation des Recessus epitympanicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellperforation nach Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelfellverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trommelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropfenförmige gelatinöse Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophische Hautveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophisches Hautgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoblastenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoblastische Krankheit in der Anamnese, die die Schwangerschaftsvorsorge beeinflußt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoblastischer Tumor mit plazentarem Sitz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoblastkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoblasttumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophodermatoneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophoneurose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trophödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropical Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Dysenterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Elephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Endomyokardfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Eosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische Steatorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropische pulmonale Eosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropischer Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tropisches phagedänisches Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trugwahrnehmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Truncus arteriosus persistens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Truncus-coeliacus-Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trunkenheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trunksucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trypanosomiasis africana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tryptophanmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tryptophanstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenabflußstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenapparatprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsendislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenentündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüseninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenlues [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenlues [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsensyphilis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsensyphilis [kodiere zusätzlich H06.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsentumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsentumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränendrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenfilminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenfluss',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränengangdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränengangfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränengangobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränengangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränengangverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenkanalanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenkanalentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenkanalkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenkanalkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränennasengangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränennasengangverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenorgananomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenproduktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenpünktchenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenpünktchenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackhydrops',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränensackstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenträufeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenweginduration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegtumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegtumor unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegverhärtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenwegverstopfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tränenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Trümmerfraktur der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tschechoslowakische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tsutsugamushi-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tsutsugamushi-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuba-auditiva-Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuba-uterina-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubarabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubare Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubarer Embryotransfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenbelüftungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenchorionepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubendurchblasung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenfunktionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubengonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubengonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenkatarrh der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenkatarrh des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenligatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenligatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenmittelohrkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenplastik nach früherer Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenplastik nach vorausgegangener Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenruptur durch Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubensterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubensterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenundurchgängigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenventilationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubenverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis coxae [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis cutis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis cutis colliquativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis cutis indurativa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis intestinalis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis lupoides',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis nodularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis peritonei [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis pulmonum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculosis verrucosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculum paramolare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculum rhombicum medianum glossis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberculum rhombicum medianum glossis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulid der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkuloide Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkuloider Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom der spinalen Hirnhäute [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom der spinalen Meningen [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom der zerebralen Hirnhäute [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom der zerebralen Meningen [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom des Gehirns [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulom des Rückenmarks [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose adenoiden Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose bei Mastdarmfistel [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Atmungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Bulbourethraldrüsen [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Cervix uteri [kodiere zusätzlich N74.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Cowper-Drüse [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Dura mater encephali [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Dura mater spinalis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Glandula suprarenalis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Hiluslymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Hornhaut des Auges [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Medulla spinalis [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Nebennierenrinde [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Pleura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Regenbogenhaut [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Rückenmarkhäute [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Sehnervenpapille [kodiere zusätzlich H48.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Speiseröhre [kodiere zusätzlich K23.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Spina iliaca superior [kodiere zusätzlich M90.05*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Thymusdrüse [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Tuba Eustachii [kodiere zusätzlich H75.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Tunica vaginalis testis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Verdauungsorgane [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Vorsteherdrüse [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der Zwischenwirbelscheibe [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der axillären Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der hilären Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der infraklavikulären Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der inguinalen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der intrathorakalen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der mediastinalen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der männlichen Genitalorgane [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der peripheren Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der peritonealen Lymphknoten [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der retroperitonealen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der spinalen Hirnhaut [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der spinalen Meningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der supraklavikulären Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der tracheobronchialen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der zerebralen Hirnhaut [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der zerebralen Meningen [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose der zervikalen Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Douglas-Raums [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Endometriums [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Ligamentum latum uteri [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Magen-Darm-Kanals [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Palatum molle [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Sakroiliakalgelenks [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Sinus epididymidis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Sternoklavikulargelenks [kodiere zusätzlich M01.11*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Stimmapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Urogenitalsystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Vas deferens [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des Zentralnervensystems a.n.k. [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des weiblichen Beckens [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose endokriner Drüsen a.n.k. [kodiere zusätzlich E35.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose mit Bronchialblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose mit Herzbeutelentzündung [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulose-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkuloseinfektion an jeglicher Körperstelle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulös Phlyktänenbildung [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Addison-Krankheit [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Addison-Melanose [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Adenopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Appendizitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Arachnoiditis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Arteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Arthritis [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Atelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Augenhöhlenkaries [kodiere zusätzlich M90.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Auszehrung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Basilarmeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bronchiektasie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bronchopneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bronchorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bronzekrankheit [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Bursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Chondritis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Chorioiditis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Chorioretinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Daktylitis [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Dammfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Degeneration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Diarrhoe [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Dysenterie [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Endarteriitis [kodiere zusätzlich I79.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Endometritis [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Enteritis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Enterokolitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Entzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Entzündung weiblicher Beckenorgane [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Epididymitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Episkleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Erstinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Extremitätenkaries a.n.k. [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Gangrän a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Gastritis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Gastroenteritis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Gelenkschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Harnblasenentzündung [kodiere zusätzlich N33.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Hornhautnarbe [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Hydronephrose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Hüftkaries [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Ileokolitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Infektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Iridozyklitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kachexie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kardiomyopathie [kodiere zusätzlich I43.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Karies [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Keratoiritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Keratoskleritis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Knochennekrose [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Konjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Koxalgie [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Koxitis [kodiere zusätzlich M01.15*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kreuzbeinkaries [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kyphose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Kyphoskoliose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Laryngotracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Leptomeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Lordose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Lungenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Lungeninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Mastoiditis [kodiere zusätzlich H75.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Mediastinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Meningoenzephalitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Meningomyelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Mononeuropathie [kodiere zusätzlich G59.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Myelitis [kodiere zusätzlich G05.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Myokarditis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Narbe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Nasenkaries [kodiere zusätzlich M90.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Nebenhodenentzündung [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Nephritis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Nierenkontraktur [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Oophoritis [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Orchitis [kodiere zusätzlich N51.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Osteomyelitis [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Ostitis [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Otitis media [kodiere zusätzlich H67.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Ovarialzyste [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pachymeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pansinusitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Peribronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Perichondritis des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Perikardadhäsion [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Perikarditis [kodiere zusätzlich I32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Periostitis [kodiere zusätzlich M90.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Peritonitis [kodiere zusätzlich K67.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Phlyktäne [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pleuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pneumorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Polyneuropathie [kodiere zusätzlich G63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Polyserositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Primärinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Proktitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pyelitis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pyelonephritis [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Pyonephrose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Sakrumkaries [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Salpingitis [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Salpingo-Oophoritis [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Schrumpfniere [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Sinusitis (jede Nasennebenhöhle)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Skleritis [kodiere zusätzlich H19.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Sklerokeratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Skoliose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Splenitis [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Spondylitis [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Synoviitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Synovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tarsitis [kodiere zusätzlich H03.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tendosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tenosynovitis [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Thyreoiditis [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tracheastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Typhlitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Uveitis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Vaginitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Vasitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Verkäsung der Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Vorsteherdrüsenentzündung [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Vulvitis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Wirbelkaries [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Wirbelsäulenkaries [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Wirbelsäulenverkrümmung [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Zervizitis [kodiere zusätzlich N74.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Zystitis [kodiere zusätzlich N33.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse basiläre Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse gastrokolische Fistel [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse interstitielle Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse interstitielle Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse perirektale Fistel [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse phlyktänuläre Keratokonjunktivitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse spinale Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse vertebrale Karies [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse zerebrale Arteriitis [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse zerebrale Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse zerebrospinale Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöse Ösophagitis [kodiere zusätzlich K23.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Abszeß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Abszeß der Wirbelsäule [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Adrenalismus [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Aszites',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Blockwirbel [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Gibbus [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Hirnabszeß [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Hydropneumothorax a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Hypoadrenalismus [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Hämothorax a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Kreuzbeinabszeß [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Lupus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Lupus vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Marasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Pneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Primärkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Pyopneumothorax a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Pyothorax a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Pyoureter [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Pyureter [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Rheumatismus a.n.k. [kodiere zusätzlich M01.19*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Sakrumabszeß [kodiere zusätzlich M49.08*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöser lumbaler Abszeß [kodiere zusätzlich M49.06*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Erythema induratum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Frühinfiltrat mit Krankheitszeichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Ganglion [kodiere zusätzlich M68.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Glaukom [kodiere zusätzlich H42.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Gumma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Kolongeschwür [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Pleuraempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Spinalgranulom [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Ulkus der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberkulöses Wirbelsäulenulkus [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberoeruptives Xanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberöse Hirnsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberöse Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberöses Spätsyphilid [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuberöses Spätsyphilid [kodiere zusätzlich L99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovariale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovariale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovarialentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovarialer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovarialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovarialtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tuboovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubotympanalkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei Glykogenspeicherkrankheit [kodiere zusätzlich N16.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei Plasmozytom [kodiere zusätzlich N16.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei Plasmozytom in kompletter Remission [kodiere zusätzlich N16.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei Wilson-Krankheit [kodiere zusätzlich N16.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei Zystinose [kodiere zusätzlich N16.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit bei gemischter Kryoglobulinämie [kodiere zusätzlich N16.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulointerstitielle Nierenkrankheit durch Salmonellen [kodiere zusätzlich N16.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovaskuläres Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovillöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovillöses Adenom des Colon ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovillöses Adenom des Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovillöses Adenom des Rektums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulovillöses Adenom des Zäkums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulusepithelverfettung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubulusschaden mit Phosphatverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Azidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Nephropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Nierennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre Störung mit Phosphatverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre anoxische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre parenchymatöse Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläre toxische Nephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Androblastom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Androblastom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Pick-Adenom bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tubuläres Pick-Adenom beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tularämie-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Ganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Hautanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Rathke-Tasche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der Vater-Pacini-Lamellenkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor der glatten Muskulatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Beckenbodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Harnblasenhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Hypophysenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Lids unbekannter Dignität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des Tractus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor des visueller Kortex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor eines Verdauungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumor eines großen Gefäßes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoranlage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoranämie (Primärtumor unbekannt) [kodiere zusätzlich D63.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorkachexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumormetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumornachsorge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorrachitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumorschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Harnblaseninfiltration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Kalzinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Nebennierenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Ureterummauerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Veränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröse Veränderung am Hoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröser Nebennierenprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tumoröser Prozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tunesisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tungiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tunnel-Anämie durch Hakenwurm [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turbantumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turmschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turmschädel mit Exophthalmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turner-Hypoplasie der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turner-Kieser-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turner-Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turner-ähnliches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Turrizephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tussis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tussis convulsiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tyloma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tylosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tylositas articulorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tylotisches Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tylotisches rhagadiformes Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanie des Abdomens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanie des Brustkorbs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanie des Brustkorbs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanie des Brustkorbs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanie des Brustkorbs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ 1 Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ II Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-A-Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-C-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Angiopathie [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Cataracta diabetica [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Polyneuropathie [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Retinopathia diabetica [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Retinopathia diabetica proliferans [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit Retinopathia diabetica simplex [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit multiplen Folgeschäden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-I-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus bei Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Amyotrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Angiopathie [kodiere zusätzlich I79.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Augenkomplikation [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Cataracta diabetica [kodiere zusätzlich H28.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Ketoazidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Nephropathie [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Nierenkomplikation [kodiere zusätzlich N08.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Polyneuropathie [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Retinopathia diabetica [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Retinopathia diabetica proliferans [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit Retinopathia diabetica simplex [kodiere zusätzlich H36.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit multiplen Folgeschäden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit multiplen Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit neurologischer Komplikation [kodiere zusätzlich G63.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus mit peripherer vaskulärer Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus ohne Adipositas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typ-II-Diabetes mellitus ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhlitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhoenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhogastrisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhoides Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhomanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhoperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus exanthematicus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus recurrens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Endokarditis [kodiere zusätzlich I39.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Myokarditis [kodiere zusätzlich I41.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Myositis [kodiere zusätzlich M63.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Paratyphus [TAB]-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhus-Pneumonie [kodiere zusätzlich J17.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhöse Osteomyelitis [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhöse Tularämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typhöses perforiertes Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typische Speichenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Typischer Speichenbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tyrosinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tyrosinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tyrosinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tätowierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tödlicher Schlag durch elektrischen Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Tödliches Untertauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Töpfer-Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uehlinger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uhl-Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uhl-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uhrglasnägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uhrglasnägel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus - s.a. Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ad pylorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus anorectale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus bulbi duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus callosum ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus chronicum der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus corneae marginale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus corneae mit Hypopyon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus corneae rodens (Mooren)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris diabeticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris diabeticum bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris diabeticum bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris nonvaricosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cruris varicosum mit Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus cutis tuberculosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus dendriticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus dendriticum der Kornea durch Herpes simplex [kodiere zusätzlich H19.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus diabeticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus diabeticum bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus diabeticum bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus duodeni mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus durum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus durum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus intestini',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus jejuni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus malignum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus molle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus molle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus molle mit Paraphimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus molle mit Paraphimose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus nasi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum duodeni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum jejuni',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum mit Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum mit Perforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pepticum ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus perforans a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus praepyloricum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus pyloricum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus rodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus rodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus rotundum ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus septi nasi perforans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus serpens corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus simplex vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus stercoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus tropicum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus varicosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus varicosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus varicosum der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus varicosum des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus varicosum des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus venereum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ventriculi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ventriculi mit Bluterbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ventriculi mit Blutstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ventriculi mit Hämatemesis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulcus ventriculi mit Teerstuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulegyrie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulerythema acneiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulerythema ophryogenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulerythema sycosiforme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus bei Varicosis cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Analsphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Blasensphinkters a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Frenulum linguae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Harnblasensphinkters a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Magen-Darm-Bereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus durch Röntgenstrahlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus durch Strahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus eines Meckel-Divertikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkus mit Blutung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkusperforation der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulkusperforation des Magen-Darm-Traktes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ullrich-Feichtinger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ullrich-Turner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnafraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnare Deviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnare Epikondylopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarislähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisneuritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisrinnensyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnarisspätparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnasarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnaschaftfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulnaverformung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzera bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeration des Nasenseptums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeration in der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerative Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerative Impetigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerierende Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerierende Venenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerierte Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerierte innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzerierte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeromembranöse Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeromembranöse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Appendizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Balanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Blepharitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Enterokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Gingivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Halsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Ileokolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Proktitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Pulpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Rektosigmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Rhinopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Samenstrangvarikozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Staphylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Veränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse eitrige Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröse tuberkulöse Kolitis [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröses Granuloma pudendorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröses Granuloma pudendorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ulzeröses Gumma bei Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikale Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikale Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikale Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikalhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikalhernie ohne Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umbilikalphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Brustkorbschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Fettpolster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Hautschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Hyperhidrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Lesestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Lymphknotenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Periostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Raumforderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Rechtschreibschwierigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Schwellung der Haut des Halses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Schwellung der Haut des Kopfes und des Nackens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Schwellung der Haut des Nackens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Verzögerung der Rechtschreibfähigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebene Verzögerung der Rechtschreibfähigkeit ohne Lesestörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umschriebenes Kleinhirnsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umständliche Detailschilderung, die die Gründe für eine Konsultation oder Inanspruchnahme verschleiert',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umweltbedingtes Fieber beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umweltneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umweltprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Umweltverschmutzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unausgewogene Nahrungszusammensetzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbegründete Besorgnis bei normalem Gesundheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbehagen/Behinderung/Schmerz/Funktionseinschränkung als Ergebnis der Anlage/des Tragens eines Heil-/Hilfsmittels: Katheter, Kolostoma, Gastrostoma, Herzklappenersatz, Gelenkersatz, Organtransplantat, Schrittmacher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbekannte Pyrexie im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbeobachteter Tod unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbestimmbares Geschlecht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unbestimmbares Geschlecht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Belastungsdyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Brustschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Effloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Effloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Effloreszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Hautflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Lepra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristische eitrige Hautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Aussatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Juckreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer feuchter Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer trockener Husten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristischer vaginaler Ausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches wochenlanges Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncharakteristisches wochenlanges Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uncinatus-Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undeutliches Sprechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenzierte Leukämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenzierte psychosomatische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenziertes Non-Hodgkin-Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenziertes Retinoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenziertes Rundzellensarkom des Knochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undifferenziertes Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undine-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undulierendes Fieber - s.a. Brucellose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängige Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Darm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Dickdarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Dünndarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Gallengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiger Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchgängiges Rektum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Undurchsichtiger Kapselüberrest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uneheliche Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerklärliches Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Reaktion auf Radiatio a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Reaktion auf Röntgenstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Reaktion auf Ultraviolettstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Reaktion durch Nachbestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Schwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung der Fluoroskopie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer Radiotherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer Röntgenaufnahme a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer Röntgendurchleuchtung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer Strahlentherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer Teleröntgentherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung einer radioaktiven Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung radioaktiver Isotope a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Bestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Infrarotstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Mesothorium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Polonium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Radioaktivität a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Radium a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Röntgenstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Ultraviolettstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von Uran a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von radioaktivem Kobalt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unerwünschte Wirkung von radioaktivem Niederschlag a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfall durch Ertrinken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfall in der Anamnese, der die Schwangerschaftsvorsorge beeinflußt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfallbedingte Hypothermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfallneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfreiwilliger Harnabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfreiwilliger Stuhlabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unfreiwilliger Stuhlabgang nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeeignete Ernährungsgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeeignete Ernährungsgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeeignete Eßgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeeignete Eßgewohnheiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungekerbtes diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeklärte abnorme Leukozyten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenaue Todesursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Beaufsichtigung des Kindes durch die Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Fürsorgeunterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Fürsorgeunterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Fürsorgeunterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Fürsorgeunterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende Kolondrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende elterliche Überwachung des Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Kommunikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende familiäre Unterstützung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügende schulische Leistung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügender Unterricht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügendes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügendes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügendes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungenügendes Einkommen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungeschicklichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungesunder Schlaf-Wach-Rhythmus in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungewollte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungewöhnliche Gewichtsabnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungewöhnliche Schäden durch Kälte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungleichmäßigkeit der Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungleichmäßigkeit der Beinlänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unglücklichsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unglücklichsein beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ungünstige Wirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unifokale Autonomie bei Struma mit Euthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unifokale Schilddrüsenautonomie bei Struma mit Hyperthyreose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale Athetose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale Esotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale Exotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale Hyperplasie des Processus condylaris mandibulae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale Hypoplasie des Processus condylaris mandibulae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale dysplastische Koxarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale posttraumatische Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale posttraumatische Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale primäre Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale primäre Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale sekundäre Gonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale sekundäre Koxarthrose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale sekundäre Rhizarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterale supravesikale Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilateraler Strabismus convergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilateraler Strabismus divergens intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilaterales Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unilobuläre Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Abdominalbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare BKS [Blutkörperchensenkungsgeschwindigkeit]-Erhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare BSG [Blutkörperchensenkungsgeschwindigkeit]-Erhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Bauchbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Bauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Erhöhung der Blutkörperchensenkungsgeschwindigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Gewichtsabnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Halsschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Nervenaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Oberbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Oberbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Schwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Transaminasenerhöhung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Unterbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare Unterbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare extrapyramidale Affektion mit abnormer Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklare extrapyramidale Affektion mit abnormer spastischer Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Ausnahmezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Bauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Drehschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Oberbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Oberbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schmerzzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schmerzzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schmerzzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schmerzzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schmerzzustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer hochfieberhafter Infekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklarer psychogener Ausnahmezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Douglasinfiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Erschöpfungsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Erschöpfungsgefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Infiltrat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares Retardierungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares azetonämisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unklares azetonämisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkomplizierte Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkomplizierte Wehentätigkeit/Entbindung Lebendgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkomplizierte Wehentätigkeit/Entbindung Totgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkoordinierte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkoordinierte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkoordinierte Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unkoordinierte Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unmittelbarer Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unna-Nävus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unna-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unnütze Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unnütze Wehen ab der 37. Schwangerschaftswoche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unnütze Wehen vor der 37. Schwangerschaftswoche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unpässlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Oligomenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige Zwischenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige verkürzte Intervalle zwischen den Menstruationsblutungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßige/häufige Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßiger Herzschlag, anderer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßiger Menstruationszyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unregelmäßiger Schlaf-Wach-Rhythmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreife Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreife Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreife des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreifes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreifes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unreifes Teratom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unruhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unruhezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsachgemäße Abnabelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsachgemäße Ernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsachgemäße Ernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Haltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Ampulla Vateri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Ampulla hepatopancreatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Analhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Atmungsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Augenlidhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Bauchdecke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Bauchspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Bindehaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Bronchien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustdrüsenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Faszien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Gelenke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Glans penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Harnorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Hauptspeicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Hirnventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Hypophyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Klitoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Knochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Konjunktiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Labien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Leber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Lippenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Lippenrotgrenze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Lippenschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Mundhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Muskeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nasenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nasenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nebenhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nebenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Ohrhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Paraganglien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Penishaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Perianalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Plasmazellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Randzone der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Samenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Scheide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Schilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Skrotalhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Speiseröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Synovialmembran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Trachea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Tuben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Urethra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Vulvahaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Weichteile',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der endokrinen Drüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der hypopharyngealen Seite der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der laryngealen Seite der aryepiglottischen Falte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der männlichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der peripheren Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der peripheren Nerven der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der peripheren Nerven der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Analkanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Anus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Anusrandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Augenlidbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Bindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Brustdrüsenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Brustdrüsenbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Brustfells',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Canalis analis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Dickdarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Douglas-Raums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Duodenums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Dünndarmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Eileiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Epipharynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Gehirns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Gelenkknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Gesichts',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Harnleiters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Hirnstamms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Hodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des IV. Ventrikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ileums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Jejunums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Kehlkopfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Knorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Larynx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Larynxknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Lobus frontalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Lobus temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Magens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Mediastinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Mesovarium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Mittelohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Nasenknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Nebenhodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ohrbindegewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ohrknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ovars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Pankreas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Parametriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Peritoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Rachenrings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Rachens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Retroperitoneums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Sphincter ani',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Thalamus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Thymus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ureters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des ZNS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Zentralnervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Zerebellums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Zerebrums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Zäkums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des autonomen Nervensystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des inneren Teils der Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des kraniopharyngealen Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des männlichen Gliedes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des rektosigmoidalen Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des suprahyoidalen Anteils der Epiglottis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung einer Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung einer großen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung einer kleinen Speicheldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Neubildung eines Verdauungsorgans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere Urothelneubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere paranephritische Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsichere zerebrale Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsoziales Verhalten beim Kind oder Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsoziales Verhalten beim Kind oder Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Adenitis mesenterialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Hauteruption und Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Hauteruption und Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Hauteruption und Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Lymphadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Orchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Salpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Splenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische Ureteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifische toxische Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer Hautausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer Papanicolaou-Befund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer atonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer klonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer myoklonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer tonisch-klonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifischer tonischer epileptischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unspezifisches Floppy-Infant-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstillbares Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstillbares Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstillbares Niesen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit in der Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Arbeitgeber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Arbeitgeber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Arbeitskollegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Arbeitskollegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Ehepartner oder Partner',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Lehrer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Mieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Mieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Mieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Mieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Mitschüler',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Nachbarn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Nachbarn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Nachbarn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Nachbarn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Schwiegereltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vermieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vermieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vermieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vermieter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vorgesetzten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit Vorgesetzten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit anderen Beschäftigten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit anderen Beschäftigten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unstimmigkeit mit angeheirateten Verwandten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unsymmetrische Augendeviation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unter Beobachtung sein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmdécollement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmgrünholzfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmverbiegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterarmzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbauchtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbindung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbindung der Eileiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrechung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrechung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrechung der Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrechung der Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrochene aktive Wehenphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrochene aktive Wehenphase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterbrochener Harnstrahl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterdruckbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterdrückung der Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untere Armplexuslähmung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untere Harnröhrenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untere Paraplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untere Rückensymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterentwicklung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterentwicklung des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterentwicklung des Oberkiefers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion der Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion der Parathyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterfunktion des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untergewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untergewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterhautinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterhautkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterhautzellgewebe-TBC [Tuberkulose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterhautzellgewebsentzündung mit Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferalveolarfortsatzatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferalveolarfortsatzkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferdrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferknochensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferosteomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferperiostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferspeicheldrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferspeicheldrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkieferzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterkühlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlappenatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlappenpneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterleibkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterleibmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterleibsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterleibsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlidchalazion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlidneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlidtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlippenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlippenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterlippenspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelerysipel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelphlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelphlebothrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkeltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelvarikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschenkelödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterschiedliche Extremitätenlänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung aufgrund eines Wachstumsschubs in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung aus rechtmedizinischen Gründen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung der Mutter unmittelbar post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung der Mutter unmittelbar post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung der stillenden Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung der stillenden Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung des Hörvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung des Sehvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung des gesunden Säuglings',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung einer Allergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung einer Überempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung potentieller Organ- oder Gewebespender',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung von Opfer oder Beschuldigtem nach angegebener Vergewaltigung oder sexuellem Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung wegen Adoption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung zu Versicherungszwecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untersuchung zur Teilnahme am Sport',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untertauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzuckerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzuckerung bei Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzuckerung bei Typ-I-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzuckerung bei Typ-II-Diabetes mellitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzungendrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzungendrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzungendrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unterzungengeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Untreue',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unverricht-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unverricht-Lundborg-Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unverricht-Lundborg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unverricht-Lundborg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unverricht-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollkommene Fusion der Schädelknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Belüftung der Lunge beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Deuteranopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Entwicklung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Erektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Hasenscharte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Knochensegmentation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Kolondrehung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Protanopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige Wirbelsegmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständige lumbosakrale Wirbelsegmentation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständiges akzessorisches Rückenmark',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unvollständiges doppeltes Rückenmark',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unwegsamkeit der Prostata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unwillkürlicher Harnabgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unwillkürlicher Spasmus im Sinne von Tic',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unwohlsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unwohlsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzinariasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzufriedenheit mit Berufstätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzufriedenheit mit Berufstätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzufriedenheit mit Schulmilieu',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Trinkwasserversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Trinkwasserversorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung bei der Arbeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung bei der Arbeit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung bei kommunaler Umwelt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche Umgebung bei kommunaler Umwelt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzulängliche schulische Leistung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzurechnungsfähigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Unzureichendes fetales Wachstum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Upside-down-Magen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachusfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachuskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachuskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachuspersistenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachuszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urachusüberrest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uranintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uranismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uranoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uranvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratablagerung in der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratische Diathese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratnephropathie [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratstein im Nierenbecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uratverstopfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urbach-Lipoidproteinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urbach-Wiethe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureter bifidus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureter duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureter triplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureter-Darm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureter-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterabgangstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterachalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteraffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteragenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteranomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteraplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteratonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteratresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterblockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterduplikatur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterdyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretererweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretereversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretergrieß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretergumma [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretergumma [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterintussuszeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterintussuszeption mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteritis cystica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteritis durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterknick des pelvinen Abgangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkolik durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterlageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretermündungsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretero-sigmoideo-abdominale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterobliteration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterobstruktion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterointestinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteropelvine Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureteropyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterosakralfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterostiumstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterostiumstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterostoma-Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterovesikale Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterozelenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterreflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterschleife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterstau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterstumpfinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretertuberkulose [kodiere zusätzlich N29.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretertumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ureterzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethra-Damm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethra-Haut-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethra-Mastdarm-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethra-Rektum-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraanhang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrabulbitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethradivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraeversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrageschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethragonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethragonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethragranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrahyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraimperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrainfektion bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrairritabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakolik durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakonkrement',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralazeration als Geburtsverletzung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralazeration als Geburtsverletzung der Mutter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraldrüsenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraldrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrale Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrale Meatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrale Sphinktersklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralithiasis mit Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralithiasis mit Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralklappe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralpolyp im Sinne der Harnröhrenkarunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralpolyp im Sinne einer Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralues [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralues [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethralulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethramalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrametaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethramykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethramündungsstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethranarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraobliteration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrapapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrapyozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrariß bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrariß bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrarotation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraschanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraschleimhautvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrasphinkterinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrasphinkterrelaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrastriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrastriktur durch Katheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrastörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrasyphilis [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrasyphilis [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethratuberkulose [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethratumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverdoppelung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverkürzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverletzung bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethraverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethravorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis candidomycetica [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis candidomycetica [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis candidomycetica [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Diplokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Diplokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Kandidose [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Kandidose [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Kandidose [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Mykoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Trichomonaden [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis durch Trichomonaden [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis externa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethritis simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethro-okulo-artikulär-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethro-okulo-synoviales Syndrom [Reiter-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrointestinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethroperineale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethroperineovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethroprostatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethroprostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethroskrotale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrostoma-Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrotrigonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrotrigonumzystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrozele beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrozele mit Zystozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urethrozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uretralreflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urhidrosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urikopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urikosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urina-spastica-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinextravasation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urininkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urininkontinenz nichtorganischen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urinuntersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z35'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urlaubsbetreuung für Pflegebedürftige',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urlaubsbetreuung für Pflegebedürftige',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urobilinogenurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Bilharziose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Kandidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Mykoplasmeninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Spätsyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Trichomonaden-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitale Trichomonaden-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitaler Soor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitalmyiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urogenitaltuberkulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urohepatisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urolithiasis mit Kolik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uromykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uronephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uropathie durch vesikoureteralen Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urosepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urothelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urothelneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urothelpapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urothelpseudopapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urotheltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ursprungsstenose der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria cholinergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria gigantea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria neonatorum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria papulosa Hebra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria pigmentosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urticaria xanthelasmoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urtikaria durch Vibration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urtikarieller Dermographismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urtikarielles Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urzsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämie bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Aphasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Apoplexie [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Blindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Demenz [kodiere zusätzlich F02.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Dyspnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Eklampsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Enzephalopathie [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Konvulsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Neuropathie [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Paralyse [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Perikarditis [kodiere zusätzlich I32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämische Toxikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämischer Krampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämisches Delirium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Urämisches Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Usher-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uta-Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterine Dystokie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterine Dystokie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterine Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteroabdominale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterointestinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteroovarialkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteroplazentare Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteroplazentare Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterourethrale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterovaginaler Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterovaginalprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus arcuatus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus bicollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus bicornis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus bicornis bicanalis unicollis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus biforis suprasimplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus didelphys',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus duplex bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus duplex mit Uterus bicollis bei Vagina duplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus fetalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus myomatosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus myomatosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus septus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus subseptus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus triplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus-Bauchwand-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterus-Harnleiter-Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusablation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatonie während der Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatonie während der Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusblutung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusdoppelbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusdyskeratose a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruseiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusekstrophie nach Geburtshilfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruserosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruseversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusextraversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfibroid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfibrom bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusflexion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgasbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusgonorrhoe [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushinterwandmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushornkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterushypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusinkarzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusinversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskalkherd',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusknickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskolik a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskonstriktion als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskonstriktion als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruslazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusleiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusleiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusmyom bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusnarbe durch früheren Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruspapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruspartialprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusprolaps 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusprolaps 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusprolaps 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusruptur bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusruptur bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusrückbildungsstörung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterussarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusschmerzen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusschnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterussepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterussubinvolution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterussynechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustetanie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustotalprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustuberkulose [kodiere zusätzlich N74.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterustumor bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusunterentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusvorderwandmyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uterusvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uteruszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Utrikuluszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvea-Kolobom-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveaangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveaektropium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveaentzündung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveaepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveales Effusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvealstaphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveatoxoplasmose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveatuberkulose [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis anterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis anterior durch Herpesviren [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis intermedia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis posterior bei Morbus Boeck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis posterior bei Morbus Whipple [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis posterior bei systemischer Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveitis posterior juxtapapillaris Jensen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveokeratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveoparotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uveoparotitis-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulapapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulatuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Uvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VACTERL-Assoziation [Vertebraldefekte, Analatresie, kardiale Anomalien, Tracheo-Ösophageal-Fistel mit Ösophagusatresie, renale und Extremitätenanomalien]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VACTERL-Syndrom [Vertebraldefekte, Analatresie, kardiale Anomalien, Tracheo-Ösophageal-Fistel mit Ösophagusatresie, renale und Extremitätenanomalien]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VATER-Assoziation [Vertebraldefekte, Analatresie, kardiale Anomalien, Tracheo-ösophageal-Fistel mit Ösophagusatresie, renale und Radiusdysplasie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VATER-Syndrom [Vertebraldefekte, Analatresie, kardiale Anomalien, Tracheo-ösophageal-Fistel mit Ösophagusatresie, renale und Radiusdysplasie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VBI [Vertebrobasiläre Insuffizienz]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VES [Ventrikuläre Extrasystolen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VLDL-Hyperlipoproteinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VSD [Ventrikelseptumdefekt] - s.a. Ventrikelseptumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'VWI [Vorderwandinfarkt]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaccinia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaccinia generalisata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagabund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagabund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagabund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagabund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagale Bradykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagina bipartita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagina septa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginafibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginafusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginahypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginainversion nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginakontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalabnormität bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalblutung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaldiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaldysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Involution',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Kraurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Leukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Leukorrhoe durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Leukorrhoe durch Trichomonas vaginalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Mißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Pilzinfektion [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Schnittverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Soormykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale intraepitheliale Neoplasie 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale intraepitheliale Neoplasie 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale intraepitheliale Neoplasie 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginale intraepitheliale Neoplasie 3. Grades mit hochgradiger Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaleiomyosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalendometriose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaler Ausfluss',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaler Ausfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaler Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginales Druckulkus durch Ringpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalhämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalkandidose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalkrankheit mit Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalmykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalprolaps nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalsoor [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalstumpfgranulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalstumpfnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalstumpfpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalulkus durch Pessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginalzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginastein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginatotalprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginatuberkulose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginatumor bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginismus NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginismus psychogenen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis bei Madenwurm-Infektion [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis candidomycetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Haemophilus influenzae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Kandidose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Monilia [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis herpetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis herpetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis nach Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis nach Molenschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginitis/Vulvitis ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginoperineale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginorektaler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaginovesikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vago-hypoglossal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagusaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagusbedingte Ohnmacht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vagusbedingter Ohnmachtsanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaguskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaguslähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakuumentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakuumentbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakuumsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakuumsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakuumsinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination - s.a. Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Cholera mit Typhus-Paratyphus [Cholera+TAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Diphtherie-Pertussis-Tetanus mit Poliomyelitis [DPT-IPV] [DTPa-IPV] [DaPT-IPV]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Diphtherie-Pertussis-Tetanus mit Typhus-Paratyphus [DPT+TAB] [DTPa+TAB] [DaPT-TAB]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Haemophilus influenzae Typ b [Hib]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Pneumokokken-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vakzination gegen Zentraleuropäische Frühsommer-Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valgusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valgusgonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valin-Abbaustörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valley-Fieber [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvuläre Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvuläre Pulmonalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvuläre Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvuläre Striktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Valvuläre kongenitale Aortenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Bogaert-Scherer-Epstein-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Bogaert-Scherer-Epstein-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Bogaert-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Creveld-von-Gierke-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Lohuizen-Syndrom [Cutis marmorata teleangiectatica congenita]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Neck-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Neck-Odelberg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Neck-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-Neck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-der-Hoeve-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-der-Hoeve-Trias',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-der-Hoeve-de-Kleyn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Van-der-Woude-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaquez-Osler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaquez-Osler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variabler Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variant-Angina-pectoris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variation der Haarfarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varicosis - s.a. Varikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varicosis cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varicosis spinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varicosis vulvae in graviditate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose der Venae perforantes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikose mit Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikosis der Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikothrombophlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikozele des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikozele des Skrotums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varikozele testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Gefäße der Plazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Phlebitis der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Phlebitis des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköse Venen des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköser Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköses Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variköses Ulkus der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola emphysematica [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola humana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola hybrida [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola illegitima [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola mitigata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola notha [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola spuria [Varizellen]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variola vera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varioloid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Variolois',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varix - s.a. Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varix aneurysmatica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varixknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen - s.a. Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Enzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Inkubation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Myelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Pneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizellen/Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizelliforme Kaposi-Eruption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen an anderen Stellen als den Beinen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der Labia majora',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der Milzvene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der Nierenpapille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der Rückenmarkgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der unteren Extremität bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der unteren Extremität mit Geschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen der unteren Extremität mit Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen des Beins mit Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen des Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen mit Phlebitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen mit Ulcus cruris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizen mit Unterschenkelgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizenblutung der Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizenblutung des Beins',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizenblutung des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varizenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varusdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varusgonarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varusgonarthrose und Femoropatellararthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Varusstellung des Kniegelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasa praevia',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasculitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasculitis - s.a. Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasculitis allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasektomiewunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasektomiewunsch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaselinoderm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis bei juveniler Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis durch Toxoplasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulitis durch Zytomegalieviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Beinbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Bindehautveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Darminsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Enzephalopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Hämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Insuffizienz des Mesenterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Kollagenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Kollagenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Myelopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Neurosyphilis a.n.k. [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Neurosyphilis a.n.k. [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Optikusatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Pseudohämophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Retinasklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Schrumpfniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Syphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Syphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre Veränderung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre degenerative Ohraffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläre vertebragene Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer Prozeß des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer Spasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer Verschluß a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskulärer kardiorenaler Schaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläres Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vaskuläres Syndrom bei zerebrovaskulären Krankheiten [kodiere zusätzlich G46.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasodilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasolabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Akroparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Dilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Instabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Nothnagel-Akroparästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Paralyse a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorische Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorischer Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorischer Fließschnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorischer Spasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorisches Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasomotorisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasoplastik nach früherer Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasoplastik nach vorausgegangener Sterilisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasopressinhyposekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospastische Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospastische Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospastische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasospastisches Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasovagal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasovagale Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasovagaler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasovagaler Reflex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vasovagales Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegane Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetativ-phobisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Dystonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Fehlsteuerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Labilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Prostatopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Reizblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Symptomatik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetative Übererregbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetatives Kreislaufproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetatives Prostatasyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vegetatives urogenitales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veitstanz - s.a. Chorea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veitstanz mit Herzbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Velumspalte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-inferior-Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-inferior-Okklusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-inferior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-superior-Kompressionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-superior-Okklusionssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vena-cava-superior-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venektasie des Afters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenaberration a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenatresie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenblockade a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venendilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenentzündung der unteren Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenfehlmündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venengerinnsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenklappeninsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenknick',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenknick',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenkonvolut des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venensklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenspasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenspasmus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstauung der Retina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venensyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venensyphilis [kodiere zusätzlich I98.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenteilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenteilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenthrombose der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenthrombose des Unterschenkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veneria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Balanitis a.n.k. [kodiere zusätzlich N51.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Lymphadenitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Lymphadenitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Salpingitis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Salpingo-Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Salpingo-Oophoritis [kodiere zusätzlich N74.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Urethritis a.n.k. [kodiere zusätzlich N37.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Vaginitis a.n.k. [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Verruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Verruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze der Anogenitalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze der Anogenitalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze der äußeren Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerische Warze der äußeren Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venerisches Kondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venezolanische Pferdeenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venezolanische Pferdeenzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venolendilatation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventilationspneumonitis [Klimaanlagenpneumonitis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventilpneumothorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventraler Zungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventraler oberflächlicher Zungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrales Defekt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelflimmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelhypoplasie links',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelinversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelseptumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikelseptumverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläre Arrhythmie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläre Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläre Laryngozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläre paroxysmale Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikulärer Stillstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläres Empyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ventrikuläres Versagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Claudicatio intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Claudicatio intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Erkrankung mit Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Insuffizienz - s.a. Chronisch-venöse Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Komplikation im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Kreislaufstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Stase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Stase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse Thrombose des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöse okklusive Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöser Gefäßverschluß der Netzhaut im Anfangsstadium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöser Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöser Symptomenkomplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöses Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Venöses Ulcus cruris ohne Varizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verarmung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verarmung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verarmung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verarmung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbale Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbale Apraxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verband/Druck/Kompression/Tamponade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z56'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbandwechsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbindung des linken Ventrikels mit dem rechten Vorhof',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbindung zwischen Uterus und Harntrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbindung zwischen Uterus und Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener Fremdkörper im Augenlid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper im Ziliarkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper in der Bulbushinterwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper in der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper in der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener amagnetischer Fremdkörper in der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper im Glaskörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper im Ziliarkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper in der Bulbushinterwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper in der Iris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper in der Linse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbliebener magnetischer Fremdkörper in der Vorderkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verblitzung der Schweißer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verblitzung mit Konjunktivitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verborgene Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie intra partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrauchskoagulopathie post partum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrechensopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrechensopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrechensopfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbreiterte Herzdämpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Augenanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Darmbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Interskapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Kreuzbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Lendengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Pudendalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Rippengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Schulterblattgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der großen Schamlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung der kleinen Schamlippe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Epigastrium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Lids und Periokularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Magen-Darm-Traktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Perineum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Präputium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Tränenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Tränensacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des Verdauungstraktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des ganzen Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung des äußeren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Elektrizität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Flamme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Inhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Strahleneinwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch Verblitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch heiße Flüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch heiße Gase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung durch heißen Gegenstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung innerer Organe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung mehrerer Körperregionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung/Verbrühung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrennung/Verbrühung alle Grade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verbrühung - s.a. Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungsinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungsproblem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungsschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungsstörungen/Magenverstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdauungssymptome/-beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdoppelung des Meatus urinarius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdoppelung des Rückenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdrängungsatelektase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdursten durch Wassermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verdünnungshyponatriämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vereiterte Pulpa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verengung der Tuba auditiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verengung des Introitus vaginae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verengung des vorderen Augenkammerwinkels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verengung des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vererbliche hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vererbtes Amyloidherz [kodiere zusätzlich I43.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verflüssigungsnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verfolgungswahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung der Thoraxwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des Iliosakralgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des Labium majus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des Labium minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des Tracheaknorpels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verformung in der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergehen bei Bandenmitgliedschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergehen bei Bandenmitgliedschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergewaltigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Antiallergika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Antiemetika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Antipruriginosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Bakterientoxin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Benzodiazepin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Biß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Botulismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Cannabis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Chinin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Drogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Eisen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Eisenverbindungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Glukokortikosteroide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch High-ceiling-Diuretika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch LSD [Lysergsäurediäthylamid]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Lysergid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Meprobamat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Mineralokortikosteroide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Muskelrelaxanzien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Ophthalmika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Oxazolidine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Oxytozin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Parasympathomimetika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Pferdebohnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Pharmaka',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Ptomaine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Quallen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Salmonellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Schlaftabletten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Schleifendiuretika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Stich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Succinimide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Thyreostatika',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Vicia faba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch Wurst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch ein Cannabis-Derivat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch eine biologisch aktive Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch eßbares Meerestier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch giftige Beeren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch giftige Pflanzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch giftige Pilze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch giftiges Insekt a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch medizinische Substanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch neuromuskuläre Blocker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch nichtmedizinische Stoffe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch orales Kontrazeptivum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch schlechtes Fleisch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch tetrazyklische Antidepressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch trizyklische Antidepressiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch verdorbene Muscheln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung durch verdorbene Schalentiere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergiftung in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergreisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergreisung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerte Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerte Gaumenmandel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerte Mandeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerte Rachenmandel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerte Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerter blinder Flecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerter blinder Flecken des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerung der Adenoide',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerung der Samenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerung des Plexus pampiniformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerung des Prostatamittellappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vergrößerung des Prostataseitenlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltene Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltene Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltener Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensabweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensauffälligkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensproblem beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensprobleme des Partners',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensprobleme mit Elternteil/Familie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung bei Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung bei körperlicher Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung bei mittelgradiger Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung bei schwerer Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung bei schwerster Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung im Kindesalter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung in der Familienanamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltensstörung und Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhaltung von Winden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verheimlichte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhornung/Schwielenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhungern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhärtetes Tuberkulid',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhärtung des Corpus cavernosum penis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verhärtung des Ligamentum latum uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkalkende Aortitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkalkende Axenfeld-Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkalkender epithelialer ontogener Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkalkendes Epitheliom nach Malherbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkalkung der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkapselter Nierenbeckenstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkehrsunfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkehrsunfall mit Polytrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkohlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkohlung des ganzen Körpers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkohlung durch Blitzschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkäsung der Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürzte Austreibungsperiode bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürzte Austreibungsperiode bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürzte EKG [Elektrokardiogramm]-Überleitungszeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürzte PQ-Dauer im EKG [Elektrokardiogramm]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürztes Zungenbändchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verkürzung der Körpergröße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerte Zahnkeime',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung der Kardia durch den Hiatus oesophageus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung der Öffnung des Wharton-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung durch Apparat, Implantat und Transplantat',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung einer Mammaprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung eines Intrauterinpessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlagerung von Zylinderepithel über den äußeren Muttermund hinaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlangsamtes Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlangsamung der Herzfrequenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlausung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlausung durch Filzläuse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlausung durch Schamläuse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung Nervensystem, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung a.n.k. in der Anamnese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung als Komplikation der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung an multiplen Lokalisationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung an äußerem Gehörgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung bei Geburtshilfe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung bei Geburtshilfe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung bei chirurgischem Eingriff',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria radialis in Höhe Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria radialis in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria radialis in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria tibialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria ulnaris in Höhe Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria ulnaris in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Arteria ulnaris in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Beckenbänder bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Beckenbänder bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Beckengelenke bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Beckengelenke bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Beckenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Blutgefäße in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Brustbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Fossa supraclavicularis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Harnwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Kehle a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Kniekehle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Leistengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Mutter bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Mutter bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Pudenda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Pudenda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Pudenda',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Regio temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Regio temporalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Schamgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Scheidenwand ohne Verletzung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Scheidenwand ohne Verletzung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Scheitelgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Scheitelgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Schläfengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Schläfengegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Skapulargegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Speichelgänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Speichelgänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Temporalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Temporalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena femoralis in Höhe Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena femoralis in Höhe Oberschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena saphena magna in Höhe Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena saphena magna in Höhe Oberschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena saphena magna in Höhe Unterschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Vena saphena parva in Höhe Unterschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Warzenfortsatzgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Warzenfortsatzgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der Zwischenwirbelscheibe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der behaarten Kopfhaut der Hinterhauptgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der behaarten Kopfhaut der Hinterhauptgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der okzipitalen Region',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der okzipitalen Region',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der parietalen Region',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der parietalen Region',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Knöchel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Oberschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der sensiblen Hautnerven in Höhe Unterschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der zerebralen Meningen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung der zervikalen sympathischen Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Chiasma opticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Epigastriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Epigastriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Epigastriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Fetus bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Gasser-Ganglions',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Gehörs, zur Taubheit führend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Hinterhauptlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Lobus occipitalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Lobus parietalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nasenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nasenseptum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus abducens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus accessorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus facialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus femoralis in Höhe Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus femoralis in Höhe Oberschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ischiadicus in Höhe Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ischiadicus in Höhe Oberschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus medianus in Höhe Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus medianus in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus medianus in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus medianus in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus oculomotorius',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus peronaeus in Höhe Unterschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus peronaeus profundus in Höhe Fuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus peronaeus profundus in Höhe Knöchel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus radialis in Höhe Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus radialis in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus radialis in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus radialis in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus tibialis in Höhe Unterschenkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus trigeminus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus trochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ulnaris in Höhe Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ulnaris in Höhe Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ulnaris in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus ulnaris in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Nervus vestibulocochlearis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Neugeborenen bei der Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Ohrlabyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Ohrlabyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Pars cervicalis der Trachea a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Perineums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Sakralnervengeflechtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Steißbeins bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des Steißbeins bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des harten Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des iliakalen Bereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des iliakalen Bereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des iliakalen Bereiches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des rektovaginalen Septums a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des rektovaginalen Septums a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des rektovaginalen Septums a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des skrotalen Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des skrotalen Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des skrotalen Samenstranges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des weichen Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des zerebralen Kortex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des äußeren Gehörganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Arthropoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Bestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Explosionsdruck a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Infrarotstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Insekten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Röntgenstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Ultraviolettstrahlen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung durch Verätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung einer Vene des Fußrückens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung einer Vene in Höhe Unterarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung einer meningealen Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung einer oberflächlichen Vene in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung einer oberflächlichen Vene in Höhe Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines Blutgefäßes der Iliakalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines Blutgefäßes der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines Blutgefäßes des Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines Blutgefäßes in Halshöhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines Organs im Abdomen, der Zähne, Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines intrathorakalen Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung eines intrathorakalen Organs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung intraabdominaler Organe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung mehrerer Beckenorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung mehrerer Blutgefäße in Höhe Oberarm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung mehrerer Blutgefäße in Höhe Schulter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung von Beckenorganen bei Fehlgeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung von Muskeln in Halshöhe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung, muskuloskelettär ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzung/Trauma von Nase/Atemwegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungen Blut/Lymphe/Milz, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungen der Atemwege, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungen des Verdauungssystems, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungen, männliches Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungen, weibliches Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungsfolgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verletzungsfolgen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Eltern in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Familie in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Kontrolle über den Rektumsphinkter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Labyrinthfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Tastlokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust der Tastlokalisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust des Erinnerungsvermögens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust des Kulturraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust des Kulturraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust einer nahen Bezugsperson in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust emotionaler Zuwendung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust emotionaler Zuwendung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust emotionaler Zuwendung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust sozialer Beziehungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust sozialer Beziehungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust von Selbstwertgefühl in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust von Sinnesfunktionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlust von sexuellem Verlangen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Blutungszeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Gerinnungszeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Koagulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Kontraktur des Uterus während der Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Kontraktur des Uterus während der Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Thromboplastinzeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerte Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängertes Wasserlassen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung des Ductus cysticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung des Epiglottisstiels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung des Frenulum praeputii',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verlängerung des Ligamentum patellae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Aldosteronproduktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Aldosteronsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Antetorsion des Oberschenkelhalses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Faltenbildung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Harnausscheidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Harnmenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Harnsäurekristalle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrte Milzaktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Abgang von Darmgasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Auswurf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Auswurf unbekannter Ursache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Haarwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Restharn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrter Tränenfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrtes Sputum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermehrung der Haut des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermeidende Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermeidende Störung beim Jugendlichen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermeidende Störung beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Harnsekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Nierenfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Tränensekretion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Ventilation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte Vitalkapazität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte funktionelle Aktivität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderte sexuelle Erfüllung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderter Harnfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderter Tränenfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermindertes Stereosehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermindertes sexuelles Verlangen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderung des Kaliumgehaltes des Blutes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderung des Natriumgehaltes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verminderung des Salzgehaltes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermuteter Tod eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Gastroenteritis mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Gastroenteritis mit Diarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich infektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Gastrojejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Jejunitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutlich nichtinfektiöse Kolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutliche Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutliche Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermutliche Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vermännlichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung der Körperpflege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Kindes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigung eines Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernachlässigungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vernet-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verocay-Knötchen im Neurinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verordnung eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verordnung eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verordnung von Ovulationshemmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verordnung von Ovulationshemmern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verrenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verrenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verringerte Herzdämpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verringerung der extrazellulären Flüssigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca acuminata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca durch Viren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca filiformis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca palmaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca peruviana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca plana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca plana juvenilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca seborrhoica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca senilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca simplex',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca subungualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca tuberculosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca vulgaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca vulgaris palmaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruca vulgaris plantaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verrucae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verrucae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruga peruana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruga peruviana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruköses Xanthom der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verruköses keratotisches Hämangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen der Intubation während der Anästhesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen der Ovulation mit Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen der genitale Reaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen der testikulären endokrinen Funktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Hauttransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Herz-Lungen-Transplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Herztransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Lebertransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Lungentransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen eines Nierentransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagen lebenswichtiger Zentren beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versagenszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschiebung der Kiefermittellinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschiebung der Nabelschnurunterbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschiebung der Zahnbogenmittellinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschiebung der Zahnmittellinie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschlucken von Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluckter Fremdkörper a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria basilaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria brachialis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria carotis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria cerebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria cilioretinalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria femoralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria renalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Arteria vertebralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Netzhautarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Nierenpolarterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Stammganglienarterien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Vena cava',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der Vena portae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der prostatischen Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß der ureterovesikalen Öffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß des Ostium ureteris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß des ureteropelviner Übergangs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß einer extrakraniellen hirnversorgenden Arterie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß einer künstlichen Körperöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß eines Gehirnventrikels a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Fixierung/Naht/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschluß/Katarrh/Funktionsstörung der Eustachischen Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschlußikterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschlußunfähigkeit der Zervix bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschmelzung von Zähnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschmelzungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschorfende Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwinden eines Familienangehörigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschwommenes Sehvermögen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschüttung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verschüttungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentlich in der Operationswunde zurückgelassene Nadel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentlich in der Operationswunde zurückgelassener Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentlich in der Operationswunde zurückgelassener Schwamm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentlich in der Operationswunde zurückgelassener Tupfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentliche chirurgische Perforation von Blutgefäßen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentliche chirurgische Perforation von Nerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentliche chirurgische Perforation von Organen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versehentliche ärztliche Uterusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verseifung des Mesenteriums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versetzung in andere soziale Umgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versetzung in andere soziale Umgebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung chirurgischer Nähte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung eines Verbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem Gerät im Harntrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem Herzschrittmacher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem Hörgerät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem Kolostoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem kieferorthopädischen Gerät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einem orthopädischen Hilfsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgung mit einer Zahnprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Versorgungsanomalie der Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verspätete Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verspätung beim Laufenlernen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verspätung beim Sprechenlernen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstauchung/Zerrung des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstauchung/Zerrung des Sprunggelenks/Knöchels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstauchung/Zerrung eines Gelenks ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstopfter Tränenkanal beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstopfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstopfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstopfungsgefühl Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstopfungsniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verstärkter Haarwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebra plana',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebragene Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebragener Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Epiphysitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Metastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrale Tuberkulose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebraler Kollaps a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebraler Kollaps a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebralisstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebralisthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrobasiläre DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrobasiläre Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertebrobasiläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertexfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo auralis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo auricularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo epileptica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo in der Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertigo zentralen Ursprungs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertikaldivergenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertikale Abscher-Fraktur [Vertical shear fracture]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertikale Heterotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vertikaler Überbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verunstaltung durch Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verurteilung mit Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verurteilung mit Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verurteilung mit Gefängnisstrafe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsene Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsene Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsene Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsung des Bauchraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsung des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwachsungsbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verweiblichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verweigerung der Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verweigerung der Erfüllung ärztlicher Anordnungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verwirrtheitszustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzweigungsblock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögert auftretende psychotische Störung bei Restzustand nach Gebrauch von Opioiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Dentition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Ejakulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung nach Blasensprengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung nach Blasensprengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung nach Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entbindung nach Blasensprung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Frakturheilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Menarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Rekonvaleszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Uterusrückbildung im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte Wundheilung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte kardiale Erregungsleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerte sexuelle Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerter Eintritt der Menarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerter Miktionsbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerter Schock nach Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerter Verschluß des Ductus arteriosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögertes Laufenlernen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögertes Sprechenlernen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerung der Sprachentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerung der primären Respiration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerung der sexuellen Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verzögerung des endochondralen Knochenwachstums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Descemet-Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Familienbeziehungen in der Kindheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Haarfarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Knochenkontinuität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Plasmaviskosität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung der Stuhlgewohnheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung des Alpha-Fetoprotein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung des Augenhintergrundes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung des Hautreliefs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderung im Erscheinungsbild der Netzhautgefäße',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Veränderungen des Stuhlgangs/der Verdauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Achselhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Augenanhangsgebilde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Handfläche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Hüfte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Interskapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Knöchelregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Lumbosakralgegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Periokularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Phalangen der Hand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Phalangen des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Skapularregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Thoraxwand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der Tränendrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung der behaarten Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Kehlkopfes und der Trachea mit Beteiligung Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Labium majus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Labium minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Magen-Darm-Traktes a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Tränenapparates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Tränenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des Tränensacks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des äußeren Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung des äußeren Thorax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung durch Inhalation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung durch Kalk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung innerer Organe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung mehrerer Körperregionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung nach eingeleitetem Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung von Fuß und Knöchelregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Verätzung von Hand und Handgelenk',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesania',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesicular-Rickettsiosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesiculitis seminalis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesiculitis tuberculosa [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Fistel a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Kontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Relaxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Schistosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikaler Tenesmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikalparese a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoabdominale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikointestinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikopelviner Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoperineale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikorektales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikorenaler Reflux',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikosigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikosigmoideovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoumbilikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoureterale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoureterale Regurgitation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoureteraler Reflux a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoureterorenaler Rückfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikoureterovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikourethrale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikourethrorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikouterine Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikovaginales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikozervikale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikozervikovaginale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulitis durch Amöben',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulitis durch Trichomonaden [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulitis durch Trichomonaden [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulitis durch Zytomegalieviren [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikuläre Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikuläre Rickettsiose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikuläre Stomatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulärer Ausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikuläres Emphysem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikuläres Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vesikulöses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularer Nystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularis-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularisausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularisneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularneuronitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibularschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vestibulitis des Ohres',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Via falsa der Harnröhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vibrationsempfindung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vibrationsempfindung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vibrionen-Kolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vidal-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vielfachtrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierfingerfurche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierklappenkrankheit des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierklappenvitium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierlingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierquadrantenperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viertage-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierte Geschlechtskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierte Geschlechtskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierte Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vierter Molar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vikariierende Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vikariierende Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vikariierende Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villaret-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villoglanduläres Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villonoduläre Synovitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöse Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöses Adenom des Colon ascendens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöses Adenom des Colon sigmoideum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Villöses Rektumadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Allgemeininfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Endophthalmitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Enzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Gastroenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Kardiomyopathie [kodiere zusätzlich I43.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Karditis [kodiere zusätzlich I52.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Meningoenzephalomyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Myokarditis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Perikarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Pharyngokonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Pleurodynie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Stomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Stomatitis aphthosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Verruca',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virale Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virales Enanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virales Exanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virales Fieber durch Moskitos übertragen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virile Klimakteriumsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virilisierung bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virulente schankröse Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virulente schankröse Bubo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusbronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusdermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusdiarrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenzephalitis durch Arthropoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenzephalitis durch Moskitos',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenzephalitis durch Stechmücken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusenzephalitis durch Zecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusexanthem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusgrippe [Influenza]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis D',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis E',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis G',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virushepatitis mit Coma hepaticum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusinfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskarditis [kodiere zusätzlich I52.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskonjunktivitis [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskrankheit des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskrankheit durch Arthropoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruskrankheit durch Zecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusmeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusmeningoenzephalitis, durch Moskitos übertragen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusmeningoenzephalitis, durch Zecken übertragen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusmyokarditis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusnephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruspneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusretinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viruswarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virusösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Virämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visuelle Agnosie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visuelle Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visuelle Halluzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visuelle Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visuelle Wahrnehmungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visueller Halo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visus <0,05 (oder GF <10 Grad), am anderen Auge Visus <0,3',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusabfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusermüdung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visustest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Visusverschlechterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Abdominalschmerzen des Oberbauches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Abdominalschmerzen des Oberbauches',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Leishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszerale Parakokzidioidomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeraler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeraler Lupus erythematodes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeraler Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeralneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeralneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeralptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Viszeroptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitalitätsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitalitätsverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitalitätsverlust des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin A-Mangel mit Phrynodermie [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-/Nährstoffmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Bitot-Flecken und Xerosis conjunctivae [kodiere zusätzlich H13.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Hemeralopie [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Hornhautnarbe [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Hornhautulzeration und Hornhautxerose [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Hornhautxerose [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Hyperkeratose [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Keratomalazie [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Keratose [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Keratosis follicularis [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Nachtblindheit [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Nyktalopie [kodiere zusätzlich H58.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Xeroderma [kodiere zusätzlich L86*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Xerophthalmie [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit Xerosis conjunctivae [kodiere zusätzlich H13.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel mit xerophthalmischer Hornhautnarbe [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-A-Mangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B1-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B12-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B12-Mangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B12-Mangelanämie beim Vegetarier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B12-Resorptionsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B2-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B6-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B6-Mangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-B6-sensible Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-C-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-Hypervitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-Intoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-Rezeptorstörung [Typ II]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-Synthesestörung [Typ I]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-resistente Osteomalazie [kodiere zusätzlich M90.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D-resistente Rachitis [kodiere zusätzlich M90.89*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-D2-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-K-Hypervitaminose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-K-Mangel beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitamin-P-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitaminabusus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitaminmangel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitaminmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitelliforme Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitelliforme autosomal-dominante Makuladegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitiligo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitiligo bei Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitiligo bei Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitiligo der Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitium cordis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitreoretinale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vitreoretinale Netzhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vocal cord dysfunction [VCD]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogelgesicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogelhalterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogelzüchterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogt-Koyanagi-Harada-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogt-Koyanagi-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogt-Limbusgürtel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vogt-Mosaikdegeneration der Augenhornhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vohwinkel-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Volkmann-Kontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Volkmann-Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständig retinierter Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Agenesie der Verdauungsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Anodontie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Armagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Beinagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Deuteranopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Durchtrennung eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Durchtrennung eines Ligaments',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Gliedmaßenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Hasenscharte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Kehlkopflähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Monosomie, Mosaik, mitotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Muskeldurchtrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Obstruktion der Eustachi-Röhre',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Paralyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Protanopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Trisomie, Mosaik, mitotische Non-disjunction',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständige Zahnlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständiger uterovaginaler Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vollständiger uterovaginaler Vorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Volvulus der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Volvulus des Intestinums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Volvulus des Kolons',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomer-Sporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomer-Sporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomer-Sporn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomerfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus faeculentus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus faeculentus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus gravidarum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus matutinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vomitus matutinus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Basedow-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Bernuth-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Bezold-Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Bezold-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Bälz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Economo-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Gierke-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Gierke-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Gräfe-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Gräfe-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Hippel-Lindau-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Hippel-Lindau-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Jaksch-Hayem-Anämie [Ziegenmilchanämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Jaksch-Hayem-Luzet-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Jaksch-Hayem-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Jaksch-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Meyenburg-Altherr-Uehlinger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Mikulicz-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Mikulicz-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Pfaundler-Hurler-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Pfaundler-Hurler-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Recklinghausen-Krankheit [Osteodystrophia fibrosa cystica generalisata]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Recklinghausen-Neurofibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Recklinghausen-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Romberg-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Willebrand-Jürgens-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Winiwarter-Buerger-Endangiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Winiwarter-Buerger-Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Winiwarter-Buerger-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Winiwarter-Buerger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Von-Zumbusch-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vor dem Termin Geborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vor dem Termin geboren a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbereitung auf eine Dialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbereitung auf nachfolgende Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbeugende Chemotherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbeugende Immunisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbeugende Immuntherapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorbeugende Impfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vordere Kreuzbandinsuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vordere Synechie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vordere Synechie des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorderer Kreuzbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorderes Brustwandsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorderhornganglienzellkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorderhornsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorderwandinfarkt des Herzens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfall der weiblichen Geschlechtsorgane',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfall fetaler Gliedmaßen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfußdeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfußgangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorfußprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgeburtliche Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgefallene Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgefallene innere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgefallene äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgetäuschte Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorgetäuschte Krankheit mit Krankheitswert im Sinne einer psychischen Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandener transurethraler Dauerkatheter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandenes Intrauterinpessar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Brille',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Gelenkprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Hüftgelenkprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Insulinpumpe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Kniegelenkprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer PEG-Sonde [perkutane endoskopische Gastrostomie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Tuba-Eustachii-Plastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer Zahnprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer intestinalen Anastomose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer koronaren Gefäßprothese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein einer äußerlichen Hörhilfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Brustimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Fingergelenkimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Gelenkimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Harnblasenimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Herzschrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Hörgerätes für Knochenleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Hüftgelenkimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Kniegelenkimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Kochlearimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Larynximplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Mammaimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Nephrostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Parazentese-Röhrchens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Schädelplattenimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Sehnenimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Stapes-Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Ureterostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Urethrostomas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines Zahnwurzelimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines aortokoronaren Transplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines audiologischen Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines automatischen implantierbaren Kardioverter-Defibrillators [AICD]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines dentalen Unterkieferimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines endokrinen Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines funktionellen Herzklappen-Implantates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines funktionellen Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines implantierbaren Kardioverter-Defibrillators [ICD]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines implantierten Gerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines intestinalen Bypasses',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines intravaskulären Implantates a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines koronaren Gefäßtransplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines orthopädischen Gelenkimplantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines ureteralen Stents',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines urethralen Stents',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines urogenitalen Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines vaskulären Implantates',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein eines äußeren Hörgerätes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein medizinischer Geräte a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein otologischer Implantate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhandensein von Kontaktlinsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhautenge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhauthypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhauttuberkulose [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhautverengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhautverklebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhautzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofextrasystolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofflimmern/-flattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofisomerismus mit Asplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofisomerismus mit Polysplenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofscheidewanddefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofseptumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhoftachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhofthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhoftumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorhoftumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsorge a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsorgeuntersuchung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsteherdrüsenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsteherdrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsteherdrüsenmalignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorsteherdrüsenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch Versorger angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A64'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Leistungserbringer angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorstellung durch jemand außer Patient/Versorger angeregt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A65'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorwehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorwiegend Zwangshandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorwiegend Zwangsrituale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorwiegend kortikale Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorwiegend psychomotorische Störung bei reaktivem Ausnahmezustand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Adrenarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Alterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Canities',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Entbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Entbindung in der Anamnese, die die Schwangerschaftsvorsorge beeinflußt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Fontanellenossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Menarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Menopause',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Plazentaerweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Plazentalösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Plazentalösung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Plazentalösung nach Bauchprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Plazentalösung nach Bauchprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Pseudopubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Pubarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Sagittalnahtsynostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Thelarche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige Vergreisung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige atrioventrikuläre Erregungsleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige muttermundwirksame Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige muttermundwirksame Wehentätigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige männliche isosexuelle Pseudopubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige sexuelle Entwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitige weibliche heterosexuelle Pseudopubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn innerhalb 24 Stunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn innerhalb 24 Stunden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn nach Ablauf von 1 bis 7 Tagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn nach Ablauf von 1 bis 7 Tagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn nach Ablauf von mehr als 7 Tagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenbeginn nach Ablauf von mehr als 7 Tagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenhemmung durch Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Blasensprung mit Wehenhemmung durch Therapie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Entbindungsbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Entbindungsbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Geburtsbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Geburtsbeginn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Milchzahnausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Schädelnahtverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Verschluß des Foramen ovale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Zahndurchbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiger Zahnwechsel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiges Einsetzen der muttermundwirksamer Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiges Einsetzen der muttermundwirksamer Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiges Ergrauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorzeitiges Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehende Fugue als Reaktion auf außerordentliche Belastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehende Situationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehende dissoziative Störung in der Kindheit und Jugend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehende ischämische Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehende ischämische Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender Mangel an Wohnmöglichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender Stupor als Reaktion auf außergewöhnlichen Streß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehender zerebraler Anfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vorübergehendes Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vrolik-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulgäre Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaabnormität bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvadruckulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvadysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvadystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaelephantiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvafehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvafistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvafremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvafurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvafusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvagangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahämatom bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvahämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvainfantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvainfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakandidose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakondylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakrankheit mit Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvakrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvalazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvalues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvamelanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvametastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvamykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvanarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaneoplasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvapapillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvapedikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvapruritus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvarhagade',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvariß als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvariß als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvastenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvasymptome/-beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvasyphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvatalgretentionszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvatuberkulose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvatumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvatumor bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaulzeration durch Herpesviren [kodiere zusätzlich N77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaulzeration durch Herpesviren [kodiere zusätzlich N77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvavarizen bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvavarizen im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverbrennung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverbrennung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverbrennung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverletzung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverletzung bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverätzung 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverätzung 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaverätzung 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvazyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis allergica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis bei Madenwurm-Infektion [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis candidomycetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis diabetica [kodiere zusätzlich N77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis diabetica bei Typ-I-Diabetes mellitus [kodiere zusätzlich N77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis diabetica bei Typ-II-Diabetes mellitus [kodiere zusätzlich N77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Kandidose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Moniliasis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis durch Östrogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis mit Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvitis mycotica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvokolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvorektale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginale Kandidomykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginale Mykose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginale Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis bei Madenwurm-Infektion [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis candidomycetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Herpesviren [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Kandidose [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Moniliasis [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis durch Trichomonaden [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis herpetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Vulvovaginitis herpetica [kodiere zusätzlich N77.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Völlegefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Völlegefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Völliger Sehkraftverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'WPW [Wolff-Parkinson-White]-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'WS-Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'WS-Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'WS-Prellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'WS-Skoliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waardenburg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wabenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wabenschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachsleber [kodiere zusätzlich K77.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachsmilz [kodiere zusätzlich D77*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachsniere [kodiere zusätzlich N29.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumshemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumshemmung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumshormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumsretardierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumsrückstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wachstumsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenbeinkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenkrämpfe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenvenenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wadenzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wagner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wagner-Parnas-Syndrom [Hepatische Form der Glykogenose]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wagner-Polymyositis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wagner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wagner-Unverricht-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnhafte Dysmorphophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnhafte Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnidee',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnsinn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnsyndrom mit Personenverkennung im Sinne einer Doppelgängerillusion [Capgras-Syndrom]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnvorstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahnvorstellungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wahrnehmungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waldenström-Syndrom [Benigne Purpura hypergammaglobulinaemica]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waldenström-Syndrom [Makroglobulinämie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wallenberg-Syndrom [kodiere zusätzlich G46.4*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wallungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wander-Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wanderhoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wandermilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wandernde Schwellung durch Gnathostoma spinigerum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wandernder Herzschrittmacher',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wanderniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wandständige Thrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenschleimhautabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenschleimhautkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenschleimhautkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenwandverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wangenwandverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warfarindysmorphie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warfarinembryopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warthin-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzempyem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatznekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Warzenfortsatzverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waschfrauenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waschfrauenhände',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waschmittelallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasseransammlung im Brustraum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasseransammlung in der Bauchhöhle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserbruch - s.a. Hydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserdiurese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserharnruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserhellzelliges Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserhellzelliges Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserhellzelliges Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserkopf - s.a. Hydrozephalus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserkrätze der Tropen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassermangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassermangel/Austrocknung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassermann-Test',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassersackniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserspalten-Speichen-Katarakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wassersucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasservergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasserverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wasting disease a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waterhouse-Friderichsen-Krankheit [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Waterhouse-Friderichsen-Syndrom [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Watsoniasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weaver-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-A-Fraktur des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-B-Fraktur des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-C-Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-C-Fraktur des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-Christian-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-Cockayne-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-Paralyse [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weber-Syndrom [kodiere zusätzlich G46.3*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel einer Fixierungsvorrichtung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel einer Zuggurtungsfixierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel einer äußeren Schiene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Dauerkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Gipsverbandes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Kirschner-Drahtes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Pessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Schrittmachers',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechsel eines Verweilkatheters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechselfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechseljahre - s.a. Klimakterium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechseljahrsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechselnde Kindslage vor den Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechselnde Lage des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wechselnde Lage des Fetus vor den Wehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wegener-Klinger-Churg-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wegener-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wegener-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wegner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wegner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen bei tiefem Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen bei tiefem Querstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen bei überstürzter Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen bei überstürzter Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen mit akutem Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen mit akutem Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen und Entbindung mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehen und Entbindung mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehendystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehendystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weheneinleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weheneinleitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehenmittel-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehenschwäche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehensturm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wehensturm',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Algopareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Epispadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Harnblasensenkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Hypospadie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Infertilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Infertilität bei Vaginalaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Infertilität bei Zervixaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Maskulinisierung bei Nebennierenrindenhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Mikrogenitalien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Pelveopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Streßinkontinenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Unfruchtbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Urethrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Virilisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche Zystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliche sexuelle Frühreife',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiblicher Descensus vesicae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiblicher Harnblasenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiblicher Hypogonadismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiblicher Unterleibskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiblicher anorektaler Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliches Dysgerminom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliches Genitale, andere Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliches Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weibliches Papillom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiche Leiste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weicher Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weicher Schanker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiches Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichschädel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilriesenzelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteiltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteiltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteiltrauma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteiltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weichteilverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weil-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weil-Landouzy-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weill-Marchesani-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weingarten-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weinkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weitauseinanderstehende Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiter Kammerwinkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiterreißen des Dammes nach Episiotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiterreißen des Dammes nach Episiotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weitsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weitsichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weitwinkelglaukom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiße Flecken, Zahnschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiße Piedra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weiße Pocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißer Schwamm - s.a. Nävus der Mundschleimhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfleckenkrankheit [Lichen sclerosus et atrophicus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfleckenkrankheit [Vitiligo]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfleckige Lila-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfluß durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißfluß durch Trichomonaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Weißsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Welander-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wellensittichzüchterkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wellensittichzüchterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wells-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wenckebach-Block vom Typ I',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wenckebach-Block vom Typ II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wenckebach-Periodik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wenckebach-Phänomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wenckebach-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werdnig-Hoffmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werkzeugstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werlhof-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werlhof-Purpura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werlhof-Wichmann-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wermer-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werner-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Werner-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wernicke-Enzephalopathie [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wernicke-Enzephalopathie beim Kind [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wernicke-Krankheit [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wernicke-Polioenzephalitis [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wernicke-Syndrom [kodiere zusätzlich G32.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wesensänderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wespengiftallergie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wespenstich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wesselsbron-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'West-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Westafrikanische Schlafkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Westafrikanische Trypanosomiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Western-Equine-Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Westliche Pferdeenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Westphal-von-Strümpell-Pseudosklerose [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whiplash-Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whiplash-Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whipple-Krankheit [kodiere zusätzlich M14.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whistling face-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'White spot disease [Lichen sclerosus et atrophicus]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whitmore-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Whitmore-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Widerhall im Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiedemann-Beckwith-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiedereinlage eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiedereinsetzen eines Intrauterinpessars',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederherstellung einer künstlichen Körperöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederherstellung/Fixierung/Naht/Gips/prothetische Versorgung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A54'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederholte Hämorrhagie nach traumatisch bedingter Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederholte Nachblutung nach traumatisch bedingter Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederholte Pillenverordnung (Kontrazeptivum)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederholungsrezept zur Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederkäuen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederkäuen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiederverordnung eines Kontrazeptivums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiesenfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wiesengräser-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wildervanck-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wildkaninchen-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wildtier-Rabies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Willebrand-Jürgens-Thrombopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Williams-Beuren-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Williams-Campbell-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Willige-Hunt-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Willige-Hunt-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilms-Adenosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilms-Tumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-Block',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-Brocq-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-I-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-II-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-Krankheit [Dermatitis exfoliativa]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-Krankheit [Hepatolentikuläre Degeneration]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wilson-Linsenkerndegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wimpernagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wimpernanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wimperntrichiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windblattern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windelausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windeldermatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windelekzem/-dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windelerythem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windelpilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windelsoor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windmole',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windpocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windpocken mit Pneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windpocken ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windpocken-Vakzination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Windschutzscheiben-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Winterfeet [Winterfüße] [Dermatitis plantaris sicca]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Winterfüße [Dermatitis plantaris sicca]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Winterstein-Fraktur [basisnahe Querfraktur des 1. Mittelhandknochens ohne Gelenkbeteiligung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelbogenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbeleinbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelfraktur durch Metastasen [kodiere zusätzlich M49.59*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelgelenkdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkompression NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperdislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperkompression a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperkompression a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörperkompressionsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörpermetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörpersarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörpersinterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelkörpersinterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelmißbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulen-TBC [Tuberkulose] [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenfraktur mit Rückenmarkschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulengangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulennekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenprellung der Lumbalregion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenprellung des Rumpfes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulensarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenschmerzen der BWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenschmerzen der HWS',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulentuberkulose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelsäulenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbeltuberkulose [kodiere zusätzlich M49.09*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirbelverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung einer chemischen Substanz a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung einer medizinischen Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung einer äußeren Ursache a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung eines Blitzes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Bewegung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Dampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Gas',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Hitze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Hochdruckflüssigkeiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Hunger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Rauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Schwerelosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Vibration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von Wasserdruck a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von atmosphärischem Druck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von außergewöhnlich starker Schwerkraft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von elektrischem Strom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von großer Höhe a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von heißem Wetter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von überhitzten Stellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirkung von übermäßiger Anstrengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirtschaftliches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirtschaftliches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirtschaftliches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wirtschaftliches Problem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wismutvergiftung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wissenserwerbstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wittmaack-Ekbom-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wittmaack-Ekbom-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Witts-Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Witzelsucht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Woakes-Ethmoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Woakes-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Adnexitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Afibrinogenämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Beckenperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Beckensepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Dyskrasie des Blutes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Koagulopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Lymphangitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Metroperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Metrosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Metrovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Nekrose der Leber (Zustände in K72.0)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Paralyse des Harnblasensphinkters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Parametritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pelviperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Perikolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Perimetritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Perimetrosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Perinephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Perivaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Phlegmasia alba dolens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Plazentapolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyelonephrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyelozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyometra',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyosalpingitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyosalpinx',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyozystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Pyämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Salpingo-Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Salpingoperitonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Schlaganfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Septikämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Subinvolutio uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Thelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Thrombozytopenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Thyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Urämie durch Nierenversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Vaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Vulvitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Vulvovaginitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit Zystopyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit glomerulärer Krankheit (Zustände in N00-N07)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit hepatorenalem Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit peritonealer Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit sekundärem perinealen Riß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit subduralem Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit varikösen Beinvenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit zerebraler Hemiplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit zerebraler Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett mit zerebrovaskulärer Störung (Zustände unter I60-I69)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett-Albuminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbett-Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettinfektion/-sepsis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettkomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettkomplikation, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettmastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochenbettpsychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wochendippel [Mumps]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wohnungs-/Nachbarschaftsprobleme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolf-Hirschhorn-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolf-Syndrom [Deletion des kurzen Arms des Chromosoms 4]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolff-Gang-Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolff-Parkinson-White-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolfsrachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wollhaar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolman-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wolman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Worm-eaten soles',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wortschwall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Worttaubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wright-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wuchernde Langhans-Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wulstnarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunddehiszenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunddehiszenz mit Platzbauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunddiphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundheilungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundheilungsstörung des Knies',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundinfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundinfektion einer Episiotomienaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundinfektion einer Sektionaht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundliegen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundsein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundstar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wundstarrkrampf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurm-Befall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurm-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurm-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurm-Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurm-Krankheit des Darmes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurmbefall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurmfortsatzabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurmfortsatzentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzelentzündung des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzellose Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzelneuritis des Nervus acusticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzelreizung im HWS-Bereich',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzelspitzenhautentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wurzelsyndrom der oberen Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutausbrüche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutausbrüche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutausbrüche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutausbrüche beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutausbrüche beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wutkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wyatt-Syndrom [Zytomegalie]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wärmeurtikaria',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Würfelbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Würgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Würgen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Würgen/Brechreiz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Würmer/andere Parasiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wüstenfieber [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wüstenleishmaniase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wüstenrheumatismus [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Wüstenulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-Bein-Stellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-Histiozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-Monosomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal gebundene Lymphoproliferation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal-gebundene Agammaglobulinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal-gebundene Agammaglobulinämie mit Wachstumshormonmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal-gebundene hypochrome sideroachrestische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal-gebundene lymphoproliferative Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomal-rezessive spinozerebelläre Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X-chromosomale Retinoschisis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'X0-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'XXXXY-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'XXY-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'XYY-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthelasma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthelasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthinstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthoastrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthofibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthofibroma thecacellulare',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthogranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthom der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthoma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthoma disseminatum der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthoma tuberosum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthomatose bei Hypercholesterinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthomatose bei Hyperlipidämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xanthomatosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xenophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xeroderma des Augenlids',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerophthalmie [kodiere zusätzlich H19.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerophthalmie nicht im Zusammenhang mit Vitamin-A-Mangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerosis conjunctivae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerosis corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xerotische Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xiphoid-Pseudarthrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xiphoid-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xiphoidalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xiphoiddislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Xiphopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Yabapocken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Yabapocken-Viruskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Yaws - s.a. Frambösie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Yellow-nail-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Youssef-Syndrom [Vesikouterine Fistel]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahn auf Eiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahn-/Zahnfleischbeschwerden/-symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahn-/Zahnfleischerkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabrasion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabrasion durch Zahnputzmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabschleifung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnalveolenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnauflagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnauflagerung aus Materia alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnauflagerung durch Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbeinkugel [Dentikel]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbelag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbelag aus Materia alba',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbelag durch Tabak',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbildungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnbogenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndiastema',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndilazeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndislokation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndurchbruchsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahndurchbruchszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnengstand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnentwicklungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnerosion durch Drogen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnerosion durch Nahrungsmittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnerosion durch ein Arzneimittel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnerosion durch unstillbares Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfachentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfarbänderung der Hartsubstanz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfehlstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischentzündung/-bluten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischfibromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischschrumpfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischschwund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfleischverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfluorose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfokus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfraß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnfäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahngeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahngranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnhalteapparatkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnhöcker',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnlageanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnlosigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnlosigkeit durch Extraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnlosigkeit durch Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnlosigkeit durch lokale Parodontose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnmarkentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnresorption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnrotation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmelzdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmelzflecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmelzhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmelzkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnsequester',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnstein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnstellungsanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahntransposition',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnungsbeschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung durch Belag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung durch Kupfer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung durch Metalle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung durch Pulpablutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverfärbung durch Silber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverlust durch Unfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnwurzelentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnwurzelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnwurzelretention',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnwurzelvereiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnwurzelzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnzementaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnzementhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnzerfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahnärztliche Untersuchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zahorsky-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung aus Beckenausgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung aus Beckenausgang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung aus Beckenmitte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung aus Beckenmitte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung mit Rotation aus Beckenmitte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangenentbindung mit Rotation aus Beckenmitte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangengeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zangengeburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zapfendystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zapfenzahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zecken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckenbißfieber a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckenenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckenfieber a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckenfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckenrückfallfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeckentyphus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenadaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenaplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenbursitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehendeformität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehendistorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenerfrierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenfehlstellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenfurunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehengliedfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenkarbunkel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehennagelverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehennagelverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenperodaktylie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenprellung mit Nagelschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenspaltung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenspitzengang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverletzung mit Sehnenbeteiligung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverstauchung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenzerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenzerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zehenzwischenraummykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeitlich befristete Betreuung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeitlich befristete Betreuung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeitweilige Hörschwellenverschiebung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellen im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung der Orbita',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung durch Anaerobier',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung durch Clostridium',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung durch Gonokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellgewebsentzündung durch Gonokokken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellulärer Immundefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zelluläres Leiomyom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zellweger-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementbildendes Fibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementkaries',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementoblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementom des Oberkieferknochens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zementose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zenker-Divertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zenker-Divertikel des Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zenker-Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentral ausgelöste Pubertas praecox',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentral-neurale Hörminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentralafrikanisches Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentralasiatisches hämorrhagisches Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Amenorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Dammlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Dammlazeration als Entbindungskomplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Fazialisparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Hornhauttrübung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Hämatomyelie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Koordinationsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Schlafapnoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Trommelfellperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale Uveitis posterior',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale areoläre Aderhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale areoläre Pigmentepitheldystrophie der Aderhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale areoläre generalisierte Chorioideadystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale kristalline Hornhautdystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale seröse Chorioretinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrale seröse Retinopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Dammriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Dammriß bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Gesichtsfeldrest',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Lagenystagmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler venöser Gefäßverschluß der Netzhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraler venöser retinaler Gefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Riesenzellgranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Rückenmarksyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Schlafapnoesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Skotom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Ulcus corneae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrales Unterkiefergranulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraleuropäische Enzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentraleuropäische Frühsommer-Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentralfibrillenmyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentralskotom des Gesichtsfelds',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentralvenenthrombose des Auges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentroblastisch-zentrozytisches Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentroblastisch-zentrozytisches diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentroblastisches diffuses Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentronukleäre Myopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zentrozytisches Lymphom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephale Hypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephales Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalhämatozele beim Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalhämatozele beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalo-brachiales Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalothorakopagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zephalozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Hemiatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellare Teleangiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellarer Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellarer Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellares Cholesteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellarsarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebelluminfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellumtuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebellumverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralabbau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralarterienaneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralarterienembolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralarterienthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Angiopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Anomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Anoxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Arteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Arteriitis durch Listerien [kodiere zusätzlich I68.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Ataxie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Atheromatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Atrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Atrophie mit Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Bewegungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Chromomykose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Claudicatio intermittens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale DBS [Durchblutungsstörung]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Durchblutungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Dysfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Ektopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Embolie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Entzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Enzephalomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Ependymitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Epilepsie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Erweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Fehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Gefäßstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Gliose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Herniation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Heterotopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Hyperämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Hypoxie durch ärztliche Maßnahmen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Irritabilität beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Kalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Kinderlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Kryptokokkose [kodiere zusätzlich G05.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Leukodystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Lobusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Malaria [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Mangeldurchblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Massenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Meningenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Meningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Meningozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Minderbelastbarkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Multiple Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Nekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Pachymeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Panarteriitis nodosa',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Reizung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Sklerose mit Verwirrtheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Störung beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Syphilis [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Syphilis [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Syphilis der Arachnoidea [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Tuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Venensinusthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Ventrikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Verletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Vertigo',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Zystizerkose [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale arteriosklerotische Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale arteriosklerotische Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale infantile spastische Lähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale ischämische Attacke',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale meningeale Adhäsionen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale subdurale Zyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale transitorische Ischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale tuberkulöse Leptomeningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrale Übererregbarkeit beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Abszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Angiospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Anthrax',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Arterienspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Arterienverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Depressionszustand beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Durchblutungsmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Gefäßprozeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Gefäßspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Infarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Kollaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Krampfanfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Milzbrand',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler Tod',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler angiospastischer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler arterieller Vasospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebraler vaskulärer Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Anfallsleiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Granulom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Koma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Malignom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Meningeom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrales Residualsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralparese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebralsklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebro-hepato-renales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebro-okulo-fazio-skeletal-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebro-okulo-renale Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebromakuläre Dystrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebromeningeale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebroretinale Angiomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebroretinale Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrosidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrosidosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrosidzellige Lipidose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospasmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Arachnoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Endarteriitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Entzündung durch Meningokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Lues',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Meningitis [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Otorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinale Tuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinaler Erguß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrospinales Fieber durch Meningokokken [kodiere zusätzlich G01*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrotendinöse Xanthomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Affektion im Wochenbett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Arteriosklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Degeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Dysregulation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Insuffizienz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Insuffizienz 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Schädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Syphilis [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskuläre Syphilis [kodiere zusätzlich I68.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskulärer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrovaskulärer Verschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrumabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerebrumtuberkulose [kodiere zusätzlich G07*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerquetschung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerquetschung des oberen Sprunggelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerrüttung der Ehe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerstückelnde Operation am Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerumen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zerumenpfropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeruminöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeruminöses Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeruminöses Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikago',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikalchondrose [Chondrosis intervertebralis cervicalis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaldrüsenschwellung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Adenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Bandscheibenprotrusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Extrauteringravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Lymphknotenmetastase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Metritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Nervenwurzelschädigung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Osteochondrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Spinalkanalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Spinalstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Wurzelläsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale Wurzelreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale epidemische Myalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale intraepitheliale Neoplasie 1. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale intraepitheliale Neoplasie 2. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale intraepitheliale Neoplasie 3. Grades',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikale intraepitheliale Neoplasie 3. Grades mit hochgradiger Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenschaden mit Myelopathie [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenschaden mit Radikulopathie [kodiere zusätzlich G55.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenvorfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Bandscheibenvorfall mit Myelopathie [kodiere zusätzlich G99.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Diskusprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Nucleus-pulposus-Prolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Sympathikusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikaler Tinnitus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikales Schmerzsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikales Wurzelreizsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikales Wurzelsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikales Ösophaguskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikalgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikalkanalstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikalsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikoaurikuläre Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikobrachiale Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikobrachialgie bei Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikobrachialsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikodorsale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikogene Kopfschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikogener Schwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikokolpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikokranielles Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikosigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikothorakale Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikothorakale Distorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikotrochantäre Schenkelhalsfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikovaginale Adhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikozephalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikozephalgie bei Blockierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervikozephalobrachialgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixabnormität bei Schwangerschaft a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixabstrich mit atypischen Kernen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixabstrich nach Papanicolaou',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdyskeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixdystokie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixendometritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixepidermisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixepithelüberfunktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixerkrankung ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixerosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixerweiterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixeversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixgonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixhyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixhypertrophie mit Elongation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixinsuffizienz der Nichtschwangeren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixinversion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkalzifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkanalverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkatarrh',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixkontraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixlazeration bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixlazeration bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixlippenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixpapillomatose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixplazenta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixpolyp bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixreizung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixretraktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixriß bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixriß bei Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixschleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixstumpfkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixstumpfprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixtorsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixtripper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixtripper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixtuberkulose [kodiere zusätzlich N74.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixtumor bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverkalkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverlagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverlängerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixzyste a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixzytologischer Papanicolaou-Abstrich PAP II',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervixöffnung des Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Herpesviren [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Herpesviren [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Trichomonaden [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis durch Trichomonaden [kodiere zusätzlich N74.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis mit Erosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis mit Ulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis mit Ulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zervizitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zestodiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zeugungsunfähigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziegenmilchanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziegenpeter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziehen an den Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziehen-Oppenheim-Krankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziehen-Oppenheim-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zieve-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zigaretteningestion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zika-Fieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliares Staphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarisneuralgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperabriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperadhäsion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperdisruption a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörpergefäßkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörpergumma [kodiere zusätzlich H22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörpergumma [kodiere zusätzlich H22.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörpermelanozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperneovaskularisation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörpertuberkulose [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperzerreißung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ziliarkörperzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zilienagenesie (der Augenwimpern)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zilienfollikulitis (der Augenwimpern)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zinkmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zinkmangelanämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zinkstoffwechselstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zinnarbeiterlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zinsser-Cole-Engman-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zipperlein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirbeldrüsenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirbeldrüsenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirbeldrüsenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirbeldrüsenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkuläre Membran',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkuläres Irresein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkumskripte Leptomeningitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkumskripte Sklerodermie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkumzision [Circumcisio] als Routinemaßnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirkumzision [Circumcisio] aus rituellen Gründen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirrhose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirrhosemischform',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirrhotische Klitorishypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zirrhotische Nephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zitrullinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zitrullinurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zitrullinämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zitterlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zittern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoeliakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zollinger-Ellison-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoophobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster auricularis [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster conjunctivae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster ischiadicus [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster ohne Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster ophthalmicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster ophthalmicus a.n.k. [kodiere zusätzlich H58.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster oticus [kodiere zusätzlich H94.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster thoracicus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Enzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Iritis [kodiere zusätzlich H22.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Keratitis [kodiere zusätzlich H19.2*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Meningitis [kodiere zusätzlich G02.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Meningoenzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Myelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Neuralgie [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Neuritis [kodiere zusätzlich G53.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zoster-Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zu hohes Geburtsgewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zu starke Menstruation bei regelmäßigem Menstruationszyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zucker im Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckergußleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckergußmilz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckerharnruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckerkrankheit - s.a. Diabetes mellitus oder s.a. Zuckerharnruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckerrohr-Pneumokoniose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuckungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zuelzer-Ogden-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zukunftsangst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zunge-Lippen-Kehlkopf-Lähmung [Paralysis laryngolabioglossalis]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenabszeß durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenabszeß durch Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenbeinfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenbläschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenbrennen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenbrennen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenfibrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundangina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengrundtonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengumma [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungengumma [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungeninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungeninfektion a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkarzinom des beweglichen Zungenteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkerbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkerbung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenkrebs des beweglichen Zungenteils',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenlähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenmandelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungennarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillenatrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillenhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenpapillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenplaques',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenrandkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenrandkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenrückenkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenrückenkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenschlundsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenspaltung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungentylosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverdickung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverformung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenvergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwanderplaque',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwanderplaque',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwurzelkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwurzelkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwurzelstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenwurzelstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zungenzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zurückgebliebene Zahnwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zusammengesetztes Odontom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach ACVB [Aortokoronarer Venenbypass]-Operation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Ablatio mammae',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Aortenklappenersatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Apoplexie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Herzinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Hysterektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Mitralklappenersatz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Tracheostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Transplantation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustand nach Unterschenkelamputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund bei Anastomose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund bei Hirnventrikelshunt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund bei aortenkoronarem Bypass',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund bei intestinalem Bypass',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund bei koronarer Gefäßplastik',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund einer künstlichen Körperöffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Ableitungsoperation am Gehirnventrikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Arthrodese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Gastrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Ileostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Kolostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Nephrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Nierendialyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Operation a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Ureterostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Urethrostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach Zystostomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach chirurgischem Eingriff a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zustandsbefund nach peripherer Angioplastie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zusätzlicher Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwanghafte Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwanghafte Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwanghaftes Glücksspiel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwanghaftes Haarausreißen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwanghaftes Spielen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangs-Rumination',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsgedanken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsgedanken und Zwangshandlungen, gemischt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangshandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsideen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsneurose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangspersönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangspersönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsphobie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsvorstellungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwangsvorstellungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zweigeschlechtlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zweigeschlechtlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zweiphasige Meningoenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zweizeitiger Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zweizeitiger Abort mit Komplikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfelladhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellaffektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellagenesie mit Hernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellbruch mit Einklemmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellbruch mit Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellerschlaffung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellfehlbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellhernie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellossifikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellverwachsung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwerchfellähmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwergniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwergwuchs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwergwuchs vom Laron-Typ',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillinge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillings-Transfusions-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsabort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsbildung des Zahns',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsfrühgeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsfusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsgravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwillingsmonstrum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall bei Bestrahlung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall bei Insulingabe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall bei Strahlentherapie a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall bei lokaler Anwendung a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenfall bei medizinischer Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenkiefergangzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenmenschliche Beziehungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenstadium der Carate',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenstadium der Pinta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenzehenmykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenzelltumor bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwischenzelltumor beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwitter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmgeschwür mit Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmkarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmkrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zwölffingerdarmtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyanokobalaminmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyanose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyanoseanfall beim Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyanotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyanotische Herzkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zygomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklenzephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklische Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklische Migräne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklischer Stupor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklisches Erbrechen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zykloide Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zykloide Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zykloide Psychose mit Symptomen einer Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zykloide Psychose ohne Symptome einer Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklophorie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklopie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zykloplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklospasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothyme Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothyme Persönlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothyme Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothyme Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothymes Temperament',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothymia depressive Phase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothymie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothymie mit Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklothymie mit Manie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklotropie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklozephalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyklusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zylinderkarzinom der Lunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zylindrische Bronchiektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zylindromatöses Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zylindromatöses Syringadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zylindrurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystadenokarzinom des Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystadenom des Gallenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystalgie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystathioninurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystathioninuriesyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystathioninämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste bei Zystizerkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Bartholin-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Bulbourethraldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Cartilago arytenoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Cauda equina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Cervix uteri a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Corpora quadrigemina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Cowper-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Dura mater encephali',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Glandula sublingualis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Glandula submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Mastoidhöhle nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Meibom-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Moll-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Ora serrata',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Papilla incisiva',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Papilla palatina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Rathke-Tasche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Rückenmarkhäute',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Skene-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Tränenwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Tyson-Drüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Vallecula epiglottica',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der Vulvovaginaldrüsen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der ureterovesikalen Öffnung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der vorderen Augenkammer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste der äußeren weiblichen Geschlechtsorgane a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Antrum Highmori',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Canalis incisivus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Chiasma opticum a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Corpus albicans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus choledochus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus hepaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus parotideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus stenonianus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus submandibularis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus submaxillaris',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Ductus whartoniacus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Funiculus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Gartner-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Graaf-Follikels',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Müller-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Nervensystems a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Nuck-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Omentum minus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Plexus chorioideus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Processus vaginalis peritonei',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Speicheldrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Stensen-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des Wharton-Ganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des mittleren Gaumens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste des weiblichen Beckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste durch Hydatiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste eines Labium majus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste eines Labium minus pudendi',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste eines Schweißdrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste eines Talgdrüsenganges',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zyste nach Mastoidektomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenauge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenleber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenlunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenmamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystenstruma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystinose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystinspeicherkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystinspeicherkrankheit mit renaler Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystinurie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisch-granulomatöse Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisch-granulomatöse Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Akne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Blasenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Choledocholithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Echinococcus-Infektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Echinokokkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Echinokokkose der Knochen [kodiere zusätzlich M90.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Echinokokkose der Leber [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Echinokokkose der Lunge [kodiere zusätzlich J99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Endometriumhyperplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibroadenose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose mit Darmmanifestation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose mit Lungenmanifestation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose mit Manifestation am Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose mit Manifestationen an der Lunge und am Verdauungstrakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Fibrose mit kombinierten Manifestationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Gebärmutterdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Hydrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Infektion von Nierenbecken und Ureter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Involution der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Leberkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Lungenkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Mastitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Mastitis vom Typ Schimmelbusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Medianekrose der Aorta',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Nierenbeckenentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Nierenbeckenveränderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Nierendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Nierenerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Oophoritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Ovariitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Pankreasfibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Papillomatose der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Pyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Sinusdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Struma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische fibröse Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystische fibröse generalisierte Ostitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystischer Nebennierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystischer Nierentumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystischer Schilddrüsenknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Adenokarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Adenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Astrozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Augenlidsteatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Hygrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Lymphangiom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystisches Mesotheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis bei Prostatavergrößerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Chlamydien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Gonokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Trichomonaden [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis durch Trichomonaden [kodiere zusätzlich N33.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitis/Anderer Harnwegsinfekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystitische Hämaturie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystizerkose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystizerkose des Gehirns [kodiere zusätzlich G94.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystizerkose des Zentralnervensystems [kodiere zusätzlich G99.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystoenterozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystoides Makulaödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystolithiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystoplegie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystoptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystopyelitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystopyelitis bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystopyelitis mit Stein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystopyelitis nach Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystopyelonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystorektozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystosarkom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystourethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystourethrozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystourethrozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystourethrozele beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystovar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele 1. Grades bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele 2. Grades bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele 3. Grades bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele bei Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele bei der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zystozele beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytoider Retinakörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegale Riesenzelleinschlußkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Adrenalitis [kodiere zusätzlich E35.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Angiitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Bronchiolitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Cholangitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Duodenitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Enteritis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Enterokolitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Enzephalitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Enzephalomyelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Ependymitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Gastritis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Glomerulonephritis [kodiere zusätzlich N08.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Glossitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Hepatitis [kodiere zusätzlich K77.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Jejunitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Kolitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Mononukleose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Myelitis [kodiere zusätzlich G05.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Myositis [kodiere zusätzlich M63.29*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Pankreatitis [kodiere zusätzlich K87.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Parathyreoiditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Pneumonie [kodiere zusätzlich J17.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Proktitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Prostatitis [kodiere zusätzlich N51.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Retinitis [kodiere zusätzlich H32.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Sialadenitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Thyreoiditis [kodiere zusätzlich E35.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Tracheitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Tracheobronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Vaskulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Vesikulitis [kodiere zusätzlich N51.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomegalie-Ösophagitis [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytomykose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytostatikalunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zytostatikaschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zähneknirschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zähneknirschen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkalfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkumentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkuminfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkumperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkumphlegmone',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäkumtumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zäpfchentuberkulose [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökosigmoidale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökostomieprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumadhäsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumdivertikulitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumdivertikulose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumhypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumhypoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumhämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumkrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumprolaps',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumptose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumruptur mit Peritonitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumschmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumstase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumtuberkulose [kodiere zusätzlich K93.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumulkus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zökumverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zöliakaler Infantilismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zöliakie beim Erwachsenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zöliakie beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zölomzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Zönästhetische Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'abnorme Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'abnorme Lipoproteinwerte',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'abnorme Plättchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'abnormes Blinzeln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'abstehende Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Erosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Infektion der unteren Atemwege NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Meniskus-/Kreuzbandschädigung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Stressreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute Tympanitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute infektiöse Polyneuropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute/ vorübergehende/puerperale Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute/chronische Zystitis (nicht venerisch)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akute/subakute Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akuter Alkoholmissbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'akzidentelles Herzgeräusch bei Kindern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alkoholbedingte Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alkoholisches Hirnsyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alle Formen der Epilepsie: focale Anfälle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alle Formen der Schizophrenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alle Hepatitiden mit angenommener viraler Genese',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alle Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alle anderen primären bösartigen Erkrankungen des Verdauungssystems, der Gallenblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'allergische Konjunktivitis mit/ohne Schnupfen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'allergische/toxische/diätetische Gastroenteropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alte Amputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alte Lazeration der Zervix',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'alter Myokardinfarkt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'analer Spasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'anaphylaktischer Schock',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Aneurysmen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Infektion mit Enteroviren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Reizleitungsstörungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Risikofaktoren für Infektionskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Risikofaktoren für bösartige Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere Symptome/Beschwerden Lymphknoten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere angeborende Mißbildung des Fußes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere chromosomale Abweichung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere endokrine Neubildungen/endokrine Neubildungen nicht als gut- oder bösartig spezifiziert/Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'andere/unklare hämatologische Abnormalität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'angeborene Anomalien des Verdauungssystems',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'angeborene Hüftluxation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'angeborene Taubheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'angeborene Zystenniere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'angioneurotisches Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'anhaltende Schmerzen an mehreren Stellen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'anogenitaler Herpes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'anogenitaler Herpes simplex der Frau',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'anomale Kindslage',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'aplastische Anäaemiea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'arterille Embolie/Thrombose/Stenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'arteriosklerotische/atherosklerotische Herzerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'arteriovenöse Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'asymptomatische Bakteriurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'atriale/junctionale/ventrikuläre Extrasystolen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'atrialer/ventrikulärer Septumdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'atrophische Colpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'auf Schwangerschaft hinweisende Symptome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'auffälliges Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'aufgetriebenes Abdomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'aufgetriebenes Abdomen ohne Gewebsmasse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'aufgsprungene Lippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'bakterielle Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'bakterielle/virale Pneumonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'bei Beratung mit keiner Erkrankung beschäftigt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'belegte Zunge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'benebelt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'benigner paroxysmaler/Lagerungsschwindel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'bestätigte Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'bipolare Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'blaues Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'blutendes/obstruierendes/perforiertes Ulcus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'blutunterlaufenes/entzündetes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'brennendes/prickelndes Gefühl an Fingern/Füßen/Zehen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'brennendes/trockenes/juckendes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chemische Dermatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronic airways limitation (CAL)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronisch aktive Hepatitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronisch obstruktive Atemwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Endokarditis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Glomerulonephritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Nasopharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Pharyngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Rhinitis NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische Tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische eitrige Mittelohrentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronische zystische Erkrankung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronischer Alkoholmissbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronischer Kniebinnenschaden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'chronisches Cor pulmonale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'depressive Neurose/Psychose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'depressives Gefühl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'der Lunge (COPD)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'des subkutanen Gewebes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'diabetische Neuropathie (T89 und T90 doppelt kodieren)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'die Schwangerschaft oder Geburt beeinträchtigen können',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'die eine Nasennebenhöhle betrifft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'die mit der Schwangerschaft interferieren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'disseminierte Sklerose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'drohender/kompletter/inkompletter/unbemerkter/habitueller Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'dunkler Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'dysfunktionale Gebärmutterblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'einschließlich Mund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'einschließlich Wirbelsäule',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'eitrige Absonderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'eitrige Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ektopische Schläge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'emotionaler Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'enges Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'entzündeter Fußballen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'entzündliches pleurales Exsudar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'epidurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'epigastrische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erfolgreicher Suizidversuch (mit A96 doppelt kodieren)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erhöhte BSG',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erhöhte Miktionsfrequenz/Harndrang',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erhöhte Werte für Cholesterin/Triglyceride',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erhöhter Augeninnendruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erhöhter Blutdruck ohne Erfüllung der Kriterien für K86 und K87',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ernährungsbedingter Mineralmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'erworbene hämolytische Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'essentielle Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'fibroider Uterus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'fixierte/schwimmende Flecken im Gesichtsfeld',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'frisches Blut im Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'früher Kaiserschnitt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gastrointestinale Infektion mit spezifischen Mikroorganismen wie Campylobacter, Giardia, Salmonellen, Shigellen, Typhus, Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gemischte Angst und Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'generalisierte Anfälle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'generalisierte chronische Schmerzen allgemeiner Art',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gereiztes Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'geringer Durchfluss',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'geringes Selbstvertrauen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'geschwollene Füße/Beine',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'geschwollene Lippen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'geschwollenes Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'grand mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'grippeartige Erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige Neubildung der Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige Neubildung der männlichen Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige Neubildung des männlichen Genitale',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige Neubildungen der Verdauungsorgane/Neubildungen der Verdauungsorgane, die nicht als gut- oder bösartig spezifiziert wurden/Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige muskuloskelettäre Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartige/bösartige Neubildung am/im Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'gutartuge/bösartige kardiovaskuläre Neubildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'humane Papilloma-Virusinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'humane Papillomavirus-Infektion beim Mann',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'hyperaktives Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'hypertrophe Niere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'hypochondrische Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'idiopathische Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'idiopathische/orthostatische Hypotonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'illegitime Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'im Alter einsetzender Dianetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'in der Jugend einsetzender Diabetes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'innere Hämorrhoiden mit/ohne Komplikationen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'innere Wendung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'innere Wendung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'inspiratorischer Stridor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'instabile Angina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'instabiles Becken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'intraduktales Karzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'intraepitheliale Neubildung der Zervix (CIN) Grad 3',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ischiorektaler Abszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ischäemische Kardiomyopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ischämischer Brustschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'juckendes Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'juvenile Arthritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kalte Schauer',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kardiales/Karotiden-/renales Arteriengeräusch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kindliche Koliken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'klimakterisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kongenitalen Röteln',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kongestives Herzversagen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'kutane Larva migrans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'körperlicher Mißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'lagebdeingte Proteinurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'laterale Epikondylitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'laufende Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'lokalisierte Naseninfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'lärmbedingte Schwerhörigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'macrozytäre Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'malignes Melanom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'manisch-depressive Störung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'manuell oder apparativ unterstützte Geburt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'megaloblastische Anämie NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'mesenteriale Gefäßerkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'morgentliche Übelkeit bei bestätigter Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'multiple psychologische Symptome/Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'multiples Myelom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'myeloproliferative Erkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nachgewiesene Streptokokkenpharyngitis/-tonsillitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nasale Polypen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nephrotisches Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nicht als gut- oder bösartig spezifiziert/ wenn Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nicht als gut- oder bösartig spezifizierte Neubildung des männlichen Genitale/Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nicht als gutartige oder bösartig klassifizierte muskuloskelettäre Neubildung wenn Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nicht als gutartige oder bösartig klassifizierte neurologische Neubildung wenn Histologie nicht verfügbar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nicht spezifizierte intestinale Parasiten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nichtorganische Impotenz oder Dyspareunie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nichtrheumatische Störungen der Aorten-',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'nichttoxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'niedriger Blutdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'oberflächliche/tiefe Venenthrombose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'parasuizidale Handlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'partielle/vollständige Taubheit beider Ohren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'pathologische Fraktur NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'pathologische Fraktur durch Osteoporose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'perianale Hämatome',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'perinephritischer Abszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'perniziöse Anämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'persistierende Anpassungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'persistierender Ductus Arteriosus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'persönliche/Familienanamnese, vorangegangene Episode, anderer Risikofaktor für kardiovaskuläre Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'petit mal',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'physiologisch bedingte Wachstumsverzögerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'physiologische Ovarialzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'pleuraler Schmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'polymorpher Lichtausschlag',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'portale Hypertension',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'post-Polio Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'post-nasal drip',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'postnatale/Wochenbettdepression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'postoperative Infektion/Hämorrhagie/Wundheilungsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'postpartale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'postpartale Symptome/Beschwerden, andere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'posttraumatische Wund-/Bißinfektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'posttraumatischer Kopfschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'postvirales Müdigkeitssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'primäre und sekundäre Sterilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'priäre pulmonale Hypertonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'prominente Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'pubertäre Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'reaktive Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'regionale Enteritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'reizbares/ärgerliches Gefühl/Verhalten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'renale Glykosurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'residuale Hautfalte nach Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'retraktiler Hoden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'rheumatische Beschwerden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'rote Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ruckartige Bewegungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schlecht oder nicht verheilte Fraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schlecht riechender Urin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schlechte Hygiene',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schmerzende Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schmerzhafte Erektion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schmerzhafte Läsion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schnellender Finger',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schwaches Herz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'schwarzer/teerartiger Stuhl',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'seborrhoische oder senile Warzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sekundäre Polycythaemie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sekundäres Megacolon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'senile Colpitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'senile Demenz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'senile Keratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sexuell übertragbare Krankheit NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sonnenbedingte Hyperkeratose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sonstige Erkrankungen der Atemwege NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'sonstige Kehlkopferkrankungen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'spastische Bronchitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'spastisches Colon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'spontaneous rupture tendon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'stumme Myokardischämie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'subarachnoidale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'subdurales Hämatom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'subkonjunktivale Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'supraventrikuläre/ventrikuläre Tachykardie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'systemic lupus erythematosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'teilweise oder völlige Erblindung auf beiden Augen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'temporomandibuläre Gelenkstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'temporäre Blindheit NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'thrombosierte äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'tief eingedrungener Fremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'toxischer Kropf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'traumatisch/druckbedingte Trommelfellriß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'traumatische Amputation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'traumatische Arthropathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'traumatische intrakranielle Blutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'trockene Haut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'trockene Kopfhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'trockener/entzündeter/geröteter/gereizter Rachen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'träges Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'typische Radiusfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'ungewöhnlich hervortretende Venen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unklare Agranulozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unklare Eosinophilie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unklare Leukozytose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unklare Lymphozytosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unklare Neutropenie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unmittelbares post-traumatische Stresstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unmäßiges Schwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unspezifische Schmerzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unspezifische Urethritis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'unwillkürliche Miktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'variköses Ekzem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vaskulärer Kopfschmerz mit/ohne Aura',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vasomotorische Rhinitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R97'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vasovagale Synkope',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'venerische Warzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'venerische Warzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'venöse Stauung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K95'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vereinzelte Zyste der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verfrühte oder verzögerte Pubertät',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vergrößerte Tonsillen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verschlagene Winde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verstopfte Nase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verstopfte Nasennebenhöhlen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verstopftes Ohr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verwandte Zustände: Spondylitis ankylosans',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verwaschene Sprache',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verzögerte Entwicklungsphasen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verzögerte Sprachentwicklung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'verzögerte oder verspätete Regelblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'veränderte Augenfarbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'virale Keratitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vorangegangene Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vorangegangene Behandlung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vorübergehende globale Amnesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K89'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vorübergehender Hörverlust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H28'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'vorübergehender oder labiler Bluthochdruck',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'was und wie ein Erwachsener gefüttert werden/essen soll',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'was und wie ein Kleinkind/Kind gefüttert werden/essen soll',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'weibliche Beschneidung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'wunde Stelle(n)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'wunder Mund',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'wässrige Stühle',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'wässriges Auge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrale Embolie/Infarzierung/Thrombose/Occlusion/ Stenose/Hämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrale Kontusion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrale Verletzung mit/ohne Schädelfraktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebraler Abszess',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrales Aneurysma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrovaskuläre Erkrankung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zerebrovaskulärer Insult',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikale Dysplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikale Leukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikale intraepitheliale Neubildung (CIN) Grad 1 und 2',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikaler Kopfschmerz',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikaler Schleimhautpolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zervikobrachiales Syndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zu kleiner Fötus für sein Entwicklungsstadium (small for date fetus)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zystische Fibroadenome der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zystische Fibrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'zystische Mastopathie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X19'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ägyptische Anämie [kodiere zusätzlich D63.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ägyptische Ophthalmie [kodiere zusätzlich H13.1*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ägyptische Splenomegalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ältere Erstgebärende',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ältere Erstschwangere',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ältere Primipara',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ängstlich-depressive Verstimmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ängstliche Depression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ängstliche Persönlichkeitsstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ängstlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P74'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Degeneration mit Gitterlinien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Degeneration mit Glitzerpunkten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Degeneration mit Schneckenspuren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Degeneration, white without pressure',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Netzhautdegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Palisadendegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriale Pflastersteindegeneration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriales Sklerastaphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äquatoriales Staphylom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztlich eingeleiteter Abort',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Abruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Beratung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Graviditätsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Interruptio graviditatis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Schwangerschaftsunterbrechung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/Teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Beurteilung des Gesundheitszustands',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/komplette Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z30'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Beurteilung des Gesundheitszustands',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztliche Untersuchung/teilweise Gesundheitsprüfung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z31'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ärztlicher Schwangerschaftsabbruch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ästhesioneuroblastom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ästhesioneuroepitheliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ästhesioneurozytom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ästivo-Autumnalfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äthanolaminurie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äthanolintoxikation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äthylismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Fistel der Tuba uterina',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Hämorrhoiden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Ohrzyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Schnittwunde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S18'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Tracheozele',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Uterusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußere Verätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Äußeres Gerstenkorn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F72'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem bei Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem bei Lymphgefäßverschluß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem beim Fetus a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem beim Neugeborenen a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem der Regenbogenhaut',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F73'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem der Tunica vaginalis testis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Ductus deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Ductus spermaticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Nasenrachenraums',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Nervus opticus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Sehnerven',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem des Vas deferens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem mit Dellenbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödem und Proteinurie in der Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödematose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödematöse Gangrän',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödematöse Laryngitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödematöser chirurgischer Amputationsstumpf',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ödematöses Bein',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K07'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Öffnung der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X85'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ölakne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ölkrätze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ölkrätze durch Kontakt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Örtlich begrenzter Haarausfall',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagealatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagektasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagismus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagitis bei Herpes [kodiere zusätzlich K23.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagitis durch Chemikalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagitis durch Zytomegalieviren [kodiere zusätzlich K93.8*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagobronchiale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagobronchialfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagogastromalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagomalazie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagopharyngeales Grenzdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagopleurokutane Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagotracheale Fistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagotrachealfistel nach Tracheotomie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusabszeß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusachalasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusadenom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusagenesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusanomalie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusatonie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusatresie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusbasaliom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusdilatation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusdivertikel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusdyskinesie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusentzündung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusepidermisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusepithelisierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguserosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusfistel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusfremdkörper',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusgeschwulst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusgeschwür',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagushypertrophie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagushämorrhagie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusimperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguskarzinom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguskompression',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguskonstriktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguskrankheit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguskrebs',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D77'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusleukoplakie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguslipom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusnekrose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusneoplasie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusobstruktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusparalyse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusperforation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguspolyp',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusruptur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusschleimhauterosion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusspasmus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusstenose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusstriktur',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusstörung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagustuberkulose [kodiere zusätzlich K23.0*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A70'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagustumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusulzeration',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusvarizen bei Schistosomiasis [kodiere zusätzlich I98.20*]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusvarizenblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusverbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusverletzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophagusverätzung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguszyste',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Ösophaguvarizen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Östliche Pferdeenzephalitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Östrogen-Nebenwirkung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Östrogenmangel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Östrogenverminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Östrogenüberschuß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übelkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übelkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übelkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übelkeit durch Bewegung von Karussell oder Schaukel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überaktive Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überaktive Störung mit Bewegungsstereotypie und Intelligenzminderung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überanstrengung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A88'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überanstrengungsperiostose',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überarbeitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A04'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überarbeitung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überdosierung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überdosis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überempfindlichkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überempfindlichkeit der oberen Luftwege',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überempfindlichkeit mit Pneumonitis a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überempfindlichkeitsreaktion',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Brust',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X21'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Brustdrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Nasenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Nasenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überentwicklung der Nasenknochen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überernährung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übererregbarkeit des Labyrinths',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übererregtes Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überessen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überforderungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Basalzellen der Cervix uteri',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X86'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Epithelkörperchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Nebennierenrinde',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Nebenschilddrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Parathyreoidea',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion der Zirbeldrüse',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion des Hypophysenvorderlappens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfunktion des Nebennierenmarks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfüllung hervorrufender Mesiodens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfüllung hervorrufender Paramolar',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überfütterung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszellkarzinom der Blase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszellkarzinom der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U76'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszellkarzinom des Nierenbeckens',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszellpapillom der Harnblase',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszellpapillom des Ureters',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U79'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergangszelltumor',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H75'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergewicht',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergewichtiges Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übergröße des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastung der Kreuzbeingegend',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L03'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastungsschaden des Handgelenks',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastungsschaden des Unterarms',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastungsschaden einer Extremität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L87'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlastungssyndrom',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überleitungsdefekt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überlänge',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßig starke Menstruation bei regelmäßigem Menstruationszyklus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Abnutzung der Zähne',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Atmung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R98'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Darmgeräusche',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D29'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Fettablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Fettablagerung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Gewichtszunahme bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Menstruation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Nahrungsaufnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Nahrungsaufnahme',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Ohrschmalzbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Pubertätsblutung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X06'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige Salivation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßige emotionale Instabilität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiger Appetit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiger Appetit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiger Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiger Durst',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T01'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiger Überbiß',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Erbrechen bei Schwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W05'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Erröten',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S08'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Essen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Fett',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Granulationsgewebe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Rauchen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P17'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Schreien beim Kleinkind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Schwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Trinken a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges Trinken von Alkohol a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P15'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges fetales Wachstum',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges lokalisiertes Schwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übermäßiges nächtliches Schwitzen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A09'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überproduktion von Somatotropin',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überproduktion von Wachstumshormon',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überprotektion der Eltern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überreife des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überreife des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überreifes Neugeborenes',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überrest des Cloquet-Kanals',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F81'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überrest des Ductus thyreoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überrest des Ductus thyreoglossus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überschießende Keloidbildung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überschießende Narbe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überschwemmungsfleckfieber',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übersekretion von ADH [Antidiuretisches Hormon]',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übersichtigkeit',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F91'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überstimulationssyndrom der Ovarien',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überstürzte Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überstürzte Entbindung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W93'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragbare Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragbare Parotitis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D71'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragene Gravidität',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragenes Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragung des Fetus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übertragung des Neugeborenen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A94'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger der humanen T-Zell-lymphotropen Viruskrankheit Typ I (HTLV-1)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger einer Geschlechtskrankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger einer bakteriellen Krankheit a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger eines Infektionserregers a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Amöben-Ruhr',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Amöbiasis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Cholera',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Diphtherie',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Gonorrhoe',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von HBc-Antigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von HBs-Antigen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Meningokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Staphylokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Streptokokken',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Syphilis',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von Typhus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überträger von gastrointestinalen Erregern a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Arzneimittel- oder Drogenmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X10'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung bei Kontrazeption',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung der Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung der Laktation',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung der Stillperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung der Stillperiode',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W92'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Drittgebärenden',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Ein-Phasen-Methode (Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W11'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Pessarträgerin (wegen Kontrazeption)',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W12'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Risikoschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Risikoschwangerschaft, durch soziales Problem bedingt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Schwangerschaft bei einer sehr jungen Erstschwangeren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer Schwangerschaft bei einer älteren Erstschwangeren',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung einer normalen Erstschwangerschaft',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W78'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung eines fortbestehenden Problems NNB',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A13'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A20'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W02'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X23'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y24'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y25'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y26'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwachung wegen Alkoholmißbrauch',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z27'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung an Facharzt',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung an Gutachter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu Arzt/Spezialisten/Klinik/Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderem Leistungserbringer/Pflegekraft/Therapeut/Sozialarbeiter',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu anderen Versorgern/Pflegekräften/Therapeuten/Sozialarbeitern',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A66'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'B67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'F67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'K67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'L67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'N67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'T67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'U67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'W67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überweisung zu einem Arzt/Spezialisten/einer Klinik/einem Krankenhaus',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Z67'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überwiegend allergisches Asthma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'R96'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Brustwarze',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'X83'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Mamma',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'Y84'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Markerchromosomen',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A90'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzählige Zahnwurzel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überzähliger Zahn',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'D82'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Überängstliche Reaktion beim Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'P22'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'Übung der Fertigkeiten des täglichen Lebens a.n.k.',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A99'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'äußere chemische Verbrennung',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'S14'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'übermäßig weinendes/unruhiges Kind',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'A16'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);
INSERT INTO ref.icpc_thesaurus (synonym, fk_code) VALUES (
	'überzählige Ohrmuschel',
	(SELECT pk_coding_system
	 FROM ref.icpc
	 WHERE
	 	code = 'H80'
	 		AND
	 	fk_data_source = (
	 		SELECT pk
	 		FROM ref.data_source
	 		WHERE
	 			name_short = 'ICPC'
	 				AND
	 			version = '2e-3.0-GM-2004'
	 				AND
	 			lang = 'de'
	 	)
	)
);

DELETE FROM ref.icpc_thesaurus rit
WHERE EXISTS (SELECT 1 FROM ref.icpc ri WHERE ri.term = rit.synonym);

-- --------------------------------------------------------------
